@@ -53,6 +53,8 @@
         Creates a dictionary in the current directory with a parent, and removes
         the given key. If "parent" is "None", no parent is assigned.
 '''
+from __future__ import print_function
+from __future__ import absolute_import
 try:
   import project          # This is necessary for us to create Project objects on load
   import build.buildGraph # This is necessary for us to create BuildGraph objects on load
@@ -60,7 +62,7 @@ except ImportError:
   pass
 import nargs
 
-import cPickle
+import pickle
 import os
 import sys
 useThreads = nargs.Arg.findArgument('useThreads', sys.argv[1:])
@@ -99,7 +101,7 @@ Arg class, which wraps the usual value.'''
     self.parentDirectory = parentDirectory
     self.packer          = xdrlib.Packer()
     self.unpacker        = xdrlib.Unpacker('')
-    self.stopCmd         = cPickle.dumps(('stop',))
+    self.stopCmd         = pickle.dumps(('stop',))
     self.writeLogLine('Greetings')
     self.connectParent(self.parentAddr, self.parentDirectory)
     if load: self.load()
@@ -122,7 +124,7 @@ Arg class, which wraps the usual value.'''
 
   def __setstate__(self, d):
     '''Reconnect the parent socket object, recreate the XDR translators and reopen the log file after unpickling'''
-    self.logFile  = file('RDict.log', 'a')
+    self.logFile  = open('RDict.log', 'a')
     self.writeLogLine('Unpickling RDict')
     self.__dict__.update(d)
     import xdrlib
@@ -138,9 +140,9 @@ Arg class, which wraps the usual value.'''
       if os.path.isfile(filename+'.bkp'):
         os.remove(filename+'.bkp')
       os.rename(filename, filename+'.bkp')
-      self.logFile = file(filename, 'w')
+      self.logFile = open(filename, 'w')
     else:
-      self.logFile = file(filename, 'a')
+      self.logFile = open(filename, 'a')
     return
 
   def writeLogLine(self, message):
@@ -159,17 +161,24 @@ Arg class, which wraps the usual value.'''
 
   def getType(self, key):
     '''Checks for the key locally, and if not found consults the parent. Returns the Arg object or None if not found.'''
-    if dict.has_key(self, key):
-      self.writeLogLine('getType: Getting local type for '+key+' '+str(dict.__getitem__(self, key)))
-      return dict.__getitem__(self, key)
-    elif not self.parent is None:
+    try:
+      value = dict.__getitem__(self, key)
+      self.writeLogLine('getType: Getting local type for '+key+' '+str(value))
+      return value
+    except KeyError:
+      pass
+    if self.parent:
       return self.send(key)
     return None
 
+  def dict_has_key(self, key):
+    """Utility to check whether the key is present in the dictionary without RDict side-effects."""
+    return key in dict(self)
+
   def __getitem__(self, key):
     '''Checks for the key locally, and if not found consults the parent. Returns the value of the Arg.
        - If the value has not been set, the user will be prompted for input'''
-    if dict.has_key(self, key):
+    if self.dict_has_key(key):
       self.writeLogLine('__getitem__: '+key+' has local type')
       pass
     elif not self.parent is None:
@@ -185,7 +194,7 @@ Arg class, which wraps the usual value.'''
           arg = nargs.Arg(key)
         try:
           value = arg.getValue()
-        except AttributeError, e:
+        except AttributeError as e:
           self.writeLogLine('__getitem__: Parent had invalid entry: '+str(e))
           arg   = nargs.Arg(key)
           value = arg.getValue()
@@ -195,7 +204,7 @@ Arg class, which wraps the usual value.'''
     else:
       self.writeLogLine('__getitem__: Setting local type for '+key)
       dict.__setitem__(self, key, nargs.Arg(key))
-      self.save()
+      #self.save()
     self.writeLogLine('__getitem__: Setting local value for '+key)
     return dict.__getitem__(self, key).getValue()
 
@@ -205,41 +214,41 @@ Arg class, which wraps the usual value.'''
     if not isinstance(value, nargs.Arg):
       raise TypeError('An argument type must be a subclass of Arg')
     value.setKey(key)
-    if forceLocal or self.parent is None or dict.has_key(self, key):
-      if dict.has_key(self, key):
+    if forceLocal or self.parent is None or self.dict_has_key(key):
+      if self.dict_has_key(key):
         v = dict.__getitem__(self, key)
         if v.isValueSet():
           try:
             value.setValue(v.getValue())
           except TypeError:
-            print value.__class__.__name__[3:]
-            print '-----------------------------------------------------------------------'
-            print 'Warning! Incorrect argument type specified: -'+str(key)+'='+str(v.getValue())+' - expecting type '+value.__class__.__name__[3:]+'.'
-            print '-----------------------------------------------------------------------'
+            print(value.__class__.__name__[3:])
+            print('-----------------------------------------------------------------------')
+            print('Warning! Incorrect argument type specified: -'+str(key)+'='+str(v.getValue())+' - expecting type '+value.__class__.__name__[3:]+'.')
+            print('-----------------------------------------------------------------------')
             pass
       dict.__setitem__(self, key, value)
-      self.save()
+      #self.save()
     else:
       return self.send(key, value)
     return
 
   def __setitem__(self, key, value):
     '''Checks for the key locally, and if not found consults the parent. Sets the value of the Arg.'''
-    if not dict.has_key(self, key):
+    if not self.dict_has_key(key):
       if not self.parent is None:
         return self.send(key, value)
       else:
         dict.__setitem__(self, key, nargs.Arg(key))
     dict.__getitem__(self, key).setValue(value)
     self.writeLogLine('__setitem__: Set value for '+key+' to '+str(dict.__getitem__(self, key)))
-    self.save()
+    #self.save()
     return
 
   def __delitem__(self, key):
     '''Checks for the key locally, and if not found consults the parent. Deletes the Arg completely.'''
-    if dict.has_key(self, key):
+    if self.dict_has_key(key):
       dict.__delitem__(self, key)
-      self.save()
+      #self.save()
     elif not self.parent is None:
       self.send(key)
     return
@@ -248,18 +257,14 @@ Arg class, which wraps the usual value.'''
     '''Clears both the local and parent dictionaries'''
     if dict.__len__(self):
       dict.clear(self)
-      self.save()
+      #self.save()
     if not self.parent is None:
       self.send()
     return
 
   def __contains__(self, key):
-    '''This method just calls self.has_key(key)'''
-    return self.has_key(key)
-
-  def has_key(self, key):
     '''Checks for the key locally, and if not found consults the parent. Then checks whether the value has been set'''
-    if dict.has_key(self, key):
+    if self.dict_has_key(key):
       if dict.__getitem__(self, key).isValueSet():
         self.writeLogLine('has_key: Have value for '+key)
       else:
@@ -270,14 +275,14 @@ Arg class, which wraps the usual value.'''
     return 0
 
   def get(self, key, default=None):
-    if self.has_key(key):
+    if key in self:
       return self.__getitem__(key)
     else:
       return default
 
   def hasType(self, key):
     '''Checks for the key locally, and if not found consults the parent. Then checks whether the type has been set'''
-    if dict.has_key(self, key):
+    if self.dict_has_key(key):
       return 1
     elif not self.parent is None:
       return self.send(key)
@@ -296,7 +301,7 @@ Arg class, which wraps the usual value.'''
 
   def keys(self):
     '''Returns the list of keys in both the local and parent dictionaries'''
-    keyList = filter(lambda key: dict.__getitem__(self, key).isValueSet(), dict.keys(self))
+    keyList = [key for key in dict.keys(self) if dict.__getitem__(self, key).isValueSet()]
     if not self.parent is None:
       keyList.extend(self.send())
     return keyList
@@ -331,14 +336,12 @@ Arg class, which wraps the usual value.'''
 
   def insertArgs(self, args):
     '''Insert some text arguments into the dictionary (list and dictionaries are recognized)'''
-    import UserDict
 
     if isinstance(args, list):
       for arg in args:
         (key, value) = nargs.Arg.parseArgument(arg)
         self.insertArg(key, value, arg)
-    # Necessary since os.environ is a UserDict
-    elif isinstance(args, dict) or isinstance(args, UserDict.UserDict):
+    elif hasattr(args, 'keys'):
       for key in args.keys():
         if isinstance(args[key], str):
           value = nargs.Arg.parseValue(args[key])
@@ -364,17 +367,17 @@ Arg class, which wraps the usual value.'''
       raise RuntimeError('Server address file does not exist: '+filename)
     try:
       f    = open(filename, 'r')
-      addr = cPickle.load(f)
+      addr = pickle.load(f)
       f.close()
       return addr
-    except Exception, e:
+    except Exception as e:
       self.writeLogLine('CLIENT: Exception during server address determination: '+str(e.__class__)+': '+str(e))
     raise RuntimeError('Could not get server address in '+filename)
 
   def writeServerAddr(self, server):
     '''Write the server socket address (in pickled form) to a file, usually RDict.loc.'''
-    f = file(self.addrFilename, 'w')
-    cPickle.dump(server.server_address, f)
+    f = open(self.addrFilename, 'w')
+    pickle.dump(server.server_address, f)
     f.close()
     self.writeLogLine('SERVER: Wrote lock file '+os.path.abspath(self.addrFilename))
     return
@@ -384,14 +387,14 @@ Arg class, which wraps the usual value.'''
     import RDict # Need this to locate server script
     import sys
     import time
-    import distutils.sysconfig
+    import sysconfig
 
     self.writeLogLine('CLIENT: Spawning a new server with lock file '+os.path.abspath(addrFilename))
     if os.path.exists(addrFilename):
       os.remove(addrFilename)
     oldDir      = os.getcwd()
     source      = os.path.join(os.path.dirname(os.path.abspath(sys.modules['RDict'].__file__)), 'RDict.py')
-    interpreter = os.path.join(distutils.sysconfig.get_config_var('BINDIR'), distutils.sysconfig.get_config_var('PYTHON'))
+    interpreter = os.path.join(sysconfig.get_config_var('BINDIR'), sysconfig.get_config_var('PYTHON'))
     if not os.path.isfile(interpreter):
       interpreter = 'python'
     os.chdir(os.path.dirname(addrFilename))
@@ -406,13 +409,13 @@ Arg class, which wraps the usual value.'''
       Rebase, under the category System.  You must run /bin/rebaseall after\n \
       turning off all cygwin services -- in particular sshd, if any such services\n \
       are running.  For more information about rebase, go to http://www.cygwin.com')
-      print '\n \
+      print('\n \
       This is a typical problem on CYGWIN systems.  If you are using CYGWIN,\n \
       you can fix this problem by running /bin/rebaseall.  If you do not have\n \
       this program, you can install it with the CYGWIN installer in the package\n \
       Rebase, under the category System.  You must run /bin/rebaseall after\n \
       turning off all cygwin services -- in particular sshd, if any such services\n \
-      are running.  For more information about rebase, go to http://www.cygwin.com\n'
+      are running.  For more information about rebase, go to http://www.cygwin.com\n')
       raise
     os.chdir(oldDir)
     timeout = 1
@@ -443,7 +446,7 @@ Arg class, which wraps the usual value.'''
         s.connect(addr)
         connected = 1
         break
-      except socket.error, e:
+      except socket.error as e:
         self.writeLogLine('CLIENT: Failed to connect: '+str(e))
         if e[0] == errno.ECONNREFUSED:
           try:
@@ -459,7 +462,7 @@ Arg class, which wraps the usual value.'''
             if os.path.isfile(filename):
               os.remove(filename)
             self.startServer(filename)
-      except Exception, e:
+      except Exception as e:
         self.writeLogLine('CLIENT: Failed to connect: '+str(e.__class__)+': '+str(e))
     if not connected:
       self.writeLogLine('CLIENT: Failed to connect to parent')
@@ -474,7 +477,7 @@ Arg class, which wraps the usual value.'''
     if isPickled:
       p = packet
     else:
-      p = cPickle.dumps(packet)
+      p = pickle.dumps(packet)
     self.packer.reset()
     self.packer.pack_uint(len(p))
     if hasattr(s, 'write'):
@@ -491,7 +494,7 @@ Arg class, which wraps the usual value.'''
     self.writeLogLine(source+': Receiving packet')
     if hasattr(s, 'read'):
       s.read(4)
-      value = cPickle.load(s)
+      value = pickle.load(s)
     else:
       # I probably need to check that it actually read these 4 bytes
       self.unpacker.reset(s.recv(4))
@@ -499,7 +502,7 @@ Arg class, which wraps the usual value.'''
       objString = ''
       while len(objString) < length:
         objString += s.recv(length - len(objString))
-      value = cPickle.loads(objString)
+      value = pickle.loads(objString)
     self.writeLogLine(source+': Received packet '+str(value))
     return value
 
@@ -521,11 +524,11 @@ Arg class, which wraps the usual value.'''
         self.sendPacket(self.parent, tuple(packet), source = 'CLIENT')
         response = self.recvPacket(self.parent, source = 'CLIENT')
         break
-      except IOError, e:
+      except IOError as e:
         self.writeLogLine('CLIENT: IOError '+str(e))
         if e.errno == 32:
           self.connectParent(self.parentAddr, self.parentDirectory)
-      except Exception, e:
+      except Exception as e:
         self.writeLogLine('CLIENT: Exception '+str(e)+' '+str(e.__class__))
     try:
       if isinstance(response, Exception):
@@ -541,7 +544,7 @@ Arg class, which wraps the usual value.'''
   def serve(self):
     '''Start a server'''
     import socket
-    import SocketServer
+    import SocketServer # novermin
 
     if not useThreads:
       raise RuntimeError('Cannot run a server if threads are disabled')
@@ -555,17 +558,17 @@ Arg class, which wraps the usual value.'''
         while 1:
           try:
             value = self.server.rdict.recvPacket(self.rfile, source = 'SERVER')
-          except EOFError, e:
+          except EOFError as e:
             self.server.rdict.writeLogLine('SERVER: EOFError receiving packet '+str(e)+' '+str(e.__class__))
             return
-          except Exception, e:
+          except Exception as e:
             self.server.rdict.writeLogLine('SERVER: Error receiving packet '+str(e)+' '+str(e.__class__))
             self.server.rdict.sendPacket(self.wfile, e, source = 'SERVER')
             continue
           if value[0] == 'stop': break
           try:
             response = getattr(self.server.rdict, value[0])(*value[1:])
-          except Exception, e:
+          except Exception as e:
             self.server.rdict.writeLogLine('SERVER: Error executing operation '+str(e)+' '+str(e.__class__))
             self.server.rdict.sendPacket(self.wfile, e, source = 'SERVER')
           else:
@@ -587,11 +590,11 @@ Arg class, which wraps the usual value.'''
       os._exit(0) # Kill off parent, so we are not a process group leader and get a new PID
     os.setsid()   # Set session ID, so that we have no controlling terminal
     # We choose to leave cwd at RDict.py: os.chdir('/') # Make sure root directory is not on a mounted drive
-    os.umask(077) # Fix creation mask
+    os.umask(0o77) # Fix creation mask
     for i in range(3): # Crappy stopgap for closing descriptors
       try:
         os.close(i)
-      except OSError, e:
+      except OSError as e:
         if e.errno != errno.EBADF:
           raise RuntimeError('Could not close default descriptor '+str(i))
 
@@ -604,7 +607,7 @@ Arg class, which wraps the usual value.'''
       try:
         server = SocketServer.ThreadingTCPServer((socket.gethostname(), basePort+p), ProcessHandler)
         flag   = 'socket'
-      except Exception, e:
+      except Exception as e:
         p = p + 1
     if flag == 'nosocket':
       p = 1
@@ -612,11 +615,11 @@ Arg class, which wraps the usual value.'''
         try:
           server = SocketServer.ThreadingTCPServer(('localhost', basePort+p), ProcessHandler)
           flag   = 'socket'
-        except Exception, e:
+        except Exception as e:
           p = p + 1
     if flag == 'nosocket':
       self.writeLogLine('SERVER: Could not established socket server on port '+str(basePort+p))
-      raise RuntimeError,'Cannot get available socket'
+      raise RuntimeError('Cannot get available socket')
     self.writeLogLine('SERVER: Established socket server on port '+str(basePort+p))
 
     self.isServer = 1
@@ -635,27 +638,27 @@ Arg class, which wraps the usual value.'''
     self.saveFilename = os.path.abspath(self.saveFilename)
     if os.path.exists(self.saveFilename):
       try:
-        dbFile = file(self.saveFilename)
-        data   = cPickle.load(dbFile)
+        dbFile = open(self.saveFilename, 'rb')
+        data   = pickle.load(dbFile)
         self.updateTypes(data)
         dbFile.close()
         self.writeLogLine('Loaded dictionary from '+self.saveFilename)
-      except Exception, e:
+      except Exception as e:
         self.writeLogLine('Problem loading dictionary from '+self.saveFilename+'\n--> '+str(e))
     else:
       self.writeLogLine('No dictionary to load in this file: '+self.saveFilename)
     return
 
-  def save(self, force = 0):
+  def save(self, force = 1):
     '''Save the dictionary after 5 seconds, ignoring all subsequent calls until the save
        - Giving force = True will cause an immediate save'''
     if self.readonly: return
     if force:
       self.saveTimer = None
       # This should be a critical section
-      dbFile = file(self.saveFilename, 'w')
-      data   = dict(filter(lambda i: not i[1].getTemporary(), self.localitems()))
-      cPickle.dump(data, dbFile)
+      dbFile = open(self.saveFilename, 'wb')
+      data   = dict([i for i in self.localitems() if not i[1].getTemporary()])
+      pickle.dump(data, dbFile)
       dbFile.close()
       self.writeLogLine('Saved local dictionary to '+os.path.abspath(self.saveFilename))
     elif not self.saveTimer:
@@ -703,7 +706,7 @@ Arg class, which wraps the usual value.'''
         else:
           self.writeLogLine('SERVER: Killing server '+str(pid))
           os.kill(pid, signal.SIGTERM)
-      except Exception, e:
+      except Exception as e:
         self.writeLogLine('SERVER: Exception killing server: '+str(e))
     return
 
@@ -711,7 +714,7 @@ if __name__ ==  '__main__':
   import sys
   try:
     if len(sys.argv) < 2:
-      print 'RDict.py [server | client | clear | insert | remove] [parent]'
+      print('RDict.py [server | client | clear | insert | remove] [parent]')
     else:
       action = sys.argv[1]
       parent = None
@@ -720,25 +723,25 @@ if __name__ ==  '__main__':
       if action == 'server':
         RDict(parentDirectory = parent).serve()
       elif action == 'client':
-        print 'Entries in server dictionary'
+        print('Entries in server dictionary')
         rdict = RDict(parentDirectory = parent)
         for key in rdict.types():
           if not key.startswith('cacheKey') and not key.startswith('stamp-'):
-            print str(key)+' '+str(rdict.getType(key))
+            print(str(key)+' '+str(rdict.getType(key)))
       elif action == 'cacheClient':
-        print 'Cache entries in server dictionary'
+        print('Cache entries in server dictionary')
         rdict = RDict(parentDirectory = parent)
         for key in rdict.types():
           if key.startswith('cacheKey'):
-            print str(key)+' '+str(rdict.getType(key))
+            print(str(key)+' '+str(rdict.getType(key)))
       elif action == 'stampClient':
-        print 'Stamp entries in server dictionary'
+        print('Stamp entries in server dictionary')
         rdict = RDict(parentDirectory = parent)
         for key in rdict.types():
           if key.startswith('stamp-'):
-            print str(key)+' '+str(rdict.getType(key))
+            print(str(key)+' '+str(rdict.getType(key)))
       elif action == 'clear':
-        print 'Clearing all dictionaries'
+        print('Clearing all dictionaries')
         RDict(parentDirectory = parent).clear()
       elif action == 'insert':
         rdict = RDict(parentDirectory = parent)
@@ -748,8 +751,8 @@ if __name__ ==  '__main__':
         del rdict[sys.argv[3]]
       else:
         sys.exit('Unknown action: '+action)
-  except Exception, e:
+  except Exception as e:
     import traceback
-    print traceback.print_tb(sys.exc_info()[2])
+    print(traceback.print_tb(sys.exc_info()[2]))
     sys.exit(str(e))
   sys.exit(0)
