@@ -214,7 +214,6 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     buf = 'Environmental variables'
     for key,val in os.environ.items():
       buf += '\n'+str(key)+'='+str(val)
-    buf = buf.encode('ascii', 'ignore').decode()
     self.logPrint(buf)
     def logPrintFilesInPath(path):
       for d in path:
@@ -227,7 +226,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       self.logWrite('    Files in path provided by default path\n')
       logPrintFilesInPath(os.environ['PATH'].split(os.path.pathsep))
     dirs = self.argDB['with-executables-search-path']
-    if not isinstance(dirs, list): dirs = [dirs]
+    if not isinstance(dirs, list): dirs = dirs.split(os.path.pathsep)
     if dirs:
       self.logWrite('    Files in path provided by --with-executables-search-path\n')
       logPrintFilesInPath(dirs)
@@ -459,7 +458,8 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     log.write("Preprocess output after filtering:\n"+output+":\n")
     return output
 
-  def filterCompileOutput(self, output):
+  def filterCompileOutput(self, output,flag = ''):
+    if flag and output.find("ignoring unknown option '"+flag+"'"): return output
     if output.find('warning:  attribute "deprecated" is unknown, ignored') >= 0: return output
     if output.find('PGC-W-0129-Floating point overflow') >= 0: return output
     if output.find('warning #264: floating-point value does not fit in required floating-point type') >= 0: return output
