@@ -6,9 +6,11 @@ import re
 class Configure(config.base.Configure):
   def __init__(self, framework, libraries = []):
     config.base.Configure.__init__(self, framework)
-    self.headerPrefix = ''
-    self.substPrefix  = ''
-    self.libraries    = libraries
+    self.headerPrefix  = ''
+    self.substPrefix   = ''
+    self.libraries     = libraries
+    self.rpathSkipDirs = [] # do not generate RPATH for dirs in this list; useful when compiling with stub libraries (.so) that do not have corresponding runtime library (.so.1) at this location. Check cuda.py for usage.
+    self.sysDirs       = ['/usr/lib','/lib','/usr/lib64','/lib64'] # skip conversion from full path to link line argument format for libraries in these dirs. For ex: some compilers internally use /usr/lib/libm.so that should not be converted to '-L/usr/lib -lm'
     return
 
   def setupDependencies(self, framework):
@@ -45,9 +47,9 @@ class Configure(config.base.Configure):
         flagName  = self.language[-1]+'SharedLinkerFlag'
         flagSubst = self.language[-1].upper()+'_LINKER_SLFLAG'
         dirname   = os.path.dirname(library).replace('\\ ',' ').replace(' ', '\\ ').replace('\\(','(').replace('(', '\\(').replace('\\)',')').replace(')', '\\)')
-        if dirname in ['/usr/lib','/lib','/usr/lib64','/lib64']:
+        if dirname in self.sysDirs:
           return [library]
-        if with_rpath:
+        if with_rpath and not dirname in self.rpathSkipDirs:
           if hasattr(self.setCompilers, flagName) and not getattr(self.setCompilers, flagName) is None:
             return [getattr(self.setCompilers, flagName)+dirname,'-L'+dirname,'-l'+name]
           if flagSubst in self.argDB:
@@ -65,6 +67,14 @@ class Configure(config.base.Configure):
     '''Same as getLibArgumentList - except it returns a string instead of list.'''
     return  ' '.join(self.getLibArgumentList(library))
 
+  def addRpathSkipDir(self, dirname):
+    '''Do not generate RPATH for this dir in getLibArgumentList.'''
+    if dirname not in self.rpathSkipDirs: self.rpathSkipDirs.append(dirname)
+
+  def addSysDir(self, dirname):
+    '''Add the dir to sysDirs[]'''
+    if dirname not in self.sysDirs: self.sysDirs.append(dirname)
+
   def getLibName(library):
     if os.path.basename(library).startswith('lib'):
       return os.path.splitext(os.path.basename(library))[0][3:]
@@ -133,7 +143,7 @@ class Configure(config.base.Configure):
       # remove duplicate -L, -Wl,-rpath options - and only consecutive -l options
       if j in newldflags and any([j.startswith(flg) for flg in dupflags]): continue
       if newlibs and j == newlibs[-1]: continue
-      if j.startswith('-l') or j.endswith('.lib') or j.endswith('.a') or j.endswith('.o') or j == '-Wl,-Bstatic' or j == '-Wl,-Bdynamic' or j == '-Wl,--start-group' or j == '-Wl,--end-group':
+      if list(filter(j.startswith,['-l'])) or list(filter(j.endswith,['.lib','.a','.so','.o'])) or j in ['-Wl,-Bstatic','-Wl,-Bdynamic','-Wl,--start-group','-Wl,--end-group']:
         newlibs.append(j)
       else:
         newldflags.append(j)
@@ -254,13 +264,17 @@ extern "C" {
             break
 
     if found and self.checkLink(includes, body, linkLanguage=linklang, examineOutput=examineOutput):
-      # define the symbol as found
-      if functionDefine: [self.addDefine(self.getDefineNameFunc(fname), 1) for f, fname in enumerate(funcs)]
-      # add to list of found libraries
-      elif libName:
-        for lib in libName:
-          shortlib = self.getShortLibName(lib)
-          if shortlib: self.addDefine(self.getDefineName(shortlib), 1)
+      if hasattr(self.compilers, 'FC') and self.language[-1] == 'C':
+        if self.compilers.checkCrossLink(includes+'\nvoid dummy(void) {'+body+'}\n',"     program main\n      print*,'testing'\n      stop\n      end\n",language1='C',language2='FC'):
+          # define the symbol as found
+          if functionDefine: [self.addDefine(self.getDefineNameFunc(fname), 1) for f, fname in enumerate(funcs)]
+          # add to list of found libraries
+          elif libName:
+            for lib in libName:
+              shortlib = self.getShortLibName(lib)
+              if shortlib: self.addDefine(self.getDefineName(shortlib), 1)
+        else:
+          found = 0
     else:
       found = 0
     self.setCompilers.LIBS = oldLibs
