@@ -14,8 +14,8 @@ class Configure(config.package.CMakePackage):
     self.hastests          = 1
     self.hastestsdatafiles = 1
     self.precisions        = ['double']
-    self.cxx               = 1
-    self.requirescxx14     = 1
+    self.buildLanguages    = ['Cxx']
+    self.minCxxVersion     = 'c++14'
     self.builtafterpetsc   = 1
     return
 
@@ -60,13 +60,6 @@ class Configure(config.package.CMakePackage):
       args.append('-DHYPRE_ROOT='+os.path.abspath(os.path.expanduser(self.argDB['prefix'])))
     else:
       args.append('-DHYPRE_ROOT='+os.path.join(self.petscdir.dir,self.arch))
-    if hasattr(self.compilers, 'FC'):
-      self.setCompilers.pushLanguage('FC')
-      if config.setCompilers.Configure.isGfortran100plus(self.setCompilers.getCompiler(), self.log):
-        args = self.addArgStartsWith(args,'-DCMAKE_Fortran_FLAGS:STRING','-fallow-argument-mismatch')
-        args = self.addArgStartsWith(args,'-DCMAKE_Fortran_FLAGS_DEBUG:STRING','-fallow-argument-mismatch')
-        args = self.addArgStartsWith(args,'-DCMAKE_Fortran_FLAGS_RELEASE:STRING','-fallow-argument-mismatch')
-      self.setCompilers.popLanguage()
     return args
 
   def Install(self):
@@ -117,12 +110,6 @@ class Configure(config.package.CMakePackage):
     self.addMakeMacro('AMREX_LIB',' '.join(map(self.libraries.getLibArgument, self.lib_a)))
     self.addMakeMacro('AMREX_INCLUDE',self.include_a)
 
-    #  if installing as Superuser than want to return to regular user for clean and build
-    if self.installSudo:
-       newuser = self.installSudo+' -u $${SUDO_USER} '
-    else:
-       newuser = ''
-
     # if installing prefix location then need to set new value for PETSC_DIR/PETSC_ARCH
     if self.argDB['prefix'] and not 'package-prefix-hash' in self.argDB:
        carg = 'PETSC_DIR='+os.path.abspath(os.path.expanduser(self.argDB['prefix']))+' PETSC_ARCH="" '
@@ -147,7 +134,7 @@ class Configure(config.package.CMakePackage):
     self.addMakeRule('amrexinstall','', \
                        ['@echo "*** Installing amrex ***"',\
                           '@(cd '+os.path.join(self.packageDir,'petsc-build')+' && \\\n\
-           '+newuser+'${OMAKE} install) >> ${PETSC_DIR}/${PETSC_ARCH}/lib/petsc/conf/amrex.log 2>&1 || \\\n\
+           '+'${OMAKE} install) >> ${PETSC_DIR}/${PETSC_ARCH}/lib/petsc/conf/amrex.log 2>&1 || \\\n\
              (echo "**************************ERROR*************************************" && \\\n\
              echo "Error building amrex. Check ${PETSC_DIR}/${PETSC_ARCH}/lib/petsc/conf/amrex.log" && \\\n\
              echo "********************************************************************" && \\\n\
