@@ -3,7 +3,7 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self, framework):
     config.package.Package.__init__(self, framework)
-    self.gitcommit              = 'aa5f86854e5d457ce6ff5041b1c308588ba71c25' # jolivet/backup-jose mar-30-2022 (pre-3.17.0)
+    self.gitcommit              = 'v3.17.0' # mar-31-2022
     self.download               = ['git://https://gitlab.com/slepc/slepc.git','https://gitlab.com/slepc/slepc/-/archive/'+self.gitcommit+'/slepc-'+self.gitcommit+'.tar.gz']
     self.functions              = []
     self.includes               = []
