@@ -1,21 +1,8 @@
+from __future__ import print_function
 try:
   import readline
 except ImportError: pass
 
-def getInteractive():
-  return isInteractive
-
-def setInteractive(interactive):
-  global isInteractive
-  isInteractive = interactive
-  return
-
-def checkInteractive(key):
-  if not isInteractive:
-    raise ValueError('Value not set for key '+str(key))
-  return
-setInteractive(1)
-
 class Arg(object):
   '''This is the base class for all objects contained in RDict. Access to the raw argument values is
 provided by getValue() and setValue(). These objects can be thought of as type objects for the
@@ -25,12 +12,14 @@ in order to declare the type of that option.
 Inputs which cannot be converted to the correct type will cause TypeError, those failing validation
 tests will cause ValueError.
 '''
-  def __init__(self, key, value = None, help = '', isTemporary = 0):
-    self.key = key
-    if not value is None:
-      self.setValue(value)
+  def __init__(self, key, value = None, help = '', isTemporary = False, deprecated = False):
+    self.key         = key
     self.help        = help
     self.isTemporary = isTemporary
+    self.deprecated  = False
+    if not value is None:
+      self.setValue(value)
+    self.deprecated  = deprecated
     return
 
   def isValueSet(self):
@@ -136,9 +125,6 @@ tests will cause ValueError.
       return str(map(str, self.value))
     return str(self.value)
 
-  def getEntryPrompt(self):
-    return 'Please enter value for '+str(self.key)+': '
-
   def getKey(self):
     '''Returns the key. SHOULD MAKE THIS A PROPERTY'''
     return self.key
@@ -151,34 +137,31 @@ tests will cause ValueError.
   def getValue(self):
     '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
     if not self.isValueSet():
-      checkInteractive(self.key)
-      if self.help: print self.help
-      while 1:
-        try:
-          self.setValue(Arg.parseValue(raw_input(self.getEntryPrompt())))
-          break
-        except KeyboardInterrupt:
-          raise KeyError('Could not find value for key '+str(self.key))
-        except TypeError, e:
-          print str(e)
+      raise KeyError('Could not find value for key '+str(self.key))
     return self.value
 
+  def checkKey(self):
+    if self.deprecated:
+      if isinstance(self.deprecated, str):
+        raise KeyError('Deprecated option '+self.key+' should be '+self.deprecated)
+      raise KeyError('Deprecated option '+self.key)
+    return
+
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    self.checkKey()
     self.value = value
     return
 
 class ArgBool(Arg):
   '''Arguments that represent boolean values'''
-  def __init__(self, key, value = None, help = '', isTemporary = 0):
-    Arg.__init__(self, key, value, help, isTemporary)
+  def __init__(self, key, value = None, help = '', isTemporary = 0, deprecated = False):
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter boolean value for '+str(self.key)+': '
-
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    self.checkKey()
     try:
       if   value == 'no':    value = 0
       elif value == 'yes':   value = 1
@@ -194,8 +177,8 @@ class ArgBool(Arg):
 
 class ArgFuzzyBool(Arg):
   '''Arguments that represent boolean values of an extended set'''
-  def __init__(self, key, value = None, help = '', isTemporary = 0):
-    Arg.__init__(self, key, value, help, isTemporary)
+  def __init__(self, key, value = None, help = '', isTemporary = 0, deprecated = False):
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
   def valueName(self, value):
@@ -214,11 +197,9 @@ class ArgFuzzyBool(Arg):
       return str(map(self.valueName, self.value))
     return self.valueName(self.value)
 
-  def getEntryPrompt(self):
-    return 'Please enter fuzzy boolean value for '+str(self.key)+': '
-
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    self.checkKey()
     try:
       if   value == '0':        value = 0
       elif value == '1':        value = 1
@@ -238,17 +219,15 @@ class ArgFuzzyBool(Arg):
 
 class ArgInt(Arg):
   '''Arguments that represent integer numbers'''
-  def __init__(self, key, value = None, help = '', min = -2147483647L, max = 2147483648L, isTemporary = 0):
+  def __init__(self, key, value = None, help = '', min = -2147483647, max = 2147483648, isTemporary = 0, deprecated = False):
     self.min = min
     self.max = max
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter integer value for '+str(self.key)+': '
-
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    self.checkKey()
     try:
       value = int(value)
     except:
@@ -260,17 +239,15 @@ class ArgInt(Arg):
 
 class ArgReal(Arg):
   '''Arguments that represent floating point numbers'''
-  def __init__(self, key, value = None, help = '', min = -1.7976931348623157e308, max = 1.7976931348623157e308, isTemporary = 0):
+  def __init__(self, key, value = None, help = '', min = -1.7976931348623157e308, max = 1.7976931348623157e308, isTemporary = 0, deprecated = False):
     self.min = min
     self.max = max
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter floating point value for '+str(self.key)+': '
-
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    self.checkKey()
     try:
       value = float(value)
     except:
@@ -282,37 +259,26 @@ class ArgReal(Arg):
 
 class ArgDir(Arg):
   '''Arguments that represent directories'''
-  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0):
+  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0, deprecated = False):
     self.mustExist = mustExist
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter directory for '+str(self.key)+': '
-
   def getValue(self):
     '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
     if not self.isValueSet():
-      checkInteractive(self.key)
-      try:
-        import GUI.FileBrowser
-        import SIDL.Loader
-        db = GUI.FileBrowser.FileBrowser(SIDL.Loader.createClass('GUI.Default.DefaultFileBrowser'))
-        if self.help: db.setTitle(self.help)
-        else:         db.setTitle('Select the directory for '+self.key)
-        db.setMustExist(self.exist)
-        self.value = db.getDirectory()
-      except Exception:
-        return Arg.getValue(self)
+      return Arg.getValue(self)
     return self.value
 
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
     import os
+    self.checkKey()
     # Should check whether it is a well-formed path
     if not isinstance(value, str):
       raise TypeError('Invalid directory: '+str(value)+' for key '+str(self.key))
     value = os.path.expanduser(value)
+    value = os.path.abspath(value)
     if self.mustExist and value and not os.path.isdir(value):
       raise ValueError('Nonexistent directory: '+str(value)+' for key '+str(self.key))
     self.value = value
@@ -320,39 +286,28 @@ class ArgDir(Arg):
 
 class ArgDirList(Arg):
   '''Arguments that represent directory lists'''
-  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0):
+  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0, deprecated = False):
     self.mustExist = mustExist
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter directory list for '+str(self.key)+': '
-
   def getValue(self):
     '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
     if not self.isValueSet():
-      checkInteractive(self.key)
-      try:
-        import GUI.FileBrowser
-        import SIDL.Loader
-        db = GUI.FileBrowser.FileBrowser(SIDL.Loader.createClass('GUI.Default.DefaultFileBrowser'))
-        if self.help: db.setTitle(self.help)
-        else:         db.setTitle('Select the directory for '+self.key)
-        db.setMustExist(self.exist)
-        self.value = db.getDirectory()
-      except Exception:
-        return Arg.getValue(self)
+      return Arg.getValue(self)
     return self.value
 
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
     import os
-    if not isinstanceof(value, list):
-      value = [value]
+    self.checkKey()
+    if not isinstance(value, list):
+      value = value.split(':')
     # Should check whether it is a well-formed path
     nvalue = []
     for dir in value:
-      nvalue.append(os.path.expanduser(dir))
+      if dir:
+        nvalue.append(os.path.expanduser(dir))
     value = nvalue
     for dir in value:
       if self.mustExist and not os.path.isdir(dir):
@@ -360,69 +315,99 @@ class ArgDirList(Arg):
     self.value = value
     return
 
-class ArgLibrary(Arg):
-  '''Arguments that represent libraries'''
-  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0):
+class ArgFile(Arg):
+  '''Arguments that represent a file'''
+  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0, deprecated = False):
     self.mustExist = mustExist
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter library for '+str(self.key)+': '
-
   def getValue(self):
     '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
     if not self.isValueSet():
-      checkInteractive(self.key)
-      try:
-        import GUI.FileBrowser
-        import SIDL.Loader
-        db = GUI.FileBrowser.FileBrowser(SIDL.Loader.createClass('GUI.Default.DefaultFileBrowser'))
-        if self.help: db.setTitle(self.help)
-        else:         db.setTitle('Select the library for '+self.key)
-        db.setMustExist(self.exist)
-        self.value = db.getFile()
-      except Exception:
-        return Arg.getValue(self)
+      return Arg.getValue(self)
     return self.value
 
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
     import os
+    self.checkKey()
+    # Should check whether it is a well-formed path
+    if not isinstance(value, str):
+      raise TypeError('Invalid file: '+str(value)+' for key '+str(self.key))
+    value = os.path.expanduser(value)
+    value = os.path.abspath(value)
+    if self.mustExist and value and not os.path.isfile(value):
+      raise ValueError('Nonexistent file: '+str(value)+' for key '+str(self.key))
+    self.value = value
+    return
+
+class ArgFileList(Arg):
+  '''Arguments that represent file lists'''
+  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0, deprecated = False):
+    self.mustExist = mustExist
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
+    return
+
+  def getValue(self):
+    '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
+    if not self.isValueSet():
+      return Arg.getValue(self)
+    return self.value
+
+  def setValue(self, value):
+    '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    import os
+    self.checkKey()
+    if not isinstance(value, list):
+      value = value.split(':')
+    # Should check whether it is a well-formed path
+    nvalue = []
+    for file in value:
+      if file:
+        nvalue.append(os.path.expanduser(file))
+    value = nvalue
+    for file in value:
+      if self.mustExist and not os.path.isfile(file):
+        raise ValueError('Invalid file: '+str(file)+' for key '+str(self.key))
+    self.value = value
+    return
+
+class ArgLibrary(Arg):
+  '''Arguments that represent libraries'''
+  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0, deprecated = False):
+    self.mustExist = mustExist
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
+    return
+
+  def getValue(self):
+    '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
+    if not self.isValueSet():
+      return Arg.getValue(self)
+    return self.value
+
+  def setValue(self, value):
+    '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    import os
+    self.checkKey()
     # Should check whether it is a well-formed path and an archive or shared object
     if self.mustExist:
       if not isinstance(value, list):
-        value = [value]
-      for lib in value:
-        if lib.startswith('/') and not os.path.isfile(lib):
-          raise ValueError('Invalid library: '+str(lib)+' for key '+str(self.key))
+        value = value.split(' ')
     self.value = value
     return
 
 class ArgExecutable(Arg):
   '''Arguments that represent executables'''
-  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0):
+  def __init__(self, key, value = None, help = '', mustExist = 1, isTemporary = 0, deprecated = False):
     self.mustExist = mustExist
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
-  def getEntryPrompt(self):
-    return 'Please enter executable for '+str(self.key)+': '
-
   def getValue(self):
     '''Returns the value. SHOULD MAKE THIS A PROPERTY'''
     if not self.isValueSet():
-      checkInteractive(self.key)
-      try:
-        import GUI.FileBrowser
-        import SIDL.Loader
-        db = GUI.FileBrowser.FileBrowser(SIDL.Loader.createClass('GUI.Default.DefaultFileBrowser'))
-        if self.help: db.setTitle(self.help)
-        else:         db.setTitle('Select the executable for '+self.key)
-        db.setMustExist(self.exist)
-        self.value = db.getFile()
-      except Exception:
-        return Arg.getValue(self)
+      return Arg.getValue(self)
     return self.value
 
   def checkExecutable(self, dir, name):
@@ -433,6 +418,7 @@ class ArgExecutable(Arg):
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
     import os
+    self.checkKey()
     # Should check whether it is a well-formed path
     if self.mustExist:
       index = value.find(' ')
@@ -454,16 +440,17 @@ class ArgExecutable(Arg):
 
 class ArgString(Arg):
   '''Arguments that represent strings satisfying a given regular expression'''
-  def __init__(self, key, value = None, help = '', regExp = None, isTemporary = 0):
+  def __init__(self, key, value = None, help = '', regExp = None, isTemporary = 0, deprecated = False):
     self.regExp = regExp
     if self.regExp:
       import re
       self.re = re.compile(self.regExp)
-    Arg.__init__(self, key, value, help, isTemporary)
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
+    self.checkKey()
     if self.regExp and not self.re.match(value):
       raise ValueError('Invalid string '+str(value)+'. You must give a string satisfying "'+str(self.regExp)+'"'+' for key '+str(self.key))
     self.value = value
@@ -471,8 +458,8 @@ class ArgString(Arg):
 
 class ArgDownload(Arg):
   '''Arguments that represent software downloads'''
-  def __init__(self, key, value = None, help = '', isTemporary = 0):
-    Arg.__init__(self, key, value, help, isTemporary)
+  def __init__(self, key, value = None, help = '', isTemporary = 0, deprecated = False):
+    Arg.__init__(self, key, value, help, isTemporary, deprecated)
     return
 
   def valueName(self, value):
@@ -480,8 +467,6 @@ class ArgDownload(Arg):
       return 'no'
     elif value == 1:
       return 'yes'
-    elif value == 2:
-      return 'ifneeded'
     return str(value)
 
   def __str__(self):
@@ -491,12 +476,10 @@ class ArgDownload(Arg):
       return str(map(self.valueName, self.value))
     return self.valueName(self.value)
 
-  def getEntryPrompt(self):
-    return 'Please enter download value for '+str(self.key)+': '
-
   def setValue(self, value):
     '''Set the value. SHOULD MAKE THIS A PROPERTY'''
     import os
+    self.checkKey()
     try:
       if   value == '0':        value = 0
       elif value == '1':        value = 1
@@ -504,12 +487,16 @@ class ArgDownload(Arg):
       elif value == 'yes':      value = 1
       elif value == 'false':    value = 0
       elif value == 'true':     value = 1
-      elif value == 'ifneeded': value = 2
       elif not isinstance(value, int):
         value = str(value)
     except:
       raise TypeError('Invalid download value: '+str(value)+' for key '+str(self.key))
-    if isinstance(value, str) and not os.path.isfile(value):
-      raise ValueError('Invalid download location: '+str(value)+' for key '+str(self.key))
+    if isinstance(value, str):
+      try:
+        import urlparse as urlparse_local # novermin
+      except ImportError:
+        from urllib import parse as urlparse_local # novermin
+      if not urlparse_local.urlparse(value)[0] and not os.path.exists(value):
+        raise ValueError('Invalid download location: '+str(value)+' for key '+str(self.key))
     self.value = value
     return
