@@ -11,6 +11,7 @@ configure_options = [
   '--useThreads=0', # for some reason cmake hangs when invoked from configure on bsd?
   #'-download-fblaslapack=1',
   '--download-mpich=1',
+  '--download-mpich-device=ch3:sock',
   '--download-cmake=1',
   '--download-metis=1',
   '--download-parmetis=1',
@@ -22,7 +23,7 @@ configure_options = [
   '--download-elemental=1',
   '--download-hdf5',
   '--with-zlib=1',
-  '--download-sundials=1',
+  '--download-sundials2=1',
   '--download-hypre=1',
   '--download-suitesparse=1',
   '--download-make=1', # required by suitesparse
@@ -31,6 +32,7 @@ configure_options = [
   '--download-netcdf=1',
   '--download-moab=1',
   '--download-saws',
+  '--download-ks',
   '--download-codipack=1',
   '--download-adblaslapack=1',
   '--download-hpddm=1'
