@@ -10,6 +10,7 @@
 #include <petscdraw.h>
 
 #include <petscsf.h>
+#include <petscsection.h>
 #include <petscdmda.h>
 #include <petscdmcomposite.h>
 #include <petscdmpatch.h>
@@ -17,12 +18,13 @@
 #include <petscdmredundant.h>
 #include <petscdmshell.h>
 #include <petscdmsliced.h>
+#include <petscdmswarm.h>
+#include <petscdmstag.h>
 
 #include <petscdt.h>
 #include <petscds.h>
 
 #include <petsccharacteristic.h>
 
-
 #include <petscts.h>
 #include <petsctao.h>
