@@ -5,7 +5,6 @@
 #include <petscdmforest.h> /*I      "petscdmforest.h"    I*/
 #include <petscbt.h>
 #include <petsc/private/dmimpl.h>
-#include <petsc/private/hash.h>
 
 typedef struct {
   PetscInt                   refct;
@@ -13,11 +12,11 @@ typedef struct {
   PetscErrorCode             (*clearadaptivityforest)(DM);
   PetscErrorCode             (*getadaptivitysuccess)(DM,PetscBool*);
   PetscErrorCode             (*transfervec)(DM,Vec,DM,Vec,PetscBool,PetscReal);
+  PetscErrorCode             (*transfervecfrombase)(DM,Vec,Vec);
   PetscErrorCode             (*createcellchart)(DM,PetscInt*,PetscInt*);
   PetscErrorCode             (*createcellsf)(DM,PetscSF*);
   PetscErrorCode             (*destroy)(DM);
   PetscErrorCode             (*ftemplate)(DM,DM);
-  PetscBool                  setfromoptionscalled;
   PetscBool                  computeAdaptSF;
   PetscErrorCode             (*mapcoordinates)(DM,PetscInt,PetscInt,const PetscReal[],PetscReal[],void*);
   void                       *mapcoordinatesctx;
@@ -47,5 +46,6 @@ typedef struct {
 PETSC_EXTERN PetscErrorCode DMCreate_Forest(DM);
 PETSC_EXTERN PetscErrorCode DMClone_Forest(DM,DM*);
 PETSC_EXTERN PetscErrorCode DMSetFromOptions_Forest(PetscOptionItems*,DM);
+PETSC_INTERN PetscErrorCode DMAdaptLabel_Forest(DM,Vec,DMLabel,DMLabel,DM *);
 
 #endif /* _FORESTIMPL_H */
