@@ -88,14 +88,13 @@ typedef struct {
   PetscScalar *B, *Binv, *tau, *work;
 } PetscFV_LeastSquares;
 
-PETSC_STATIC_INLINE PetscErrorCode PetscFVInterpolate_Static(PetscFV fv, const PetscScalar x[], PetscInt q, PetscScalar interpolant[])
+static inline PetscErrorCode PetscFVInterpolate_Static(PetscFV fv, const PetscScalar x[], PetscInt q, PetscScalar interpolant[])
 {
-  PetscInt       Nc, fc;
-  PetscErrorCode ierr;
+  PetscInt Nc;
 
   PetscFunctionBeginHot;
-  ierr = PetscFVGetNumComponents(fv, &Nc);CHKERRQ(ierr);
-  for (fc = 0; fc < Nc; ++fc) {interpolant[fc] = x[fc];}
+  PetscCall(PetscFVGetNumComponents(fv, &Nc));
+  PetscCall(PetscArraycpy(interpolant,x,Nc));
   PetscFunctionReturn(0);
 }
 
