@@ -4,19 +4,11 @@
 #if !defined(PETSCSF_H)
 #define PETSCSF_H
 #include <petscsys.h>
-#include <petscis.h>
 #include <petscsftypes.h>
+#include <petscvec.h> /* for Vec, VecScatter etc */
 
 PETSC_EXTERN PetscClassId PETSCSF_CLASSID;
 
-/*J
-    PetscSFType - String with the name of a PetscSF type
-
-   Level: beginner
-
-.seealso: PetscSFSetType(), PetscSF
-J*/
-typedef const char *PetscSFType;
 #define PETSCSFBASIC      "basic"
 #define PETSCSFNEIGHBOR   "neighbor"
 #define PETSCSFALLGATHERV "allgatherv"
@@ -103,15 +95,15 @@ PETSC_EXTERN PetscErrorCode PetscSFWindowSetSyncType(PetscSF,PetscSFWindowSyncTy
 PETSC_EXTERN PetscErrorCode PetscSFWindowGetSyncType(PetscSF,PetscSFWindowSyncType*);
 PETSC_EXTERN PetscErrorCode PetscSFWindowSetFlavorType(PetscSF,PetscSFWindowFlavorType);
 PETSC_EXTERN PetscErrorCode PetscSFWindowGetFlavorType(PetscSF,PetscSFWindowFlavorType*);
-PETSC_EXTERN PetscErrorCode MPIAPI PetscSFWindowSetInfo(PetscSF,MPI_Info);
-PETSC_EXTERN PetscErrorCode MPIAPI PetscSFWindowGetInfo(PetscSF,MPI_Info*);
+PETSC_EXTERN PetscErrorCode PetscSFWindowSetInfo(PetscSF,MPI_Info);
+PETSC_EXTERN PetscErrorCode PetscSFWindowGetInfo(PetscSF,MPI_Info*);
 PETSC_EXTERN PetscErrorCode PetscSFSetRankOrder(PetscSF,PetscBool);
-PETSC_EXTERN PetscErrorCode PetscSFSetGraph(PetscSF,PetscInt,PetscInt,const PetscInt*,PetscCopyMode,const PetscSFNode*,PetscCopyMode);
+PETSC_EXTERN PetscErrorCode PetscSFSetGraph(PetscSF,PetscInt,PetscInt,PetscInt*,PetscCopyMode,PetscSFNode*,PetscCopyMode);
 PETSC_EXTERN PetscErrorCode PetscSFSetGraphWithPattern(PetscSF,PetscLayout,PetscSFPattern);
 PETSC_EXTERN PetscErrorCode PetscSFGetGraph(PetscSF,PetscInt*,PetscInt*,const PetscInt**,const PetscSFNode**);
 PETSC_EXTERN PetscErrorCode PetscSFGetLeafRange(PetscSF,PetscInt*,PetscInt*);
-PETSC_EXTERN PetscErrorCode PetscSFCreateEmbeddedSF(PetscSF,PetscInt,const PetscInt*,PetscSF*);
-PETSC_EXTERN PetscErrorCode PetscSFCreateEmbeddedLeafSF(PetscSF,PetscInt,const PetscInt *, PetscSF *);
+PETSC_EXTERN PetscErrorCode PetscSFCreateEmbeddedRootSF(PetscSF,PetscInt,const PetscInt*,PetscSF*);
+PETSC_EXTERN PetscErrorCode PetscSFCreateEmbeddedLeafSF(PetscSF,PetscInt,const PetscInt*,PetscSF*);
 PETSC_EXTERN PetscErrorCode PetscSFReset(PetscSF);
 PETSC_EXTERN PetscErrorCode PetscSFSetUpRanks(PetscSF,MPI_Group);
 PETSC_EXTERN PetscErrorCode PetscSFGetRootRanks(PetscSF,PetscInt*,const PetscMPIInt**,const PetscInt**,const PetscInt**,const PetscInt**);
@@ -119,22 +111,46 @@ PETSC_EXTERN PetscErrorCode PetscSFGetLeafRanks(PetscSF,PetscInt*,const PetscMPI
 PETSC_EXTERN PetscErrorCode PetscSFGetGroups(PetscSF,MPI_Group*,MPI_Group*);
 PETSC_EXTERN PetscErrorCode PetscSFGetMultiSF(PetscSF,PetscSF*);
 PETSC_EXTERN PetscErrorCode PetscSFCreateInverseSF(PetscSF,PetscSF*);
+PETSC_EXTERN PetscErrorCode PetscSFConcatenate(MPI_Comm,PetscInt,PetscSF[],PetscBool,PetscInt[],PetscSF*);
+
+/* Build PetscSF from PetscLayout */
+PETSC_EXTERN PetscErrorCode PetscSFSetGraphLayout(PetscSF,PetscLayout,PetscInt,PetscInt*,PetscCopyMode,const PetscInt*);
+PETSC_EXTERN PetscErrorCode PetscSFCreateFromLayouts(PetscLayout,PetscLayout,PetscSF*);
+PETSC_DEPRECATED_FUNCTION("Use PetscSFCreateFromLayouts (since v3.15)")
+static inline PetscErrorCode PetscLayoutsCreateSF(PetscLayout rmap, PetscLayout lmap, PetscSF* sf) { return PetscSFCreateFromLayouts(rmap, lmap, sf); }
+PETSC_EXTERN PetscErrorCode PetscSFCreateByMatchingIndices(PetscLayout,PetscInt,const PetscInt*,const PetscInt*,PetscInt,PetscInt,const PetscInt*,const PetscInt*,PetscInt,PetscSF*,PetscSF*);
+
+/* PetscSection interoperability */
+PETSC_EXTERN PetscErrorCode PetscSFSetGraphSection(PetscSF,PetscSection,PetscSection);
+PETSC_EXTERN PetscErrorCode PetscSFCreateRemoteOffsets(PetscSF, PetscSection, PetscSection, PetscInt **);
+PETSC_EXTERN PetscErrorCode PetscSFDistributeSection(PetscSF, PetscSection, PetscInt **, PetscSection);
+PETSC_EXTERN PetscErrorCode PetscSFCreateSectionSF(PetscSF, PetscSection, PetscInt [], PetscSection, PetscSF *);
 
 /* Reduce rootdata to leafdata using provided operation */
-PETSC_EXTERN PetscErrorCode PetscSFBcastAndOpBegin(PetscSF,MPI_Datatype,const void*,void*,MPI_Op)
+PETSC_EXTERN PetscErrorCode PetscSFBcastBegin(PetscSF,MPI_Datatype,const void*,void*,MPI_Op)
   PetscAttrMPIPointerWithType(3,2) PetscAttrMPIPointerWithType(4,2);
-PETSC_EXTERN PetscErrorCode PetscSFBcastAndOpEnd(PetscSF,MPI_Datatype,const void*,void*,MPI_Op)
+PETSC_EXTERN PetscErrorCode PetscSFBcastEnd(PetscSF,MPI_Datatype,const void*,void*,MPI_Op)
   PetscAttrMPIPointerWithType(3,2) PetscAttrMPIPointerWithType(4,2);
+PETSC_EXTERN PetscErrorCode PetscSFBcastWithMemTypeBegin(PetscSF,MPI_Datatype,PetscMemType,const void*,PetscMemType,void*,MPI_Op)
+  PetscAttrMPIPointerWithType(4,2) PetscAttrMPIPointerWithType(6,2);
+
 /* Reduce leafdata into rootdata using provided operation */
 PETSC_EXTERN PetscErrorCode PetscSFReduceBegin(PetscSF,MPI_Datatype,const void*,void *,MPI_Op)
   PetscAttrMPIPointerWithType(3,2) PetscAttrMPIPointerWithType(4,2);
 PETSC_EXTERN PetscErrorCode PetscSFReduceEnd(PetscSF,MPI_Datatype,const void*,void*,MPI_Op)
   PetscAttrMPIPointerWithType(3,2) PetscAttrMPIPointerWithType(4,2);
+PETSC_EXTERN PetscErrorCode PetscSFReduceWithMemTypeBegin(PetscSF,MPI_Datatype,PetscMemType,const void*,PetscMemType,void *,MPI_Op)
+  PetscAttrMPIPointerWithType(4,2) PetscAttrMPIPointerWithType(6,2);
+
 /* Atomically modifies (using provided operation) rootdata using leafdata from each leaf, value at root at time of modification is returned in leafupdate. */
 PETSC_EXTERN PetscErrorCode PetscSFFetchAndOpBegin(PetscSF,MPI_Datatype,void*,const void*,void*,MPI_Op)
   PetscAttrMPIPointerWithType(3,2) PetscAttrMPIPointerWithType(4,2) PetscAttrMPIPointerWithType(5,2);
 PETSC_EXTERN PetscErrorCode PetscSFFetchAndOpEnd(PetscSF,MPI_Datatype,void*,const void*,void*,MPI_Op)
   PetscAttrMPIPointerWithType(3,2) PetscAttrMPIPointerWithType(4,2) PetscAttrMPIPointerWithType(5,2);
+
+PETSC_EXTERN PetscErrorCode PetscSFFetchAndOpWithMemTypeBegin(PetscSF,MPI_Datatype,PetscMemType,void*,PetscMemType,const void*,PetscMemType,void*,MPI_Op)
+  PetscAttrMPIPointerWithType(4,2) PetscAttrMPIPointerWithType(6,2) PetscAttrMPIPointerWithType(8,2);
+
 /* Compute the degree of every root vertex (number of leaves in its star) */
 PETSC_EXTERN PetscErrorCode PetscSFComputeDegreeBegin(PetscSF,const PetscInt**);
 PETSC_EXTERN PetscErrorCode PetscSFComputeDegreeEnd(PetscSF,const PetscInt**);
@@ -153,61 +169,26 @@ PETSC_EXTERN PetscErrorCode PetscSFScatterEnd(PetscSF,MPI_Datatype,const void*,v
 PETSC_EXTERN PetscErrorCode PetscSFCompose(PetscSF,PetscSF,PetscSF*);
 PETSC_EXTERN PetscErrorCode PetscSFComposeInverse(PetscSF,PetscSF,PetscSF*);
 
-#if defined(MPI_REPLACE)
-#  define MPIU_REPLACE MPI_REPLACE
-#else
-/* When using an old MPI such that MPI_REPLACE is not defined, we do not pass MPI_REPLACE to MPI at all.  Instead, we
- * use it as a flag for our own reducer in the PETSCSFBASIC implementation.  This could be any unique value unlikely to
- * collide with another MPI_Op so we'll just use the value that has been used by every version of MPICH since
- * MPICH2-1.0.6. */
-#  define MPIU_REPLACE (MPI_Op)(0x5800000d)
-#endif
+#define MPIU_REPLACE MPI_REPLACE PETSC_DEPRECATED_MACRO("GCC warning \"MPIU_REPLACE macro is deprecated use MPI_REPLACE (since version 3.15)\"")
 
 PETSC_DEPRECATED_FUNCTION("Use PetscSFGetRootRanks (since v3.12)")
-PETSC_STATIC_INLINE PetscErrorCode PetscSFGetRanks(PetscSF sf,PetscInt *nranks,const PetscMPIInt **ranks,const PetscInt **roffset,const PetscInt **rmine,const PetscInt **rremote) {
-  return PetscSFGetRootRanks(sf,nranks,ranks,roffset,rmine,rremote);
-}
+static inline PetscErrorCode PetscSFGetRanks(PetscSF sf,PetscInt *nranks,const PetscMPIInt **ranks,const PetscInt **roffset,const PetscInt **rmine,const PetscInt **rremote)
+{ return PetscSFGetRootRanks(sf,nranks,ranks,roffset,rmine,rremote); }
 
-/*@C
-   PetscSFBcastBegin - begin pointwise broadcast to be concluded with call to PetscSFBcastEnd()
+PETSC_DEPRECATED_FUNCTION("Use PetscSFCreateEmbeddedRootSF (since v3.15)")
+static inline PetscErrorCode PetscSFCreateEmbeddedSF(PetscSF sf,PetscInt nselected,const PetscInt *selected,PetscSF *esf)
+{ return PetscSFCreateEmbeddedRootSF(sf,nselected,selected,esf); }
 
-   Collective on PetscSF
+PETSC_DEPRECATED_FUNCTION("Use PetscSFBcastBegin (since v3.15)")
+static inline PetscErrorCode PetscSFBcastAndOpBegin(PetscSF sf,MPI_Datatype unit,const void* rootdata,void* leafdata,MPI_Op op)
+{ return PetscSFBcastBegin(sf,unit,rootdata,leafdata,op); }
 
-   Input Arguments:
-+  sf - star forest on which to communicate
-.  unit - data type associated with each node
--  rootdata - buffer to broadcast
+PETSC_DEPRECATED_FUNCTION("Use PetscSFBcastEnd (since v3.15)")
+static inline PetscErrorCode PetscSFBcastAndOpEnd(PetscSF sf,MPI_Datatype unit,const void* rootdata,void* leafdata,MPI_Op op)
+{ return PetscSFBcastEnd(sf,unit,rootdata,leafdata,op); }
 
-   Output Arguments:
-.  leafdata - buffer to update with values from each leaf's respective root
-
-   Level: intermediate
-
-.seealso: PetscSFCreate(), PetscSFSetGraph(), PetscSFView(), PetscSFBcastEnd(), PetscSFReduceBegin(), PetscSFBcastAndOpBegin()
-@*/
-PETSC_STATIC_INLINE PetscErrorCode PetscSFBcastBegin(PetscSF sf,MPI_Datatype unit,const void* rootdata,void* leafdata) {
-  return PetscSFBcastAndOpBegin(sf,unit,rootdata,leafdata,MPIU_REPLACE);
-}
-
-/*@C
-   PetscSFBcastEnd - end a broadcast operation started with PetscSFBcastBegin()
-
-   Collective
-
-   Input Arguments:
-+  sf - star forest
-.  unit - data type
--  rootdata - buffer to broadcast
-
-   Output Arguments:
-.  leafdata - buffer to update with values from each leaf's respective root
-
-   Level: intermediate
-
-.seealso: PetscSFSetGraph(), PetscSFReduceEnd()
-@*/
-PETSC_STATIC_INLINE PetscErrorCode PetscSFBcastEnd(PetscSF sf,MPI_Datatype unit,const void* rootdata,void* leafdata) {
-  return PetscSFBcastAndOpEnd(sf,unit,rootdata,leafdata,MPIU_REPLACE);
-}
+PETSC_DEPRECATED_FUNCTION("Use PetscSFBcastWithMemTypeBegin (since v3.15)")
+static inline PetscErrorCode PetscSFBcastAndOpWithMemtypeBegin(PetscSF sf,MPI_Datatype unit,PetscMemType rootmtype,const void *rootdata,PetscMemType leafmtype,void *leafdata,MPI_Op op)
+{ return PetscSFBcastWithMemTypeBegin(sf,unit,rootmtype,rootdata,leafmtype,leafdata,op); }
 
 #endif
