@@ -4,12 +4,35 @@
 */
 
 #include <petsc/private/dmdaimpl.h>    /*I   "petscdmda.h"   I*/
+#include <petscdmfield.h>
 
 PetscErrorCode DMCreateCoordinateDM_DA(DM dm, DM *cdm)
 {
-  PetscErrorCode ierr;
   PetscFunctionBegin;
-  ierr = DMDAGetReducedDMDA(dm,dm->dim,cdm);CHKERRQ(ierr);
+  PetscCall(DMDACreateCompatibleDMDA(dm,dm->dim,cdm));
+  PetscFunctionReturn(0);
+}
+
+PetscErrorCode DMCreateCoordinateField_DA(DM dm, DMField *field)
+{
+  PetscReal      gmin[3], gmax[3];
+  PetscScalar    corners[24];
+  PetscInt       dim;
+  PetscInt       i, j;
+  DM             cdm;
+
+  PetscFunctionBegin;
+  PetscCall(DMGetDimension(dm,&dim));
+  /* TODO: this is wrong if coordinates are not rectilinear */
+  PetscCall(DMGetBoundingBox(dm,gmin,gmax));
+  for (i = 0; i < (1 << dim); i++) {
+    for (j = 0; j < dim; j++) {
+      corners[i*dim + j] = (i & (1 << j)) ? gmax[j] : gmin[j];
+    }
+  }
+  PetscCall(DMClone(dm,&cdm));
+  PetscCall(DMFieldCreateDA(cdm,dim,corners,field));
+  PetscCall(DMDestroy(&cdm));
   PetscFunctionReturn(0);
 }
 
@@ -17,7 +40,7 @@ PetscErrorCode DMCreateCoordinateDM_DA(DM dm, DM *cdm)
    DMDASetFieldName - Sets the names of individual field components in multicomponent
    vectors associated with a DMDA.
 
-   Not Collective
+   Logically collective; name must contain a common value
 
    Input Parameters:
 +  da - the distributed array
@@ -25,32 +48,30 @@ PetscErrorCode DMCreateCoordinateDM_DA(DM dm, DM *cdm)
         number of degrees of freedom per node within the DMDA
 -  names - the name of the field (component)
 
-  Notes: It must be called after having called DMSetUp().
+  Notes:
+    It must be called after having called DMSetUp().
 
   Level: intermediate
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDAGetFieldName(), DMDASetCoordinateName(), DMDAGetCoordinateName(), DMDASetFieldNames(), DMSetUp()
 @*/
 PetscErrorCode  DMDASetFieldName(DM da,PetscInt nf,const char name[])
 {
-  PetscErrorCode ierr;
   DM_DA          *dd = (DM_DA*)da->data;
 
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(da,DM_CLASSID,1);
-  if (nf < 0 || nf >= dd->w) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid field number: %D",nf);
-  if (!dd->fieldname) SETERRQ(PetscObjectComm((PetscObject)da),PETSC_ERR_ORDER,"You should call DMSetUp() first");
-  ierr = PetscFree(dd->fieldname[nf]);CHKERRQ(ierr);
-  ierr = PetscStrallocpy(name,&dd->fieldname[nf]);CHKERRQ(ierr);
+  PetscValidHeaderSpecificType(da,DM_CLASSID,1,DMDA);
+  PetscCheckFalse(nf < 0 || nf >= dd->w,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid field number: %D",nf);
+  PetscCheck(dd->fieldname,PetscObjectComm((PetscObject)da),PETSC_ERR_ORDER,"You should call DMSetUp() first");
+  PetscCall(PetscFree(dd->fieldname[nf]));
+  PetscCall(PetscStrallocpy(name,&dd->fieldname[nf]));
   PetscFunctionReturn(0);
 }
 
 /*@C
    DMDAGetFieldNames - Gets the name of each component in the vector associated with the DMDA
 
-   Collective on TS
+   Not collective; names will contain a common value
 
    Input Parameter:
 .  dm - the DMDA object
@@ -62,8 +83,6 @@ PetscErrorCode  DMDASetFieldName(DM da,PetscInt nf,const char name[])
 
    Not supported from Fortran, use DMDAGetFieldName()
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDAGetFieldName(), DMDASetCoordinateName(), DMDAGetCoordinateName(), DMDASetFieldName(), DMDASetFieldNames()
 @*/
 PetscErrorCode  DMDAGetFieldNames(DM da,const char * const **names)
@@ -78,35 +97,33 @@ PetscErrorCode  DMDAGetFieldNames(DM da,const char * const **names)
 /*@C
    DMDASetFieldNames - Sets the name of each component in the vector associated with the DMDA
 
-   Collective on TS
+   Logically collective; names must contain a common value
 
    Input Parameters:
 +  dm - the DMDA object
 -  names - the names of the components, final string must be NULL, must have the same number of entries as the dof used in creating the DMDA
 
-   Notes: It must be called after having called DMSetUp().
+   Notes:
+    It must be called after having called DMSetUp().
 
    Level: intermediate
 
    Not supported from Fortran, use DMDASetFieldName()
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDAGetFieldName(), DMDASetCoordinateName(), DMDAGetCoordinateName(), DMDASetFieldName(), DMSetUp()
 @*/
 PetscErrorCode  DMDASetFieldNames(DM da,const char * const *names)
 {
-  PetscErrorCode ierr;
   DM_DA          *dd = (DM_DA*)da->data;
   char           **fieldname;
   PetscInt       nf = 0;
 
   PetscFunctionBegin;
-  if (!dd->fieldname) SETERRQ(PetscObjectComm((PetscObject)da),PETSC_ERR_ORDER,"You should call DMSetUp() first");
+  PetscCheck(dd->fieldname,PetscObjectComm((PetscObject)da),PETSC_ERR_ORDER,"You should call DMSetUp() first");
   while (names[nf++]) {};
-  if (nf != dd->w+1) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid number of fields %D",nf-1);
-  ierr = PetscStrArrayallocpy(names,&fieldname);CHKERRQ(ierr);
-  ierr = PetscStrArrayDestroy(&dd->fieldname);CHKERRQ(ierr);
+  PetscCheckFalse(nf != dd->w+1,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid number of fields %D",nf-1);
+  PetscCall(PetscStrArrayallocpy(names,&fieldname));
+  PetscCall(PetscStrArrayDestroy(&dd->fieldname));
   dd->fieldname = fieldname;
   PetscFunctionReturn(0);
 }
@@ -115,9 +132,9 @@ PetscErrorCode  DMDASetFieldNames(DM da,const char * const *names)
    DMDAGetFieldName - Gets the names of individual field components in multicomponent
    vectors associated with a DMDA.
 
-   Not Collective
+   Not collective; name will contain a common value
 
-   Input Parameter:
+   Input Parameters:
 +  da - the distributed array
 -  nf - field number for the DMDA (0, 1, ... dof-1), where dof indicates the
         number of degrees of freedom per node within the DMDA
@@ -125,12 +142,11 @@ PetscErrorCode  DMDASetFieldNames(DM da,const char * const *names)
    Output Parameter:
 .  names - the name of the field (component)
 
-  Notes: It must be called after having called DMSetUp().
+  Notes:
+    It must be called after having called DMSetUp().
 
   Level: intermediate
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDASetFieldName(), DMDASetCoordinateName(), DMDAGetCoordinateName(), DMSetUp()
 @*/
 PetscErrorCode  DMDAGetFieldName(DM da,PetscInt nf,const char **name)
@@ -138,10 +154,10 @@ PetscErrorCode  DMDAGetFieldName(DM da,PetscInt nf,const char **name)
   DM_DA *dd = (DM_DA*)da->data;
 
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(da,DM_CLASSID,1);
+  PetscValidHeaderSpecificType(da,DM_CLASSID,1,DMDA);
   PetscValidPointer(name,3);
-  if (nf < 0 || nf >= dd->w) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid field number: %D",nf);
-  if (!dd->fieldname) SETERRQ(PetscObjectComm((PetscObject)da),PETSC_ERR_ORDER,"You should call DMSetUp() first");
+  PetscCheckFalse(nf < 0 || nf >= dd->w,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid field number: %D",nf);
+  PetscCheck(dd->fieldname,PetscObjectComm((PetscObject)da),PETSC_ERR_ORDER,"You should call DMSetUp() first");
   *name = dd->fieldname[nf];
   PetscFunctionReturn(0);
 }
@@ -149,57 +165,54 @@ PetscErrorCode  DMDAGetFieldName(DM da,PetscInt nf,const char **name)
 /*@C
    DMDASetCoordinateName - Sets the name of the coordinate directions associated with a DMDA, for example "x" or "y"
 
-   Not Collective
+   Logically collective; name must contain a common value
 
    Input Parameters:
 +  dm - the DM
 .  nf - coordinate number for the DMDA (0, 1, ... dim-1),
 -  name - the name of the coordinate
 
-  Notes: It must be called after having called DMSetUp().
+  Notes:
+    It must be called after having called DMSetUp().
 
   Level: intermediate
 
   Not supported from Fortran
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDAGetCoordinateName(), DMDASetFieldName(), DMDAGetFieldName(), DMSetUp()
 @*/
 PetscErrorCode DMDASetCoordinateName(DM dm,PetscInt nf,const char name[])
 {
-  PetscErrorCode ierr;
   DM_DA          *dd = (DM_DA*)dm->data;
 
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  if (nf < 0 || nf >= dm->dim) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid coordinate number: %D",nf);
-  if (!dd->coordinatename) SETERRQ(PetscObjectComm((PetscObject)dm),PETSC_ERR_ORDER,"You should call DMSetUp() first");
-  ierr = PetscFree(dd->coordinatename[nf]);CHKERRQ(ierr);
-  ierr = PetscStrallocpy(name,&dd->coordinatename[nf]);CHKERRQ(ierr);
+  PetscValidHeaderSpecificType(dm,DM_CLASSID,1,DMDA);
+  PetscCheckFalse(nf < 0 || nf >= dm->dim,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid coordinate number: %D",nf);
+  PetscCheck(dd->coordinatename,PetscObjectComm((PetscObject)dm),PETSC_ERR_ORDER,"You should call DMSetUp() first");
+  PetscCall(PetscFree(dd->coordinatename[nf]));
+  PetscCall(PetscStrallocpy(name,&dd->coordinatename[nf]));
   PetscFunctionReturn(0);
 }
 
 /*@C
    DMDAGetCoordinateName - Gets the name of a coodinate direction associated with a DMDA.
 
-   Not Collective
+   Not collective; name will contain a common value
 
-   Input Parameter:
+   Input Parameters:
 +  dm - the DM
 -  nf -  number for the DMDA (0, 1, ... dim-1)
 
    Output Parameter:
 .  names - the name of the coordinate direction
 
-  Notes: It must be called after having called DMSetUp().
+  Notes:
+    It must be called after having called DMSetUp().
 
   Level: intermediate
 
   Not supported from Fortran
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDASetCoordinateName(), DMDASetFieldName(), DMDAGetFieldName(), DMSetUp()
 @*/
 PetscErrorCode DMDAGetCoordinateName(DM dm,PetscInt nf,const char **name)
@@ -207,10 +220,10 @@ PetscErrorCode DMDAGetCoordinateName(DM dm,PetscInt nf,const char **name)
   DM_DA *dd = (DM_DA*)dm->data;
 
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(dm,DM_CLASSID,1);
+  PetscValidHeaderSpecificType(dm,DM_CLASSID,1,DMDA);
   PetscValidPointer(name,3);
-  if (nf < 0 || nf >= dm->dim) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid coordinate number: %D",nf);
-  if (!dd->coordinatename) SETERRQ(PetscObjectComm((PetscObject)dm),PETSC_ERR_ORDER,"You should call DMSetUp() first");
+  PetscCheckFalse(nf < 0 || nf >= dm->dim,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Invalid coordinate number: %D",nf);
+  PetscCheck(dd->coordinatename,PetscObjectComm((PetscObject)dm),PETSC_ERR_ORDER,"You should call DMSetUp() first");
   *name = dd->coordinatename[nf];
   PetscFunctionReturn(0);
 }
@@ -219,16 +232,18 @@ PetscErrorCode DMDAGetCoordinateName(DM dm,PetscInt nf,const char **name)
    DMDAGetCorners - Returns the global (x,y,z) indices of the lower left
    corner and size of the local region, excluding ghost points.
 
-   Not Collective
+   Not collective
 
    Input Parameter:
 .  da - the distributed array
 
    Output Parameters:
-+  x,y,z - the corner indices (where y and z are optional; these are used
-           for 2D and 3D problems)
--  m,n,p - widths in the corresponding directions (where n and p are optional;
-           these are used for 2D and 3D problems)
++  x - the corner index for the first dimension
+.  y - the corner index for the second dimension (only used in 2D and 3D problems)
+.  z - the corner index for the third dimension (only used in 3D problems)
+.  m - the width in the first dimension
+.  n - the width in the second dimension (only used in 2D and 3D problems)
+-  p - the width in the third dimension (only used in 3D problems)
 
    Note:
    The corner information is independent of the number of degrees of
@@ -239,9 +254,7 @@ PetscErrorCode DMDAGetCoordinateName(DM dm,PetscInt nf,const char **name)
 
   Level: beginner
 
-.keywords: distributed array, get, corners, nodes, local indices
-
-.seealso: DMDAGetGhostCorners(), DMDAGetOwnershipRanges()
+.seealso: DMDAGetGhostCorners(), DMDAGetOwnershipRanges(), DMStagGetCorners()
 @*/
 PetscErrorCode  DMDAGetCorners(DM da,PetscInt *x,PetscInt *y,PetscInt *z,PetscInt *m,PetscInt *n,PetscInt *p)
 {
@@ -249,7 +262,7 @@ PetscErrorCode  DMDAGetCorners(DM da,PetscInt *x,PetscInt *y,PetscInt *z,PetscIn
   DM_DA    *dd = (DM_DA*)da->data;
 
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(da,DM_CLASSID,1);
+  PetscValidHeaderSpecificType(da,DM_CLASSID,1,DMDA);
   /* since the xs, xe ... have all been multiplied by the number of degrees
      of freedom per cell, w = dd->w, we divide that out before returning.*/
   w = dd->w;
@@ -263,102 +276,37 @@ PetscErrorCode  DMDAGetCorners(DM da,PetscInt *x,PetscInt *y,PetscInt *z,PetscIn
   PetscFunctionReturn(0);
 }
 
-/*@
-   DMDAGetLocalBoundingBox - Returns the local bounding box for the DMDA.
-
-   Not Collective
-
-   Input Parameter:
-.  dm - the DM
-
-   Output Parameters:
-+  lmin - local minimum coordinates (length dim, optional)
--  lmax - local maximim coordinates (length dim, optional)
-
-  Level: beginner
-
-  Not supported from Fortran
-
-.keywords: distributed array, get, coordinates
-
-.seealso: DMDAGetCoordinateDA(), DMGetCoordinates(), DMDAGetBoundingBox()
-@*/
-PetscErrorCode DMDAGetLocalBoundingBox(DM dm,PetscReal lmin[],PetscReal lmax[])
+PetscErrorCode DMGetLocalBoundingIndices_DMDA(DM dm, PetscReal lmin[], PetscReal lmax[])
 {
-  PetscErrorCode    ierr;
-  Vec               coords = NULL;
-  PetscInt          dim,i,j;
-  const PetscScalar *local_coords;
-  PetscReal         min[3]={PETSC_MAX_REAL,PETSC_MAX_REAL,PETSC_MAX_REAL},max[3]={PETSC_MIN_REAL,PETSC_MIN_REAL,PETSC_MIN_REAL};
-  PetscInt          N,Ni;
+  DMDALocalInfo  info;
 
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  dim  = dm->dim;
-  ierr = DMGetCoordinates(dm,&coords);CHKERRQ(ierr);
-  if (coords) {
-    ierr = VecGetArrayRead(coords,&local_coords);CHKERRQ(ierr);
-    ierr = VecGetLocalSize(coords,&N);CHKERRQ(ierr);
-    Ni   = N/dim;
-    for (i=0; i<Ni; i++) {
-      for (j=0; j<3; j++) {
-        min[j] = j < dim ? PetscMin(min[j],PetscRealPart(local_coords[i*dim+j])) : 0;
-        max[j] = j < dim ? PetscMax(max[j],PetscRealPart(local_coords[i*dim+j])) : 0;
-      }
-    }
-    ierr = VecRestoreArrayRead(coords,&local_coords);CHKERRQ(ierr);
-  } else {                      /* Just use grid indices */
-    DMDALocalInfo info;
-    ierr   = DMDAGetLocalInfo(dm,&info);CHKERRQ(ierr);
-    min[0] = info.xs;
-    min[1] = info.ys;
-    min[2] = info.zs;
-    max[0] = info.xs + info.xm-1;
-    max[1] = info.ys + info.ym-1;
-    max[2] = info.zs + info.zm-1;
-  }
-  if (lmin) {ierr = PetscMemcpy(lmin,min,dim*sizeof(PetscReal));CHKERRQ(ierr);}
-  if (lmax) {ierr = PetscMemcpy(lmax,max,dim*sizeof(PetscReal));CHKERRQ(ierr);}
+  PetscCall(DMDAGetLocalInfo(dm, &info));
+  lmin[0] = info.xs;
+  lmin[1] = info.ys;
+  lmin[2] = info.zs;
+  lmax[0] = info.xs + info.xm-1;
+  lmax[1] = info.ys + info.ym-1;
+  lmax[2] = info.zs + info.zm-1;
   PetscFunctionReturn(0);
 }
 
 /*@
-   DMDAGetBoundingBox - Returns the global bounding box for the DMDA.
+   DMDAGetReducedDMDA - Deprecated; use DMDACreateCompatibleDMDA()
 
-   Collective on DMDA
-
-   Input Parameter:
-.  dm - the DM
-
-   Output Parameters:
-+  gmin - global minimum coordinates (length dim, optional)
--  gmax - global maximim coordinates (length dim, optional)
-
-  Level: beginner
-
-.keywords: distributed array, get, coordinates
-
-.seealso: DMDAGetCoordinateDA(), DMGetCoordinates(), DMDAGetLocalBoundingBox()
+   Level: deprecated
 @*/
-PetscErrorCode DMDAGetBoundingBox(DM dm,PetscReal gmin[],PetscReal gmax[])
+PetscErrorCode DMDAGetReducedDMDA(DM da,PetscInt nfields,DM *nda)
 {
-  PetscErrorCode ierr;
-  PetscMPIInt    count;
-  PetscReal      lmin[3],lmax[3];
-
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  ierr = PetscMPIIntCast(dm->dim,&count);CHKERRQ(ierr);
-  ierr = DMDAGetLocalBoundingBox(dm,lmin,lmax);CHKERRQ(ierr);
-  if (gmin) {ierr = MPIU_Allreduce(lmin,gmin,count,MPIU_REAL,MPIU_MIN,PetscObjectComm((PetscObject)dm));CHKERRQ(ierr);}
-  if (gmax) {ierr = MPIU_Allreduce(lmax,gmax,count,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)dm));CHKERRQ(ierr);}
+  PetscCall(DMDACreateCompatibleDMDA(da,nfields,nda));
   PetscFunctionReturn(0);
 }
 
 /*@
-   DMDAGetReducedDMDA - Gets the DMDA with the same layout but with fewer or more fields
+   DMDACreateCompatibleDMDA - Creates a DMDA with the same layout but with fewer or more fields
 
-   Collective on DMDA
+   Collective
 
    Input Parameters:
 +  da - the distributed array
@@ -369,13 +317,10 @@ PetscErrorCode DMDAGetBoundingBox(DM dm,PetscReal gmin[],PetscReal gmax[])
 
   Level: intermediate
 
-.keywords: distributed array, get, corners, nodes, local indices, coordinates
-
-.seealso: DMDAGetGhostCorners(), DMSetCoordinates(), DMDASetUniformCoordinates(), DMGetCoordinates(), DMDAGetGhostedCoordinates()
+.seealso: DMDAGetGhostCorners(), DMSetCoordinates(), DMDASetUniformCoordinates(), DMGetCoordinates(), DMDAGetGhostedCoordinates(), DMStagCreateCompatibleDMStag()
 @*/
-PetscErrorCode  DMDAGetReducedDMDA(DM da,PetscInt nfields,DM *nda)
+PetscErrorCode  DMDACreateCompatibleDMDA(DM da,PetscInt nfields,DM *nda)
 {
-  PetscErrorCode   ierr;
   DM_DA            *dd = (DM_DA*)da->data;
   PetscInt         s,m,n,p,M,N,P,dim,Mo,No,Po;
   const PetscInt   *lx,*ly,*lz;
@@ -399,27 +344,27 @@ PetscErrorCode  DMDAGetReducedDMDA(DM da,PetscInt nfields,DM *nda)
 
   stencil_type = dd->stencil_type;
 
-  ierr = DMDAGetOwnershipRanges(da,&lx,&ly,&lz);CHKERRQ(ierr);
+  PetscCall(DMDAGetOwnershipRanges(da,&lx,&ly,&lz));
   if (dim == 1) {
-    ierr = DMDACreate1d(PetscObjectComm((PetscObject)da),bx,M,nfields,s,dd->lx,nda);CHKERRQ(ierr);
+    PetscCall(DMDACreate1d(PetscObjectComm((PetscObject)da),bx,M,nfields,s,dd->lx,nda));
   } else if (dim == 2) {
-    ierr = DMDACreate2d(PetscObjectComm((PetscObject)da),bx,by,stencil_type,M,N,m,n,nfields,s,lx,ly,nda);CHKERRQ(ierr);
+    PetscCall(DMDACreate2d(PetscObjectComm((PetscObject)da),bx,by,stencil_type,M,N,m,n,nfields,s,lx,ly,nda));
   } else if (dim == 3) {
-    ierr = DMDACreate3d(PetscObjectComm((PetscObject)da),bx,by,bz,stencil_type,M,N,P,m,n,p,nfields,s,lx,ly,lz,nda);CHKERRQ(ierr);
+    PetscCall(DMDACreate3d(PetscObjectComm((PetscObject)da),bx,by,bz,stencil_type,M,N,P,m,n,p,nfields,s,lx,ly,lz,nda));
   }
-  ierr = DMSetUp(*nda);CHKERRQ(ierr);
+  PetscCall(DMSetUp(*nda));
   if (da->coordinates) {
-    ierr = PetscObjectReference((PetscObject)da->coordinates);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)da->coordinates));
     (*nda)->coordinates = da->coordinates;
   }
 
   /* allow for getting a reduced DA corresponding to a domain decomposition */
-  ierr = DMDAGetOffset(da,&ox,&oy,&oz,&Mo,&No,&Po);CHKERRQ(ierr);
-  ierr = DMDASetOffset(*nda,ox,oy,oz,Mo,No,Po);CHKERRQ(ierr);
+  PetscCall(DMDAGetOffset(da,&ox,&oy,&oz,&Mo,&No,&Po));
+  PetscCall(DMDASetOffset(*nda,ox,oy,oz,Mo,No,Po));
 
   /* allow for getting a reduced DA corresponding to a coarsened DA */
-  ierr = DMGetCoarsenLevel(da,&cl);CHKERRQ(ierr);
-  ierr = DMGetRefineLevel(da,&rl);CHKERRQ(ierr);
+  PetscCall(DMGetCoarsenLevel(da,&cl));
+  PetscCall(DMGetRefineLevel(da,&rl));
 
   (*nda)->levelup   = rl;
   (*nda)->leveldown = cl;
@@ -429,7 +374,7 @@ PetscErrorCode  DMDAGetReducedDMDA(DM da,PetscInt nfields,DM *nda)
 /*@C
    DMDAGetCoordinateArray - Gets an array containing the coordinates of the DMDA
 
-   Not Collective
+   Not collective
 
    Input Parameter:
 .  dm - the DM
@@ -441,30 +386,27 @@ PetscErrorCode  DMDAGetReducedDMDA(DM da,PetscInt nfields,DM *nda)
 
   Not supported from Fortran
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDASetCoordinateName(), DMDASetFieldName(), DMDAGetFieldName(), DMDARestoreCoordinateArray()
 @*/
 PetscErrorCode DMDAGetCoordinateArray(DM dm,void *xc)
 {
-  PetscErrorCode ierr;
   DM             cdm;
   Vec            x;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  ierr = DMGetCoordinates(dm,&x);CHKERRQ(ierr);
-  ierr = DMGetCoordinateDM(dm,&cdm);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(cdm,x,xc);CHKERRQ(ierr);
+  PetscCall(DMGetCoordinates(dm,&x));
+  PetscCall(DMGetCoordinateDM(dm,&cdm));
+  PetscCall(DMDAVecGetArray(cdm,x,xc));
   PetscFunctionReturn(0);
 }
 
 /*@C
    DMDARestoreCoordinateArray - Sets an array containing the coordinates of the DMDA
 
-   Not Collective
+   Not collective
 
-   Input Parameter:
+   Input Parameters:
 +  dm - the DM
 -  xc - the coordinates
 
@@ -472,20 +414,17 @@ PetscErrorCode DMDAGetCoordinateArray(DM dm,void *xc)
 
   Not supported from Fortran
 
-.keywords: distributed array, get, component name
-
 .seealso: DMDASetCoordinateName(), DMDASetFieldName(), DMDAGetFieldName(), DMDAGetCoordinateArray()
 @*/
 PetscErrorCode DMDARestoreCoordinateArray(DM dm,void *xc)
 {
-  PetscErrorCode ierr;
   DM             cdm;
   Vec            x;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  ierr = DMGetCoordinates(dm,&x);CHKERRQ(ierr);
-  ierr = DMGetCoordinateDM(dm,&cdm);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(cdm,x,xc);CHKERRQ(ierr);
+  PetscCall(DMGetCoordinates(dm,&x));
+  PetscCall(DMGetCoordinateDM(dm,&cdm));
+  PetscCall(DMDAVecRestoreArray(cdm,x,xc));
   PetscFunctionReturn(0);
 }
