@@ -10,7 +10,6 @@
 
 PetscErrorCode DMView_DA_Matlab(DM da,PetscViewer viewer)
 {
-  PetscErrorCode   ierr;
   PetscMPIInt      rank;
   PetscInt         dim,m,n,p,dof,swidth;
   DMDAStencilType  stencil;
@@ -19,11 +18,11 @@ PetscErrorCode DMView_DA_Matlab(DM da,PetscViewer viewer)
   const char       *fnames[] = {"dimension","m","n","p","dof","stencil_width","bx","by","bz","stencil_type"};
 
   PetscFunctionBegin;
-  ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)da),&rank);CHKERRQ(ierr);
-  if (!rank) {
-    ierr = DMDAGetInfo(da,&dim,&m,&n,&p,0,0,0,&dof,&swidth,&bx,&by,&bz,&stencil);CHKERRQ(ierr);
+  PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)da),&rank));
+  if (rank == 0) {
+    PetscCall(DMDAGetInfo(da,&dim,&m,&n,&p,0,0,0,&dof,&swidth,&bx,&by,&bz,&stencil));
     mx   = mxCreateStructMatrix(1,1,8,(const char**)fnames);
-    if (!mx) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Unable to generate MATLAB struct array to hold DMDA informations");
+    PetscCheck(mx,PETSC_COMM_SELF,PETSC_ERR_LIB,"Unable to generate MATLAB struct array to hold DMDA information");
     mxSetFieldByNumber(mx,0,0,mxCreateDoubleScalar((double)dim));
     mxSetFieldByNumber(mx,0,1,mxCreateDoubleScalar((double)m));
     mxSetFieldByNumber(mx,0,2,mxCreateDoubleScalar((double)n));
@@ -34,8 +33,8 @@ PetscErrorCode DMView_DA_Matlab(DM da,PetscViewer viewer)
     mxSetFieldByNumber(mx,0,7,mxCreateDoubleScalar((double)by));
     mxSetFieldByNumber(mx,0,8,mxCreateDoubleScalar((double)bz));
     mxSetFieldByNumber(mx,0,9,mxCreateDoubleScalar((double)stencil));
-    ierr = PetscObjectName((PetscObject)da);CHKERRQ(ierr);
-    ierr = PetscViewerMatlabPutVariable(viewer,((PetscObject)da)->name,mx);CHKERRQ(ierr);
+    PetscCall(PetscObjectName((PetscObject)da));
+    PetscCall(PetscViewerMatlabPutVariable(viewer,((PetscObject)da)->name,mx));
   }
   PetscFunctionReturn(0);
 }
@@ -43,7 +42,6 @@ PetscErrorCode DMView_DA_Matlab(DM da,PetscViewer viewer)
 
 PetscErrorCode DMView_DA_Binary(DM da,PetscViewer viewer)
 {
-  PetscErrorCode   ierr;
   PetscMPIInt      rank;
   PetscInt         dim,m,n,p,dof,swidth,M,N,P;
   DMDAStencilType  stencil;
@@ -52,28 +50,28 @@ PetscErrorCode DMView_DA_Binary(DM da,PetscViewer viewer)
   PetscBool        coors = PETSC_FALSE;
 
   PetscFunctionBegin;
-  ierr = PetscObjectGetComm((PetscObject)da,&comm);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetComm((PetscObject)da,&comm));
 
-  ierr = DMDAGetInfo(da,&dim,&m,&n,&p,&M,&N,&P,&dof,&swidth,&bx,&by,&bz,&stencil);CHKERRQ(ierr);
-  ierr = MPI_Comm_rank(comm,&rank);CHKERRQ(ierr);
-  if (!rank) {
-    ierr = PetscViewerBinaryWrite(viewer,&dim,1,PETSC_INT);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&m,1,PETSC_INT);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&n,1,PETSC_INT);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&p,1,PETSC_INT);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&dof,1,PETSC_INT);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&swidth,1,PETSC_INT);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&bx,1,PETSC_ENUM);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&by,1,PETSC_ENUM);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&bz,1,PETSC_ENUM);CHKERRQ(ierr);
-    ierr = PetscViewerBinaryWrite(viewer,&stencil,1,PETSC_ENUM);CHKERRQ(ierr);
+  PetscCall(DMDAGetInfo(da,&dim,&m,&n,&p,&M,&N,&P,&dof,&swidth,&bx,&by,&bz,&stencil));
+  PetscCallMPI(MPI_Comm_rank(comm,&rank));
+  if (rank == 0) {
+    PetscCall(PetscViewerBinaryWrite(viewer,&dim,1,PETSC_INT));
+    PetscCall(PetscViewerBinaryWrite(viewer,&m,1,PETSC_INT));
+    PetscCall(PetscViewerBinaryWrite(viewer,&n,1,PETSC_INT));
+    PetscCall(PetscViewerBinaryWrite(viewer,&p,1,PETSC_INT));
+    PetscCall(PetscViewerBinaryWrite(viewer,&dof,1,PETSC_INT));
+    PetscCall(PetscViewerBinaryWrite(viewer,&swidth,1,PETSC_INT));
+    PetscCall(PetscViewerBinaryWrite(viewer,&bx,1,PETSC_ENUM));
+    PetscCall(PetscViewerBinaryWrite(viewer,&by,1,PETSC_ENUM));
+    PetscCall(PetscViewerBinaryWrite(viewer,&bz,1,PETSC_ENUM));
+    PetscCall(PetscViewerBinaryWrite(viewer,&stencil,1,PETSC_ENUM));
     if (da->coordinates) coors = PETSC_TRUE;
-    ierr = PetscViewerBinaryWrite(viewer,&coors,1,PETSC_BOOL);CHKERRQ(ierr);
+    PetscCall(PetscViewerBinaryWrite(viewer,&coors,1,PETSC_BOOL));
   }
 
   /* save the coordinates if they exist to disk (in the natural ordering) */
   if (da->coordinates) {
-    ierr = VecView(da->coordinates,viewer);CHKERRQ(ierr);
+    PetscCall(VecView(da->coordinates,viewer));
   }
   PetscFunctionReturn(0);
 }
@@ -81,31 +79,30 @@ PetscErrorCode DMView_DA_Binary(DM da,PetscViewer viewer)
 PetscErrorCode DMView_DA_VTK(DM da, PetscViewer viewer)
 {
   PetscInt       dim, dof, M = 0, N = 0, P = 0;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = DMDAGetInfo(da, &dim, &M, &N, &P, NULL, NULL, NULL, &dof, NULL, NULL, NULL, NULL, NULL);CHKERRQ(ierr);
-  if (!da->coordinates) SETERRQ(PetscObjectComm((PetscObject)da),PETSC_ERR_SUP, "VTK output requires DMDA coordinates.");
+  PetscCall(DMDAGetInfo(da, &dim, &M, &N, &P, NULL, NULL, NULL, &dof, NULL, NULL, NULL, NULL, NULL));
+  PetscCheck(da->coordinates,PetscObjectComm((PetscObject)da),PETSC_ERR_SUP, "VTK output requires DMDA coordinates.");
   /* Write Header */
-  ierr = PetscViewerASCIIPrintf(viewer,"# vtk DataFile Version 2.0\n");CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"Structured Mesh Example\n");CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"ASCII\n");CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"DATASET STRUCTURED_GRID\n");CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"DIMENSIONS %d %d %d\n", M, N, P);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"POINTS %d double\n", M*N*P);CHKERRQ(ierr);
+  PetscCall(PetscViewerASCIIPrintf(viewer,"# vtk DataFile Version 2.0\n"));
+  PetscCall(PetscViewerASCIIPrintf(viewer,"Structured Mesh Example\n"));
+  PetscCall(PetscViewerASCIIPrintf(viewer,"ASCII\n"));
+  PetscCall(PetscViewerASCIIPrintf(viewer,"DATASET STRUCTURED_GRID\n"));
+  PetscCall(PetscViewerASCIIPrintf(viewer,"DIMENSIONS %d %d %d\n", M, N, P));
+  PetscCall(PetscViewerASCIIPrintf(viewer,"POINTS %d double\n", M*N*P));
   if (da->coordinates) {
     DM  dac;
     Vec natural;
 
-    ierr = DMGetCoordinateDM(da, &dac);CHKERRQ(ierr);
-    ierr = DMDACreateNaturalVector(dac, &natural);CHKERRQ(ierr);
-    ierr = PetscObjectSetOptionsPrefix((PetscObject) natural, "coor_");CHKERRQ(ierr);
-    ierr = DMDAGlobalToNaturalBegin(dac, da->coordinates, INSERT_VALUES, natural);CHKERRQ(ierr);
-    ierr = DMDAGlobalToNaturalEnd(dac, da->coordinates, INSERT_VALUES, natural);CHKERRQ(ierr);
-    ierr = PetscViewerPushFormat(viewer, PETSC_VIEWER_ASCII_VTK_COORDS_DEPRECATED);CHKERRQ(ierr);
-    ierr = VecView(natural, viewer);CHKERRQ(ierr);
-    ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
-    ierr = VecDestroy(&natural);CHKERRQ(ierr);
+    PetscCall(DMGetCoordinateDM(da, &dac));
+    PetscCall(DMDACreateNaturalVector(dac, &natural));
+    PetscCall(PetscObjectSetOptionsPrefix((PetscObject) natural, "coor_"));
+    PetscCall(DMDAGlobalToNaturalBegin(dac, da->coordinates, INSERT_VALUES, natural));
+    PetscCall(DMDAGlobalToNaturalEnd(dac, da->coordinates, INSERT_VALUES, natural));
+    PetscCall(PetscViewerPushFormat(viewer, PETSC_VIEWER_ASCII_VTK_COORDS_DEPRECATED));
+    PetscCall(VecView(natural, viewer));
+    PetscCall(PetscViewerPopFormat(viewer));
+    PetscCall(VecDestroy(&natural));
   }
   PetscFunctionReturn(0);
 }
@@ -120,12 +117,17 @@ PetscErrorCode DMView_DA_VTK(DM da, PetscViewer viewer)
 
    Output Parameters:
 +  dim      - dimension of the distributed array (1, 2, or 3)
-.  M, N, P  - global dimension in each direction of the array
-.  m, n, p  - corresponding number of procs in each dimension
+.  M        - global dimension in first direction of the array
+.  N        - global dimension in second direction of the array
+.  P        - global dimension in third direction of the array
+.  m        - corresponding number of procs in first dimension
+.  n        - corresponding number of procs in second dimension
+.  p        - corresponding number of procs in third dimension
 .  dof      - number of degrees of freedom per node
 .  s        - stencil width
-.  bx,by,bz - type of ghost nodes at boundary, one of DM_BOUNDARY_NONE, DM_BOUNDARY_GHOSTED,
-              DM_BOUNDARY_MIRROR, DM_BOUNDARY_PERIODIC
+.  bx       - type of ghost nodes at boundary in first dimension
+.  by       - type of ghost nodes at boundary in second dimension
+.  bz       - type of ghost nodes at boundary in third dimension
 -  st       - stencil type, either DMDA_STENCIL_STAR or DMDA_STENCIL_BOX
 
    Level: beginner
