@@ -24,52 +24,49 @@ typedef struct {
 
 static PetscErrorCode  VecSquare(Vec v)
 {
-  PetscErrorCode ierr;
   PetscScalar    *x;
   PetscInt       i, n;
 
   PetscFunctionBegin;
-  ierr = VecGetLocalSize(v, &n);CHKERRQ(ierr);
-  ierr = VecGetArray(v, &x);CHKERRQ(ierr);
+  PetscCall(VecGetLocalSize(v, &n));
+  PetscCall(VecGetArray(v, &x));
   for (i = 0; i < n; i++) x[i] *= PetscConj(x[i]);
-  ierr = VecRestoreArray(v, &x);CHKERRQ(ierr);
+  PetscCall(VecRestoreArray(v, &x));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode KSPSetUp_LSQR(KSP ksp)
 {
-  PetscErrorCode ierr;
   KSP_LSQR       *lsqr = (KSP_LSQR*)ksp->data;
   PetscBool      nopreconditioner;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)ksp->pc,PCNONE,&nopreconditioner);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)ksp->pc,PCNONE,&nopreconditioner));
 
   if (lsqr->vwork_m) {
-    ierr = VecDestroyVecs(lsqr->nwork_m,&lsqr->vwork_m);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(lsqr->nwork_m,&lsqr->vwork_m));
   }
 
   if (lsqr->vwork_n) {
-    ierr = VecDestroyVecs(lsqr->nwork_n,&lsqr->vwork_n);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(lsqr->nwork_n,&lsqr->vwork_n));
   }
 
   lsqr->nwork_m = 2;
   if (nopreconditioner) lsqr->nwork_n = 4;
   else lsqr->nwork_n = 5;
-  ierr = KSPCreateVecs(ksp,lsqr->nwork_n,&lsqr->vwork_n,lsqr->nwork_m,&lsqr->vwork_m);CHKERRQ(ierr);
+  PetscCall(KSPCreateVecs(ksp,lsqr->nwork_n,&lsqr->vwork_n,lsqr->nwork_m,&lsqr->vwork_m));
 
   if (lsqr->se_flg && !lsqr->se) {
-    ierr = VecDuplicate(lsqr->vwork_n[0],&lsqr->se);CHKERRQ(ierr);
-    ierr = VecSet(lsqr->se,PETSC_INFINITY);CHKERRQ(ierr);
+    PetscCall(VecDuplicate(lsqr->vwork_n[0],&lsqr->se));
+    PetscCall(VecSet(lsqr->se,PETSC_INFINITY));
   } else if (!lsqr->se_flg) {
-    ierr = VecDestroy(&lsqr->se);CHKERRQ(ierr);
+    PetscCall(VecDestroy(&lsqr->se));
   }
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode KSPSolve_LSQR(KSP ksp)
 {
-  PetscErrorCode ierr;
   PetscInt       i,size1,size2;
   PetscScalar    rho,rhobar,phi,phibar,theta,c,s,tmp,tau;
   PetscReal      beta,alpha,rnorm;
@@ -79,11 +76,11 @@ static PetscErrorCode KSPSolve_LSQR(KSP ksp)
   PetscBool      diagonalscale,nopreconditioner;
 
   PetscFunctionBegin;
-  ierr = PCGetDiagonalScale(ksp->pc,&diagonalscale);CHKERRQ(ierr);
-  if (diagonalscale) SETERRQ1(PetscObjectComm((PetscObject)ksp),PETSC_ERR_SUP,"Krylov method %s does not support diagonal scaling",((PetscObject)ksp)->type_name);
+  PetscCall(PCGetDiagonalScale(ksp->pc,&diagonalscale));
+  PetscCheck(!diagonalscale,PetscObjectComm((PetscObject)ksp),PETSC_ERR_SUP,"Krylov method %s does not support diagonal scaling",((PetscObject)ksp)->type_name);
 
-  ierr = PCGetOperators(ksp->pc,&Amat,&Pmat);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)ksp->pc,PCNONE,&nopreconditioner);CHKERRQ(ierr);
+  PetscCall(PCGetOperators(ksp->pc,&Amat,&Pmat));
+  PetscCall(PetscObjectTypeCompare((PetscObject)ksp->pc,PCNONE,&nopreconditioner));
 
   /* vectors of length m, where system size is mxn */
   B  = ksp->vec_rhs;
@@ -100,56 +97,56 @@ static PetscErrorCode KSPSolve_LSQR(KSP ksp)
 
   /* standard error vector */
   if (lsqr->se) {
-    ierr = VecSet(lsqr->se,0.0);CHKERRQ(ierr);
+    PetscCall(VecSet(lsqr->se,0.0));
   }
 
   /* Compute initial residual, temporarily use work vector u */
   if (!ksp->guess_zero) {
-    ierr = KSP_MatMult(ksp,Amat,X,U);CHKERRQ(ierr);       /*   u <- b - Ax     */
-    ierr = VecAYPX(U,-1.0,B);CHKERRQ(ierr);
+    PetscCall(KSP_MatMult(ksp,Amat,X,U));       /*   u <- b - Ax     */
+    PetscCall(VecAYPX(U,-1.0,B));
   } else {
-    ierr = VecCopy(B,U);CHKERRQ(ierr);            /*   u <- b (x is 0) */
+    PetscCall(VecCopy(B,U));            /*   u <- b (x is 0) */
   }
 
   /* Test for nothing to do */
-  ierr       = VecNorm(U,NORM_2,&rnorm);CHKERRQ(ierr);
+  PetscCall(VecNorm(U,NORM_2,&rnorm));
   KSPCheckNorm(ksp,rnorm);
-  ierr       = PetscObjectSAWsTakeAccess((PetscObject)ksp);CHKERRQ(ierr);
+  PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
   ksp->its   = 0;
   ksp->rnorm = rnorm;
-  ierr       = PetscObjectSAWsGrantAccess((PetscObject)ksp);CHKERRQ(ierr);
-  ierr = KSPLogResidualHistory(ksp,rnorm);CHKERRQ(ierr);
-  ierr = KSPMonitor(ksp,0,rnorm);CHKERRQ(ierr);
-  ierr = (*ksp->converged)(ksp,0,rnorm,&ksp->reason,ksp->cnvP);CHKERRQ(ierr);
+  PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+  PetscCall(KSPLogResidualHistory(ksp,rnorm));
+  PetscCall(KSPMonitor(ksp,0,rnorm));
+  PetscCall((*ksp->converged)(ksp,0,rnorm,&ksp->reason,ksp->cnvP));
   if (ksp->reason) PetscFunctionReturn(0);
 
   beta = rnorm;
-  ierr = VecScale(U,1.0/beta);CHKERRQ(ierr);
-  ierr = KSP_MatMultHermitianTranspose(ksp,Amat,U,V);CHKERRQ(ierr);
+  PetscCall(VecScale(U,1.0/beta));
+  PetscCall(KSP_MatMultHermitianTranspose(ksp,Amat,U,V));
   if (nopreconditioner) {
-    ierr = VecNorm(V,NORM_2,&alpha);CHKERRQ(ierr);
+    PetscCall(VecNorm(V,NORM_2,&alpha));
     KSPCheckNorm(ksp,rnorm);
   } else {
     /* this is an application of the preconditioner for the normal equations; not the operator, see the manual page */
-    ierr = PCApply(ksp->pc,V,Z);CHKERRQ(ierr);
-    ierr = VecDotRealPart(V,Z,&alpha);CHKERRQ(ierr);
+    PetscCall(PCApply(ksp->pc,V,Z));
+    PetscCall(VecDotRealPart(V,Z,&alpha));
     if (alpha <= 0.0) {
       ksp->reason = KSP_DIVERGED_BREAKDOWN;
       PetscFunctionReturn(0);
     }
     alpha = PetscSqrtReal(alpha);
-    ierr  = VecScale(Z,1.0/alpha);CHKERRQ(ierr);
+    PetscCall(VecScale(Z,1.0/alpha));
   }
-  ierr = VecScale(V,1.0/alpha);CHKERRQ(ierr);
+  PetscCall(VecScale(V,1.0/alpha));
 
   if (nopreconditioner) {
-    ierr = VecCopy(V,W);CHKERRQ(ierr);
+    PetscCall(VecCopy(V,W));
   } else {
-    ierr = VecCopy(Z,W);CHKERRQ(ierr);
+    PetscCall(VecCopy(Z,W));
   }
 
   if (lsqr->exact_norm) {
-    ierr = MatNorm(Amat,NORM_FROBENIUS,&lsqr->anorm);CHKERRQ(ierr);
+    PetscCall(MatNorm(Amat,NORM_FROBENIUS,&lsqr->anorm));
   } else lsqr->anorm = 0.0;
 
   lsqr->arnorm = alpha * beta;
@@ -158,36 +155,36 @@ static PetscErrorCode KSPSolve_LSQR(KSP ksp)
   i            = 0;
   do {
     if (nopreconditioner) {
-      ierr = KSP_MatMult(ksp,Amat,V,U1);CHKERRQ(ierr);
+      PetscCall(KSP_MatMult(ksp,Amat,V,U1));
     } else {
-      ierr = KSP_MatMult(ksp,Amat,Z,U1);CHKERRQ(ierr);
+      PetscCall(KSP_MatMult(ksp,Amat,Z,U1));
     }
-    ierr = VecAXPY(U1,-alpha,U);CHKERRQ(ierr);
-    ierr = VecNorm(U1,NORM_2,&beta);CHKERRQ(ierr);
+    PetscCall(VecAXPY(U1,-alpha,U));
+    PetscCall(VecNorm(U1,NORM_2,&beta));
     KSPCheckNorm(ksp,beta);
     if (beta > 0.0) {
-      ierr = VecScale(U1,1.0/beta);CHKERRQ(ierr); /* beta*U1 = Amat*V - alpha*U */
+      PetscCall(VecScale(U1,1.0/beta)); /* beta*U1 = Amat*V - alpha*U */
       if (!lsqr->exact_norm) {
         lsqr->anorm = PetscSqrtReal(PetscSqr(lsqr->anorm) + PetscSqr(alpha) + PetscSqr(beta));
       }
     }
 
-    ierr = KSP_MatMultHermitianTranspose(ksp,Amat,U1,V1);CHKERRQ(ierr);
-    ierr = VecAXPY(V1,-beta,V);CHKERRQ(ierr);
+    PetscCall(KSP_MatMultHermitianTranspose(ksp,Amat,U1,V1));
+    PetscCall(VecAXPY(V1,-beta,V));
     if (nopreconditioner) {
-      ierr = VecNorm(V1,NORM_2,&alpha);CHKERRQ(ierr);
+      PetscCall(VecNorm(V1,NORM_2,&alpha));
       KSPCheckNorm(ksp,alpha);
     } else {
-      ierr = PCApply(ksp->pc,V1,Z);CHKERRQ(ierr);
-      ierr = VecDotRealPart(V1,Z,&alpha);CHKERRQ(ierr);
+      PetscCall(PCApply(ksp->pc,V1,Z));
+      PetscCall(VecDotRealPart(V1,Z,&alpha));
       if (alpha <= 0.0) {
         ksp->reason = KSP_DIVERGED_BREAKDOWN;
         break;
       }
       alpha = PetscSqrtReal(alpha);
-      ierr  = VecScale(Z,1.0/alpha);CHKERRQ(ierr);
+      PetscCall(VecScale(Z,1.0/alpha));
     }
-    ierr   = VecScale(V1,1.0/alpha);CHKERRQ(ierr); /* alpha*V1 = Amat^T*U1 - beta*V */
+    PetscCall(VecScale(V1,1.0/alpha)); /* alpha*V1 = Amat^T*U1 - beta*V */
     rho    = PetscSqrtScalar(rhobar*rhobar + beta*beta);
     c      = rhobar / rho;
     s      = beta / rho;
@@ -197,30 +194,30 @@ static PetscErrorCode KSPSolve_LSQR(KSP ksp)
     phibar = s * phibar;
     tau    = s * phi;
 
-    ierr = VecAXPY(X,phi/rho,W);CHKERRQ(ierr);  /*    x <- x + (phi/rho) w   */
+    PetscCall(VecAXPY(X,phi/rho,W));  /*    x <- x + (phi/rho) w   */
 
     if (lsqr->se) {
-      ierr = VecCopy(W,W2);CHKERRQ(ierr);
-      ierr = VecSquare(W2);CHKERRQ(ierr);
-      ierr = VecScale(W2,1.0/(rho*rho));CHKERRQ(ierr);
-      ierr = VecAXPY(lsqr->se, 1.0, W2);CHKERRQ(ierr); /* lsqr->se <- lsqr->se + (w^2/rho^2) */
+      PetscCall(VecCopy(W,W2));
+      PetscCall(VecSquare(W2));
+      PetscCall(VecScale(W2,1.0/(rho*rho)));
+      PetscCall(VecAXPY(lsqr->se, 1.0, W2)); /* lsqr->se <- lsqr->se + (w^2/rho^2) */
     }
     if (nopreconditioner) {
-      ierr = VecAYPX(W,-theta/rho,V1);CHKERRQ(ierr);  /* w <- v - (theta/rho) w */
+      PetscCall(VecAYPX(W,-theta/rho,V1));  /* w <- v - (theta/rho) w */
     } else {
-      ierr = VecAYPX(W,-theta/rho,Z);CHKERRQ(ierr);   /* w <- z - (theta/rho) w */
+      PetscCall(VecAYPX(W,-theta/rho,Z));   /* w <- z - (theta/rho) w */
     }
 
     lsqr->arnorm = alpha*PetscAbsScalar(tau);
     rnorm        = PetscRealPart(phibar);
 
-    ierr = PetscObjectSAWsTakeAccess((PetscObject)ksp);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
     ksp->its++;
     ksp->rnorm = rnorm;
-    ierr       = PetscObjectSAWsGrantAccess((PetscObject)ksp);CHKERRQ(ierr);
-    ierr = KSPLogResidualHistory(ksp,rnorm);CHKERRQ(ierr);
-    ierr = KSPMonitor(ksp,i+1,rnorm);CHKERRQ(ierr);
-    ierr = (*ksp->converged)(ksp,i+1,rnorm,&ksp->reason,ksp->cnvP);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+    PetscCall(KSPLogResidualHistory(ksp,rnorm));
+    PetscCall(KSPMonitor(ksp,i+1,rnorm));
+    PetscCall((*ksp->converged)(ksp,i+1,rnorm,&ksp->reason,ksp->cnvP));
     if (ksp->reason) break;
     SWAP(U1,U,TMP);
     SWAP(V1,V,TMP);
@@ -232,11 +229,11 @@ static PetscErrorCode KSPSolve_LSQR(KSP ksp)
   /* Finish off the standard error estimates */
   if (lsqr->se) {
     tmp  = 1.0;
-    ierr = MatGetSize(Amat,&size1,&size2);CHKERRQ(ierr);
+    PetscCall(MatGetSize(Amat,&size1,&size2));
     if (size1 > size2) tmp = size1 - size2;
     tmp  = rnorm / PetscSqrtScalar(tmp);
-    ierr = VecSqrtAbs(lsqr->se);CHKERRQ(ierr);
-    ierr = VecScale(lsqr->se,tmp);CHKERRQ(ierr);
+    PetscCall(VecSqrtAbs(lsqr->se));
+    PetscCall(VecScale(lsqr->se,tmp));
   }
   PetscFunctionReturn(0);
 }
@@ -244,23 +241,22 @@ static PetscErrorCode KSPSolve_LSQR(KSP ksp)
 PetscErrorCode KSPDestroy_LSQR(KSP ksp)
 {
   KSP_LSQR       *lsqr = (KSP_LSQR*)ksp->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   /* Free work vectors */
   if (lsqr->vwork_n) {
-    ierr = VecDestroyVecs(lsqr->nwork_n,&lsqr->vwork_n);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(lsqr->nwork_n,&lsqr->vwork_n));
   }
   if (lsqr->vwork_m) {
-    ierr = VecDestroyVecs(lsqr->nwork_m,&lsqr->vwork_m);CHKERRQ(ierr);
+    PetscCall(VecDestroyVecs(lsqr->nwork_m,&lsqr->vwork_m));
   }
-  ierr = VecDestroy(&lsqr->se);CHKERRQ(ierr);
+  PetscCall(VecDestroy(&lsqr->se));
   /* Revert convergence test */
-  ierr = KSPSetConvergenceTest(ksp,lsqr->converged,lsqr->cnvP,lsqr->convergeddestroy);CHKERRQ(ierr);
+  PetscCall(KSPSetConvergenceTest(ksp,lsqr->converged,lsqr->cnvP,lsqr->convergeddestroy));
   /* Free the KSP_LSQR context */
-  ierr = PetscFree(ksp->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidual_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidualDrawLG_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(ksp->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidual_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidualDrawLG_C",NULL));
   PetscFunctionReturn(0);
 }
 
@@ -388,23 +384,22 @@ PetscErrorCode KSPLSQRMonitorResidual_LSQR(KSP ksp, PetscInt n, PetscReal rnorm,
   char              normtype[256];
   PetscInt          tablevel;
   const char        *prefix;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
-  ierr = PetscObjectGetTabLevel((PetscObject) ksp, &tablevel);CHKERRQ(ierr);
-  ierr = PetscObjectGetOptionsPrefix((PetscObject) ksp, &prefix);CHKERRQ(ierr);
-  ierr = PetscStrncpy(normtype, KSPNormTypes[ksp->normtype], sizeof(normtype));CHKERRQ(ierr);
-  ierr = PetscStrtolower(normtype);CHKERRQ(ierr);
-  ierr = PetscViewerPushFormat(viewer, format);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIAddTab(viewer, tablevel);CHKERRQ(ierr);
-  if (n == 0 && prefix) {ierr = PetscViewerASCIIPrintf(viewer, "  Residual norm, norm of normal equations, and matrix norm for %s solve.\n", prefix);CHKERRQ(ierr);}
+  PetscCall(PetscObjectGetTabLevel((PetscObject) ksp, &tablevel));
+  PetscCall(PetscObjectGetOptionsPrefix((PetscObject) ksp, &prefix));
+  PetscCall(PetscStrncpy(normtype, KSPNormTypes[ksp->normtype], sizeof(normtype)));
+  PetscCall(PetscStrtolower(normtype));
+  PetscCall(PetscViewerPushFormat(viewer, format));
+  PetscCall(PetscViewerASCIIAddTab(viewer, tablevel));
+  if (n == 0 && prefix) PetscCall(PetscViewerASCIIPrintf(viewer, "  Residual norm, norm of normal equations, and matrix norm for %s solve.\n", prefix));
   if (!n) {
-    ierr = PetscViewerASCIIPrintf(viewer,"%3D KSP resid norm %14.12e\n",n,(double)rnorm);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"%3D KSP resid norm %14.12e\n",n,(double)rnorm));
   } else {
-    ierr = PetscViewerASCIIPrintf(viewer,"%3D KSP resid norm %14.12e normal eq resid norm %14.12e matrix norm %14.12e\n",n,(double)rnorm,(double)lsqr->arnorm,(double)lsqr->anorm);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"%3D KSP resid norm %14.12e normal eq resid norm %14.12e matrix norm %14.12e\n",n,(double)rnorm,(double)lsqr->arnorm,(double)lsqr->anorm));
   }
-  ierr = PetscViewerASCIISubtractTab(viewer, tablevel);CHKERRQ(ierr);
-  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscCall(PetscViewerASCIISubtractTab(viewer, tablevel));
+  PetscCall(PetscViewerPopFormat(viewer));
   PetscFunctionReturn(0);
 }
 
@@ -428,13 +423,11 @@ PetscErrorCode KSPLSQRMonitorResidual_LSQR(KSP ksp, PetscInt n, PetscReal rnorm,
 @*/
 PetscErrorCode KSPLSQRMonitorResidual(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidPointer(vf, 4);
   PetscValidHeaderSpecific(vf->viewer, PETSC_VIEWER_CLASSID, 4);
-  ierr = PetscTryMethod(ksp, "KSPLSQRMonitorResidual_C", (KSP,PetscInt,PetscReal,PetscViewerAndFormat*), (ksp,n,rnorm,vf));CHKERRQ(ierr);
+  PetscTryMethod(ksp, "KSPLSQRMonitorResidual_C", (KSP,PetscInt,PetscReal,PetscViewerAndFormat*), (ksp,n,rnorm,vf));
   PetscFunctionReturn(0);
 }
 
@@ -446,24 +439,23 @@ PetscErrorCode KSPLSQRMonitorResidualDrawLG_LSQR(KSP ksp, PetscInt n, PetscReal
   PetscDrawLG        lg     = vf->lg;
   KSPConvergedReason reason;
   PetscReal          x[2], y[2];
-  PetscErrorCode     ierr;
 
   PetscFunctionBegin;
-  ierr = PetscViewerPushFormat(viewer, format);CHKERRQ(ierr);
-  if (!n) {ierr = PetscDrawLGReset(lg);CHKERRQ(ierr);}
+  PetscCall(PetscViewerPushFormat(viewer, format));
+  if (!n) PetscCall(PetscDrawLGReset(lg));
   x[0] = (PetscReal) n;
   if (rnorm > 0.0) y[0] = PetscLog10Real(rnorm);
   else y[0] = -15.0;
   x[1] = (PetscReal) n;
   if (lsqr->arnorm > 0.0) y[1] = PetscLog10Real(lsqr->arnorm);
   else y[1] = -15.0;
-  ierr = PetscDrawLGAddPoint(lg, x, y);CHKERRQ(ierr);
-  ierr = KSPGetConvergedReason(ksp, &reason);CHKERRQ(ierr);
+  PetscCall(PetscDrawLGAddPoint(lg, x, y));
+  PetscCall(KSPGetConvergedReason(ksp, &reason));
   if (n <= 20 || !(n % 5) || reason) {
-    ierr = PetscDrawLGDraw(lg);CHKERRQ(ierr);
-    ierr = PetscDrawLGSave(lg);CHKERRQ(ierr);
+    PetscCall(PetscDrawLGDraw(lg));
+    PetscCall(PetscDrawLGSave(lg));
   }
-  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscCall(PetscViewerPopFormat(viewer));
   PetscFunctionReturn(0);
 }
 
@@ -487,14 +479,12 @@ PetscErrorCode KSPLSQRMonitorResidualDrawLG_LSQR(KSP ksp, PetscInt n, PetscReal
 @*/
 PetscErrorCode KSPLSQRMonitorResidualDrawLG(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidPointer(vf, 4);
   PetscValidHeaderSpecific(vf->viewer, PETSC_VIEWER_CLASSID, 4);
   PetscValidHeaderSpecific(vf->lg, PETSC_DRAWLG_CLASSID, 4);
-  ierr = PetscTryMethod(ksp, "KSPLSQRMonitorResidualDrawLG_C", (KSP,PetscInt,PetscReal,PetscViewerAndFormat*), (ksp,n,rnorm,vf));CHKERRQ(ierr);
+  PetscTryMethod(ksp, "KSPLSQRMonitorResidualDrawLG_C", (KSP,PetscInt,PetscReal,PetscViewerAndFormat*), (ksp,n,rnorm,vf));
   PetscFunctionReturn(0);
 }
 
@@ -518,49 +508,46 @@ PetscErrorCode KSPLSQRMonitorResidualDrawLG(KSP ksp, PetscInt n, PetscReal rnorm
 PetscErrorCode KSPLSQRMonitorResidualDrawLGCreate(PetscViewer viewer, PetscViewerFormat format, void *ctx, PetscViewerAndFormat **vf)
 {
   const char    *names[] = {"residual", "normal eqn residual"};
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscViewerAndFormatCreate(viewer, format, vf);CHKERRQ(ierr);
+  PetscCall(PetscViewerAndFormatCreate(viewer, format, vf));
   (*vf)->data = ctx;
-  ierr = KSPMonitorLGCreate(PetscObjectComm((PetscObject) viewer), NULL, NULL, "Log Residual Norm", 2, names, PETSC_DECIDE, PETSC_DECIDE, 400, 300, &(*vf)->lg);CHKERRQ(ierr);
+  PetscCall(KSPMonitorLGCreate(PetscObjectComm((PetscObject) viewer), NULL, NULL, "Log Residual Norm", 2, names, PETSC_DECIDE, PETSC_DECIDE, 400, 300, &(*vf)->lg));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode KSPSetFromOptions_LSQR(PetscOptionItems *PetscOptionsObject,KSP ksp)
 {
-  PetscErrorCode ierr;
   KSP_LSQR       *lsqr = (KSP_LSQR*)ksp->data;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"KSP LSQR Options");CHKERRQ(ierr);
-  ierr = PetscOptionsBool("-ksp_lsqr_compute_standard_error","Set Standard Error Estimates of Solution","KSPLSQRSetComputeStandardErrorVec",lsqr->se_flg,&lsqr->se_flg,NULL);CHKERRQ(ierr);
-  ierr = PetscOptionsBool("-ksp_lsqr_exact_mat_norm","Compute exact matrix norm instead of iteratively refined estimate","KSPLSQRSetExactMatNorm",lsqr->exact_norm,&lsqr->exact_norm,NULL);CHKERRQ(ierr);
-  ierr = KSPMonitorSetFromOptions(ksp, "-ksp_lsqr_monitor", "lsqr_residual", NULL);CHKERRQ(ierr);
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"KSP LSQR Options"));
+  PetscCall(PetscOptionsBool("-ksp_lsqr_compute_standard_error","Set Standard Error Estimates of Solution","KSPLSQRSetComputeStandardErrorVec",lsqr->se_flg,&lsqr->se_flg,NULL));
+  PetscCall(PetscOptionsBool("-ksp_lsqr_exact_mat_norm","Compute exact matrix norm instead of iteratively refined estimate","KSPLSQRSetExactMatNorm",lsqr->exact_norm,&lsqr->exact_norm,NULL));
+  PetscCall(KSPMonitorSetFromOptions(ksp, "-ksp_lsqr_monitor", "lsqr_residual", NULL));
+  PetscCall(PetscOptionsTail());
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode KSPView_LSQR(KSP ksp,PetscViewer viewer)
 {
   KSP_LSQR       *lsqr = (KSP_LSQR*)ksp->data;
-  PetscErrorCode ierr;
   PetscBool      iascii;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii));
   if (iascii) {
     if (lsqr->se) {
       PetscReal rnorm;
-      ierr = VecNorm(lsqr->se,NORM_2,&rnorm);CHKERRQ(ierr);
-      ierr = PetscViewerASCIIPrintf(viewer,"  norm of standard error %g, iterations %d\n",(double)rnorm,ksp->its);CHKERRQ(ierr);
+      PetscCall(VecNorm(lsqr->se,NORM_2,&rnorm));
+      PetscCall(PetscViewerASCIIPrintf(viewer,"  norm of standard error %g, iterations %d\n",(double)rnorm,ksp->its));
     } else {
-      ierr = PetscViewerASCIIPrintf(viewer,"  standard error not computed\n");CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"  standard error not computed\n"));
     }
     if (lsqr->exact_norm) {
-      ierr = PetscViewerASCIIPrintf(viewer,"  using exact matrix norm\n");CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"  using exact matrix norm\n"));
     } else {
-      ierr = PetscViewerASCIIPrintf(viewer,"  using inexact matrix norm\n");CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIIPrintf(viewer,"  using inexact matrix norm\n"));
     }
   }
   PetscFunctionReturn(0);
@@ -597,20 +584,19 @@ PetscErrorCode KSPView_LSQR(KSP ksp,PetscViewer viewer)
 @*/
 PetscErrorCode  KSPLSQRConvergedDefault(KSP ksp,PetscInt n,PetscReal rnorm,KSPConvergedReason *reason,void *ctx)
 {
-  PetscErrorCode ierr;
   KSP_LSQR       *lsqr = (KSP_LSQR*)ksp->data;
 
   PetscFunctionBegin;
   /* check for convergence in A*x=b */
-  ierr = KSPConvergedDefault(ksp,n,rnorm,reason,ctx);CHKERRQ(ierr);
+  PetscCall(KSPConvergedDefault(ksp,n,rnorm,reason,ctx));
   if (!n || *reason) PetscFunctionReturn(0);
 
   /* check for convergence in min{|b-A*x|} */
   if (lsqr->arnorm < ksp->abstol) {
-    ierr = PetscInfo3(ksp,"LSQR solver has converged. Normal equation residual %14.12e is less than absolute tolerance %14.12e at iteration %D\n",(double)lsqr->arnorm,(double)ksp->abstol,n);CHKERRQ(ierr);
+    PetscCall(PetscInfo(ksp,"LSQR solver has converged. Normal equation residual %14.12e is less than absolute tolerance %14.12e at iteration %D\n",(double)lsqr->arnorm,(double)ksp->abstol,n));
     *reason = KSP_CONVERGED_ATOL_NORMAL;
   } else if (lsqr->arnorm < ksp->rtol * lsqr->anorm * rnorm) {
-    ierr = PetscInfo6(ksp,"LSQR solver has converged. Normal equation residual %14.12e is less than rel. tol. %14.12e times %s Frobenius norm of matrix %14.12e times residual %14.12e at iteration %D\n",(double)lsqr->arnorm,(double)ksp->rtol,lsqr->exact_norm?"exact":"approx.",(double)lsqr->anorm,(double)rnorm,n);CHKERRQ(ierr);
+    PetscCall(PetscInfo(ksp,"LSQR solver has converged. Normal equation residual %14.12e is less than rel. tol. %14.12e times %s Frobenius norm of matrix %14.12e times residual %14.12e at iteration %D\n",(double)lsqr->arnorm,(double)ksp->rtol,lsqr->exact_norm?"exact":"approx.",(double)lsqr->anorm,(double)rnorm,n));
     *reason = KSP_CONVERGED_RTOL_NORMAL;
   }
   PetscFunctionReturn(0);
@@ -640,7 +626,7 @@ PetscErrorCode  KSPLSQRConvergedDefault(KSP ksp,PetscInt n,PetscReal rnorm,KSPCo
      For least squares problems with nonzero residual A*x - b, there are additional convergence tests for the residual of the normal equations, A'*(b - Ax), see KSPLSQRConvergedDefault().
 
    References:
-.  1. - The original unpreconditioned algorithm can be found in Paige and Saunders, ACM Transactions on Mathematical Software, Vol 8, 1982.
+.  * - The original unpreconditioned algorithm can be found in Paige and Saunders, ACM Transactions on Mathematical Software, Vol 8, 1982.
 
      In exact arithmetic the LSQR method (with no preconditioning) is identical to the KSPCG algorithm applied to the normal equations.
      The preconditioned variant was implemented by Bas van't Hof and is essentially a left preconditioning for the Normal Equations. It appears the implementation with preconditioner
@@ -657,17 +643,16 @@ PETSC_EXTERN PetscErrorCode KSPCreate_LSQR(KSP ksp)
 {
   KSP_LSQR       *lsqr;
   void           *ctx;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr         = PetscNewLog(ksp,&lsqr);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(ksp,&lsqr));
   lsqr->se     = NULL;
   lsqr->se_flg = PETSC_FALSE;
   lsqr->exact_norm = PETSC_FALSE;
   lsqr->anorm  = -1.0;
   lsqr->arnorm = -1.0;
   ksp->data    = (void*)lsqr;
-  ierr         = KSPSetSupportedNorm(ksp,KSP_NORM_UNPRECONDITIONED,PC_LEFT,3);CHKERRQ(ierr);
+  PetscCall(KSPSetSupportedNorm(ksp,KSP_NORM_UNPRECONDITIONED,PC_LEFT,3));
 
   ksp->ops->setup          = KSPSetUp_LSQR;
   ksp->ops->solve          = KSPSolve_LSQR;
@@ -676,11 +661,11 @@ PETSC_EXTERN PetscErrorCode KSPCreate_LSQR(KSP ksp)
   ksp->ops->view           = KSPView_LSQR;
 
   /* Backup current convergence test; remove destroy routine from KSP to prevent destroying the convergence context in KSPSetConvergenceTest() */
-  ierr = KSPGetAndClearConvergenceTest(ksp,&lsqr->converged,&lsqr->cnvP,&lsqr->convergeddestroy);CHKERRQ(ierr);
+  PetscCall(KSPGetAndClearConvergenceTest(ksp,&lsqr->converged,&lsqr->cnvP,&lsqr->convergeddestroy));
   /* Override current convergence test */
-  ierr = KSPConvergedDefaultCreate(&ctx);CHKERRQ(ierr);
-  ierr = KSPSetConvergenceTest(ksp,KSPLSQRConvergedDefault,ctx,KSPConvergedDefaultDestroy);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidual_C",KSPLSQRMonitorResidual_LSQR);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidualDrawLG_C",KSPLSQRMonitorResidualDrawLG_LSQR);CHKERRQ(ierr);
+  PetscCall(KSPConvergedDefaultCreate(&ctx));
+  PetscCall(KSPSetConvergenceTest(ksp,KSPLSQRConvergedDefault,ctx,KSPConvergedDefaultDestroy));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidual_C",KSPLSQRMonitorResidual_LSQR));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPLSQRMonitorResidualDrawLG_C",KSPLSQRMonitorResidualDrawLG_LSQR));
   PetscFunctionReturn(0);
 }
