@@ -13,19 +13,17 @@ static PetscErrorCode KSPQCGQuadraticRoots(Vec,Vec,PetscReal,PetscReal*,PetscRea
 -   delta - the trust region radius (Infinity is the default)
 
     Options Database Key:
-.   -ksp_qcg_trustregionradius <delta>
+.   -ksp_qcg_trustregionradius <delta> - trust region radius
 
     Level: advanced
 
 @*/
 PetscErrorCode  KSPQCGSetTrustRegionRadius(KSP ksp,PetscReal delta)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  if (delta < 0.0) SETERRQ(PetscObjectComm((PetscObject)ksp),PETSC_ERR_ARG_OUTOFRANGE,"Tolerance must be non-negative");
-  ierr = PetscTryMethod(ksp,"KSPQCGSetTrustRegionRadius_C",(KSP,PetscReal),(ksp,delta));CHKERRQ(ierr);
+  PetscCheckFalse(delta < 0.0,PetscObjectComm((PetscObject)ksp),PETSC_ERR_ARG_OUTOFRANGE,"Tolerance must be non-negative");
+  PetscTryMethod(ksp,"KSPQCGSetTrustRegionRadius_C",(KSP,PetscReal),(ksp,delta));
   PetscFunctionReturn(0);
 }
 
@@ -45,11 +43,9 @@ PetscErrorCode  KSPQCGSetTrustRegionRadius(KSP ksp,PetscReal delta)
 @*/
 PetscErrorCode  KSPQCGGetTrialStepNorm(KSP ksp,PetscReal *tsnorm)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  ierr = PetscUseMethod(ksp,"KSPQCGGetTrialStepNorm_C",(KSP,PetscReal*),(ksp,tsnorm));CHKERRQ(ierr);
+  PetscUseMethod(ksp,"KSPQCGGetTrialStepNorm_C",(KSP,PetscReal*),(ksp,tsnorm));
   PetscFunctionReturn(0);
 }
 
@@ -81,11 +77,9 @@ PetscErrorCode  KSPQCGGetTrialStepNorm(KSP ksp,PetscReal *tsnorm)
 @*/
 PetscErrorCode  KSPQCGGetQuadratic(KSP ksp,PetscReal *quadratic)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  ierr = PetscUseMethod(ksp,"KSPQCGGetQuadratic_C",(KSP,PetscReal*),(ksp,quadratic));CHKERRQ(ierr);
+  PetscUseMethod(ksp,"KSPQCGGetQuadratic_C",(KSP,PetscReal*),(ksp,quadratic));
   PetscFunctionReturn(0);
 }
 
@@ -105,16 +99,15 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
   PetscReal      q1,q2,xnorm,step1,step2,rnrm = 0.0,btx,xtax;
   PetscReal      ptasp,rtr,wtasp,bstp;
   PetscReal      dzero = 0.0,bsnrm = 0.0;
-  PetscErrorCode ierr;
   PetscInt       i,maxit;
   PC             pc = ksp->pc;
   PCSide         side;
   PetscBool      diagonalscale;
 
   PetscFunctionBegin;
-  ierr = PCGetDiagonalScale(ksp->pc,&diagonalscale);CHKERRQ(ierr);
-  if (diagonalscale) SETERRQ1(PetscObjectComm((PetscObject)ksp),PETSC_ERR_SUP,"Krylov method %s does not support diagonal scaling",((PetscObject)ksp)->type_name);
-  if (ksp->transpose_solve) SETERRQ(PetscObjectComm((PetscObject)ksp),PETSC_ERR_SUP,"Currently does not support transpose solve");
+  PetscCall(PCGetDiagonalScale(ksp->pc,&diagonalscale));
+  PetscCheck(!diagonalscale,PetscObjectComm((PetscObject)ksp),PETSC_ERR_SUP,"Krylov method %s does not support diagonal scaling",((PetscObject)ksp)->type_name);
+  PetscCheck(!ksp->transpose_solve,PetscObjectComm((PetscObject)ksp),PETSC_ERR_SUP,"Currently does not support transpose solve");
 
   ksp->its = 0;
   maxit    = ksp->max_it;
@@ -128,88 +121,88 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
   X        = ksp->vec_sol;
   B        = ksp->vec_rhs;
 
-  if (pcgP->delta <= dzero) SETERRQ(PetscObjectComm((PetscObject)ksp),PETSC_ERR_ARG_OUTOFRANGE,"Input error: delta <= 0");
-  ierr = KSPGetPCSide(ksp,&side);CHKERRQ(ierr);
-  if (side != PC_SYMMETRIC) SETERRQ(PetscObjectComm((PetscObject)ksp),PETSC_ERR_ARG_OUTOFRANGE,"Requires symmetric preconditioner!");
+  PetscCheckFalse(pcgP->delta <= dzero,PetscObjectComm((PetscObject)ksp),PETSC_ERR_ARG_OUTOFRANGE,"Input error: delta <= 0");
+  PetscCall(KSPGetPCSide(ksp,&side));
+  PetscCheckFalse(side != PC_SYMMETRIC,PetscObjectComm((PetscObject)ksp),PETSC_ERR_ARG_OUTOFRANGE,"Requires symmetric preconditioner!");
 
   /* Initialize variables */
-  ierr = VecSet(W,0.0);CHKERRQ(ierr);  /* W = 0 */
-  ierr = VecSet(X,0.0);CHKERRQ(ierr);  /* X = 0 */
-  ierr = PCGetOperators(pc,&Amat,&Pmat);CHKERRQ(ierr);
+  PetscCall(VecSet(W,0.0));  /* W = 0 */
+  PetscCall(VecSet(X,0.0));  /* X = 0 */
+  PetscCall(PCGetOperators(pc,&Amat,&Pmat));
 
   /* Compute:  BS = D^{-1} B */
-  ierr = PCApplySymmetricLeft(pc,B,BS);CHKERRQ(ierr);
+  PetscCall(PCApplySymmetricLeft(pc,B,BS));
 
   if (ksp->normtype != KSP_NORM_NONE) {
-    ierr = VecNorm(BS,NORM_2,&bsnrm);CHKERRQ(ierr);
+    PetscCall(VecNorm(BS,NORM_2,&bsnrm));
     KSPCheckNorm(ksp,bsnrm);
   }
-  ierr       = PetscObjectSAWsTakeAccess((PetscObject)ksp);CHKERRQ(ierr);
+  PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
   ksp->its   = 0;
   ksp->rnorm = bsnrm;
-  ierr       = PetscObjectSAWsGrantAccess((PetscObject)ksp);CHKERRQ(ierr);
-  ierr = KSPLogResidualHistory(ksp,bsnrm);CHKERRQ(ierr);
-  ierr = KSPMonitor(ksp,0,bsnrm);CHKERRQ(ierr);
-  ierr = (*ksp->converged)(ksp,0,bsnrm,&ksp->reason,ksp->cnvP);CHKERRQ(ierr);
+  PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+  PetscCall(KSPLogResidualHistory(ksp,bsnrm));
+  PetscCall(KSPMonitor(ksp,0,bsnrm));
+  PetscCall((*ksp->converged)(ksp,0,bsnrm,&ksp->reason,ksp->cnvP));
   if (ksp->reason) PetscFunctionReturn(0);
 
   /* Compute the initial scaled direction and scaled residual */
-  ierr = VecCopy(BS,R);CHKERRQ(ierr);
-  ierr = VecScale(R,-1.0);CHKERRQ(ierr);
-  ierr = VecCopy(R,P);CHKERRQ(ierr);
-  ierr = VecDotRealPart(R,R,&rtr);CHKERRQ(ierr);
+  PetscCall(VecCopy(BS,R));
+  PetscCall(VecScale(R,-1.0));
+  PetscCall(VecCopy(R,P));
+  PetscCall(VecDotRealPart(R,R,&rtr));
 
   for (i=0; i<=maxit; i++) {
-    ierr = PetscObjectSAWsTakeAccess((PetscObject)ksp);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
     ksp->its++;
-    ierr = PetscObjectSAWsGrantAccess((PetscObject)ksp);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
 
     /* Compute:  asp = D^{-T}*A*D^{-1}*p  */
-    ierr = PCApplySymmetricRight(pc,P,WA);CHKERRQ(ierr);
-    ierr = KSP_MatMult(ksp,Amat,WA,WA2);CHKERRQ(ierr);
-    ierr = PCApplySymmetricLeft(pc,WA2,ASP);CHKERRQ(ierr);
+    PetscCall(PCApplySymmetricRight(pc,P,WA));
+    PetscCall(KSP_MatMult(ksp,Amat,WA,WA2));
+    PetscCall(PCApplySymmetricLeft(pc,WA2,ASP));
 
     /* Check for negative curvature */
-    ierr = VecDotRealPart(P,ASP,&ptasp);CHKERRQ(ierr);
+    PetscCall(VecDotRealPart(P,ASP,&ptasp));
     if (ptasp <= dzero) {
 
       /* Scaled negative curvature direction:  Compute a step so that
         ||w + step*p|| = delta and QS(w + step*p) is least */
 
       if (!i) {
-        ierr = VecCopy(P,X);CHKERRQ(ierr);
-        ierr = VecNorm(X,NORM_2,&xnorm);CHKERRQ(ierr);
+        PetscCall(VecCopy(P,X));
+        PetscCall(VecNorm(X,NORM_2,&xnorm));
         KSPCheckNorm(ksp,xnorm);
         scal = pcgP->delta / xnorm;
-        ierr = VecScale(X,scal);CHKERRQ(ierr);
+        PetscCall(VecScale(X,scal));
       } else {
         /* Compute roots of quadratic */
-        ierr = KSPQCGQuadraticRoots(W,P,pcgP->delta,&step1,&step2);CHKERRQ(ierr);
-        ierr = VecDotRealPart(W,ASP,&wtasp);CHKERRQ(ierr);
-        ierr = VecDotRealPart(BS,P,&bstp);CHKERRQ(ierr);
-        ierr = VecCopy(W,X);CHKERRQ(ierr);
+        PetscCall(KSPQCGQuadraticRoots(W,P,pcgP->delta,&step1,&step2));
+        PetscCall(VecDotRealPart(W,ASP,&wtasp));
+        PetscCall(VecDotRealPart(BS,P,&bstp));
+        PetscCall(VecCopy(W,X));
         q1   = step1*(bstp + wtasp + .5*step1*ptasp);
         q2   = step2*(bstp + wtasp + .5*step2*ptasp);
         if (q1 <= q2) {
-          ierr = VecAXPY(X,step1,P);CHKERRQ(ierr);
+          PetscCall(VecAXPY(X,step1,P));
         } else {
-          ierr = VecAXPY(X,step2,P);CHKERRQ(ierr);
+          PetscCall(VecAXPY(X,step2,P));
         }
       }
       pcgP->ltsnrm = pcgP->delta;                       /* convergence in direction of */
       ksp->reason  = KSP_CONVERGED_CG_NEG_CURVE;  /* negative curvature */
       if (!i) {
-        ierr = PetscInfo1(ksp,"negative curvature: delta=%g\n",(double)pcgP->delta);CHKERRQ(ierr);
+        PetscCall(PetscInfo(ksp,"negative curvature: delta=%g\n",(double)pcgP->delta));
       } else {
-        ierr = PetscInfo3(ksp,"negative curvature: step1=%g, step2=%g, delta=%g\n",(double)step1,(double)step2,(double)pcgP->delta);CHKERRQ(ierr);
+        PetscCall(PetscInfo(ksp,"negative curvature: step1=%g, step2=%g, delta=%g\n",(double)step1,(double)step2,(double)pcgP->delta));
       }
 
     } else {
       /* Compute step along p */
       step = rtr/ptasp;
-      ierr = VecCopy(W,X);CHKERRQ(ierr);        /*  x = w  */
-      ierr = VecAXPY(X,step,P);CHKERRQ(ierr);   /*  x <- step*p + x  */
-      ierr = VecNorm(X,NORM_2,&pcgP->ltsnrm);CHKERRQ(ierr);
+      PetscCall(VecCopy(W,X));        /*  x = w  */
+      PetscCall(VecAXPY(X,step,P));   /*  x <- step*p + x  */
+      PetscCall(VecNorm(X,NORM_2,&pcgP->ltsnrm));
       KSPCheckNorm(ksp,pcgP->ltsnrm);
 
       if (pcgP->ltsnrm > pcgP->delta) {
@@ -219,57 +212,57 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
           The positive step is always better in this case. */
         if (!i) {
           scal = pcgP->delta / pcgP->ltsnrm;
-          ierr = VecScale(X,scal);CHKERRQ(ierr);
+          PetscCall(VecScale(X,scal));
         } else {
           /* Compute roots of quadratic */
-          ierr = KSPQCGQuadraticRoots(W,P,pcgP->delta,&step1,&step2);CHKERRQ(ierr);
-          ierr = VecCopy(W,X);CHKERRQ(ierr);
-          ierr = VecAXPY(X,step1,P);CHKERRQ(ierr);  /*  x <- step1*p + x  */
+          PetscCall(KSPQCGQuadraticRoots(W,P,pcgP->delta,&step1,&step2));
+          PetscCall(VecCopy(W,X));
+          PetscCall(VecAXPY(X,step1,P));  /*  x <- step1*p + x  */
         }
         pcgP->ltsnrm = pcgP->delta;
         ksp->reason  = KSP_CONVERGED_CG_CONSTRAINED; /* convergence along constrained step */
         if (!i) {
-          ierr = PetscInfo1(ksp,"constrained step: delta=%g\n",(double)pcgP->delta);CHKERRQ(ierr);
+          PetscCall(PetscInfo(ksp,"constrained step: delta=%g\n",(double)pcgP->delta));
         } else {
-          ierr = PetscInfo3(ksp,"constrained step: step1=%g, step2=%g, delta=%g\n",(double)step1,(double)step2,(double)pcgP->delta);CHKERRQ(ierr);
+          PetscCall(PetscInfo(ksp,"constrained step: step1=%g, step2=%g, delta=%g\n",(double)step1,(double)step2,(double)pcgP->delta));
         }
 
       } else {
         /* Evaluate the current step */
-        ierr = VecCopy(X,W);CHKERRQ(ierr);  /* update interior iterate */
-        ierr = VecAXPY(R,-step,ASP);CHKERRQ(ierr); /* r <- -step*asp + r */
+        PetscCall(VecCopy(X,W));  /* update interior iterate */
+        PetscCall(VecAXPY(R,-step,ASP)); /* r <- -step*asp + r */
         if (ksp->normtype != KSP_NORM_NONE) {
-          ierr = VecNorm(R,NORM_2,&rnrm);CHKERRQ(ierr);
+          PetscCall(VecNorm(R,NORM_2,&rnrm));
           KSPCheckNorm(ksp,rnrm);
         }
-        ierr       = PetscObjectSAWsTakeAccess((PetscObject)ksp);CHKERRQ(ierr);
+        PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
         ksp->rnorm = rnrm;
-        ierr       = PetscObjectSAWsGrantAccess((PetscObject)ksp);CHKERRQ(ierr);
-        ierr = KSPLogResidualHistory(ksp,rnrm);CHKERRQ(ierr);
-        ierr = KSPMonitor(ksp,i+1,rnrm);CHKERRQ(ierr);
-        ierr = (*ksp->converged)(ksp,i+1,rnrm,&ksp->reason,ksp->cnvP);CHKERRQ(ierr);
+        PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+        PetscCall(KSPLogResidualHistory(ksp,rnrm));
+        PetscCall(KSPMonitor(ksp,i+1,rnrm));
+        PetscCall((*ksp->converged)(ksp,i+1,rnrm,&ksp->reason,ksp->cnvP));
         if (ksp->reason) {                 /* convergence for */
-          ierr = PetscInfo3(ksp,"truncated step: step=%g, rnrm=%g, delta=%g\n",(double)PetscRealPart(step),(double)rnrm,(double)pcgP->delta);CHKERRQ(ierr);
+          PetscCall(PetscInfo(ksp,"truncated step: step=%g, rnrm=%g, delta=%g\n",(double)PetscRealPart(step),(double)rnrm,(double)pcgP->delta));
         }
       }
     }
     if (ksp->reason) break;  /* Convergence has been attained */
     else {                   /* Compute a new AS-orthogonal direction */
-      ierr = VecDot(R,R,&rntrn);CHKERRQ(ierr);
+      PetscCall(VecDot(R,R,&rntrn));
       beta = rntrn/rtr;
-      ierr = VecAYPX(P,beta,R);CHKERRQ(ierr);  /*  p <- r + beta*p  */
+      PetscCall(VecAYPX(P,beta,R));  /*  p <- r + beta*p  */
       rtr  = PetscRealPart(rntrn);
     }
   }
   if (!ksp->reason) ksp->reason = KSP_DIVERGED_ITS;
 
   /* Unscale x */
-  ierr = VecCopy(X,WA2);CHKERRQ(ierr);
-  ierr = PCApplySymmetricRight(pc,WA2,X);CHKERRQ(ierr);
+  PetscCall(VecCopy(X,WA2));
+  PetscCall(PCApplySymmetricRight(pc,WA2,X));
 
-  ierr = KSP_MatMult(ksp,Amat,X,WA);CHKERRQ(ierr);
-  ierr = VecDotRealPart(B,X,&btx);CHKERRQ(ierr);
-  ierr = VecDotRealPart(X,WA,&xtax);CHKERRQ(ierr);
+  PetscCall(KSP_MatMult(ksp,Amat,X,WA));
+  PetscCall(VecDotRealPart(B,X,&btx));
+  PetscCall(VecDotRealPart(X,WA,&xtax));
 
   pcgP->quadratic = btx + .5*xtax;
   PetscFunctionReturn(0);
@@ -277,23 +270,19 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
 
 PetscErrorCode KSPSetUp_QCG(KSP ksp)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   /* Get work vectors from user code */
-  ierr = KSPSetWorkVecs(ksp,7);CHKERRQ(ierr);
+  PetscCall(KSPSetWorkVecs(ksp,7));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode KSPDestroy_QCG(KSP ksp)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetQuadratic_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetTrialStepNorm_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGSetTrustRegionRadius_C",NULL);CHKERRQ(ierr);
-  ierr = KSPDestroyDefault(ksp);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetQuadratic_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetTrialStepNorm_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGSetTrustRegionRadius_C",NULL));
+  PetscCall(KSPDestroyDefault(ksp));
   PetscFunctionReturn(0);
 }
 
@@ -326,16 +315,15 @@ static PetscErrorCode  KSPQCGGetQuadratic_QCG(KSP ksp,PetscReal *quadratic)
 
 PetscErrorCode KSPSetFromOptions_QCG(PetscOptionItems *PetscOptionsObject,KSP ksp)
 {
-  PetscErrorCode ierr;
   PetscReal      delta;
   KSP_QCG        *cgP = (KSP_QCG*)ksp->data;
   PetscBool      flg;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"KSP QCG Options");CHKERRQ(ierr);
-  ierr = PetscOptionsReal("-ksp_qcg_trustregionradius","Trust Region Radius","KSPQCGSetTrustRegionRadius",cgP->delta,&delta,&flg);CHKERRQ(ierr);
-  if (flg) { ierr = KSPQCGSetTrustRegionRadius(ksp,delta);CHKERRQ(ierr); }
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"KSP QCG Options"));
+  PetscCall(PetscOptionsReal("-ksp_qcg_trustregionradius","Trust Region Radius","KSPQCGSetTrustRegionRadius",cgP->delta,&delta,&flg));
+  if (flg) PetscCall(KSPQCGSetTrustRegionRadius(ksp,delta));
+  PetscCall(PetscOptionsTail());
   PetscFunctionReturn(0);
 }
 
@@ -381,7 +369,7 @@ $  other KSP converged/diverged reasons
                 Here L is an incomplete Cholesky factor of H.
 
   References:
-.  1. - Trond Steihaug, The Conjugate Gradient Method and Trust Regions in Large Scale Optimization,
+. * - Trond Steihaug, The Conjugate Gradient Method and Trust Regions in Large Scale Optimization,
    SIAM Journal on Numerical Analysis, Vol. 20, No. 3 (Jun., 1983).
 
 .seealso:  KSPCreate(), KSPSetType(), KSPType (for list of available types), KSP, KSPQCGSetTrustRegionRadius()
@@ -390,13 +378,12 @@ M*/
 
 PETSC_EXTERN PetscErrorCode KSPCreate_QCG(KSP ksp)
 {
-  PetscErrorCode ierr;
   KSP_QCG        *cgP;
 
   PetscFunctionBegin;
-  ierr = KSPSetSupportedNorm(ksp,KSP_NORM_PRECONDITIONED,PC_SYMMETRIC,3);CHKERRQ(ierr);
-  ierr = KSPSetSupportedNorm(ksp,KSP_NORM_NONE,PC_SYMMETRIC,1);CHKERRQ(ierr);
-  ierr = PetscNewLog(ksp,&cgP);CHKERRQ(ierr);
+  PetscCall(KSPSetSupportedNorm(ksp,KSP_NORM_PRECONDITIONED,PC_SYMMETRIC,3));
+  PetscCall(KSPSetSupportedNorm(ksp,KSP_NORM_NONE,PC_SYMMETRIC,1));
+  PetscCall(PetscNewLog(ksp,&cgP));
 
   ksp->data                = (void*)cgP;
   ksp->ops->setup          = KSPSetUp_QCG;
@@ -407,9 +394,9 @@ PETSC_EXTERN PetscErrorCode KSPCreate_QCG(KSP ksp)
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
   ksp->ops->view           = NULL;
 
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetQuadratic_C",KSPQCGGetQuadratic_QCG);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetTrialStepNorm_C",KSPQCGGetTrialStepNorm_QCG);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGSetTrustRegionRadius_C",KSPQCGSetTrustRegionRadius_QCG);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetQuadratic_C",KSPQCGGetQuadratic_QCG));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGGetTrialStepNorm_C",KSPQCGGetTrialStepNorm_QCG));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp,"KSPQCGSetTrustRegionRadius_C",KSPQCGSetTrustRegionRadius_QCG));
   cgP->delta = PETSC_MAX_REAL; /* default trust region radius is infinite */
   PetscFunctionReturn(0);
 }
@@ -435,12 +422,11 @@ PETSC_EXTERN PetscErrorCode KSPCreate_QCG(KSP ksp)
 static PetscErrorCode KSPQCGQuadraticRoots(Vec s,Vec p,PetscReal delta,PetscReal *step1,PetscReal *step2)
 {
   PetscReal      dsq,ptp,pts,rad,sts;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = VecDotRealPart(p,s,&pts);CHKERRQ(ierr);
-  ierr = VecDotRealPart(p,p,&ptp);CHKERRQ(ierr);
-  ierr = VecDotRealPart(s,s,&sts);CHKERRQ(ierr);
+  PetscCall(VecDotRealPart(p,s,&pts));
+  PetscCall(VecDotRealPart(p,p,&ptp));
+  PetscCall(VecDotRealPart(s,s,&sts));
   dsq  = delta*delta;
   rad  = PetscSqrtReal((pts*pts) - ptp*(sts - dsq));
   if (pts > 0.0) {
