@@ -21,10 +21,6 @@ users manual for a discussion of preloading.  Input parameters include\n\
    mpiexec -n <np> ./ex72 -f0 <datafile> -ksp_type cg -pc_type asm -pc_asm_type basic -sub_pc_type icc -mat_type sbaij
  \n\n";
 */
-/*T
-   Concepts: KSP^solving a linear system
-   Processors: n
-T*/
 
 /*
   Include "petscksp.h" so that we can use KSP solvers.  Note that this file
@@ -363,7 +359,7 @@ int main(int argc,char **args)
     PetscCall(VecAXPY(u,-1.0,b));
     PetscCall(VecNorm(u,NORM_2,&norm));
     /*
-     Write output (optinally using table for solver details).
+     Write output (optionally using table for solver details).
       - PetscPrintf() handles output for multiprocessor jobs
         by printing from only one processor in the communicator.
       - KSPView() prints information about the linear solver.
