@@ -16,7 +16,6 @@ typedef struct {
 static PetscErrorCode PCApply_VPBJacobi(PC pc,Vec x,Vec y)
 {
   PC_VPBJacobi      *jac = (PC_VPBJacobi*)pc->data;
-  PetscErrorCode    ierr;
   PetscInt          i,ncnt = 0;
   const MatScalar   *diag = jac->diag;
   PetscInt          ib,jb,bs;
@@ -26,9 +25,9 @@ static PetscErrorCode PCApply_VPBJacobi(PC pc,Vec x,Vec y)
   const PetscInt    *bsizes;
 
   PetscFunctionBegin;
-  ierr = MatGetVariableBlockSizes(pc->pmat,&nblocks,&bsizes);CHKERRQ(ierr);
-  ierr = VecGetArrayRead(x,&xx);CHKERRQ(ierr);
-  ierr = VecGetArray(y,&yy);CHKERRQ(ierr);
+  PetscCall(MatGetVariableBlockSizes(pc->pmat,&nblocks,&bsizes));
+  PetscCall(VecGetArrayRead(x,&xx));
+  PetscCall(VecGetArray(y,&yy));
   for (i=0; i<nblocks; i++) {
     bs = bsizes[i];
     switch (bs) {
@@ -92,8 +91,8 @@ static PetscErrorCode PCApply_VPBJacobi(PC pc,Vec x,Vec y)
     ncnt += bsizes[i];
     diag += bsizes[i]*bsizes[i];
   }
-  ierr = VecRestoreArrayRead(x,&xx);CHKERRQ(ierr);
-  ierr = VecRestoreArray(y,&yy);CHKERRQ(ierr);
+  PetscCall(VecRestoreArrayRead(x,&xx));
+  PetscCall(VecRestoreArray(y,&yy));
   PetscFunctionReturn(0);
 }
 
@@ -101,7 +100,6 @@ static PetscErrorCode PCApply_VPBJacobi(PC pc,Vec x,Vec y)
 static PetscErrorCode PCSetUp_VPBJacobi(PC pc)
 {
   PC_VPBJacobi    *jac = (PC_VPBJacobi*)pc->data;
-  PetscErrorCode ierr;
   Mat            A = pc->pmat;
   MatFactorError err;
   PetscInt       i,nsize = 0,nlocal;
@@ -109,15 +107,15 @@ static PetscErrorCode PCSetUp_VPBJacobi(PC pc)
   const PetscInt *bsizes;
 
   PetscFunctionBegin;
-  ierr = MatGetVariableBlockSizes(pc->pmat,&nblocks,&bsizes);CHKERRQ(ierr);
-  ierr = MatGetLocalSize(pc->pmat,&nlocal,NULL);CHKERRQ(ierr);
-  if (nlocal && !nblocks) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONGSTATE,"Must call MatSetVariableBlockSizes() before using PCVPBJACOBI");
+  PetscCall(MatGetVariableBlockSizes(pc->pmat,&nblocks,&bsizes));
+  PetscCall(MatGetLocalSize(pc->pmat,&nlocal,NULL));
+  PetscCheckFalse(nlocal && !nblocks,PETSC_COMM_SELF,PETSC_ERR_ARG_WRONGSTATE,"Must call MatSetVariableBlockSizes() before using PCVPBJACOBI");
   if (!jac->diag) {
     for (i=0; i<nblocks; i++) nsize += bsizes[i]*bsizes[i];
-    ierr = PetscMalloc1(nsize,&jac->diag);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(nsize,&jac->diag));
   }
-  ierr = MatInvertVariableBlockDiagonal(A,nblocks,bsizes,jac->diag);CHKERRQ(ierr);
-  ierr = MatFactorGetError(A,&err);CHKERRQ(ierr);
+  PetscCall(MatInvertVariableBlockDiagonal(A,nblocks,bsizes,jac->diag));
+  PetscCall(MatFactorGetError(A,&err));
   if (err) pc->failedreason = (PCFailedReason)err;
   pc->ops->apply = PCApply_VPBJacobi;
   PetscFunctionReturn(0);
@@ -126,14 +124,13 @@ static PetscErrorCode PCSetUp_VPBJacobi(PC pc)
 static PetscErrorCode PCDestroy_VPBJacobi(PC pc)
 {
   PC_VPBJacobi    *jac = (PC_VPBJacobi*)pc->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   /*
       Free the private data structure that was hanging off the PC
   */
-  ierr = PetscFree(jac->diag);CHKERRQ(ierr);
-  ierr = PetscFree(pc->data);CHKERRQ(ierr);
+  PetscCall(PetscFree(jac->diag));
+  PetscCall(PetscFree(pc->data));
   PetscFunctionReturn(0);
 }
 
@@ -142,40 +139,40 @@ static PetscErrorCode PCDestroy_VPBJacobi(PC pc)
      PCVPBJACOBI - Variable size point block Jacobi preconditioner
 
    Notes:
-    See PCJACOBI for point Jacobi preconditioning, PCPBJACOBI for fixed point block size, and PCBJACOBI for large size blocks
+     See PCJACOBI for point Jacobi preconditioning, PCPBJACOBI for fixed point block size, and PCBJACOBI for large size blocks
 
-   This works for AIJ matrices
+     This works for AIJ matrices
 
-   Uses dense LU factorization with partial pivoting to invert the blocks; if a zero pivot
-   is detected a PETSc error is generated.
+     Uses dense LU factorization with partial pivoting to invert the blocks; if a zero pivot
+     is detected a PETSc error is generated.
+
+     One must call MatSetVariableBlockSizes() to use this preconditioner
 
-   One must call MatSetVariableBlockSizes() to use this preconditioner
    Developer Notes:
-    This should support the PCSetErrorIfFailure() flag set to PETSC_TRUE to allow
-   the factorization to continue even after a zero pivot is found resulting in a Nan and hence
-   terminating KSP with a KSP_DIVERGED_NANORIF allowing
-   a nonlinear solver/ODE integrator to recover without stopping the program as currently happens.
+     This should support the PCSetErrorIfFailure() flag set to PETSC_TRUE to allow
+     the factorization to continue even after a zero pivot is found resulting in a Nan and hence
+     terminating KSP with a KSP_DIVERGED_NANORIF allowing
+     a nonlinear solver/ODE integrator to recover without stopping the program as currently happens.
 
-   Perhaps should provide an option that allows generation of a valid preconditioner
-   even if a block is singular as the PCJACOBI does.
+     Perhaps should provide an option that allows generation of a valid preconditioner
+     even if a block is singular as the PCJACOBI does.
 
    Level: beginner
 
-.seealso:  MatSetVariableBlockSizes(), PCCreate(), PCSetType(), PCType (for list of available types), PC, PCJACOBI
+.seealso:  MatSetVariableBlockSizes(), PCCreate(), PCSetType(), PCType (for list of available types), PC, PCJACOBI, PCPBJACOBI, PCBJACOBI
 
 M*/
 
 PETSC_EXTERN PetscErrorCode PCCreate_VPBJacobi(PC pc)
 {
   PC_VPBJacobi   *jac;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   /*
      Creates the private data structure for this preconditioner and
      attach it to the PC object.
   */
-  ierr     = PetscNewLog(pc,&jac);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(pc,&jac));
   pc->data = (void*)jac;
 
   /*
@@ -201,4 +198,3 @@ PETSC_EXTERN PetscErrorCode PCCreate_VPBJacobi(PC pc)
   pc->ops->applysymmetricright = NULL;
   PetscFunctionReturn(0);
 }
-
