@@ -21,38 +21,37 @@ static PetscErrorCode MatCreateSubMatrix_MPIAdj_data(Mat adj,IS irows, IS icols,
   PetscSF            sf;
   PetscSFNode       *iremote;
   PetscBool          done;
-  PetscErrorCode     ierr;
 
   PetscFunctionBegin;
-  ierr = PetscObjectGetComm((PetscObject)adj,&comm);CHKERRQ(ierr);
-  ierr = MatGetLayouts(adj,&rmap,NULL);CHKERRQ(ierr);
-  ierr = ISGetLocalSize(irows,&nlrows_is);CHKERRQ(ierr);
-  ierr = ISGetIndices(irows,&irows_indices);CHKERRQ(ierr);
-  ierr = PetscMalloc1(nlrows_is,&iremote);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetComm((PetscObject)adj,&comm));
+  PetscCall(MatGetLayouts(adj,&rmap,NULL));
+  PetscCall(ISGetLocalSize(irows,&nlrows_is));
+  PetscCall(ISGetIndices(irows,&irows_indices));
+  PetscCall(PetscMalloc1(nlrows_is,&iremote));
   /* construct sf graph*/
   nleaves = nlrows_is;
   for (i=0; i<nlrows_is; i++) {
     owner = -1;
     rlocalindex = -1;
-    ierr = PetscLayoutFindOwnerIndex(rmap,irows_indices[i],&owner,&rlocalindex);CHKERRQ(ierr);
+    PetscCall(PetscLayoutFindOwnerIndex(rmap,irows_indices[i],&owner,&rlocalindex));
     iremote[i].rank  = owner;
     iremote[i].index = rlocalindex;
   }
-  ierr = MatGetRowIJ(adj,0,PETSC_FALSE,PETSC_FALSE,&nlrows_mat,&xadj,&adjncy,&done);CHKERRQ(ierr);
-  ierr = PetscCalloc4(nlrows_mat,&ncols_send,nlrows_is,&xadj_recv,nlrows_is+1,&ncols_recv_offsets,nlrows_is,&ncols_recv);CHKERRQ(ierr);
+  PetscCall(MatGetRowIJ(adj,0,PETSC_FALSE,PETSC_FALSE,&nlrows_mat,&xadj,&adjncy,&done));
+  PetscCall(PetscCalloc4(nlrows_mat,&ncols_send,nlrows_is,&xadj_recv,nlrows_is+1,&ncols_recv_offsets,nlrows_is,&ncols_recv));
   nroots = nlrows_mat;
   for (i=0; i<nlrows_mat; i++) {
     ncols_send[i] = xadj[i+1]-xadj[i];
   }
-  ierr = PetscSFCreate(comm,&sf);CHKERRQ(ierr);
-  ierr = PetscSFSetGraph(sf,nroots,nleaves,NULL,PETSC_OWN_POINTER,iremote,PETSC_OWN_POINTER);CHKERRQ(ierr);
-  ierr = PetscSFSetType(sf,PETSCSFBASIC);CHKERRQ(ierr);
-  ierr = PetscSFSetFromOptions(sf);CHKERRQ(ierr);
-  ierr = PetscSFBcastBegin(sf,MPIU_INT,ncols_send,ncols_recv,MPI_REPLACE);CHKERRQ(ierr);
-  ierr = PetscSFBcastEnd(sf,MPIU_INT,ncols_send,ncols_recv,MPI_REPLACE);CHKERRQ(ierr);
-  ierr = PetscSFBcastBegin(sf,MPIU_INT,xadj,xadj_recv,MPI_REPLACE);CHKERRQ(ierr);
-  ierr = PetscSFBcastEnd(sf,MPIU_INT,xadj,xadj_recv,MPI_REPLACE);CHKERRQ(ierr);
-  ierr = PetscSFDestroy(&sf);CHKERRQ(ierr);
+  PetscCall(PetscSFCreate(comm,&sf));
+  PetscCall(PetscSFSetGraph(sf,nroots,nleaves,NULL,PETSC_OWN_POINTER,iremote,PETSC_OWN_POINTER));
+  PetscCall(PetscSFSetType(sf,PETSCSFBASIC));
+  PetscCall(PetscSFSetFromOptions(sf));
+  PetscCall(PetscSFBcastBegin(sf,MPIU_INT,ncols_send,ncols_recv,MPI_REPLACE));
+  PetscCall(PetscSFBcastEnd(sf,MPIU_INT,ncols_send,ncols_recv,MPI_REPLACE));
+  PetscCall(PetscSFBcastBegin(sf,MPIU_INT,xadj,xadj_recv,MPI_REPLACE));
+  PetscCall(PetscSFBcastEnd(sf,MPIU_INT,xadj,xadj_recv,MPI_REPLACE));
+  PetscCall(PetscSFDestroy(&sf));
   Ncols_recv =0;
   for (i=0; i<nlrows_is; i++) {
     Ncols_recv             += ncols_recv[i];
@@ -62,39 +61,39 @@ static PetscErrorCode MatCreateSubMatrix_MPIAdj_data(Mat adj,IS irows, IS icols,
   for (i=0; i<nlrows_mat; i++) {
     Ncols_send += ncols_send[i];
   }
-  ierr = PetscCalloc1(Ncols_recv,&iremote);CHKERRQ(ierr);
-  ierr = PetscCalloc1(Ncols_recv,&adjncy_recv);CHKERRQ(ierr);
+  PetscCall(PetscCalloc1(Ncols_recv,&iremote));
+  PetscCall(PetscCalloc1(Ncols_recv,&adjncy_recv));
   nleaves = Ncols_recv;
   Ncols_recv = 0;
   for (i=0; i<nlrows_is; i++) {
-    ierr = PetscLayoutFindOwner(rmap,irows_indices[i],&owner);CHKERRQ(ierr);
+    PetscCall(PetscLayoutFindOwner(rmap,irows_indices[i],&owner));
     for (j=0; j<ncols_recv[i]; j++) {
       iremote[Ncols_recv].rank    = owner;
       iremote[Ncols_recv++].index = xadj_recv[i]+j;
     }
   }
-  ierr = ISRestoreIndices(irows,&irows_indices);CHKERRQ(ierr);
+  PetscCall(ISRestoreIndices(irows,&irows_indices));
   /*if we need to deal with edge weights ???*/
-  if (a->useedgeweights) {ierr = PetscCalloc1(Ncols_recv,&values_recv);CHKERRQ(ierr);}
+  if (a->useedgeweights) PetscCall(PetscCalloc1(Ncols_recv,&values_recv));
   nroots = Ncols_send;
-  ierr = PetscSFCreate(comm,&sf);CHKERRQ(ierr);
-  ierr = PetscSFSetGraph(sf,nroots,nleaves,NULL,PETSC_OWN_POINTER,iremote,PETSC_OWN_POINTER);CHKERRQ(ierr);
-  ierr = PetscSFSetType(sf,PETSCSFBASIC);CHKERRQ(ierr);
-  ierr = PetscSFSetFromOptions(sf);CHKERRQ(ierr);
-  ierr = PetscSFBcastBegin(sf,MPIU_INT,adjncy,adjncy_recv,MPI_REPLACE);CHKERRQ(ierr);
-  ierr = PetscSFBcastEnd(sf,MPIU_INT,adjncy,adjncy_recv,MPI_REPLACE);CHKERRQ(ierr);
+  PetscCall(PetscSFCreate(comm,&sf));
+  PetscCall(PetscSFSetGraph(sf,nroots,nleaves,NULL,PETSC_OWN_POINTER,iremote,PETSC_OWN_POINTER));
+  PetscCall(PetscSFSetType(sf,PETSCSFBASIC));
+  PetscCall(PetscSFSetFromOptions(sf));
+  PetscCall(PetscSFBcastBegin(sf,MPIU_INT,adjncy,adjncy_recv,MPI_REPLACE));
+  PetscCall(PetscSFBcastEnd(sf,MPIU_INT,adjncy,adjncy_recv,MPI_REPLACE));
   if (a->useedgeweights) {
-    ierr = PetscSFBcastBegin(sf,MPIU_INT,a->values,values_recv,MPI_REPLACE);CHKERRQ(ierr);
-    ierr = PetscSFBcastEnd(sf,MPIU_INT,a->values,values_recv,MPI_REPLACE);CHKERRQ(ierr);
+    PetscCall(PetscSFBcastBegin(sf,MPIU_INT,a->values,values_recv,MPI_REPLACE));
+    PetscCall(PetscSFBcastEnd(sf,MPIU_INT,a->values,values_recv,MPI_REPLACE));
   }
-  ierr = PetscSFDestroy(&sf);CHKERRQ(ierr);
-  ierr = MatRestoreRowIJ(adj,0,PETSC_FALSE,PETSC_FALSE,&nlrows_mat,&xadj,&adjncy,&done);CHKERRQ(ierr);
-  ierr = ISGetLocalSize(icols,&icols_n);CHKERRQ(ierr);
-  ierr = ISGetIndices(icols,&icols_indices);CHKERRQ(ierr);
+  PetscCall(PetscSFDestroy(&sf));
+  PetscCall(MatRestoreRowIJ(adj,0,PETSC_FALSE,PETSC_FALSE,&nlrows_mat,&xadj,&adjncy,&done));
+  PetscCall(ISGetLocalSize(icols,&icols_n));
+  PetscCall(ISGetIndices(icols,&icols_indices));
   rnclos = 0;
   for (i=0; i<nlrows_is; i++) {
     for (j=ncols_recv_offsets[i]; j<ncols_recv_offsets[i+1]; j++) {
-      ierr = PetscFindInt(adjncy_recv[j], icols_n, icols_indices, &loc);CHKERRQ(ierr);
+      PetscCall(PetscFindInt(adjncy_recv[j], icols_n, icols_indices, &loc));
       if (loc<0) {
         adjncy_recv[j] = -1;
         if (a->useedgeweights) values_recv[j] = -1;
@@ -104,10 +103,10 @@ static PetscErrorCode MatCreateSubMatrix_MPIAdj_data(Mat adj,IS irows, IS icols,
       }
     }
   }
-  ierr = ISRestoreIndices(icols,&icols_indices);CHKERRQ(ierr);
-  ierr = PetscCalloc1(rnclos,&sadjncy);CHKERRQ(ierr);
-  if (a->useedgeweights) {ierr = PetscCalloc1(rnclos,&svalues);CHKERRQ(ierr);}
-  ierr = PetscCalloc1(nlrows_is+1,&sxadj);CHKERRQ(ierr);
+  PetscCall(ISRestoreIndices(icols,&icols_indices));
+  PetscCall(PetscCalloc1(rnclos,&sadjncy));
+  if (a->useedgeweights) PetscCall(PetscCalloc1(rnclos,&svalues));
+  PetscCall(PetscCalloc1(nlrows_is+1,&sxadj));
   rnclos = 0;
   for (i=0; i<nlrows_is; i++) {
     for (j=ncols_recv_offsets[i]; j<ncols_recv_offsets[i+1]; j++) {
@@ -120,16 +119,16 @@ static PetscErrorCode MatCreateSubMatrix_MPIAdj_data(Mat adj,IS irows, IS icols,
   for (i=0; i<nlrows_is; i++) {
     sxadj[i+1] = sxadj[i]+ncols_recv[i];
   }
-  if (sadj_xadj)  { *sadj_xadj = sxadj;} else    { ierr = PetscFree(sxadj);CHKERRQ(ierr);}
-  if (sadj_adjncy) { *sadj_adjncy = sadjncy;} else { ierr = PetscFree(sadjncy);CHKERRQ(ierr);}
+  if (sadj_xadj)  { *sadj_xadj = sxadj;} else    PetscCall(PetscFree(sxadj));
+  if (sadj_adjncy) { *sadj_adjncy = sadjncy;} else PetscCall(PetscFree(sadjncy));
   if (sadj_values) {
     if (a->useedgeweights) *sadj_values = svalues; else *sadj_values=NULL;
   } else {
-    if (a->useedgeweights) {ierr = PetscFree(svalues);CHKERRQ(ierr);}
+    if (a->useedgeweights) PetscCall(PetscFree(svalues));
   }
-  ierr = PetscFree4(ncols_send,xadj_recv,ncols_recv_offsets,ncols_recv);CHKERRQ(ierr);
-  ierr = PetscFree(adjncy_recv);CHKERRQ(ierr);
-  if (a->useedgeweights) {ierr = PetscFree(values_recv);CHKERRQ(ierr);}
+  PetscCall(PetscFree4(ncols_send,xadj_recv,ncols_recv_offsets,ncols_recv));
+  PetscCall(PetscFree(adjncy_recv));
+  if (a->useedgeweights) PetscCall(PetscFree(values_recv));
   PetscFunctionReturn(0);
 }
 
@@ -140,7 +139,6 @@ static PetscErrorCode MatCreateSubMatrices_MPIAdj_Private(Mat mat,PetscInt n,con
   PetscMPIInt        issame;
   const PetscInt    *irow_indices,*icol_indices;
   MPI_Comm           scomm_row,scomm_col,scomm_mat;
-  PetscErrorCode     ierr;
 
   PetscFunctionBegin;
   nindx = 0;
@@ -148,127 +146,122 @@ static PetscErrorCode MatCreateSubMatrices_MPIAdj_Private(Mat mat,PetscInt n,con
    * Estimate a maximum number for allocating memory
    */
   for (i=0; i<n; i++) {
-    ierr = ISGetLocalSize(irow[i],&irow_n);CHKERRQ(ierr);
-    ierr = ISGetLocalSize(icol[i],&icol_n);CHKERRQ(ierr);
+    PetscCall(ISGetLocalSize(irow[i],&irow_n));
+    PetscCall(ISGetLocalSize(icol[i],&icol_n));
     nindx = nindx>(irow_n+icol_n)? nindx:(irow_n+icol_n);
   }
-  ierr = PetscMalloc1(nindx,&indices);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(nindx,&indices));
   /* construct a submat */
   for (i=0; i<n; i++) {
     if (subcomm) {
-      ierr = PetscObjectGetComm((PetscObject)irow[i],&scomm_row);CHKERRQ(ierr);
-      ierr = PetscObjectGetComm((PetscObject)icol[i],&scomm_col);CHKERRQ(ierr);
-      ierr = MPI_Comm_compare(scomm_row,scomm_col,&issame);CHKERRMPI(ierr);
-      if (issame != MPI_IDENT) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"row index set must have the same comm as the col index set\n");
-      ierr = MPI_Comm_compare(scomm_row,PETSC_COMM_SELF,&issame);CHKERRMPI(ierr);
-      if (issame == MPI_IDENT) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP," can not use PETSC_COMM_SELF as comm when extracting a parallel submatrix\n");
+      PetscCall(PetscObjectGetComm((PetscObject)irow[i],&scomm_row));
+      PetscCall(PetscObjectGetComm((PetscObject)icol[i],&scomm_col));
+      PetscCallMPI(MPI_Comm_compare(scomm_row,scomm_col,&issame));
+      PetscCheckFalse(issame != MPI_IDENT,PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"row index set must have the same comm as the col index set");
+      PetscCallMPI(MPI_Comm_compare(scomm_row,PETSC_COMM_SELF,&issame));
+      PetscCheckFalse(issame == MPI_IDENT,PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP," can not use PETSC_COMM_SELF as comm when extracting a parallel submatrix");
     } else {
       scomm_row = PETSC_COMM_SELF;
     }
     /*get sub-matrix data*/
     sxadj=NULL; sadjncy=NULL; svalues=NULL;
-    ierr = MatCreateSubMatrix_MPIAdj_data(mat,irow[i],icol[i],&sxadj,&sadjncy,&svalues);CHKERRQ(ierr);
-    ierr = ISGetLocalSize(irow[i],&irow_n);CHKERRQ(ierr);
-    ierr = ISGetLocalSize(icol[i],&icol_n);CHKERRQ(ierr);
-    ierr = ISGetIndices(irow[i],&irow_indices);CHKERRQ(ierr);
-    ierr = PetscArraycpy(indices,irow_indices,irow_n);CHKERRQ(ierr);
-    ierr = ISRestoreIndices(irow[i],&irow_indices);CHKERRQ(ierr);
-    ierr = ISGetIndices(icol[i],&icol_indices);CHKERRQ(ierr);
-    ierr = PetscArraycpy(indices+irow_n,icol_indices,icol_n);CHKERRQ(ierr);
-    ierr = ISRestoreIndices(icol[i],&icol_indices);CHKERRQ(ierr);
+    PetscCall(MatCreateSubMatrix_MPIAdj_data(mat,irow[i],icol[i],&sxadj,&sadjncy,&svalues));
+    PetscCall(ISGetLocalSize(irow[i],&irow_n));
+    PetscCall(ISGetLocalSize(icol[i],&icol_n));
+    PetscCall(ISGetIndices(irow[i],&irow_indices));
+    PetscCall(PetscArraycpy(indices,irow_indices,irow_n));
+    PetscCall(ISRestoreIndices(irow[i],&irow_indices));
+    PetscCall(ISGetIndices(icol[i],&icol_indices));
+    PetscCall(PetscArraycpy(indices+irow_n,icol_indices,icol_n));
+    PetscCall(ISRestoreIndices(icol[i],&icol_indices));
     nindx = irow_n+icol_n;
-    ierr = PetscSortRemoveDupsInt(&nindx,indices);CHKERRQ(ierr);
+    PetscCall(PetscSortRemoveDupsInt(&nindx,indices));
     /* renumber columns */
     for (j=0; j<irow_n; j++) {
       for (k=sxadj[j]; k<sxadj[j+1]; k++) {
-        ierr = PetscFindInt(sadjncy[k],nindx,indices,&loc);CHKERRQ(ierr);
-        if (loc<0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"can not find col %D",sadjncy[k]);
+        PetscCall(PetscFindInt(sadjncy[k],nindx,indices,&loc));
+        PetscCheckFalse(loc<0,PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"can not find col %" PetscInt_FMT,sadjncy[k]);
         sadjncy[k] = loc;
       }
     }
     if (scall==MAT_INITIAL_MATRIX) {
-      ierr = MatCreateMPIAdj(scomm_row,irow_n,icol_n,sxadj,sadjncy,svalues,submat[i]);CHKERRQ(ierr);
+      PetscCall(MatCreateMPIAdj(scomm_row,irow_n,icol_n,sxadj,sadjncy,svalues,submat[i]));
     } else {
        Mat                sadj = *(submat[i]);
        Mat_MPIAdj         *sa  = (Mat_MPIAdj*)((sadj)->data);
-       ierr = PetscObjectGetComm((PetscObject)sadj,&scomm_mat);CHKERRQ(ierr);
-       ierr = MPI_Comm_compare(scomm_row,scomm_mat,&issame);CHKERRMPI(ierr);
-       if (issame != MPI_IDENT) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"submatrix  must have the same comm as the col index set\n");
-       ierr = PetscArraycpy(sa->i,sxadj,irow_n+1);CHKERRQ(ierr);
-       ierr = PetscArraycpy(sa->j,sadjncy,sxadj[irow_n]);CHKERRQ(ierr);
-       if (svalues) {ierr = PetscArraycpy(sa->values,svalues,sxadj[irow_n]);CHKERRQ(ierr);}
-       ierr = PetscFree(sxadj);CHKERRQ(ierr);
-       ierr = PetscFree(sadjncy);CHKERRQ(ierr);
-       if (svalues) {ierr = PetscFree(svalues);CHKERRQ(ierr);}
+       PetscCall(PetscObjectGetComm((PetscObject)sadj,&scomm_mat));
+       PetscCallMPI(MPI_Comm_compare(scomm_row,scomm_mat,&issame));
+       PetscCheckFalse(issame != MPI_IDENT,PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"submatrix  must have the same comm as the col index set");
+       PetscCall(PetscArraycpy(sa->i,sxadj,irow_n+1));
+       PetscCall(PetscArraycpy(sa->j,sadjncy,sxadj[irow_n]));
+       if (svalues) PetscCall(PetscArraycpy(sa->values,svalues,sxadj[irow_n]));
+       PetscCall(PetscFree(sxadj));
+       PetscCall(PetscFree(sadjncy));
+       if (svalues) PetscCall(PetscFree(svalues));
     }
   }
-  ierr = PetscFree(indices);CHKERRQ(ierr);
+  PetscCall(PetscFree(indices));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatCreateSubMatricesMPI_MPIAdj(Mat mat,PetscInt n, const IS irow[],const IS icol[],MatReuse scall,Mat *submat[])
 {
-  PetscErrorCode     ierr;
   /*get sub-matrices across a sub communicator */
   PetscFunctionBegin;
-  ierr = MatCreateSubMatrices_MPIAdj_Private(mat,n,irow,icol,PETSC_TRUE,scall,submat);CHKERRQ(ierr);
+  PetscCall(MatCreateSubMatrices_MPIAdj_Private(mat,n,irow,icol,PETSC_TRUE,scall,submat));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatCreateSubMatrices_MPIAdj(Mat mat,PetscInt n,const IS irow[],const IS icol[],MatReuse scall,Mat *submat[])
 {
-  PetscErrorCode     ierr;
-
   PetscFunctionBegin;
   /*get sub-matrices based on PETSC_COMM_SELF */
-  ierr = MatCreateSubMatrices_MPIAdj_Private(mat,n,irow,icol,PETSC_FALSE,scall,submat);CHKERRQ(ierr);
+  PetscCall(MatCreateSubMatrices_MPIAdj_Private(mat,n,irow,icol,PETSC_FALSE,scall,submat));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatView_MPIAdj_ASCII(Mat A,PetscViewer viewer)
 {
   Mat_MPIAdj        *a = (Mat_MPIAdj*)A->data;
-  PetscErrorCode    ierr;
   PetscInt          i,j,m = A->rmap->n;
   const char        *name;
   PetscViewerFormat format;
 
   PetscFunctionBegin;
-  ierr = PetscObjectGetName((PetscObject)A,&name);CHKERRQ(ierr);
-  ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetName((PetscObject)A,&name));
+  PetscCall(PetscViewerGetFormat(viewer,&format));
   if (format == PETSC_VIEWER_ASCII_INFO) {
     PetscFunctionReturn(0);
-  } else if (format == PETSC_VIEWER_ASCII_MATLAB) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_SUP,"MATLAB format not supported");
+  } else PetscCheckFalse(format == PETSC_VIEWER_ASCII_MATLAB,PetscObjectComm((PetscObject)A),PETSC_ERR_SUP,"MATLAB format not supported");
   else {
-    ierr = PetscViewerASCIIUseTabs(viewer,PETSC_FALSE);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPushSynchronized(viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_FALSE));
+    PetscCall(PetscViewerASCIIPushSynchronized(viewer));
     for (i=0; i<m; i++) {
-      ierr = PetscViewerASCIISynchronizedPrintf(viewer,"row %D:",i+A->rmap->rstart);CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"row %" PetscInt_FMT ":",i+A->rmap->rstart));
       for (j=a->i[i]; j<a->i[i+1]; j++) {
         if (a->values) {
-          ierr = PetscViewerASCIISynchronizedPrintf(viewer," (%D, %D) ",a->j[j], a->values[j]);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer," (%" PetscInt_FMT ", %" PetscInt_FMT ") ",a->j[j], a->values[j]));
         } else {
-          ierr = PetscViewerASCIISynchronizedPrintf(viewer," %D ",a->j[j]);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer," %" PetscInt_FMT " ",a->j[j]));
         }
       }
-      ierr = PetscViewerASCIISynchronizedPrintf(viewer,"\n");CHKERRQ(ierr);
+      PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"\n"));
     }
-    ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
-    ierr = PetscViewerFlush(viewer);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPopSynchronized(viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_TRUE));
+    PetscCall(PetscViewerFlush(viewer));
+    PetscCall(PetscViewerASCIIPopSynchronized(viewer));
   }
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatView_MPIAdj(Mat A,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
   PetscBool      iascii;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii));
   if (iascii) {
-    ierr = MatView_MPIAdj_ASCII(A,viewer);CHKERRQ(ierr);
+    PetscCall(MatView_MPIAdj_ASCII(A,viewer));
   }
   PetscFunctionReturn(0);
 }
@@ -276,35 +269,33 @@ static PetscErrorCode MatView_MPIAdj(Mat A,PetscViewer viewer)
 static PetscErrorCode MatDestroy_MPIAdj(Mat mat)
 {
   Mat_MPIAdj     *a = (Mat_MPIAdj*)mat->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
 #if defined(PETSC_USE_LOG)
-  PetscLogObjectState((PetscObject)mat,"Rows=%D, Cols=%D, NZ=%D",mat->rmap->n,mat->cmap->n,a->nz);
+  PetscLogObjectState((PetscObject)mat,"Rows=%" PetscInt_FMT ", Cols=%" PetscInt_FMT ", NZ=%" PetscInt_FMT,mat->rmap->n,mat->cmap->n,a->nz);
 #endif
-  ierr = PetscFree(a->diag);CHKERRQ(ierr);
+  PetscCall(PetscFree(a->diag));
   if (a->freeaij) {
     if (a->freeaijwithfree) {
       if (a->i) free(a->i);
       if (a->j) free(a->j);
     } else {
-      ierr = PetscFree(a->i);CHKERRQ(ierr);
-      ierr = PetscFree(a->j);CHKERRQ(ierr);
-      ierr = PetscFree(a->values);CHKERRQ(ierr);
+      PetscCall(PetscFree(a->i));
+      PetscCall(PetscFree(a->j));
+      PetscCall(PetscFree(a->values));
     }
   }
-  ierr = PetscFree(a->rowvalues);CHKERRQ(ierr);
-  ierr = PetscFree(mat->data);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)mat,NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMPIAdjSetPreallocation_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMPIAdjCreateNonemptySubcommMat_C",NULL);CHKERRQ(ierr);
+  PetscCall(PetscFree(a->rowvalues));
+  PetscCall(PetscFree(mat->data));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)mat,NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)mat,"MatMPIAdjSetPreallocation_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)mat,"MatMPIAdjCreateNonemptySubcommMat_C",NULL));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatSetOption_MPIAdj(Mat A,MatOption op,PetscBool flg)
 {
   Mat_MPIAdj     *a = (Mat_MPIAdj*)A->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   switch (op) {
@@ -316,7 +307,7 @@ static PetscErrorCode MatSetOption_MPIAdj(Mat A,MatOption op,PetscBool flg)
   case MAT_SYMMETRY_ETERNAL:
     break;
   default:
-    ierr = PetscInfo1(A,"Option %s ignored\n",MatOptions[op]);CHKERRQ(ierr);
+    PetscCall(PetscInfo(A,"Option %s ignored\n",MatOptions[op]));
     break;
   }
   PetscFunctionReturn(0);
@@ -325,18 +316,17 @@ static PetscErrorCode MatSetOption_MPIAdj(Mat A,MatOption op,PetscBool flg)
 static PetscErrorCode MatGetRow_MPIAdj(Mat A,PetscInt row,PetscInt *nz,PetscInt **idx,PetscScalar **v)
 {
   Mat_MPIAdj *a = (Mat_MPIAdj*)A->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   row -= A->rmap->rstart;
-  if (row < 0 || row >= A->rmap->n) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Row out of range");
+  PetscCheckFalse(row < 0 || row >= A->rmap->n,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Row out of range");
   *nz = a->i[row+1] - a->i[row];
   if (v) {
     PetscInt j;
     if (a->rowvalues_alloc < *nz) {
-      ierr = PetscFree(a->rowvalues);CHKERRQ(ierr);
+      PetscCall(PetscFree(a->rowvalues));
       a->rowvalues_alloc = PetscMax(a->rowvalues_alloc*2, *nz);
-      ierr = PetscMalloc1(a->rowvalues_alloc,&a->rowvalues);CHKERRQ(ierr);
+      PetscCall(PetscMalloc1(a->rowvalues_alloc,&a->rowvalues));
     }
     for (j=0; j<*nz; j++) {
       a->rowvalues[j] = a->values ? a->values[a->i[row]+j]:1.0;
@@ -356,7 +346,6 @@ static PetscErrorCode MatRestoreRow_MPIAdj(Mat A,PetscInt row,PetscInt *nz,Petsc
 static PetscErrorCode MatEqual_MPIAdj(Mat A,Mat B,PetscBool * flg)
 {
   Mat_MPIAdj     *a = (Mat_MPIAdj*)A->data,*b = (Mat_MPIAdj*)B->data;
-  PetscErrorCode ierr;
   PetscBool      flag;
 
   PetscFunctionBegin;
@@ -366,12 +355,12 @@ static PetscErrorCode MatEqual_MPIAdj(Mat A,Mat B,PetscBool * flg)
   }
 
   /* if the a->i are the same */
-  ierr = PetscArraycmp(a->i,b->i,A->rmap->n+1,&flag);CHKERRQ(ierr);
+  PetscCall(PetscArraycmp(a->i,b->i,A->rmap->n+1,&flag));
 
   /* if a->j are the same */
-  ierr = PetscMemcmp(a->j,b->j,(a->nz)*sizeof(PetscInt),&flag);CHKERRQ(ierr);
+  PetscCall(PetscMemcmp(a->j,b->j,(a->nz)*sizeof(PetscInt),&flag));
 
-  ierr = MPIU_Allreduce(&flag,flg,1,MPIU_BOOL,MPI_LAND,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+  PetscCall(MPIU_Allreduce(&flag,flg,1,MPIU_BOOL,MPI_LAND,PetscObjectComm((PetscObject)A)));
   PetscFunctionReturn(0);
 }
 
@@ -402,11 +391,11 @@ static PetscErrorCode MatRestoreRowIJ_MPIAdj(Mat A,PetscInt oshift,PetscBool sym
   PetscInt   **ia = (PetscInt**)inia,**ja = (PetscInt**)inja;
 
   PetscFunctionBegin;
-  if (ia && a->i != *ia) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"ia passed back is not one obtained with MatGetRowIJ()");
-  if (ja && a->j != *ja) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"ja passed back is not one obtained with MatGetRowIJ()");
+  PetscCheckFalse(ia && a->i != *ia,PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"ia passed back is not one obtained with MatGetRowIJ()");
+  PetscCheckFalse(ja && a->j != *ja,PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"ja passed back is not one obtained with MatGetRowIJ()");
   if (oshift) {
-    if (!ia) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"If oshift then you must passed in inia[] argument");
-    if (!ja) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"If oshift then you must passed in inja[] argument");
+    PetscCheck(ia,PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"If oshift then you must passed in inia[] argument");
+    PetscCheck(ja,PetscObjectComm((PetscObject)A),PETSC_ERR_ARG_WRONGSTATE,"If oshift then you must passed in inja[] argument");
     for (i=0; i<=(*m); i++) (*ia)[i]--;
     for (i=0; i<(*ia)[*m]; i++) {
       (*ja)[i]--;
@@ -418,36 +407,35 @@ static PetscErrorCode MatRestoreRowIJ_MPIAdj(Mat A,PetscInt oshift,PetscBool sym
 PetscErrorCode  MatConvertFrom_MPIAdj(Mat A,MatType type,MatReuse reuse,Mat *newmat)
 {
   Mat               B;
-  PetscErrorCode    ierr;
   PetscInt          i,m,N,nzeros = 0,*ia,*ja,len,rstart,cnt,j,*a;
   const PetscInt    *rj;
   const PetscScalar *ra;
   MPI_Comm          comm;
 
   PetscFunctionBegin;
-  ierr = MatGetSize(A,NULL,&N);CHKERRQ(ierr);
-  ierr = MatGetLocalSize(A,&m,NULL);CHKERRQ(ierr);
-  ierr = MatGetOwnershipRange(A,&rstart,NULL);CHKERRQ(ierr);
+  PetscCall(MatGetSize(A,NULL,&N));
+  PetscCall(MatGetLocalSize(A,&m,NULL));
+  PetscCall(MatGetOwnershipRange(A,&rstart,NULL));
 
   /* count the number of nonzeros per row */
   for (i=0; i<m; i++) {
-    ierr = MatGetRow(A,i+rstart,&len,&rj,NULL);CHKERRQ(ierr);
+    PetscCall(MatGetRow(A,i+rstart,&len,&rj,NULL));
     for (j=0; j<len; j++) {
       if (rj[j] == i+rstart) {len--; break;}    /* don't count diagonal */
     }
     nzeros += len;
-    ierr    = MatRestoreRow(A,i+rstart,&len,&rj,NULL);CHKERRQ(ierr);
+    PetscCall(MatRestoreRow(A,i+rstart,&len,&rj,NULL));
   }
 
   /* malloc space for nonzeros */
-  ierr = PetscMalloc1(nzeros+1,&a);CHKERRQ(ierr);
-  ierr = PetscMalloc1(N+1,&ia);CHKERRQ(ierr);
-  ierr = PetscMalloc1(nzeros+1,&ja);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(nzeros+1,&a));
+  PetscCall(PetscMalloc1(N+1,&ia));
+  PetscCall(PetscMalloc1(nzeros+1,&ja));
 
   nzeros = 0;
   ia[0]  = 0;
   for (i=0; i<m; i++) {
-    ierr = MatGetRow(A,i+rstart,&len,&rj,&ra);CHKERRQ(ierr);
+    PetscCall(MatGetRow(A,i+rstart,&len,&rj,&ra));
     cnt  = 0;
     for (j=0; j<len; j++) {
       if (rj[j] != i+rstart) { /* if not diagonal */
@@ -455,19 +443,19 @@ PetscErrorCode  MatConvertFrom_MPIAdj(Mat A,MatType type,MatReuse reuse,Mat *new
         ja[nzeros+cnt++] = rj[j];
       }
     }
-    ierr    = MatRestoreRow(A,i+rstart,&len,&rj,&ra);CHKERRQ(ierr);
+    PetscCall(MatRestoreRow(A,i+rstart,&len,&rj,&ra));
     nzeros += cnt;
     ia[i+1] = nzeros;
   }
 
-  ierr = PetscObjectGetComm((PetscObject)A,&comm);CHKERRQ(ierr);
-  ierr = MatCreate(comm,&B);CHKERRQ(ierr);
-  ierr = MatSetSizes(B,m,PETSC_DETERMINE,PETSC_DETERMINE,N);CHKERRQ(ierr);
-  ierr = MatSetType(B,type);CHKERRQ(ierr);
-  ierr = MatMPIAdjSetPreallocation(B,ia,ja,a);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetComm((PetscObject)A,&comm));
+  PetscCall(MatCreate(comm,&B));
+  PetscCall(MatSetSizes(B,m,PETSC_DETERMINE,PETSC_DETERMINE,N));
+  PetscCall(MatSetType(B,type));
+  PetscCall(MatMPIAdjSetPreallocation(B,ia,ja,a));
 
   if (reuse == MAT_INPLACE_MATRIX) {
-    ierr = MatHeaderReplace(A,&B);CHKERRQ(ierr);
+    PetscCall(MatHeaderReplace(A,&B));
   } else {
     *newmat = B;
   }
@@ -615,6 +603,12 @@ static struct _MatOps MatOps_Values = {NULL,
                                        NULL,
                                        NULL,
                                /*139*/ NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                /*144*/NULL,
+                                       NULL,
                                        NULL,
                                        NULL
 };
@@ -623,24 +617,23 @@ static PetscErrorCode  MatMPIAdjSetPreallocation_MPIAdj(Mat B,PetscInt *i,PetscI
 {
   Mat_MPIAdj     *b = (Mat_MPIAdj*)B->data;
   PetscBool       useedgeweights;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutSetUp(B->rmap);CHKERRQ(ierr);
-  ierr = PetscLayoutSetUp(B->cmap);CHKERRQ(ierr);
+  PetscCall(PetscLayoutSetUp(B->rmap));
+  PetscCall(PetscLayoutSetUp(B->cmap));
   if (values) useedgeweights = PETSC_TRUE; else useedgeweights = PETSC_FALSE;
   /* Make everybody knows if they are using edge weights or not */
-  ierr = MPIU_Allreduce((int*)&useedgeweights,(int*)&b->useedgeweights,1,MPI_INT,MPI_MAX,PetscObjectComm((PetscObject)B));CHKERRMPI(ierr);
+  PetscCall(MPIU_Allreduce((int*)&useedgeweights,(int*)&b->useedgeweights,1,MPI_INT,MPI_MAX,PetscObjectComm((PetscObject)B)));
 
   if (PetscDefined(USE_DEBUG)) {
     PetscInt ii;
 
-    if (i[0] != 0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"First i[] index must be zero, instead it is %D\n",i[0]);
+    PetscCheckFalse(i[0] != 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"First i[] index must be zero, instead it is %" PetscInt_FMT,i[0]);
     for (ii=1; ii<B->rmap->n; ii++) {
-      if (i[ii] < 0 || i[ii] < i[ii-1]) SETERRQ4(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"i[%D]=%D index is out of range: i[%D]=%D",ii,i[ii],ii-1,i[ii-1]);
+      PetscCheckFalse(i[ii] < 0 || i[ii] < i[ii-1],PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"i[%" PetscInt_FMT "]=%" PetscInt_FMT " index is out of range: i[%" PetscInt_FMT "]=%" PetscInt_FMT,ii,i[ii],ii-1,i[ii-1]);
     }
     for (ii=0; ii<i[B->rmap->n]; ii++) {
-      if (j[ii] < 0 || j[ii] >= B->cmap->N) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Column index %D out of range %D\n",ii,j[ii]);
+      PetscCheckFalse(j[ii] < 0 || j[ii] >= B->cmap->N,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Column index %" PetscInt_FMT " out of range %" PetscInt_FMT,ii,j[ii]);
     }
   }
   B->preallocated = PETSC_TRUE;
@@ -654,15 +647,14 @@ static PetscErrorCode  MatMPIAdjSetPreallocation_MPIAdj(Mat B,PetscInt *i,PetscI
   b->symmetric = PETSC_FALSE;
   b->freeaij   = PETSC_TRUE;
 
-  ierr = MatAssemblyBegin(B,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(B,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(B,MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(B,MAT_FINAL_ASSEMBLY));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode MatMPIAdjCreateNonemptySubcommMat_MPIAdj(Mat A,Mat *B)
 {
   Mat_MPIAdj     *a = (Mat_MPIAdj*)A->data;
-  PetscErrorCode ierr;
   const PetscInt *ranges;
   MPI_Comm       acomm,bcomm;
   MPI_Group      agroup,bgroup;
@@ -670,84 +662,83 @@ static PetscErrorCode MatMPIAdjCreateNonemptySubcommMat_MPIAdj(Mat A,Mat *B)
 
   PetscFunctionBegin;
   *B    = NULL;
-  ierr  = PetscObjectGetComm((PetscObject)A,&acomm);CHKERRQ(ierr);
-  ierr  = MPI_Comm_size(acomm,&size);CHKERRMPI(ierr);
-  ierr  = MPI_Comm_size(acomm,&rank);CHKERRMPI(ierr);
-  ierr  = MatGetOwnershipRanges(A,&ranges);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetComm((PetscObject)A,&acomm));
+  PetscCallMPI(MPI_Comm_size(acomm,&size));
+  PetscCallMPI(MPI_Comm_size(acomm,&rank));
+  PetscCall(MatGetOwnershipRanges(A,&ranges));
   for (i=0,nranks=0; i<size; i++) {
     if (ranges[i+1] - ranges[i] > 0) nranks++;
   }
   if (nranks == size) {         /* All ranks have a positive number of rows, so we do not need to create a subcomm; */
-    ierr = PetscObjectReference((PetscObject)A);CHKERRQ(ierr);
+    PetscCall(PetscObjectReference((PetscObject)A));
     *B   = A;
     PetscFunctionReturn(0);
   }
 
-  ierr = PetscMalloc1(nranks,&ranks);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(nranks,&ranks));
   for (i=0,nranks=0; i<size; i++) {
     if (ranges[i+1] - ranges[i] > 0) ranks[nranks++] = i;
   }
-  ierr = MPI_Comm_group(acomm,&agroup);CHKERRMPI(ierr);
-  ierr = MPI_Group_incl(agroup,nranks,ranks,&bgroup);CHKERRMPI(ierr);
-  ierr = PetscFree(ranks);CHKERRQ(ierr);
-  ierr = MPI_Comm_create(acomm,bgroup,&bcomm);CHKERRMPI(ierr);
-  ierr = MPI_Group_free(&agroup);CHKERRMPI(ierr);
-  ierr = MPI_Group_free(&bgroup);CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Comm_group(acomm,&agroup));
+  PetscCallMPI(MPI_Group_incl(agroup,nranks,ranks,&bgroup));
+  PetscCall(PetscFree(ranks));
+  PetscCallMPI(MPI_Comm_create(acomm,bgroup,&bcomm));
+  PetscCallMPI(MPI_Group_free(&agroup));
+  PetscCallMPI(MPI_Group_free(&bgroup));
   if (bcomm != MPI_COMM_NULL) {
     PetscInt   m,N;
     Mat_MPIAdj *b;
-    ierr       = MatGetLocalSize(A,&m,NULL);CHKERRQ(ierr);
-    ierr       = MatGetSize(A,NULL,&N);CHKERRQ(ierr);
-    ierr       = MatCreateMPIAdj(bcomm,m,N,a->i,a->j,a->values,B);CHKERRQ(ierr);
+    PetscCall(MatGetLocalSize(A,&m,NULL));
+    PetscCall(MatGetSize(A,NULL,&N));
+    PetscCall(MatCreateMPIAdj(bcomm,m,N,a->i,a->j,a->values,B));
     b          = (Mat_MPIAdj*)(*B)->data;
     b->freeaij = PETSC_FALSE;
-    ierr       = MPI_Comm_free(&bcomm);CHKERRMPI(ierr);
+    PetscCallMPI(MPI_Comm_free(&bcomm));
   }
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode  MatMPIAdjToSeq_MPIAdj(Mat A,Mat *B)
 {
-  PetscErrorCode ierr;
   PetscInt       M,N,*II,*J,NZ,nz,m,nzstart,i;
   PetscInt       *Values = NULL;
   Mat_MPIAdj     *adj = (Mat_MPIAdj*)A->data;
   PetscMPIInt    mnz,mm,*allnz,*allm,size,*dispnz,*dispm;
 
   PetscFunctionBegin;
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)A),&size);CHKERRMPI(ierr);
-  ierr = MatGetSize(A,&M,&N);CHKERRQ(ierr);
-  ierr = MatGetLocalSize(A,&m,NULL);CHKERRQ(ierr);
+  PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)A),&size));
+  PetscCall(MatGetSize(A,&M,&N));
+  PetscCall(MatGetLocalSize(A,&m,NULL));
   nz   = adj->nz;
-  if (adj->i[m] != nz) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_PLIB,"nz %D not correct i[m] %d",nz,adj->i[m]);
-  ierr = MPI_Allreduce(&nz,&NZ,1,MPIU_INT,MPI_SUM,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+  PetscCheckFalse(adj->i[m] != nz,PETSC_COMM_SELF,PETSC_ERR_PLIB,"nz %" PetscInt_FMT " not correct i[m] %" PetscInt_FMT,nz,adj->i[m]);
+  PetscCallMPI(MPI_Allreduce(&nz,&NZ,1,MPIU_INT,MPI_SUM,PetscObjectComm((PetscObject)A)));
 
-  ierr = PetscMPIIntCast(nz,&mnz);CHKERRQ(ierr);
-  ierr = PetscMalloc2(size,&allnz,size,&dispnz);CHKERRQ(ierr);
-  ierr = MPI_Allgather(&mnz,1,MPI_INT,allnz,1,MPI_INT,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+  PetscCall(PetscMPIIntCast(nz,&mnz));
+  PetscCall(PetscMalloc2(size,&allnz,size,&dispnz));
+  PetscCallMPI(MPI_Allgather(&mnz,1,MPI_INT,allnz,1,MPI_INT,PetscObjectComm((PetscObject)A)));
   dispnz[0] = 0; for (i=1; i<size; i++) dispnz[i] = dispnz[i-1]+ allnz[i-1];
   if (adj->values) {
-    ierr = PetscMalloc1(NZ,&Values);CHKERRQ(ierr);
-    ierr = MPI_Allgatherv(adj->values,mnz,MPIU_INT,Values,allnz,dispnz,MPIU_INT,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+    PetscCall(PetscMalloc1(NZ,&Values));
+    PetscCallMPI(MPI_Allgatherv(adj->values,mnz,MPIU_INT,Values,allnz,dispnz,MPIU_INT,PetscObjectComm((PetscObject)A)));
   }
-  ierr = PetscMalloc1(NZ,&J);CHKERRQ(ierr);
-  ierr = MPI_Allgatherv(adj->j,mnz,MPIU_INT,J,allnz,dispnz,MPIU_INT,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
-  ierr = PetscFree2(allnz,dispnz);CHKERRQ(ierr);
-  ierr = MPI_Scan(&nz,&nzstart,1,MPIU_INT,MPI_SUM,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+  PetscCall(PetscMalloc1(NZ,&J));
+  PetscCallMPI(MPI_Allgatherv(adj->j,mnz,MPIU_INT,J,allnz,dispnz,MPIU_INT,PetscObjectComm((PetscObject)A)));
+  PetscCall(PetscFree2(allnz,dispnz));
+  PetscCallMPI(MPI_Scan(&nz,&nzstart,1,MPIU_INT,MPI_SUM,PetscObjectComm((PetscObject)A)));
   nzstart -= nz;
   /* shift the i[] values so they will be correct after being received */
   for (i=0; i<m; i++) adj->i[i] += nzstart;
-  ierr = PetscMalloc1(M+1,&II);CHKERRQ(ierr);
-  ierr = PetscMPIIntCast(m,&mm);CHKERRQ(ierr);
-  ierr = PetscMalloc2(size,&allm,size,&dispm);CHKERRQ(ierr);
-  ierr = MPI_Allgather(&mm,1,MPI_INT,allm,1,MPI_INT,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+  PetscCall(PetscMalloc1(M+1,&II));
+  PetscCall(PetscMPIIntCast(m,&mm));
+  PetscCall(PetscMalloc2(size,&allm,size,&dispm));
+  PetscCallMPI(MPI_Allgather(&mm,1,MPI_INT,allm,1,MPI_INT,PetscObjectComm((PetscObject)A)));
   dispm[0] = 0; for (i=1; i<size; i++) dispm[i] = dispm[i-1]+ allm[i-1];
-  ierr = MPI_Allgatherv(adj->i,mm,MPIU_INT,II,allm,dispm,MPIU_INT,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
-  ierr = PetscFree2(allm,dispm);CHKERRQ(ierr);
+  PetscCallMPI(MPI_Allgatherv(adj->i,mm,MPIU_INT,II,allm,dispm,MPIU_INT,PetscObjectComm((PetscObject)A)));
+  PetscCall(PetscFree2(allm,dispm));
   II[M] = NZ;
   /* shift the i[] values back */
   for (i=0; i<m; i++) adj->i[i] -= nzstart;
-  ierr = MatCreateMPIAdj(PETSC_COMM_SELF,M,N,II,J,Values,B);CHKERRQ(ierr);
+  PetscCall(MatCreateMPIAdj(PETSC_COMM_SELF,M,N,II,J,Values,B));
   PetscFunctionReturn(0);
 }
 
@@ -773,11 +764,9 @@ PetscErrorCode  MatMPIAdjToSeq_MPIAdj(Mat A,Mat *B)
 @*/
 PetscErrorCode MatMPIAdjCreateNonemptySubcommMat(Mat A,Mat *B)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A,MAT_CLASSID,1);
-  ierr = PetscUseMethod(A,"MatMPIAdjCreateNonemptySubcommMat_C",(Mat,Mat*),(A,B));CHKERRQ(ierr);
+  PetscUseMethod(A,"MatMPIAdjCreateNonemptySubcommMat_C",(Mat,Mat*),(A,B));
   PetscFunctionReturn(0);
 }
 
@@ -793,18 +782,17 @@ M*/
 PETSC_EXTERN PetscErrorCode MatCreate_MPIAdj(Mat B)
 {
   Mat_MPIAdj     *b;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr         = PetscNewLog(B,&b);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(B,&b));
   B->data      = (void*)b;
-  ierr         = PetscMemcpy(B->ops,&MatOps_Values,sizeof(struct _MatOps));CHKERRQ(ierr);
+  PetscCall(PetscMemcpy(B->ops,&MatOps_Values,sizeof(struct _MatOps)));
   B->assembled = PETSC_FALSE;
 
-  ierr = PetscObjectComposeFunction((PetscObject)B,"MatMPIAdjSetPreallocation_C",MatMPIAdjSetPreallocation_MPIAdj);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)B,"MatMPIAdjCreateNonemptySubcommMat_C",MatMPIAdjCreateNonemptySubcommMat_MPIAdj);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)B,"MatMPIAdjToSeq_C",MatMPIAdjToSeq_MPIAdj);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)B,MATMPIADJ);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)B,"MatMPIAdjSetPreallocation_C",MatMPIAdjSetPreallocation_MPIAdj));
+  PetscCall(PetscObjectComposeFunction((PetscObject)B,"MatMPIAdjCreateNonemptySubcommMat_C",MatMPIAdjCreateNonemptySubcommMat_MPIAdj));
+  PetscCall(PetscObjectComposeFunction((PetscObject)B,"MatMPIAdjToSeq_C",MatMPIAdjToSeq_MPIAdj));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)B,MATMPIADJ));
   PetscFunctionReturn(0);
 }
 
@@ -825,10 +813,8 @@ PETSC_EXTERN PetscErrorCode MatCreate_MPIAdj(Mat B)
 @*/
 PetscErrorCode  MatMPIAdjToSeq(Mat A,Mat *B)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscUseMethod(A,"MatMPIAdjToSeq_C",(Mat,Mat*),(A,B));CHKERRQ(ierr);
+  PetscUseMethod(A,"MatMPIAdjToSeq_C",(Mat,Mat*),(A,B));
   PetscFunctionReturn(0);
 }
 
@@ -850,10 +836,8 @@ PetscErrorCode  MatMPIAdjToSeq(Mat A,Mat *B)
 @*/
 PetscErrorCode  MatMPIAdjSetPreallocation(Mat B,PetscInt *i,PetscInt *j,PetscInt *values)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscTryMethod(B,"MatMPIAdjSetPreallocation_C",(Mat,PetscInt*,PetscInt*,PetscInt*),(B,i,j,values));CHKERRQ(ierr);
+  PetscTryMethod(B,"MatMPIAdjSetPreallocation_C",(Mat,PetscInt*,PetscInt*,PetscInt*),(B,i,j,values));
   PetscFunctionReturn(0);
 }
 
@@ -895,12 +879,10 @@ PetscErrorCode  MatMPIAdjSetPreallocation(Mat B,PetscInt *i,PetscInt *j,PetscInt
 @*/
 PetscErrorCode  MatCreateMPIAdj(MPI_Comm comm,PetscInt m,PetscInt N,PetscInt *i,PetscInt *j,PetscInt *values,Mat *A)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = MatCreate(comm,A);CHKERRQ(ierr);
-  ierr = MatSetSizes(*A,m,PETSC_DETERMINE,PETSC_DETERMINE,N);CHKERRQ(ierr);
-  ierr = MatSetType(*A,MATMPIADJ);CHKERRQ(ierr);
-  ierr = MatMPIAdjSetPreallocation(*A,i,j,values);CHKERRQ(ierr);
+  PetscCall(MatCreate(comm,A));
+  PetscCall(MatSetSizes(*A,m,PETSC_DETERMINE,PETSC_DETERMINE,N));
+  PetscCall(MatSetType(*A,MATMPIADJ));
+  PetscCall(MatMPIAdjSetPreallocation(*A,i,j,values));
   PetscFunctionReturn(0);
 }
