@@ -16,22 +16,21 @@
 
 PetscErrorCode MatGetSymbolicTranspose_SeqAIJ(Mat A,PetscInt *Ati[],PetscInt *Atj[])
 {
-  PetscErrorCode ierr;
   PetscInt       i,j,anzj;
   Mat_SeqAIJ     *a=(Mat_SeqAIJ*)A->data;
   PetscInt       an=A->cmap->N,am=A->rmap->N;
   PetscInt       *ati,*atj,*atfill,*ai=a->i,*aj=a->j;
 
   PetscFunctionBegin;
-  ierr = PetscInfo(A,"Getting Symbolic Transpose.\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(A,"Getting Symbolic Transpose.\n"));
 
   /* Set up timers */
-  ierr = PetscLogEventBegin(MAT_Getsymtranspose,A,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventBegin(MAT_Getsymtranspose,A,0,0,0));
 
   /* Allocate space for symbolic transpose info and work array */
-  ierr = PetscCalloc1(an+1,&ati);CHKERRQ(ierr);
-  ierr = PetscMalloc1(ai[am],&atj);CHKERRQ(ierr);
-  ierr = PetscMalloc1(an,&atfill);CHKERRQ(ierr);
+  PetscCall(PetscCalloc1(an+1,&ati));
+  PetscCall(PetscMalloc1(ai[am],&atj));
+  PetscCall(PetscMalloc1(an,&atfill));
 
   /* Walk through aj and count ## of non-zeros in each row of A^T. */
   /* Note: offset by 1 for fast conversion into csr format. */
@@ -44,7 +43,7 @@ PetscErrorCode MatGetSymbolicTranspose_SeqAIJ(Mat A,PetscInt *Ati[],PetscInt *At
   }
 
   /* Copy ati into atfill so we have locations of the next free space in atj */
-  ierr = PetscArraycpy(atfill,ati,an);CHKERRQ(ierr);
+  PetscCall(PetscArraycpy(atfill,ati,an));
 
   /* Walk through A row-wise and mark nonzero entries of A^T. */
   for (i=0; i<am; i++) {
@@ -56,11 +55,11 @@ PetscErrorCode MatGetSymbolicTranspose_SeqAIJ(Mat A,PetscInt *Ati[],PetscInt *At
   }
 
   /* Clean up temporary space and complete requests. */
-  ierr = PetscFree(atfill);CHKERRQ(ierr);
+  PetscCall(PetscFree(atfill));
   *Ati = ati;
   *Atj = atj;
 
-  ierr = PetscLogEventEnd(MAT_Getsymtranspose,A,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventEnd(MAT_Getsymtranspose,A,0,0,0));
   PetscFunctionReturn(0);
 }
 /*
@@ -69,21 +68,20 @@ PetscErrorCode MatGetSymbolicTranspose_SeqAIJ(Mat A,PetscInt *Ati[],PetscInt *At
 */
 PetscErrorCode MatGetSymbolicTransposeReduced_SeqAIJ(Mat A,PetscInt rstart,PetscInt rend,PetscInt *Ati[],PetscInt *Atj[])
 {
-  PetscErrorCode ierr;
   PetscInt       i,j,anzj;
   Mat_SeqAIJ     *a=(Mat_SeqAIJ*)A->data;
   PetscInt       an=A->cmap->N;
   PetscInt       *ati,*atj,*atfill,*ai=a->i,*aj=a->j;
 
   PetscFunctionBegin;
-  ierr = PetscInfo(A,"Getting Symbolic Transpose\n");CHKERRQ(ierr);
-  ierr = PetscLogEventBegin(MAT_Getsymtransreduced,A,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscInfo(A,"Getting Symbolic Transpose\n"));
+  PetscCall(PetscLogEventBegin(MAT_Getsymtransreduced,A,0,0,0));
 
   /* Allocate space for symbolic transpose info and work array */
-  ierr = PetscCalloc1(an+1,&ati);CHKERRQ(ierr);
+  PetscCall(PetscCalloc1(an+1,&ati));
   anzj = ai[rend] - ai[rstart];
-  ierr = PetscMalloc1(anzj+1,&atj);CHKERRQ(ierr);
-  ierr = PetscMalloc1(an+1,&atfill);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(anzj+1,&atj));
+  PetscCall(PetscMalloc1(an+1,&atfill));
 
   /* Walk through aj and count ## of non-zeros in each row of A^T. */
   /* Note: offset by 1 for fast conversion into csr format. */
@@ -96,7 +94,7 @@ PetscErrorCode MatGetSymbolicTransposeReduced_SeqAIJ(Mat A,PetscInt rstart,Petsc
   }
 
   /* Copy ati into atfill so we have locations of the next free space in atj */
-  ierr = PetscArraycpy(atfill,ati,an);CHKERRQ(ierr);
+  PetscCall(PetscArraycpy(atfill,ati,an));
 
   /* Walk through A row-wise and mark nonzero entries of A^T. */
   aj = aj + ai[rstart];
@@ -109,17 +107,16 @@ PetscErrorCode MatGetSymbolicTransposeReduced_SeqAIJ(Mat A,PetscInt rstart,Petsc
   }
 
   /* Clean up temporary space and complete requests. */
-  ierr = PetscFree(atfill);CHKERRQ(ierr);
+  PetscCall(PetscFree(atfill));
   *Ati = ati;
   *Atj = atj;
 
-  ierr = PetscLogEventEnd(MAT_Getsymtransreduced,A,0,0,0);CHKERRQ(ierr);
+  PetscCall(PetscLogEventEnd(MAT_Getsymtransreduced,A,0,0,0));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode MatTranspose_SeqAIJ(Mat A,MatReuse reuse,Mat *B)
 {
-  PetscErrorCode  ierr;
   PetscInt        i,j,anzj;
   Mat             At;
   Mat_SeqAIJ      *a=(Mat_SeqAIJ*)A->data,*at;
@@ -129,13 +126,13 @@ PetscErrorCode MatTranspose_SeqAIJ(Mat A,MatReuse reuse,Mat *B)
   const MatScalar *aa,*av;
 
   PetscFunctionBegin;
-  ierr = MatSeqAIJGetArrayRead(A,&av);CHKERRQ(ierr);
+  PetscCall(MatSeqAIJGetArrayRead(A,&av));
   aa   = av;
   if (reuse == MAT_INITIAL_MATRIX || reuse == MAT_INPLACE_MATRIX) {
     /* Allocate space for symbolic transpose info and work array */
-    ierr = PetscCalloc1(an+1,&ati);CHKERRQ(ierr);
-    ierr = PetscMalloc1(ai[am],&atj);CHKERRQ(ierr);
-    ierr = PetscMalloc1(ai[am],&ata);CHKERRQ(ierr);
+    PetscCall(PetscCalloc1(an+1,&ati));
+    PetscCall(PetscMalloc1(ai[am],&atj));
+    PetscCall(PetscMalloc1(ai[am],&ata));
     /* Walk through aj and count ## of non-zeros in each row of A^T. */
     /* Note: offset by 1 for fast conversion into csr format. */
     for (i=0;i<ai[am];i++) {
@@ -154,8 +151,8 @@ PetscErrorCode MatTranspose_SeqAIJ(Mat A,MatReuse reuse,Mat *B)
   }
 
   /* Copy ati into atfill so we have locations of the next free space in atj */
-  ierr = PetscMalloc1(an,&atfill);CHKERRQ(ierr);
-  ierr = PetscArraycpy(atfill,ati,an);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(an,&atfill));
+  PetscCall(PetscArraycpy(atfill,ati,an));
 
   /* Walk through A row-wise and mark nonzero entries of A^T. */
   for (i=0;i<am;i++) {
@@ -166,13 +163,13 @@ PetscErrorCode MatTranspose_SeqAIJ(Mat A,MatReuse reuse,Mat *B)
       atfill[*aj++]   += 1;
     }
   }
-  ierr = MatSeqAIJRestoreArrayRead(A,&av);CHKERRQ(ierr);
+  PetscCall(MatSeqAIJRestoreArrayRead(A,&av));
 
   /* Clean up temporary space and complete requests. */
-  ierr = PetscFree(atfill);CHKERRQ(ierr);
+  PetscCall(PetscFree(atfill));
   if (reuse == MAT_INITIAL_MATRIX || reuse == MAT_INPLACE_MATRIX) {
-    ierr = MatCreateSeqAIJWithArrays(PetscObjectComm((PetscObject)A),an,am,ati,atj,ata,&At);CHKERRQ(ierr);
-    ierr = MatSetBlockSizes(At,PetscAbs(A->cmap->bs),PetscAbs(A->rmap->bs));CHKERRQ(ierr);
+    PetscCall(MatCreateSeqAIJWithArrays(PetscObjectComm((PetscObject)A),an,am,ati,atj,ata,&At));
+    PetscCall(MatSetBlockSizes(At,PetscAbs(A->cmap->bs),PetscAbs(A->rmap->bs)));
 
     at          = (Mat_SeqAIJ*)(At->data);
     at->free_a  = PETSC_TRUE;
@@ -180,27 +177,22 @@ PetscErrorCode MatTranspose_SeqAIJ(Mat A,MatReuse reuse,Mat *B)
     at->nonew   = 0;
     at->maxnz   = ati[an];
 
-    ierr = MatSetType(At,((PetscObject)A)->type_name);CHKERRQ(ierr);
+    PetscCall(MatSetType(At,((PetscObject)A)->type_name));
   }
 
   if (reuse == MAT_INITIAL_MATRIX || reuse == MAT_REUSE_MATRIX) {
     *B = At;
   } else {
-    ierr = MatHeaderMerge(A,&At);CHKERRQ(ierr);
+    PetscCall(MatHeaderMerge(A,&At));
   }
-#if defined(PETSC_HAVE_DEVICE)
-  (*B)->offloadmask = PETSC_OFFLOAD_CPU;
-#endif
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode MatRestoreSymbolicTranspose_SeqAIJ(Mat A,PetscInt *ati[],PetscInt *atj[])
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(A,"Restoring Symbolic Transpose.\n");CHKERRQ(ierr);
-  ierr = PetscFree(*ati);CHKERRQ(ierr);
-  ierr = PetscFree(*atj);CHKERRQ(ierr);
+  PetscCall(PetscInfo(A,"Restoring Symbolic Transpose.\n"));
+  PetscCall(PetscFree(*ati));
+  PetscCall(PetscFree(*atj));
   PetscFunctionReturn(0);
 }
