@@ -45,10 +45,9 @@ PETSC_EXTERN PetscErrorCode PetscKernel_A_gets_inverse_A_7(MatScalar *a,PetscRea
     if (a[l + k3] == 0.0) {
       if (shift == 0.0) {
         if (allowzeropivot) {
-          PetscErrorCode ierr;
-          ierr = PetscInfo1(NULL,"Zero pivot, row %D\n",k-1);CHKERRQ(ierr);
+          PetscCall(PetscInfo(NULL,"Zero pivot, row %" PetscInt_FMT "\n",k-1));
           if (zeropivotdetected) *zeropivotdetected = PETSC_TRUE;
-        } else SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_MAT_LU_ZRPVT,"Zero pivot, row %D",k-1);
+        } else SETERRQ(PETSC_COMM_SELF,PETSC_ERR_MAT_LU_ZRPVT,"Zero pivot, row %" PetscInt_FMT,k-1);
       } else {
         /* SHIFT is applied to SINGLE diagonal entry; does this make any sense? */
         a[l + k3] = shift;
@@ -85,11 +84,10 @@ PETSC_EXTERN PetscErrorCode PetscKernel_A_gets_inverse_A_7(MatScalar *a,PetscRea
   }
   ipvt[6] = 7;
   if (a[56] == 0.0) {
-    if (allowzeropivot) {
-      PetscErrorCode ierr;
-      ierr = PetscInfo1(NULL,"Zero pivot, row %D\n",6);CHKERRQ(ierr);
+    if (PetscLikely(allowzeropivot)) {
+      PetscCall(PetscInfo(NULL,"Zero pivot, row 6\n"));
       if (zeropivotdetected) *zeropivotdetected = PETSC_TRUE;
-    } else SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_MAT_LU_ZRPVT,"Zero pivot, row %D",6);
+    } else SETERRQ(PETSC_COMM_SELF,PETSC_ERR_MAT_LU_ZRPVT,"Zero pivot, row 6");
   }
 
   /* Now form the inverse */
@@ -151,4 +149,3 @@ PETSC_EXTERN PetscErrorCode PetscKernel_A_gets_inverse_A_7(MatScalar *a,PetscRea
   }
   PetscFunctionReturn(0);
 }
-
