@@ -4,8 +4,6 @@
 PETSC_EXTERN PetscErrorCode MatCreateMFFD_DS(MatMFFD);
 PETSC_EXTERN PetscErrorCode MatCreateMFFD_WP(MatMFFD);
 
-#undef __FUNCT__
-#define __FUNCT__ "MatMFFDRegisterAll"
 /*@C
   MatMFFDRegisterAll - Registers all of the compute-h in the MatMFFD package.
 
@@ -13,21 +11,16 @@ PETSC_EXTERN PetscErrorCode MatCreateMFFD_WP(MatMFFD);
 
   Level: developer
 
-.keywords: MatMFFD, register, all
-
 .seealso:  MatMFFDRegisterDestroy(), MatMFFDRegister(), MatCreateMFFD(),
            MatMFFDSetType()
 @*/
 PetscErrorCode  MatMFFDRegisterAll(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (MatMFFDRegisterAllCalled) PetscFunctionReturn(0);
   MatMFFDRegisterAllCalled = PETSC_TRUE;
 
-  ierr = MatMFFDRegister(MATMFFD_DS,MatCreateMFFD_DS);CHKERRQ(ierr);
-  ierr = MatMFFDRegister(MATMFFD_WP,MatCreateMFFD_WP);CHKERRQ(ierr);
+  PetscCall(MatMFFDRegister(MATMFFD_DS,MatCreateMFFD_DS));
+  PetscCall(MatMFFDRegister(MATMFFD_WP,MatCreateMFFD_WP));
   PetscFunctionReturn(0);
 }
-
