@@ -6,20 +6,20 @@ typedef struct {
   PetscInt   *dnz, *onz;
   PetscInt   *dnzu, *onzu;
   PetscBool   nooffproc;
+  PetscBool   used;
 } Mat_Preallocator;
 
 PetscErrorCode MatDestroy_Preallocator(Mat A)
 {
   Mat_Preallocator *p = (Mat_Preallocator *) A->data;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
-  ierr = MatStashDestroy_Private(&A->stash);CHKERRQ(ierr);
-  ierr = PetscHSetIJDestroy(&p->ht);CHKERRQ(ierr);
-  ierr = PetscFree4(p->dnz, p->onz, p->dnzu, p->onzu);CHKERRQ(ierr);
-  ierr = PetscFree(A->data);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject) A, NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject) A, "MatPreallocatorPreallocate_C", NULL);CHKERRQ(ierr);
+  PetscCall(MatStashDestroy_Private(&A->stash));
+  PetscCall(PetscHSetIJDestroy(&p->ht));
+  PetscCall(PetscFree4(p->dnz, p->onz, p->dnzu, p->onzu));
+  PetscCall(PetscFree(A->data));
+  PetscCall(PetscObjectChangeTypeName((PetscObject) A, NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject) A, "MatPreallocatorPreallocate_C", NULL));
   PetscFunctionReturn(0);
 }
 
@@ -27,19 +27,18 @@ PetscErrorCode MatSetUp_Preallocator(Mat A)
 {
   Mat_Preallocator *p = (Mat_Preallocator *) A->data;
   PetscInt          m, bs, mbs;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutSetUp(A->rmap);CHKERRQ(ierr);
-  ierr = PetscLayoutSetUp(A->cmap);CHKERRQ(ierr);
-  ierr = MatGetLocalSize(A, &m, NULL);CHKERRQ(ierr);
-  ierr = PetscHSetIJCreate(&p->ht);CHKERRQ(ierr);
-  ierr = MatGetBlockSize(A, &bs);CHKERRQ(ierr);
+  PetscCall(PetscLayoutSetUp(A->rmap));
+  PetscCall(PetscLayoutSetUp(A->cmap));
+  PetscCall(MatGetLocalSize(A, &m, NULL));
+  PetscCall(PetscHSetIJCreate(&p->ht));
+  PetscCall(MatGetBlockSize(A, &bs));
   /* Do not bother bstash since MatPreallocator does not implement MatSetValuesBlocked */
-  ierr = MatStashCreate_Private(PetscObjectComm((PetscObject) A), 1, &A->stash);CHKERRQ(ierr);
+  PetscCall(MatStashCreate_Private(PetscObjectComm((PetscObject) A), 1, &A->stash));
   /* arrays are for blocked rows/cols */
   mbs  = m/bs;
-  ierr = PetscCalloc4(mbs, &p->dnz, mbs, &p->onz, mbs, &p->dnzu, mbs, &p->onzu);CHKERRQ(ierr);
+  PetscCall(PetscCalloc4(mbs, &p->dnz, mbs, &p->onz, mbs, &p->dnzu, mbs, &p->onzu));
   PetscFunctionReturn(0);
 }
 
@@ -47,12 +46,11 @@ PetscErrorCode MatSetValues_Preallocator(Mat A, PetscInt m, const PetscInt *rows
 {
   Mat_Preallocator *p = (Mat_Preallocator *) A->data;
   PetscInt          rStart, rEnd, r, cStart, cEnd, c, bs;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
-  ierr = MatGetBlockSize(A, &bs);CHKERRQ(ierr);
-  ierr = MatGetOwnershipRange(A, &rStart, &rEnd);CHKERRQ(ierr);
-  ierr = MatGetOwnershipRangeColumn(A, &cStart, &cEnd);CHKERRQ(ierr);
+  PetscCall(MatGetBlockSize(A, &bs));
+  PetscCall(MatGetOwnershipRange(A, &rStart, &rEnd));
+  PetscCall(MatGetOwnershipRangeColumn(A, &cStart, &cEnd));
   for (r = 0; r < m; ++r) {
     PetscHashIJKey key;
     PetscBool      missing;
@@ -60,13 +58,13 @@ PetscErrorCode MatSetValues_Preallocator(Mat A, PetscInt m, const PetscInt *rows
     key.i = rows[r];
     if (key.i < 0) continue;
     if ((key.i < rStart) || (key.i >= rEnd)) {
-      ierr = MatStashValuesRow_Private(&A->stash, key.i, n, cols, values, PETSC_FALSE);CHKERRQ(ierr);
+      PetscCall(MatStashValuesRow_Private(&A->stash, key.i, n, cols, values, PETSC_FALSE));
     } else { /* Hash table is for blocked rows/cols */
       key.i = rows[r]/bs;
       for (c = 0; c < n; ++c) {
         key.j = cols[c]/bs;
         if (key.j < 0) continue;
-        ierr = PetscHSetIJQueryAdd(p->ht, key, &missing);CHKERRQ(ierr);
+        PetscCall(PetscHSetIJQueryAdd(p->ht, key, &missing));
         if (missing) {
           if ((key.j >= cStart/bs) && (key.j < cEnd/bs)) {
             ++p->dnz[key.i-rStart/bs];
@@ -85,12 +83,11 @@ PetscErrorCode MatSetValues_Preallocator(Mat A, PetscInt m, const PetscInt *rows
 PetscErrorCode MatAssemblyBegin_Preallocator(Mat A, MatAssemblyType type)
 {
   PetscInt       nstash, reallocs;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = MatStashScatterBegin_Private(A, &A->stash, A->rmap->range);CHKERRQ(ierr);
-  ierr = MatStashGetInfo_Private(&A->stash, &nstash, &reallocs);CHKERRQ(ierr);
-  ierr = PetscInfo2(A, "Stash has %D entries, uses %D mallocs.\n", nstash, reallocs);CHKERRQ(ierr);
+  PetscCall(MatStashScatterBegin_Private(A, &A->stash, A->rmap->range));
+  PetscCall(MatStashGetInfo_Private(&A->stash, &nstash, &reallocs));
+  PetscCall(PetscInfo(A, "Stash has %" PetscInt_FMT " entries, uses %" PetscInt_FMT " mallocs.\n", nstash, reallocs));
   PetscFunctionReturn(0);
 }
 
@@ -101,12 +98,11 @@ PetscErrorCode MatAssemblyEnd_Preallocator(Mat A, MatAssemblyType type)
   PetscInt         i, j, rstart, ncols, flg;
   PetscMPIInt      n;
   Mat_Preallocator *p = (Mat_Preallocator *) A->data;
-  PetscErrorCode   ierr;
 
   PetscFunctionBegin;
   p->nooffproc = PETSC_TRUE;
   while (1) {
-    ierr = MatStashScatterGetMesg_Private(&A->stash, &n, &row, &col, &val, &flg);CHKERRQ(ierr);
+    PetscCall(MatStashScatterGetMesg_Private(&A->stash, &n, &row, &col, &val, &flg));
     if (flg) p->nooffproc = PETSC_FALSE;
     if (!flg) break;
 
@@ -118,12 +114,12 @@ PetscErrorCode MatAssemblyEnd_Preallocator(Mat A, MatAssemblyType type)
       if (j < n) ncols = j-i;
       else       ncols = n-i;
       /* Now assemble all these values with a single function call */
-      ierr = MatSetValues_Preallocator(A, 1, row+i, ncols, col+i, val+i, INSERT_VALUES);CHKERRQ(ierr);
+      PetscCall(MatSetValues_Preallocator(A, 1, row+i, ncols, col+i, val+i, INSERT_VALUES));
       i = j;
     }
   }
-  ierr = MatStashScatterEnd_Private(&A->stash);CHKERRQ(ierr);
-  ierr = MPIU_Allreduce(MPI_IN_PLACE,&p->nooffproc,1,MPIU_BOOL,MPI_LAND,PetscObjectComm((PetscObject)A));CHKERRMPI(ierr);
+  PetscCall(MatStashScatterEnd_Private(&A->stash));
+  PetscCall(MPIU_Allreduce(MPI_IN_PLACE,&p->nooffproc,1,MPIU_BOOL,MPI_LAND,PetscObjectComm((PetscObject)A)));
   PetscFunctionReturn(0);
 }
 
@@ -143,33 +139,34 @@ PetscErrorCode MatPreallocatorPreallocate_Preallocator(Mat mat, PetscBool fill,
 {
   Mat_Preallocator *p = (Mat_Preallocator *) mat->data;
   PetscInt          bs;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
-  if (!fill) {ierr = PetscHSetIJDestroy(&p->ht);CHKERRQ(ierr);}
-  ierr = MatGetBlockSize(mat, &bs);CHKERRQ(ierr);
-  ierr = MatXAIJSetPreallocation(A, bs, p->dnz, p->onz, p->dnzu, p->onzu);CHKERRQ(ierr);
-  ierr = MatSetUp(A);CHKERRQ(ierr);
-  ierr = MatSetOption(A, MAT_NEW_NONZERO_ALLOCATION_ERR, PETSC_TRUE);CHKERRQ(ierr);
-  ierr = MatSetOption(A, MAT_NO_OFF_PROC_ENTRIES, p->nooffproc);CHKERRQ(ierr);
+  PetscCheck(!p->used,PetscObjectComm((PetscObject)mat),PETSC_ERR_SUP,"MatPreallocatorPreallocate() can only be used once for a give MatPreallocator object. Consider using MatDuplicate() after preallocation.");
+  p->used = PETSC_TRUE;
+  if (!fill) PetscCall(PetscHSetIJDestroy(&p->ht));
+  PetscCall(MatGetBlockSize(mat, &bs));
+  PetscCall(MatXAIJSetPreallocation(A, bs, p->dnz, p->onz, p->dnzu, p->onzu));
+  PetscCall(MatSetUp(A));
+  PetscCall(MatSetOption(A, MAT_NEW_NONZERO_ALLOCATION_ERR, PETSC_TRUE));
+  PetscCall(MatSetOption(A, MAT_NO_OFF_PROC_ENTRIES, p->nooffproc));
   if (fill) {
     PetscHashIter  hi;
     PetscHashIJKey key;
     PetscScalar    *zeros;
     PetscInt       n,maxrow=1,*cols,rStart,rEnd,*rowstarts;
 
-    ierr = MatGetOwnershipRange(A, &rStart, &rEnd);CHKERRQ(ierr);
+    PetscCall(MatGetOwnershipRange(A, &rStart, &rEnd));
     // Ownership range is in terms of scalar entries, but we deal with blocks
     rStart /= bs;
     rEnd /= bs;
-    ierr = PetscHSetIJGetSize(p->ht,&n);CHKERRQ(ierr);
-    ierr = PetscMalloc2(n,&cols,rEnd-rStart+1,&rowstarts);CHKERRQ(ierr);
+    PetscCall(PetscHSetIJGetSize(p->ht,&n));
+    PetscCall(PetscMalloc2(n,&cols,rEnd-rStart+1,&rowstarts));
     rowstarts[0] = 0;
     for (PetscInt i=0; i<rEnd-rStart; i++) {
       rowstarts[i+1] = rowstarts[i] + p->dnz[i] + p->onz[i];
       maxrow = PetscMax(maxrow, p->dnz[i] + p->onz[i]);
     }
-    if (rowstarts[rEnd-rStart] != n) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Hash claims %D entries, but dnz+onz counts %D",n,rowstarts[rEnd-rStart]);
+    PetscCheckFalse(rowstarts[rEnd-rStart] != n,PETSC_COMM_SELF,PETSC_ERR_PLIB,"Hash claims %" PetscInt_FMT " entries, but dnz+onz counts %" PetscInt_FMT,n,rowstarts[rEnd-rStart]);
 
     PetscHashIterBegin(p->ht,hi);
     for (PetscInt i=0; !PetscHashIterAtEnd(p->ht,hi); i++) {
@@ -179,20 +176,20 @@ PetscErrorCode MatPreallocatorPreallocate_Preallocator(Mat mat, PetscBool fill,
       rowstarts[lrow]++;
       PetscHashIterNext(p->ht,hi);
     }
-    ierr = PetscHSetIJDestroy(&p->ht);CHKERRQ(ierr);
+    PetscCall(PetscHSetIJDestroy(&p->ht));
 
-    ierr = PetscCalloc1(maxrow*bs*bs,&zeros);CHKERRQ(ierr);
+    PetscCall(PetscCalloc1(maxrow*bs*bs,&zeros));
     for (PetscInt i=0; i<rEnd-rStart; i++) {
       PetscInt grow = rStart + i;
       PetscInt end = rowstarts[i], start = end - p->dnz[i] - p->onz[i];
-      ierr = PetscSortInt(end-start,&cols[start]);CHKERRQ(ierr);
-      ierr = MatSetValuesBlocked(A, 1, &grow, end-start, &cols[start], zeros, INSERT_VALUES);CHKERRQ(ierr);
+      PetscCall(PetscSortInt(end-start,&cols[start]));
+      PetscCall(MatSetValuesBlocked(A, 1, &grow, end-start, &cols[start], zeros, INSERT_VALUES));
     }
-    ierr = PetscFree(zeros);CHKERRQ(ierr);
-    ierr = PetscFree2(cols,rowstarts);CHKERRQ(ierr);
+    PetscCall(PetscFree(zeros));
+    PetscCall(PetscFree2(cols,rowstarts));
 
-    ierr = MatAssemblyBegin(A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-    ierr = MatAssemblyEnd(A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+    PetscCall(MatAssemblyBegin(A,MAT_FINAL_ASSEMBLY));
+    PetscCall(MatAssemblyEnd(A,MAT_FINAL_ASSEMBLY));
   }
   PetscFunctionReturn(0);
 }
@@ -220,18 +217,21 @@ PetscErrorCode MatPreallocatorPreallocate_Preallocator(Mat mat, PetscBool fill,
   fill = PETSC_TRUE will insert zeros into the matrix A. Internally MatPreallocatorPreallocate()
   will call MatSetOption(A, MAT_NEW_NONZERO_ALLOCATION_ERR, PETSC_TRUE);
 
+  This function may only be called once for a given MatPreallocator object. If
+  multiple Mats need to be preallocated, consider using MatDuplicate() after
+  this function.
+
   Level: advanced
 
 .seealso: MATPREALLOCATOR
 @*/
 PetscErrorCode MatPreallocatorPreallocate(Mat mat, PetscBool fill, Mat A)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
-  PetscValidHeaderSpecific(A,   MAT_CLASSID, 3);
-  ierr = PetscUseMethod(mat, "MatPreallocatorPreallocate_C", (Mat,PetscBool,Mat),(mat,fill,A));CHKERRQ(ierr);
+  PetscValidHeaderSpecific(mat,MAT_CLASSID,1);
+  PetscValidLogicalCollectiveBool(mat,fill,2);
+  PetscValidHeaderSpecific(A,MAT_CLASSID,3);
+  PetscUseMethod(mat,"MatPreallocatorPreallocate_C",(Mat,PetscBool,Mat),(mat,fill,A));
   PetscFunctionReturn(0);
 }
 
@@ -239,7 +239,9 @@ PetscErrorCode MatPreallocatorPreallocate(Mat mat, PetscBool fill, Mat A)
    MATPREALLOCATOR - MATPREALLOCATOR = "preallocator" - A matrix type to be used for computing a matrix preallocation.
 
    Operations Provided:
-.  MatSetValues()
+.vb
+  MatSetValues()
+.ve
 
    Options Database Keys:
 . -mat_type preallocator - sets the matrix type to "preallocator" during a call to MatSetFromOptions()
@@ -253,10 +255,9 @@ M*/
 PETSC_EXTERN PetscErrorCode MatCreate_Preallocator(Mat A)
 {
   Mat_Preallocator *p;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(A, &p);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(A, &p));
   A->data = (void *) p;
 
   p->ht   = NULL;
@@ -264,9 +265,10 @@ PETSC_EXTERN PetscErrorCode MatCreate_Preallocator(Mat A)
   p->onz  = NULL;
   p->dnzu = NULL;
   p->onzu = NULL;
+  p->used = PETSC_FALSE;
 
   /* matrix ops */
-  ierr = PetscMemzero(A->ops, sizeof(struct _MatOps));CHKERRQ(ierr);
+  PetscCall(PetscMemzero(A->ops, sizeof(struct _MatOps)));
 
   A->ops->destroy       = MatDestroy_Preallocator;
   A->ops->setup         = MatSetUp_Preallocator;
@@ -278,7 +280,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_Preallocator(Mat A)
   A->ops->setblocksizes = MatSetBlockSizes_Default; /* once set, user is not allowed to change the block sizes */
 
   /* special MATPREALLOCATOR functions */
-  ierr = PetscObjectComposeFunction((PetscObject) A, "MatPreallocatorPreallocate_C", MatPreallocatorPreallocate_Preallocator);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject) A, MATPREALLOCATOR);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject) A, "MatPreallocatorPreallocate_C", MatPreallocatorPreallocate_Preallocator));
+  PetscCall(PetscObjectChangeTypeName((PetscObject) A, MATPREALLOCATOR));
   PetscFunctionReturn(0);
 }
