@@ -9,11 +9,8 @@
 static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat,PetscInt,IS*);
 static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat,PetscInt*,PetscInt,PetscInt*,PetscBT*);
 
-#undef __FUNCT__
-#define __FUNCT__ "MatIncreaseOverlap_MPISBAIJ"
 PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C,PetscInt is_max,IS is[],PetscInt ov)
 {
-  PetscErrorCode ierr;
   PetscInt       i,N=C->cmap->N, bs=C->rmap->bs,M=C->rmap->N,Mbs=M/bs,*nidx,isz,iov;
   IS             *is_new,*is_row;
   Mat            *submats;
@@ -22,51 +19,37 @@ PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C,PetscInt is_max,IS is[],PetscIn
   PetscBT        table;
   PetscInt       *ai,brow,nz,nis,l,nmax,nstages_local,nstages,max_no,pos;
   const PetscInt *idx;
-  PetscBool      flg,*allcolumns,*allrows;
+  PetscBool      flg;
 
   PetscFunctionBegin;
-  ierr = PetscMalloc1(is_max,&is_new);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(is_max,&is_new));
   /* Convert the indices into block format */
-  ierr = ISCompressIndicesGeneral(N,C->rmap->n,bs,is_max,is,is_new);CHKERRQ(ierr);
-  if (ov < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Negative overlap specified\n");
+  PetscCall(ISCompressIndicesGeneral(N,C->rmap->n,bs,is_max,is,is_new));
+  PetscCheckFalse(ov < 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Negative overlap specified");
 
   /* ----- previous non-scalable implementation ----- */
   flg  = PETSC_FALSE;
-  ierr = PetscOptionsHasName(NULL,NULL, "-IncreaseOverlap_old", &flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL,NULL, "-IncreaseOverlap_old", &flg));
   if (flg) { /* previous non-scalable implementation */
     printf("use previous non-scalable implementation...\n");
     for (i=0; i<ov; ++i) {
-      ierr = MatIncreaseOverlap_MPISBAIJ_Once(C,is_max,is_new);CHKERRQ(ierr);
+      PetscCall(MatIncreaseOverlap_MPISBAIJ_Once(C,is_max,is_new));
     }
   } else { /* implementation using modified BAIJ routines */
 
-    ierr = PetscMalloc1(Mbs+1,&nidx);CHKERRQ(ierr);
-    ierr = PetscBTCreate(Mbs,&table);CHKERRQ(ierr); /* for column search */
-    ierr = PetscMalloc2(is_max+1,&allcolumns,is_max+1,&allrows);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(Mbs+1,&nidx));
+    PetscCall(PetscBTCreate(Mbs,&table)); /* for column search */
 
     /* Create is_row */
-    ierr = PetscMalloc1(is_max,&is_row);CHKERRQ(ierr);
-    ierr = ISCreateStride(PETSC_COMM_SELF,Mbs,0,1,&is_row[0]);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(is_max,&is_row));
+    PetscCall(ISCreateStride(PETSC_COMM_SELF,Mbs,0,1,&is_row[0]));
 
-    allrows[0] = PETSC_TRUE;
     for (i=1; i<is_max; i++) {
       is_row[i]  = is_row[0]; /* reuse is_row[0] */
-      allrows[i] = PETSC_TRUE;
     }
 
-    /* Allocate memory to hold all the submatrices - Modified from MatGetSubMatrices_MPIBAIJ() */
-    ierr = PetscMalloc1(is_max+1,&submats);CHKERRQ(ierr);
-
-    /* Check for special case: each processor gets entire matrix columns */
-    for (i=0; i<is_max; i++) {
-      ierr = ISIdentity(is_new[i],&flg);CHKERRQ(ierr);
-      ierr = ISGetLocalSize(is_new[i],&isz);CHKERRQ(ierr);
-      if (flg && isz == Mbs) {
-        allcolumns[i] = PETSC_TRUE;
-      } else {
-        allcolumns[i] = PETSC_FALSE;
-      }
-    }
+    /* Allocate memory to hold all the submatrices - Modified from MatCreateSubMatrices_MPIBAIJ() */
+    PetscCall(PetscMalloc1(is_max+1,&submats));
 
     /* Determine the number of stages through which submatrices are done */
     nmax = 20*1000000 / (c->Nbs * sizeof(PetscInt));
@@ -74,7 +57,7 @@ PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C,PetscInt is_max,IS is[],PetscIn
     nstages_local = is_max/nmax + ((is_max % nmax) ? 1 : 0);
 
     /* Make sure every processor loops through the nstages */
-    ierr = MPIU_Allreduce(&nstages_local,&nstages,1,MPIU_INT,MPI_MAX,PetscObjectComm((PetscObject)C));CHKERRQ(ierr);
+    PetscCall(MPIU_Allreduce(&nstages_local,&nstages,1,MPIU_INT,MPI_MAX,PetscObjectComm((PetscObject)C)));
 
     for (iov=0; iov<ov; ++iov) {
       /* 1) Get submats for column search */
@@ -82,26 +65,29 @@ PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C,PetscInt is_max,IS is[],PetscIn
         if (pos+nmax <= is_max) max_no = nmax;
         else if (pos == is_max) max_no = 0;
         else                    max_no = is_max-pos;
-        c->ijonly = PETSC_TRUE;
-        ierr      = MatGetSubMatrices_MPIBAIJ_local(C,max_no,is_row+pos,is_new+pos,MAT_INITIAL_MATRIX,allrows+pos,allcolumns+pos,submats+pos);CHKERRQ(ierr);
+        c->ijonly = PETSC_TRUE; /* only matrix data structures are requested */
+        /* The resulting submatrices should be BAIJ, not SBAIJ, hence we change this value to trigger that */
+        PetscCall(PetscStrcpy(((PetscObject)c->A)->type_name,MATSEQBAIJ));
+        PetscCall(MatCreateSubMatrices_MPIBAIJ_local(C,max_no,is_row+pos,is_new+pos,MAT_INITIAL_MATRIX,submats+pos));
+        PetscCall(PetscStrcpy(((PetscObject)c->A)->type_name,MATSEQSBAIJ));
         pos      += max_no;
       }
 
       /* 2) Row search */
-      ierr = MatIncreaseOverlap_MPIBAIJ_Once(C,is_max,is_new);CHKERRQ(ierr);
+      PetscCall(MatIncreaseOverlap_MPIBAIJ_Once(C,is_max,is_new));
 
       /* 3) Column search */
       for (i=0; i<is_max; i++) {
         asub_i = (Mat_SeqSBAIJ*)submats[i]->data;
-        ai     = asub_i->i;;
+        ai     = asub_i->i;
 
         /* put is_new obtained from MatIncreaseOverlap_MPIBAIJ() to table */
-        ierr = PetscBTMemzero(Mbs,table);CHKERRQ(ierr);
+        PetscCall(PetscBTMemzero(Mbs,table));
 
-        ierr = ISGetIndices(is_new[i],&idx);CHKERRQ(ierr);
-        ierr = ISGetLocalSize(is_new[i],&nis);CHKERRQ(ierr);
+        PetscCall(ISGetIndices(is_new[i],&idx));
+        PetscCall(ISGetLocalSize(is_new[i],&nis));
         for (l=0; l<nis; l++) {
-          ierr    = PetscBTSet(table,idx[l]);CHKERRQ(ierr);
+          PetscCall(PetscBTSet(table,idx[l]));
           nidx[l] = idx[l];
         }
         isz = nis;
@@ -113,32 +99,32 @@ PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C,PetscInt is_max,IS is[],PetscIn
             if (!PetscBTLookupSet(table,brow)) nidx[isz++] = brow;
           }
         }
-        ierr = ISRestoreIndices(is_new[i],&idx);CHKERRQ(ierr);
-        ierr = ISDestroy(&is_new[i]);CHKERRQ(ierr);
+        PetscCall(ISRestoreIndices(is_new[i],&idx));
+        PetscCall(ISDestroy(&is_new[i]));
 
         /* create updated is_new */
-        ierr = ISCreateGeneral(PETSC_COMM_SELF,isz,nidx,PETSC_COPY_VALUES,is_new+i);CHKERRQ(ierr);
+        PetscCall(ISCreateGeneral(PETSC_COMM_SELF,isz,nidx,PETSC_COPY_VALUES,is_new+i));
       }
 
       /* Free tmp spaces */
       for (i=0; i<is_max; i++) {
-        ierr = MatDestroy(&submats[i]);CHKERRQ(ierr);
+        PetscCall(MatDestroy(&submats[i]));
       }
     }
-    ierr = PetscFree2(allcolumns,allrows);CHKERRQ(ierr);
-    ierr = PetscBTDestroy(&table);CHKERRQ(ierr);
-    ierr = PetscFree(submats);CHKERRQ(ierr);
-    ierr = ISDestroy(&is_row[0]);CHKERRQ(ierr);
-    ierr = PetscFree(is_row);CHKERRQ(ierr);
-    ierr = PetscFree(nidx);CHKERRQ(ierr);
+
+    PetscCall(PetscBTDestroy(&table));
+    PetscCall(PetscFree(submats));
+    PetscCall(ISDestroy(&is_row[0]));
+    PetscCall(PetscFree(is_row));
+    PetscCall(PetscFree(nidx));
 
   }
 
-  for (i=0; i<is_max; i++) {ierr = ISDestroy(&is[i]);CHKERRQ(ierr);}
-  ierr = ISExpandIndicesGeneral(N,N,bs,is_max,is_new,is);CHKERRQ(ierr);
+  for (i=0; i<is_max; i++) PetscCall(ISDestroy(&is[i]));
+  PetscCall(ISExpandIndicesGeneral(N,N,bs,is_max,is_new,is));
 
-  for (i=0; i<is_max; i++) {ierr = ISDestroy(&is_new[i]);CHKERRQ(ierr);}
-  ierr = PetscFree(is_new);CHKERRQ(ierr);
+  for (i=0; i<is_max; i++) PetscCall(ISDestroy(&is_new[i]));
+  PetscCall(PetscFree(is_new));
   PetscFunctionReturn(0);
 }
 
@@ -162,17 +148,14 @@ typedef enum {MINE,OTHER} WhoseOwner;
        data[is_max + 1 + Mbs*i) = data(is[i])
         ...
 */
-#undef __FUNCT__
-#define __FUNCT__ "MatIncreaseOverlap_MPISBAIJ_Once"
 static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS is[])
 {
   Mat_MPISBAIJ   *c = (Mat_MPISBAIJ*)C->data;
-  PetscErrorCode ierr;
   PetscMPIInt    size,rank,tag1,tag2,*len_s,nrqr,nrqs,*id_r1,*len_r1,flag,len,*iwork;
   const PetscInt *idx_i;
   PetscInt       idx,isz,col,*n,*data1,**data1_start,*data2,*data2_i,*data,*data_i;
   PetscInt       Mbs,i,j,k,*odata1,*odata2;
-  PetscInt       proc_id,**odata2_ptr,*ctable=0,*btable,len_max,len_est;
+  PetscInt       proc_id,**odata2_ptr,*ctable=NULL,*btable,len_max,len_est;
   PetscInt       proc_end=0,len_unused,nodata2;
   PetscInt       ois_max; /* max no of is[] in each of processor */
   char           *t_p;
@@ -186,33 +169,33 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
   IS             garray_local,garray_gl;
 
   PetscFunctionBegin;
-  ierr = PetscObjectGetComm((PetscObject)C,&comm);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetComm((PetscObject)C,&comm));
   size = c->size;
   rank = c->rank;
   Mbs  = c->Mbs;
 
-  ierr = PetscObjectGetNewTag((PetscObject)C,&tag1);CHKERRQ(ierr);
-  ierr = PetscObjectGetNewTag((PetscObject)C,&tag2);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetNewTag((PetscObject)C,&tag1));
+  PetscCall(PetscObjectGetNewTag((PetscObject)C,&tag2));
 
   /* create tables used in
      step 1: table[i] - mark c->garray of proc [i]
      step 3: table[i] - mark indices of is[i] when whose=MINE
              table[0] - mark incideces of is[] when whose=OTHER */
-  len  = PetscMax(is_max, size);CHKERRQ(ierr);
-  ierr = PetscMalloc2(len,&table,(Mbs/PETSC_BITS_PER_BYTE+1)*len,&t_p);CHKERRQ(ierr);
+  len  = PetscMax(is_max, size);
+  PetscCall(PetscMalloc2(len,&table,(Mbs/PETSC_BITS_PER_BYTE+1)*len,&t_p));
   for (i=0; i<len; i++) {
     table[i] = t_p  + (Mbs/PETSC_BITS_PER_BYTE+1)*i;
   }
 
-  ierr = MPIU_Allreduce(&is_max,&ois_max,1,MPIU_INT,MPI_MAX,comm);CHKERRQ(ierr);
+  PetscCall(MPIU_Allreduce(&is_max,&ois_max,1,MPIU_INT,MPI_MAX,comm));
 
   /* 1. Send this processor's is[] to other processors */
   /*---------------------------------------------------*/
   /* allocate spaces */
-  ierr = PetscMalloc1(is_max,&n);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(is_max,&n));
   len  = 0;
   for (i=0; i<is_max; i++) {
-    ierr = ISGetLocalSize(is[i],&n[i]);CHKERRQ(ierr);
+    PetscCall(ISGetLocalSize(is[i],&n[i]));
     len += n[i];
   }
   if (!len) {
@@ -221,41 +204,40 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
     len += 1 + is_max; /* max length of data1 for one processor */
   }
 
-
-  ierr = PetscMalloc1(size*len+1,&data1);CHKERRQ(ierr);
-  ierr = PetscMalloc1(size,&data1_start);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(size*len+1,&data1));
+  PetscCall(PetscMalloc1(size,&data1_start));
   for (i=0; i<size; i++) data1_start[i] = data1 + i*len;
 
-  ierr = PetscMalloc4(size,&len_s,size,&btable,size,&iwork,size+1,&Bowners);CHKERRQ(ierr);
+  PetscCall(PetscMalloc4(size,&len_s,size,&btable,size,&iwork,size+1,&Bowners));
 
   /* gather c->garray from all processors */
-  ierr = ISCreateGeneral(comm,Bnbs,c->garray,PETSC_COPY_VALUES,&garray_local);CHKERRQ(ierr);
-  ierr = ISAllGather(garray_local, &garray_gl);CHKERRQ(ierr);
-  ierr = ISDestroy(&garray_local);CHKERRQ(ierr);
-  ierr = MPI_Allgather(&Bnbs,1,MPIU_INT,Bowners+1,1,MPIU_INT,comm);CHKERRQ(ierr);
+  PetscCall(ISCreateGeneral(comm,Bnbs,c->garray,PETSC_COPY_VALUES,&garray_local));
+  PetscCall(ISAllGather(garray_local, &garray_gl));
+  PetscCall(ISDestroy(&garray_local));
+  PetscCallMPI(MPI_Allgather(&Bnbs,1,MPIU_INT,Bowners+1,1,MPIU_INT,comm));
 
   Bowners[0] = 0;
   for (i=0; i<size; i++) Bowners[i+1] += Bowners[i];
 
   if (is_max) {
     /* hash table ctable which maps c->row to proc_id) */
-    ierr = PetscMalloc1(Mbs,&ctable);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(Mbs,&ctable));
     for (proc_id=0,j=0; proc_id<size; proc_id++) {
       for (; j<C->rmap->range[proc_id+1]/bs; j++) ctable[j] = proc_id;
     }
 
     /* hash tables marking c->garray */
-    ierr = ISGetIndices(garray_gl,&idx_i);CHKERRQ(ierr);
+    PetscCall(ISGetIndices(garray_gl,&idx_i));
     for (i=0; i<size; i++) {
       table_i = table[i];
-      ierr    = PetscBTMemzero(Mbs,table_i);CHKERRQ(ierr);
+      PetscCall(PetscBTMemzero(Mbs,table_i));
       for (j = Bowners[i]; j<Bowners[i+1]; j++) { /* go through B cols of proc[i]*/
-        ierr = PetscBTSet(table_i,idx_i[j]);CHKERRQ(ierr);
+        PetscCall(PetscBTSet(table_i,idx_i[j]));
       }
     }
-    ierr = ISRestoreIndices(garray_gl,&idx_i);CHKERRQ(ierr);
+    PetscCall(ISRestoreIndices(garray_gl,&idx_i));
   }  /* if (is_max) */
-  ierr = ISDestroy(&garray_gl);CHKERRQ(ierr);
+  PetscCall(ISDestroy(&garray_gl));
 
   /* evaluate communication - mesg to who, length, and buffer space */
   for (i=0; i<size; i++) len_s[i] = 0;
@@ -276,7 +258,7 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
   }
 
   for (i=0; i<is_max; i++) {
-    ierr = ISGetIndices(is[i],&idx_i);CHKERRQ(ierr);
+    PetscCall(ISGetIndices(is[i],&idx_i));
     for (j=0; j<n[i]; j++) {
       idx                = idx_i[j];
       *data1_start[rank] = idx; data1_start[rank]++; /* for local proccessing */
@@ -294,7 +276,7 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
       *(data1 + proc_id*len + 1 + i) = len_s[proc_id] - iwork[proc_id];
       iwork[proc_id]                 = len_s[proc_id];
     }
-    ierr = ISRestoreIndices(is[i],&idx_i);CHKERRQ(ierr);
+    PetscCall(ISRestoreIndices(is[i],&idx_i));
   }
 
   nrqs = 0; nrqr = 0;
@@ -307,21 +289,21 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
   }
 
   for (i=0; i<is_max; i++) {
-    ierr = ISDestroy(&is[i]);CHKERRQ(ierr);
+    PetscCall(ISDestroy(&is[i]));
   }
-  ierr = PetscFree(n);CHKERRQ(ierr);
-  ierr = PetscFree(ctable);CHKERRQ(ierr);
+  PetscCall(PetscFree(n));
+  PetscCall(PetscFree(ctable));
 
   /* Determine the number of messages to expect, their lengths, from from-ids */
-  ierr = PetscGatherNumberOfMessages(comm,NULL,len_s,&nrqr);CHKERRQ(ierr);
-  ierr = PetscGatherMessageLengths(comm,nrqs,nrqr,len_s,&id_r1,&len_r1);CHKERRQ(ierr);
+  PetscCall(PetscGatherNumberOfMessages(comm,NULL,len_s,&nrqr));
+  PetscCall(PetscGatherMessageLengths(comm,nrqs,nrqr,len_s,&id_r1,&len_r1));
 
   /*  Now  post the sends */
-  ierr = PetscMalloc2(size,&s_waits1,size,&s_waits2);CHKERRQ(ierr);
+  PetscCall(PetscMalloc2(size,&s_waits1,size,&s_waits2));
   k    = 0;
   for (proc_id=0; proc_id<size; proc_id++) {  /* send data1 to processor [proc_id] */
     if (len_s[proc_id]) {
-      ierr = MPI_Isend(data1_start[proc_id],len_s[proc_id],MPIU_INT,proc_id,tag1,comm,s_waits1+k);CHKERRQ(ierr);
+      PetscCallMPI(MPI_Isend(data1_start[proc_id],len_s[proc_id],MPIU_INT,proc_id,tag1,comm,s_waits1+k));
       k++;
     }
   }
@@ -332,18 +314,18 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
   for (i=0; i<nrqr; i++) {
     if (len_r1[i] > len) len = len_r1[i];
   }
-  ierr = PetscFree(len_r1);CHKERRQ(ierr);
-  ierr = PetscFree(id_r1);CHKERRQ(ierr);
+  PetscCall(PetscFree(len_r1));
+  PetscCall(PetscFree(id_r1));
 
   for (proc_id=0; proc_id<size; proc_id++) len_s[proc_id] = iwork[proc_id] = 0;
 
-  ierr = PetscMalloc1(len+1,&odata1);CHKERRQ(ierr);
-  ierr = PetscMalloc1(size,&odata2_ptr);CHKERRQ(ierr);
-  ierr = PetscBTCreate(Mbs,&otable);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(len+1,&odata1));
+  PetscCall(PetscMalloc1(size,&odata2_ptr));
+  PetscCall(PetscBTCreate(Mbs,&otable));
 
   len_max = ois_max*(Mbs+1); /* max space storing all is[] for each receive */
   len_est = 2*len_max;       /* estimated space of storing is[] for all receiving messages */
-  ierr    = PetscMalloc1(len_est+1,&odata2);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(len_est+1,&odata2));
   nodata2 = 0;               /* nodata2+1: num of PetscMalloc(,&odata2_ptr[]) called */
 
   odata2_ptr[nodata2] = odata2;
@@ -353,70 +335,70 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
   k = 0;
   while (k < nrqr) {
     /* Receive messages */
-    ierr = MPI_Iprobe(MPI_ANY_SOURCE,tag1,comm,&flag,&r_status);CHKERRQ(ierr);
+    PetscCallMPI(MPI_Iprobe(MPI_ANY_SOURCE,tag1,comm,&flag,&r_status));
     if (flag) {
-      ierr    = MPI_Get_count(&r_status,MPIU_INT,&len);CHKERRQ(ierr);
+      PetscCallMPI(MPI_Get_count(&r_status,MPIU_INT,&len));
       proc_id = r_status.MPI_SOURCE;
-      ierr    = MPI_Irecv(odata1,len,MPIU_INT,proc_id,r_status.MPI_TAG,comm,&r_req);CHKERRQ(ierr);
-      ierr    = MPI_Wait(&r_req,&r_status);CHKERRQ(ierr);
+      PetscCallMPI(MPI_Irecv(odata1,len,MPIU_INT,proc_id,r_status.MPI_TAG,comm,&r_req));
+      PetscCallMPI(MPI_Wait(&r_req,&r_status));
 
       /*  Process messages */
       /*  make sure there is enough unused space in odata2 array */
       if (len_unused < len_max) { /* allocate more space for odata2 */
-        ierr = PetscMalloc1(len_est+1,&odata2);CHKERRQ(ierr);
+        PetscCall(PetscMalloc1(len_est+1,&odata2));
 
         odata2_ptr[++nodata2] = odata2;
 
         len_unused = len_est;
       }
 
-      ierr = MatIncreaseOverlap_MPISBAIJ_Local(C,odata1,OTHER,odata2,&otable);CHKERRQ(ierr);
+      PetscCall(MatIncreaseOverlap_MPISBAIJ_Local(C,odata1,OTHER,odata2,&otable));
       len  = 1 + odata2[0];
       for (i=0; i<odata2[0]; i++) len += odata2[1 + i];
 
       /* Send messages back */
-      ierr = MPI_Isend(odata2,len,MPIU_INT,proc_id,tag2,comm,s_waits2+k);CHKERRQ(ierr);
+      PetscCallMPI(MPI_Isend(odata2,len,MPIU_INT,proc_id,tag2,comm,s_waits2+k));
       k++;
       odata2        += len;
       len_unused    -= len;
       len_s[proc_id] = len; /* num of messages sending back to [proc_id] by this proc */
     }
   }
-  ierr = PetscFree(odata1);CHKERRQ(ierr);
-  ierr = PetscBTDestroy(&otable);CHKERRQ(ierr);
+  PetscCall(PetscFree(odata1));
+  PetscCall(PetscBTDestroy(&otable));
 
   /* 3. Do local work on this processor's is[] */
   /*-------------------------------------------*/
   /* make sure there is enough unused space in odata2(=data) array */
   len_max = is_max*(Mbs+1); /* max space storing all is[] for this processor */
   if (len_unused < len_max) { /* allocate more space for odata2 */
-    ierr = PetscMalloc1(len_est+1,&odata2);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(len_est+1,&odata2));
 
     odata2_ptr[++nodata2] = odata2;
   }
 
   data = odata2;
-  ierr = MatIncreaseOverlap_MPISBAIJ_Local(C,data1_start[rank],MINE,data,table);CHKERRQ(ierr);
-  ierr = PetscFree(data1_start);CHKERRQ(ierr);
+  PetscCall(MatIncreaseOverlap_MPISBAIJ_Local(C,data1_start[rank],MINE,data,table));
+  PetscCall(PetscFree(data1_start));
 
   /* 4. Receive work done on other processors, then merge */
   /*------------------------------------------------------*/
   /* get max number of messages that this processor expects to recv */
-  ierr = MPIU_Allreduce(len_s,iwork,size,MPI_INT,MPI_MAX,comm);CHKERRQ(ierr);
-  ierr = PetscMalloc1(iwork[rank]+1,&data2);CHKERRQ(ierr);
-  ierr = PetscFree4(len_s,btable,iwork,Bowners);CHKERRQ(ierr);
+  PetscCall(MPIU_Allreduce(len_s,iwork,size,MPI_INT,MPI_MAX,comm));
+  PetscCall(PetscMalloc1(iwork[rank]+1,&data2));
+  PetscCall(PetscFree4(len_s,btable,iwork,Bowners));
 
   k = 0;
   while (k < nrqs) {
     /* Receive messages */
-    ierr = MPI_Iprobe(MPI_ANY_SOURCE,tag2,comm,&flag,&r_status);CHKERRQ(ierr);
+    PetscCallMPI(MPI_Iprobe(MPI_ANY_SOURCE,tag2,comm,&flag,&r_status));
     if (flag) {
-      ierr = MPI_Get_count(&r_status,MPIU_INT,&len);CHKERRQ(ierr);
+      PetscCallMPI(MPI_Get_count(&r_status,MPIU_INT,&len));
 
       proc_id = r_status.MPI_SOURCE;
 
-      ierr = MPI_Irecv(data2,len,MPIU_INT,proc_id,r_status.MPI_TAG,comm,&r_req);CHKERRQ(ierr);
-      ierr = MPI_Wait(&r_req,&r_status);CHKERRQ(ierr);
+      PetscCallMPI(MPI_Irecv(data2,len,MPIU_INT,proc_id,r_status.MPI_TAG,comm,&r_req));
+      PetscCallMPI(MPI_Wait(&r_req,&r_status));
       if (len > 1+is_max) { /* Add data2 into data */
         data2_i = data2 + 1 + is_max;
         for (i=0; i<is_max; i++) {
@@ -434,34 +416,32 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C,PetscInt is_max,IS
       k++;
     }
   }
-  ierr = PetscFree(data2);CHKERRQ(ierr);
-  ierr = PetscFree2(table,t_p);CHKERRQ(ierr);
+  PetscCall(PetscFree(data2));
+  PetscCall(PetscFree2(table,t_p));
 
   /* phase 1 sends are complete */
-  ierr = PetscMalloc1(size,&s_status);CHKERRQ(ierr);
-  if (nrqs) {ierr = MPI_Waitall(nrqs,s_waits1,s_status);CHKERRQ(ierr);}
-  ierr = PetscFree(data1);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(size,&s_status));
+  if (nrqs) PetscCallMPI(MPI_Waitall(nrqs,s_waits1,s_status));
+  PetscCall(PetscFree(data1));
 
   /* phase 2 sends are complete */
-  if (nrqr) {ierr = MPI_Waitall(nrqr,s_waits2,s_status);CHKERRQ(ierr);}
-  ierr = PetscFree2(s_waits1,s_waits2);CHKERRQ(ierr);
-  ierr = PetscFree(s_status);CHKERRQ(ierr);
+  if (nrqr) PetscCallMPI(MPI_Waitall(nrqr,s_waits2,s_status));
+  PetscCall(PetscFree2(s_waits1,s_waits2));
+  PetscCall(PetscFree(s_status));
 
   /* 5. Create new is[] */
   /*--------------------*/
   for (i=0; i<is_max; i++) {
     data_i = data + 1 + is_max + Mbs*i;
-    ierr   = ISCreateGeneral(PETSC_COMM_SELF,data[1+i],data_i,PETSC_COPY_VALUES,is+i);CHKERRQ(ierr);
+    PetscCall(ISCreateGeneral(PETSC_COMM_SELF,data[1+i],data_i,PETSC_COPY_VALUES,is+i));
   }
   for (k=0; k<=nodata2; k++) {
-    ierr = PetscFree(odata2_ptr[k]);CHKERRQ(ierr);
+    PetscCall(PetscFree(odata2_ptr[k]));
   }
-  ierr = PetscFree(odata2_ptr);CHKERRQ(ierr);
+  PetscCall(PetscFree(odata2_ptr));
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "MatIncreaseOverlap_MPISBAIJ_Local"
 /*
    MatIncreaseOverlap_MPISBAIJ_Local - Called by MatIncreaseOverlap, to do
        the work on the local processor.
@@ -485,7 +465,6 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C,PetscInt *data,Pet
   Mat_MPISBAIJ   *c = (Mat_MPISBAIJ*)C->data;
   Mat_SeqSBAIJ   *a = (Mat_SeqSBAIJ*)(c->A)->data;
   Mat_SeqBAIJ    *b = (Mat_SeqBAIJ*)(c->B)->data;
-  PetscErrorCode ierr;
   PetscInt       row,mbs,Mbs,*nidx_i,col,col_max,isz,isz0,*ai,*aj,*bi,*bj,*garray,rstart,l;
   PetscInt       a_start,a_end,b_start,b_end,i,j,k,is_max,*idx_i,n;
   PetscBT        table0;  /* mark the indices of input is[] for look up */
@@ -499,7 +478,7 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C,PetscInt *data,Pet
   rstart = c->rstartbs;
   is_max = data[0];
 
-  ierr = PetscBTCreate(Mbs,&table0);CHKERRQ(ierr);
+  PetscCall(PetscBTCreate(Mbs,&table0));
 
   nidx[0] = is_max;
   idx_i   = data + is_max + 1; /* ptr to input is[0] array */
@@ -515,8 +494,8 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C,PetscInt *data,Pet
     } else {            /* process other processor's is[] - only use one temp table */
       table_i = table[0];
     }
-    ierr = PetscBTMemzero(Mbs,table_i);CHKERRQ(ierr);
-    ierr = PetscBTMemzero(Mbs,table0);CHKERRQ(ierr);
+    PetscCall(PetscBTMemzero(Mbs,table_i));
+    PetscCall(PetscBTMemzero(Mbs,table0));
     if (n==0) {
       nidx[1+i] = 0;  /* size of new is[i] */
       continue;
@@ -525,9 +504,9 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C,PetscInt *data,Pet
     isz0 = 0; col_max = 0;
     for (j=0; j<n; j++) {
       col = idx_i[j];
-      if (col >= Mbs) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"index col %D >= Mbs %D",col,Mbs);
+      PetscCheckFalse(col >= Mbs,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"index col %" PetscInt_FMT " >= Mbs %" PetscInt_FMT,col,Mbs);
       if (!PetscBTLookupSet(table_i,col)) {
-        ierr = PetscBTSet(table0,col);CHKERRQ(ierr);
+        PetscCall(PetscBTSet(table0,col));
         if (whose == MINE) nidx_i[isz0] = col;
         if (col_max < col) col_max = col;
         isz0++;
@@ -578,8 +557,6 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C,PetscInt *data,Pet
     }
     nidx[1+i] = isz; /* size of new is[i] */
   } /* for each is */
-  ierr = PetscBTDestroy(&table0);CHKERRQ(ierr);
+  PetscCall(PetscBTDestroy(&table0));
   PetscFunctionReturn(0);
 }
-
-
