@@ -39,28 +39,25 @@ PETSC_EXTERN PetscErrorCode MatPartitioningCreate_PTScotch(MatPartitioning);
 @*/
 PetscErrorCode  MatPartitioningRegisterAll(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (MatPartitioningRegisterAllCalled) PetscFunctionReturn(0);
   MatPartitioningRegisterAllCalled = PETSC_TRUE;
 
-  ierr = MatPartitioningRegister(MATPARTITIONINGCURRENT, MatPartitioningCreate_Current);CHKERRQ(ierr);
-  ierr = MatPartitioningRegister(MATPARTITIONINGAVERAGE, MatPartitioningCreate_Average);CHKERRQ(ierr);
-  ierr = MatPartitioningRegister(MATPARTITIONINGSQUARE,  MatPartitioningCreate_Square);CHKERRQ(ierr);
-  ierr = MatPartitioningRegister(MATPARTITIONINGHIERARCH,MatPartitioningCreate_Hierarchical);CHKERRQ(ierr);
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGCURRENT, MatPartitioningCreate_Current));
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGAVERAGE, MatPartitioningCreate_Average));
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGSQUARE,  MatPartitioningCreate_Square));
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGHIERARCH,MatPartitioningCreate_Hierarchical));
 #if defined(PETSC_HAVE_PARMETIS)
-  ierr = MatPartitioningRegister(MATPARTITIONINGPARMETIS,MatPartitioningCreate_Parmetis);CHKERRQ(ierr);
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGPARMETIS,MatPartitioningCreate_Parmetis));
 #endif
 #if defined(PETSC_HAVE_CHACO)
-  ierr = MatPartitioningRegister(MATPARTITIONINGCHACO,   MatPartitioningCreate_Chaco);CHKERRQ(ierr);
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGCHACO,   MatPartitioningCreate_Chaco));
 #endif
 #if defined(PETSC_HAVE_PARTY)
-  ierr = MatPartitioningRegister(MATPARTITIONINGPARTY,   MatPartitioningCreate_Party);CHKERRQ(ierr);
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGPARTY,   MatPartitioningCreate_Party));
 #endif
 #if defined(PETSC_HAVE_PTSCOTCH)
-  ierr = MatPartitioningRegister(MATPARTITIONINGPTSCOTCH,MatPartitioningCreate_PTScotch);CHKERRQ(ierr);
+  PetscCall(MatPartitioningRegister(MATPARTITIONINGPTSCOTCH,MatPartitioningCreate_PTScotch));
 #endif
   PetscFunctionReturn(0);
 }
-
