@@ -39,15 +39,13 @@ typedef struct {
 @*/
 PetscErrorCode SNESMSRegisterAll(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (SNESMSRegisterAllCalled) PetscFunctionReturn(0);
   SNESMSRegisterAllCalled = PETSC_TRUE;
 
   {
     PetscReal alpha[1] = {1.0};
-    ierr = SNESMSRegister(SNESMSEULER,1,1,1.0,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSEULER,1,1,1.0,NULL,NULL,alpha));
   }
 
   {
@@ -58,37 +56,37 @@ PetscErrorCode SNESMSRegisterAll(void)
     };
     PetscReal delta[6]   = {1.0000000000000000E+00, 5.3275427433201750E-01, 6.0143544663985238E-01, 4.5874077053842177E-01, 2.7544386906104651E-01, 0.0000000000000000E+00};
     PetscReal betasub[6] = {8.4753115429481929E-01, 7.4018896368655618E-01, 6.5963574086583309E-03, 4.6747795645517759E-01, 1.3314545813643919E-01, 5.3260800028018784E-01};
-    ierr = SNESMSRegister(SNESMSM62,6,3,1.0,&gamma[0][0],delta,betasub);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSM62,6,3,1.0,&gamma[0][0],delta,betasub));
   }
 
   { /* Jameson (1983) */
     PetscReal alpha[4] = {0.25, 0.5, 0.55, 1.0};
-    ierr = SNESMSRegister(SNESMSJAMESON83,4,1,1.0,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSJAMESON83,4,1,1.0,NULL,NULL,alpha));
   }
 
   { /* Van Leer, Tai, and Powell (1989) 1 stage, order 1 */
     PetscReal alpha[1]  = {1.0};
-    ierr = SNESMSRegister(SNESMSVLTP11,1,1,0.5,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSVLTP11,1,1,0.5,NULL,NULL,alpha));
   }
   { /* Van Leer, Tai, and Powell (1989) 2 stage, order 1 */
     PetscReal alpha[2] = {0.3333, 1.0};
-    ierr = SNESMSRegister(SNESMSVLTP21,2,1,1.0,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSVLTP21,2,1,1.0,NULL,NULL,alpha));
   }
   { /* Van Leer, Tai, and Powell (1989) 3 stage, order 1 */
     PetscReal alpha[3] = {0.1481, 0.4000, 1.0};
-    ierr = SNESMSRegister(SNESMSVLTP31,3,1,1.5,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSVLTP31,3,1,1.5,NULL,NULL,alpha));
   }
   { /* Van Leer, Tai, and Powell (1989) 4 stage, order 1 */
     PetscReal alpha[4] = {0.0833, 0.2069, 0.4265, 1.0};
-    ierr = SNESMSRegister(SNESMSVLTP41,4,1,2.0,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSVLTP41,4,1,2.0,NULL,NULL,alpha));
   }
   { /* Van Leer, Tai, and Powell (1989) 5 stage, order 1 */
     PetscReal alpha[5] = {0.0533, 0.1263, 0.2375, 0.4414,1.0};
-    ierr = SNESMSRegister(SNESMSVLTP51,5,1,2.5,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSVLTP51,5,1,2.5,NULL,NULL,alpha));
   }
   { /* Van Leer, Tai, and Powell (1989) 6 stage, order 1 */
     PetscReal alpha[6] = {0.0370, 0.0851, 0.1521, 0.2562, 0.4512, 1.0};
-    ierr = SNESMSRegister(SNESMSVLTP61,6,1,3.0,NULL,NULL,alpha);CHKERRQ(ierr);
+    PetscCall(SNESMSRegister(SNESMSVLTP61,6,1,3.0,NULL,NULL,alpha));
   }
   PetscFunctionReturn(0);
 }
@@ -104,7 +102,6 @@ PetscErrorCode SNESMSRegisterAll(void)
 @*/
 PetscErrorCode SNESMSRegisterDestroy(void)
 {
-  PetscErrorCode    ierr;
   SNESMSTableauLink link;
 
   PetscFunctionBegin;
@@ -112,11 +109,11 @@ PetscErrorCode SNESMSRegisterDestroy(void)
     SNESMSTableau t = &link->tab;
     SNESMSTableauList = link->next;
 
-    ierr = PetscFree(t->name);CHKERRQ(ierr);
-    ierr = PetscFree(t->gamma);CHKERRQ(ierr);
-    ierr = PetscFree(t->delta);CHKERRQ(ierr);
-    ierr = PetscFree(t->betasub);CHKERRQ(ierr);
-    ierr = PetscFree(link);CHKERRQ(ierr);
+    PetscCall(PetscFree(t->name));
+    PetscCall(PetscFree(t->gamma));
+    PetscCall(PetscFree(t->delta));
+    PetscCall(PetscFree(t->betasub));
+    PetscCall(PetscFree(link));
   }
   SNESMSRegisterAllCalled = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -132,14 +129,12 @@ PetscErrorCode SNESMSRegisterDestroy(void)
 @*/
 PetscErrorCode SNESMSInitializePackage(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (SNESMSPackageInitialized) PetscFunctionReturn(0);
   SNESMSPackageInitialized = PETSC_TRUE;
 
-  ierr = SNESMSRegisterAll();CHKERRQ(ierr);
-  ierr = PetscRegisterFinalize(SNESMSFinalizePackage);CHKERRQ(ierr);
+  PetscCall(SNESMSRegisterAll());
+  PetscCall(PetscRegisterFinalize(SNESMSFinalizePackage));
   PetscFunctionReturn(0);
 }
 
@@ -153,12 +148,10 @@ PetscErrorCode SNESMSInitializePackage(void)
 @*/
 PetscErrorCode SNESMSFinalizePackage(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   SNESMSPackageInitialized = PETSC_FALSE;
 
-  ierr = SNESMSRegisterDestroy();CHKERRQ(ierr);
+  PetscCall(SNESMSRegisterDestroy());
   PetscFunctionReturn(0);
 }
 
@@ -194,38 +187,37 @@ PetscErrorCode SNESMSFinalizePackage(void)
 @*/
 PetscErrorCode SNESMSRegister(SNESMSType name,PetscInt nstages,PetscInt nregisters,PetscReal stability,const PetscReal gamma[],const PetscReal delta[],const PetscReal betasub[])
 {
-  PetscErrorCode    ierr;
   SNESMSTableauLink link;
   SNESMSTableau     t;
 
   PetscFunctionBegin;
   PetscValidCharPointer(name,1);
-  if (nstages < 1) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Must have at least one stage");
+  PetscCheckFalse(nstages < 1,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Must have at least one stage");
   if (gamma || delta) {
-    if (nregisters != 3) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Only support for methods written in 3-register form");
+    PetscCheckFalse(nregisters != 3,PETSC_COMM_SELF,PETSC_ERR_SUP,"Only support for methods written in 3-register form");
     PetscValidRealPointer(gamma,5);
     PetscValidRealPointer(delta,6);
   } else {
-    if (nregisters != 1) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Only support for methods written in 1-register form");
+    PetscCheckFalse(nregisters != 1,PETSC_COMM_SELF,PETSC_ERR_SUP,"Only support for methods written in 1-register form");
   }
   PetscValidRealPointer(betasub,7);
 
-  ierr          = SNESMSInitializePackage();CHKERRQ(ierr);
-  ierr          = PetscNew(&link);CHKERRQ(ierr);
+  PetscCall(SNESMSInitializePackage());
+  PetscCall(PetscNew(&link));
   t             = &link->tab;
-  ierr          = PetscStrallocpy(name,&t->name);CHKERRQ(ierr);
+  PetscCall(PetscStrallocpy(name,&t->name));
   t->nstages    = nstages;
   t->nregisters = nregisters;
   t->stability  = stability;
 
   if (gamma && delta) {
-    ierr = PetscMalloc1(nstages*nregisters,&t->gamma);CHKERRQ(ierr);
-    ierr = PetscMalloc1(nstages,&t->delta);CHKERRQ(ierr);
-    ierr = PetscArraycpy(t->gamma,gamma,nstages*nregisters);CHKERRQ(ierr);
-    ierr = PetscArraycpy(t->delta,delta,nstages);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(nstages*nregisters,&t->gamma));
+    PetscCall(PetscMalloc1(nstages,&t->delta));
+    PetscCall(PetscArraycpy(t->gamma,gamma,nstages*nregisters));
+    PetscCall(PetscArraycpy(t->delta,delta,nstages));
   }
-  ierr = PetscMalloc1(nstages,&t->betasub);CHKERRQ(ierr);
-  ierr = PetscArraycpy(t->betasub,betasub,nstages);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(nstages,&t->betasub));
+  PetscCall(PetscArraycpy(t->betasub,betasub,nstages));
 
   link->next        = SNESMSTableauList;
   SNESMSTableauList = link;
@@ -238,7 +230,6 @@ PetscErrorCode SNESMSRegister(SNESMSType name,PetscInt nstages,PetscInt nregiste
 */
 static PetscErrorCode SNESMSStep_3Sstar(SNES snes,Vec X,Vec F)
 {
-  PetscErrorCode  ierr;
   SNES_MS         *ms    = (SNES_MS*)snes->data;
   SNESMSTableau   t      = ms->tableau;
   const PetscReal *gamma = t->gamma,*delta = t->delta,*betasub = t->betasub;
@@ -250,8 +241,8 @@ static PetscErrorCode SNESMSStep_3Sstar(SNES snes,Vec X,Vec F)
   S1   = X;
   S2   = snes->work[1];
   S3   = snes->work[2];
-  ierr = VecZeroEntries(S2);CHKERRQ(ierr);
-  ierr = VecCopy(X,S3);CHKERRQ(ierr);
+  PetscCall(VecZeroEntries(S2));
+  PetscCall(VecCopy(X,S3));
   for (i = 0; i < nstages; i++) {
     Vec         Ss[4];
     PetscScalar scoeff[4];
@@ -263,12 +254,12 @@ static PetscErrorCode SNESMSStep_3Sstar(SNES snes,Vec X,Vec F)
     scoeff[2] = gamma[2*nstages+i];
     scoeff[3] = -betasub[i]*ms->damping;
 
-    ierr = VecAXPY(S2,delta[i],S1);CHKERRQ(ierr);
+    PetscCall(VecAXPY(S2,delta[i],S1));
     if (i > 0) {
-      ierr = SNESComputeFunction(snes,S1,F);CHKERRQ(ierr);
+      PetscCall(SNESComputeFunction(snes,S1,F));
     }
-    ierr = KSPSolve(snes->ksp,F,Y);CHKERRQ(ierr);
-    ierr = VecMAXPY(S1,4,scoeff,Ss);CHKERRQ(ierr);
+    PetscCall(KSPSolve(snes->ksp,F,Y));
+    PetscCall(VecMAXPY(S1,4,scoeff,Ss));
   }
   PetscFunctionReturn(0);
 }
@@ -279,7 +270,6 @@ static PetscErrorCode SNESMSStep_3Sstar(SNES snes,Vec X,Vec F)
 */
 static PetscErrorCode SNESMSStep_Basic(SNES snes,Vec X,Vec F)
 {
-  PetscErrorCode  ierr;
   SNES_MS         *ms    = (SNES_MS*)snes->data;
   SNESMSTableau   tab    = ms->tableau;
   const PetscReal *alpha = tab->betasub, h = ms->damping;
@@ -287,13 +277,13 @@ static PetscErrorCode SNESMSStep_Basic(SNES snes,Vec X,Vec F)
   Vec             X0 = snes->work[0];
 
   PetscFunctionBegin;
-  ierr = VecCopy(X,X0);CHKERRQ(ierr);
+  PetscCall(VecCopy(X,X0));
   for (i = 0; i < nstages; i++) {
     if (i > 0) {
-      ierr = SNESComputeFunction(snes,X,F);CHKERRQ(ierr);
+      PetscCall(SNESComputeFunction(snes,X,F));
     }
-    ierr = KSPSolve(snes->ksp,F,X);CHKERRQ(ierr);
-    ierr = VecAYPX(X,-alpha[i]*h,X0);CHKERRQ(ierr);
+    PetscCall(KSPSolve(snes->ksp,F,X));
+    PetscCall(VecAYPX(X,-alpha[i]*h,X0));
   }
   PetscFunctionReturn(0);
 }
@@ -302,13 +292,12 @@ static PetscErrorCode SNESMSStep_Step(SNES snes,Vec X,Vec F)
 {
   SNES_MS        *ms = (SNES_MS*)snes->data;
   SNESMSTableau  tab = ms->tableau;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (tab->gamma && tab->delta) {
-    ierr = SNESMSStep_3Sstar(snes,X,F);CHKERRQ(ierr);
+    PetscCall(SNESMSStep_3Sstar(snes,X,F));
   } else {
-    ierr = SNESMSStep_Basic(snes,X,F);CHKERRQ(ierr);
+    PetscCall(SNESMSStep_Basic(snes,X,F));
   }
   PetscFunctionReturn(0);
 }
@@ -317,25 +306,24 @@ static PetscErrorCode SNESMSStep_Norms(SNES snes,PetscInt iter,Vec F)
 {
   SNES_MS        *ms = (SNES_MS*)snes->data;
   PetscReal      fnorm;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (ms->norms) {
-    ierr = VecNorm(F,NORM_2,&fnorm);CHKERRQ(ierr); /* fnorm <- ||F||  */
+    PetscCall(VecNorm(F,NORM_2,&fnorm)); /* fnorm <- ||F||  */
     SNESCheckFunctionNorm(snes,fnorm);
     /* Monitor convergence */
-    ierr = PetscObjectSAWsTakeAccess((PetscObject)snes);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsTakeAccess((PetscObject)snes));
     snes->iter = iter;
     snes->norm = fnorm;
-    ierr = PetscObjectSAWsGrantAccess((PetscObject)snes);CHKERRQ(ierr);
-    ierr = SNESLogConvergenceHistory(snes,snes->norm,0);CHKERRQ(ierr);
-    ierr = SNESMonitor(snes,snes->iter,snes->norm);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
+    PetscCall(SNESLogConvergenceHistory(snes,snes->norm,0));
+    PetscCall(SNESMonitor(snes,snes->iter,snes->norm));
     /* Test for convergence */
-    ierr = (*snes->ops->converged)(snes,snes->iter,0.0,0.0,fnorm,&snes->reason,snes->cnvP);CHKERRQ(ierr);
+    PetscCall((*snes->ops->converged)(snes,snes->iter,0.0,0.0,fnorm,&snes->reason,snes->cnvP));
   } else if (iter > 0) {
-    ierr = PetscObjectSAWsTakeAccess((PetscObject)snes);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsTakeAccess((PetscObject)snes));
     snes->iter = iter;
-    ierr = PetscObjectSAWsGrantAccess((PetscObject)snes);CHKERRQ(ierr);
+    PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
   }
   PetscFunctionReturn(0);
 }
@@ -345,46 +333,45 @@ static PetscErrorCode SNESSolve_MS(SNES snes)
   SNES_MS        *ms = (SNES_MS*)snes->data;
   Vec            X   = snes->vec_sol,F = snes->vec_func;
   PetscInt       i;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  if (snes->xl || snes->xu || snes->ops->computevariablebounds) SETERRQ1(PetscObjectComm((PetscObject)snes),PETSC_ERR_ARG_WRONGSTATE, "SNES solver %s does not support bounds", ((PetscObject)snes)->type_name);
-  ierr = PetscCitationsRegister(SNESCitation,&SNEScite);CHKERRQ(ierr);
+  PetscCheckFalse(snes->xl || snes->xu || snes->ops->computevariablebounds,PetscObjectComm((PetscObject)snes),PETSC_ERR_ARG_WRONGSTATE, "SNES solver %s does not support bounds", ((PetscObject)snes)->type_name);
+  PetscCall(PetscCitationsRegister(SNESCitation,&SNEScite));
 
   snes->reason = SNES_CONVERGED_ITERATING;
-  ierr         = PetscObjectSAWsTakeAccess((PetscObject)snes);CHKERRQ(ierr);
+  PetscCall(PetscObjectSAWsTakeAccess((PetscObject)snes));
   snes->iter   = 0;
   snes->norm   = 0;
-  ierr         = PetscObjectSAWsGrantAccess((PetscObject)snes);CHKERRQ(ierr);
+  PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
 
   if (!snes->vec_func_init_set) {
-    ierr = SNESComputeFunction(snes,X,F);CHKERRQ(ierr);
+    PetscCall(SNESComputeFunction(snes,X,F));
   } else snes->vec_func_init_set = PETSC_FALSE;
 
-  ierr = SNESMSStep_Norms(snes,0,F);CHKERRQ(ierr);
+  PetscCall(SNESMSStep_Norms(snes,0,F));
   if (snes->reason) PetscFunctionReturn(0);
 
   for (i = 0; i < snes->max_its; i++) {
 
     /* Call general purpose update function */
     if (snes->ops->update) {
-      ierr = (*snes->ops->update)(snes,snes->iter);CHKERRQ(ierr);
+      PetscCall((*snes->ops->update)(snes,snes->iter));
     }
 
     if (i == 0 && snes->jacobian) {
       /* This method does not require a Jacobian, but it is usually preconditioned by PBJacobi */
-      ierr = SNESComputeJacobian(snes,snes->vec_sol,snes->jacobian,snes->jacobian_pre);CHKERRQ(ierr);
+      PetscCall(SNESComputeJacobian(snes,snes->vec_sol,snes->jacobian,snes->jacobian_pre));
       SNESCheckJacobianDomainerror(snes);
-      ierr = KSPSetOperators(snes->ksp,snes->jacobian,snes->jacobian_pre);CHKERRQ(ierr);
+      PetscCall(KSPSetOperators(snes->ksp,snes->jacobian,snes->jacobian_pre));
     }
 
-    ierr = SNESMSStep_Step(snes,X,F);CHKERRQ(ierr);
+    PetscCall(SNESMSStep_Step(snes,X,F));
 
     if (i < snes->max_its-1 || ms->norms) {
-      ierr = SNESComputeFunction(snes,X,F);CHKERRQ(ierr);
+      PetscCall(SNESComputeFunction(snes,X,F));
     }
 
-    ierr = SNESMSStep_Norms(snes,i+1,F);CHKERRQ(ierr);
+    PetscCall(SNESMSStep_Norms(snes,i+1,F));
     if (snes->reason) PetscFunctionReturn(0);
   }
   if (!snes->reason) snes->reason = SNES_CONVERGED_ITS;
@@ -396,11 +383,10 @@ static PetscErrorCode SNESSetUp_MS(SNES snes)
   SNES_MS        *ms   = (SNES_MS*)snes->data;
   SNESMSTableau  tab   = ms->tableau;
   PetscInt       nwork = tab->nregisters;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = SNESSetWorkVecs(snes,nwork);CHKERRQ(ierr);
-  ierr = SNESSetUpMatrices(snes);CHKERRQ(ierr);
+  PetscCall(SNESSetWorkVecs(snes,nwork));
+  PetscCall(SNESSetUpMatrices(snes));
   PetscFunctionReturn(0);
 }
 
@@ -412,29 +398,26 @@ static PetscErrorCode SNESReset_MS(SNES snes)
 
 static PetscErrorCode SNESDestroy_MS(SNES snes)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = SNESReset_MS(snes);CHKERRQ(ierr);
-  ierr = PetscFree(snes->data);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetType_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetType_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetDamping_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetDamping_C",NULL);CHKERRQ(ierr);
+  PetscCall(SNESReset_MS(snes));
+  PetscCall(PetscFree(snes->data));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetType_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetType_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetDamping_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetDamping_C",NULL));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode SNESView_MS(SNES snes,PetscViewer viewer)
 {
   PetscBool      iascii;
-  PetscErrorCode ierr;
   SNES_MS        *ms = (SNES_MS*)snes->data;
   SNESMSTableau  tab = ms->tableau;
 
   PetscFunctionBegin;
-  ierr = PetscObjectTypeCompare((PetscObject) viewer, PETSCVIEWERASCII, &iascii);CHKERRQ(ierr);
+  PetscCall(PetscObjectTypeCompare((PetscObject) viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) {
-    ierr = PetscViewerASCIIPrintf(viewer,"  multi-stage method type: %s\n",tab->name);CHKERRQ(ierr);
+    PetscCall(PetscViewerASCIIPrintf(viewer,"  multi-stage method type: %s\n",tab->name));
   }
   PetscFunctionReturn(0);
 }
@@ -442,10 +425,9 @@ static PetscErrorCode SNESView_MS(SNES snes,PetscViewer viewer)
 static PetscErrorCode SNESSetFromOptions_MS(PetscOptionItems *PetscOptionsObject,SNES snes)
 {
   SNES_MS        *ms = (SNES_MS*)snes->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsHead(PetscOptionsObject,"SNES MS options");CHKERRQ(ierr);
+  PetscCall(PetscOptionsHead(PetscOptionsObject,"SNES MS options"));
   {
     SNESMSTableauLink link;
     PetscInt          count,choice;
@@ -454,19 +436,19 @@ static PetscErrorCode SNESSetFromOptions_MS(PetscOptionItems *PetscOptionsObject
     SNESMSType        mstype;
     PetscReal         damping;
 
-    ierr = SNESMSGetType(snes,&mstype);CHKERRQ(ierr);
+    PetscCall(SNESMSGetType(snes,&mstype));
     for (link=SNESMSTableauList,count=0; link; link=link->next,count++) ;
-    ierr = PetscMalloc1(count,(char***)&namelist);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(count,(char***)&namelist));
     for (link=SNESMSTableauList,count=0; link; link=link->next,count++) namelist[count] = link->tab.name;
-    ierr = PetscOptionsEList("-snes_ms_type","Multistage smoother type","SNESMSSetType",(const char*const*)namelist,count,mstype,&choice,&flg);CHKERRQ(ierr);
-    if (flg) {ierr = SNESMSSetType(snes,namelist[choice]);CHKERRQ(ierr);}
-    ierr = PetscFree(namelist);CHKERRQ(ierr);
-    ierr = SNESMSGetDamping(snes,&damping);CHKERRQ(ierr);
-    ierr = PetscOptionsReal("-snes_ms_damping","Damping for multistage method","SNESMSSetDamping",damping,&damping,&flg);CHKERRQ(ierr);
-    if (flg) {ierr = SNESMSSetDamping(snes,damping);CHKERRQ(ierr);}
-    ierr = PetscOptionsBool("-snes_ms_norms","Compute norms for monitoring","none",ms->norms,&ms->norms,NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsEList("-snes_ms_type","Multistage smoother type","SNESMSSetType",(const char*const*)namelist,count,mstype,&choice,&flg));
+    if (flg) PetscCall(SNESMSSetType(snes,namelist[choice]));
+    PetscCall(PetscFree(namelist));
+    PetscCall(SNESMSGetDamping(snes,&damping));
+    PetscCall(PetscOptionsReal("-snes_ms_damping","Damping for multistage method","SNESMSSetDamping",damping,&damping,&flg));
+    if (flg) PetscCall(SNESMSSetDamping(snes,damping));
+    PetscCall(PetscOptionsBool("-snes_ms_norms","Compute norms for monitoring","none",ms->norms,&ms->norms,NULL));
   }
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(PetscOptionsTail());
   PetscFunctionReturn(0);
 }
 
@@ -485,23 +467,22 @@ static PetscErrorCode SNESMSSetType_MS(SNES snes,SNESMSType mstype)
   SNES_MS           *ms = (SNES_MS*)snes->data;
   SNESMSTableauLink link;
   PetscBool         match;
-  PetscErrorCode    ierr;
 
   PetscFunctionBegin;
   if (ms->tableau) {
-    ierr = PetscStrcmp(ms->tableau->name,mstype,&match);CHKERRQ(ierr);
+    PetscCall(PetscStrcmp(ms->tableau->name,mstype,&match));
     if (match) PetscFunctionReturn(0);
   }
   for (link = SNESMSTableauList; link; link=link->next) {
-    ierr = PetscStrcmp(link->tab.name,mstype,&match);CHKERRQ(ierr);
+    PetscCall(PetscStrcmp(link->tab.name,mstype,&match));
     if (match) {
-      if (snes->setupcalled)  {ierr = SNESReset_MS(snes);CHKERRQ(ierr);}
+      if (snes->setupcalled)  PetscCall(SNESReset_MS(snes));
       ms->tableau = &link->tab;
-      if (snes->setupcalled)  {ierr = SNESSetUp_MS(snes);CHKERRQ(ierr);}
+      if (snes->setupcalled)  PetscCall(SNESSetUp_MS(snes));
       PetscFunctionReturn(0);
     }
   }
-  SETERRQ1(PetscObjectComm((PetscObject)snes),PETSC_ERR_ARG_UNKNOWN_TYPE,"Could not find '%s'",mstype);
+  SETERRQ(PetscObjectComm((PetscObject)snes),PETSC_ERR_ARG_UNKNOWN_TYPE,"Could not find '%s'",mstype);
 }
 
 /*@C
@@ -521,12 +502,10 @@ static PetscErrorCode SNESMSSetType_MS(SNES snes,SNESMSType mstype)
 @*/
 PetscErrorCode SNESMSGetType(SNES snes,SNESMSType *mstype)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
   PetscValidPointer(mstype,2);
-  ierr = PetscUseMethod(snes,"SNESMSGetType_C",(SNES,SNESMSType*),(snes,mstype));CHKERRQ(ierr);
+  PetscUseMethod(snes,"SNESMSGetType_C",(SNES,SNESMSType*),(snes,mstype));
   PetscFunctionReturn(0);
 }
 
@@ -545,12 +524,10 @@ PetscErrorCode SNESMSGetType(SNES snes,SNESMSType *mstype)
 @*/
 PetscErrorCode SNESMSSetType(SNES snes,SNESMSType mstype)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
-  PetscValidPointer(mstype,2);
-  ierr = PetscTryMethod(snes,"SNESMSSetType_C",(SNES,SNESMSType),(snes,mstype));CHKERRQ(ierr);
+  PetscValidCharPointer(mstype,2);
+  PetscTryMethod(snes,"SNESMSSetType_C",(SNES,SNESMSType),(snes,mstype));
   PetscFunctionReturn(0);
 }
 
@@ -589,12 +566,10 @@ static PetscErrorCode SNESMSSetDamping_MS(SNES snes,PetscReal damping)
 @*/
 PetscErrorCode SNESMSGetDamping(SNES snes,PetscReal *damping)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
-  PetscValidPointer(damping,2);
-  ierr = PetscUseMethod(snes,"SNESMSGetDamping_C",(SNES,PetscReal*),(snes,damping));CHKERRQ(ierr);
+  PetscValidRealPointer(damping,2);
+  PetscUseMethod(snes,"SNESMSGetDamping_C",(SNES,PetscReal*),(snes,damping));
   PetscFunctionReturn(0);
 }
 
@@ -613,12 +588,10 @@ PetscErrorCode SNESMSGetDamping(SNES snes,PetscReal *damping)
 @*/
 PetscErrorCode SNESMSSetDamping(SNES snes,PetscReal damping)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
   PetscValidLogicalCollectiveReal(snes,damping,2);
-  ierr = PetscTryMethod(snes,"SNESMSSetDamping_C",(SNES,PetscReal),(snes,damping));CHKERRQ(ierr);
+  PetscTryMethod(snes,"SNESMSSetDamping_C",(SNES,PetscReal),(snes,damping));
   PetscFunctionReturn(0);
 }
 
@@ -640,10 +613,10 @@ PetscErrorCode SNESMSSetDamping(SNES snes,PetscReal damping)
       The methods are specified in low storage form (Ketcheson 2010). New methods can be registered with SNESMSRegister().
 
       References:
-+   1. -   Ketcheson (2010) Runge Kutta methods with minimum storage implementations (https://doi.org/10.1016/j.jcp.2009.11.006).
-.   2. -   Jameson (1983) Solution of the Euler equations for two dimensional transonic flow by a multigrid method (https://doi.org/10.1016/0096-3003(83)90019-X).
-.   3. -   Pierce and Giles (1997) Preconditioned multigrid methods for compressible flow calculations on stretched meshes (https://doi.org/10.1006/jcph.1997.5772).
--   4. -   Van Leer, Tai, and Powell (1989) Design of optimally smoothing multi-stage schemes for the Euler equations (https://doi.org/10.2514/6.1989-1933).
++     * - Ketcheson (2010) Runge Kutta methods with minimum storage implementations (https://doi.org/10.1016/j.jcp.2009.11.006).
+.     * - Jameson (1983) Solution of the Euler equations for two dimensional transonic flow by a multigrid method (https://doi.org/10.1016/0096-3003(83)90019-X).
+.     * - Pierce and Giles (1997) Preconditioned multigrid methods for compressible flow calculations on stretched meshes (https://doi.org/10.1006/jcph.1997.5772).
+-     * - Van Leer, Tai, and Powell (1989) Design of optimally smoothing multi-stage schemes for the Euler equations (https://doi.org/10.2514/6.1989-1933).
 
       Level: beginner
 
@@ -652,11 +625,10 @@ PetscErrorCode SNESMSSetDamping(SNES snes,PetscReal damping)
 M*/
 PETSC_EXTERN PetscErrorCode SNESCreate_MS(SNES snes)
 {
-  PetscErrorCode ierr;
   SNES_MS        *ms;
 
   PetscFunctionBegin;
-  ierr = SNESMSInitializePackage();CHKERRQ(ierr);
+  PetscCall(SNESMSInitializePackage());
 
   snes->ops->setup          = SNESSetUp_MS;
   snes->ops->solve          = SNESSolve_MS;
@@ -670,16 +642,16 @@ PETSC_EXTERN PetscErrorCode SNESCreate_MS(SNES snes)
 
   snes->alwayscomputesfinalresidual = PETSC_FALSE;
 
-  ierr        = PetscNewLog(snes,&ms);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(snes,&ms));
   snes->data  = (void*)ms;
   ms->damping = 0.9;
   ms->norms   = PETSC_FALSE;
 
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetType_C",SNESMSGetType_MS);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetType_C",SNESMSSetType_MS);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetDamping_C",SNESMSGetDamping_MS);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetDamping_C",SNESMSSetDamping_MS);CHKERRQ(ierr);
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetType_C",SNESMSGetType_MS));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetType_C",SNESMSSetType_MS));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSGetDamping_C",SNESMSGetDamping_MS));
+  PetscCall(PetscObjectComposeFunction((PetscObject)snes,"SNESMSSetDamping_C",SNESMSSetDamping_MS));
 
-  ierr = SNESMSSetType(snes,SNESMSDefault);CHKERRQ(ierr);
+  PetscCall(SNESMSSetType(snes,SNESMSDefault));
   PetscFunctionReturn(0);
 }
