@@ -13,13 +13,6 @@ The flow can be driven with the lid or with bouyancy or both:\n\
       See src/ksp/ksp/tutorials/ex45.c
 */
 
-/*T
-   Concepts: SNES^solving a system of nonlinear equations (parallel multicomponent example);
-   Concepts: DMDA^using distributed arrays;
-   Concepts: multicomponent
-   Processors: n
-T*/
-
 /*F-----------------------------------------------------------------------
 
     We thank David E. Keyes for contributing the driven cavity discretization within this example code.
