@@ -21,11 +21,10 @@ typedef struct {
 */
 PetscErrorCode FormInitialGuess(Vec x)
 {
-  PetscErrorCode ierr;
   PetscScalar    pfive = .50;
 
   PetscFunctionBeginUser;
-  ierr = VecSet(x,pfive);CHKERRQ(ierr);
+  PetscCall(VecSet(x,pfive));
   PetscFunctionReturn(0);
 }
 
@@ -50,19 +49,18 @@ PetscErrorCode CpuFunction(SNES snes,Vec x,Vec r,void *ctx)
   ApplicationCtx *user = (ApplicationCtx*) ctx;
   DM             da    = user->da;
   PetscScalar    *X,*R,*F,d;
-  PetscErrorCode ierr;
   PetscInt       i,M,xs,xm;
   Vec            xl;
 
   PetscFunctionBeginUser;
-  ierr = DMGetLocalVector(da,&xl);CHKERRQ(ierr);
-  ierr = DMGlobalToLocal(da,x,INSERT_VALUES,xl);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,xl,&X);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,r,&R);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,user->F,&F);CHKERRQ(ierr);
+  PetscCall(DMGetLocalVector(da,&xl));
+  PetscCall(DMGlobalToLocal(da,x,INSERT_VALUES,xl));
+  PetscCall(DMDAVecGetArray(da,xl,&X));
+  PetscCall(DMDAVecGetArray(da,r,&R));
+  PetscCall(DMDAVecGetArray(da,user->F,&F));
 
-  ierr = DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL);CHKERRQ(ierr);
-  ierr = DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL));
+  PetscCall(DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL));
 
   if (xs == 0) { /* left boundary */
     R[0] = X[0];
@@ -75,10 +73,10 @@ PetscErrorCode CpuFunction(SNES snes,Vec x,Vec r,void *ctx)
   d = 1.0/(user->h*user->h);
   for (i=xs; i<xs+xm; i++) R[i] = d*(X[i-1] - 2.0*X[i] + X[i+1]) + X[i]*X[i] - F[i];
 
-  ierr = DMDAVecRestoreArray(da,xl,&X);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(da,r,&R);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(da,user->F,&F);CHKERRQ(ierr);
-  ierr = DMRestoreLocalVector(da,&xl);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArray(da,xl,&X));
+  PetscCall(DMDAVecRestoreArray(da,r,&R));
+  PetscCall(DMDAVecRestoreArray(da,user->F,&F));
+  PetscCall(DMRestoreLocalVector(da,&xl));
   PetscFunctionReturn(0);
 }
 
@@ -89,7 +87,6 @@ using ConstPetscScalarKokkosOffsetView  = Kokkos::Experimental::OffsetView<const
 
 PetscErrorCode KokkosFunction(SNES snes,Vec x,Vec r,void *ctx)
 {
-  PetscErrorCode                       ierr;
   ApplicationCtx                       *user = (ApplicationCtx*) ctx;
   DM                                   da = user->da;
   PetscScalar                          d;
@@ -99,41 +96,40 @@ PetscErrorCode KokkosFunction(SNES snes,Vec x,Vec r,void *ctx)
   ConstPetscScalarKokkosOffsetView     X,F;
 
   PetscFunctionBeginUser;
-  ierr = DMGetLocalVector(da,&xl);CHKERRQ(ierr);
-  ierr = DMGlobalToLocal(da,x,INSERT_VALUES,xl);CHKERRQ(ierr);
+  PetscCall(DMGetLocalVector(da,&xl));
+  PetscCall(DMGlobalToLocal(da,x,INSERT_VALUES,xl));
   d    = 1.0/(user->h*user->h);
-  ierr = DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
-  ierr = DMDAVecGetKokkosOffsetView(da,xl,&X);CHKERRQ(ierr); /* read only */
-  ierr = DMDAVecGetKokkosOffsetViewWrite(da,r,&R);CHKERRQ(ierr); /* write only */
-  ierr = DMDAVecGetKokkosOffsetView(da,user->F,&F);CHKERRQ(ierr); /* read only */
+  PetscCall(DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL));
+  PetscCall(DMDAVecGetKokkosOffsetView(da,xl,&X)); /* read only */
+  PetscCall(DMDAVecGetKokkosOffsetViewWrite(da,r,&R)); /* write only */
+  PetscCall(DMDAVecGetKokkosOffsetView(da,user->F,&F)); /* read only */
   Kokkos:: parallel_for (Kokkos::RangePolicy<>(R.begin(0),R.end(0)),KOKKOS_LAMBDA (int i) {
     if (i == 0)        R(0) = X(0);        /* left boundary */
     else if (i == M-1) R(i) = X(i) - 1.0;  /* right boundary */
     else               R(i) = d*(X(i-1) - 2.0*X(i) + X(i+1)) + X(i)*X(i) - F(i); /* interior */
   });
-  ierr = DMDAVecRestoreKokkosOffsetView(da,xl,&X);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreKokkosOffsetViewWrite(da,r,&R);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreKokkosOffsetView(da,user->F,&F);CHKERRQ(ierr);
-  ierr = DMRestoreLocalVector(da,&xl);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreKokkosOffsetView(da,xl,&X));
+  PetscCall(DMDAVecRestoreKokkosOffsetViewWrite(da,r,&R));
+  PetscCall(DMDAVecRestoreKokkosOffsetView(da,user->F,&F));
+  PetscCall(DMRestoreLocalVector(da,&xl));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode StubFunction(SNES snes ,Vec x,Vec r,void *ctx)
 {
-  PetscErrorCode                       ierr;
   ApplicationCtx                       *user = (ApplicationCtx*) ctx;
   DM                                   da = user->da;
   Vec                                  rk;
   PetscReal                            norm=0;
 
   PetscFunctionBeginUser;
-  ierr = DMGetGlobalVector(da,&rk);CHKERRQ(ierr);
-  ierr = CpuFunction(snes,x,r,ctx);CHKERRQ(ierr);
-  ierr = KokkosFunction(snes,x,rk,ctx);CHKERRQ(ierr);
-  ierr = VecAXPY(rk,-1.0,r);CHKERRQ(ierr);
-  ierr = VecNorm(rk,NORM_2,&norm);CHKERRQ(ierr);
-  ierr = DMRestoreGlobalVector(da,&rk);CHKERRQ(ierr);
-  if (norm > 1e-6) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_PLIB,"KokkosFunction() different from CpuFunction() with a diff norm = %g\n",norm);
+  PetscCall(DMGetGlobalVector(da,&rk));
+  PetscCall(CpuFunction(snes,x,r,ctx));
+  PetscCall(KokkosFunction(snes,x,rk,ctx));
+  PetscCall(VecAXPY(rk,-1.0,r));
+  PetscCall(VecNorm(rk,NORM_2,&norm));
+  PetscCall(DMRestoreGlobalVector(da,&rk));
+  PetscCheckFalse(norm > 1e-6,PETSC_COMM_SELF,PETSC_ERR_PLIB,"KokkosFunction() different from CpuFunction() with a diff norm = %g",norm);
   PetscFunctionReturn(0);
 }
 /* ------------------------------------------------------------------- */
@@ -154,7 +150,6 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
 {
   ApplicationCtx *user = (ApplicationCtx*) ctx;
   PetscScalar    *xx,d,A[3];
-  PetscErrorCode ierr;
   PetscInt       i,j[3],M,xs,xm;
   DM             da = user->da;
 
@@ -162,13 +157,13 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
   /*
      Get pointer to vector data
   */
-  ierr = DMDAVecGetArrayRead(da,x,&xx);CHKERRQ(ierr);
-  ierr = DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArrayRead(da,x,&xx));
+  PetscCall(DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL));
 
   /*
     Get range of locally owned matrix
   */
-  ierr = DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL));
 
   /*
      Determine starting and ending local indices for interior grid points.
@@ -178,13 +173,13 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
   if (xs == 0) {  /* left boundary */
     i = 0; A[0] = 1.0;
 
-    ierr = MatSetValues(jac,1,&i,1,&i,A,INSERT_VALUES);CHKERRQ(ierr);
+    PetscCall(MatSetValues(jac,1,&i,1,&i,A,INSERT_VALUES));
     xs++;xm--;
   }
   if (xs+xm == M) { /* right boundary */
     i    = M-1;
     A[0] = 1.0;
-    ierr = MatSetValues(jac,1,&i,1,&i,A,INSERT_VALUES);CHKERRQ(ierr);
+    PetscCall(MatSetValues(jac,1,&i,1,&i,A,INSERT_VALUES));
     xm--;
   }
 
@@ -197,7 +192,7 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
   for (i=xs; i<xs+xm; i++) {
     j[0] = i - 1; j[1] = i; j[2] = i + 1;
     A[0] = A[2] = d; A[1] = -2.0*d + 2.0*xx[i];
-    ierr = MatSetValues(jac,1,&i,3,j,A,INSERT_VALUES);CHKERRQ(ierr);
+    PetscCall(MatSetValues(jac,1,&i,3,j,A,INSERT_VALUES));
   }
 
   /*
@@ -209,54 +204,52 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
      Also, restore vector.
   */
 
-  ierr = MatAssemblyBegin(jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArrayRead(da,x,&xx);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(jac,MAT_FINAL_ASSEMBLY));
+  PetscCall(DMDAVecRestoreArrayRead(da,x,&xx));
+  PetscCall(MatAssemblyEnd(jac,MAT_FINAL_ASSEMBLY));
 
   PetscFunctionReturn(0);
 }
 
 int main(int argc,char **argv)
 {
-  SNES                        snes;                 /* SNES context */
-  Mat                         J;                    /* Jacobian matrix */
-  ApplicationCtx              ctx;                  /* user-defined context */
-  Vec                         x,r,U,F;              /* vectors */
-  PetscScalar                 none = -1.0;
-  PetscErrorCode              ierr;
-  PetscInt                    its,N = 5,maxit,maxf;
-  PetscReal                   abstol,rtol,stol,norm;
-  PetscBool                   viewinitial = PETSC_FALSE;
-  PetscScalarKokkosOffsetView FF,UU;
+  SNES           snes;          /* SNES context */
+  Mat            J;             /* Jacobian matrix */
+  ApplicationCtx ctx;           /* user-defined context */
+  Vec            x,r,U,F;       /* vectors */
+  PetscScalar    none        = -1.0;
+  PetscInt       its,N       = 5,maxit,maxf;
+  PetscReal      abstol,rtol,stol,norm;
+  PetscBool      viewinitial = PETSC_FALSE;
 
-  ierr  = PetscInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
-  ierr  = PetscOptionsGetInt(NULL,NULL,"-n",&N,NULL);CHKERRQ(ierr);
+  PetscCall(PetscInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&N,NULL));
   ctx.h = 1.0/(N-1);
-  ierr  = PetscOptionsGetBool(NULL,NULL,"-view_initial",&viewinitial,NULL);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetBool(NULL,NULL,"-view_initial",&viewinitial,NULL));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create nonlinear solver context
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  ierr = SNESCreate(PETSC_COMM_WORLD,&snes);CHKERRQ(ierr);
+  PetscCall(SNESCreate(PETSC_COMM_WORLD,&snes));
 
   /*
      Create distributed array (DMDA) to manage parallel grid and vectors
   */
-  ierr = DMDACreate1d(PETSC_COMM_WORLD,DM_BOUNDARY_NONE,N,1,1,NULL,&ctx.da);CHKERRQ(ierr);
-  ierr = DMSetFromOptions(ctx.da);CHKERRQ(ierr);
-  ierr = DMSetUp(ctx.da);CHKERRQ(ierr);
+  PetscCall(DMDACreate1d(PETSC_COMM_WORLD,DM_BOUNDARY_NONE,N,1,1,NULL,&ctx.da));
+  PetscCall(DMSetFromOptions(ctx.da));
+  PetscCall(DMSetUp(ctx.da));
 
   /*
      Extract global and local vectors from DMDA; then duplicate for remaining
      vectors that are the same types
   */
-  ierr = DMCreateGlobalVector(ctx.da,&x);CHKERRQ(ierr);
-  ierr = PetscObjectSetName((PetscObject)x,"Approximate Solution");CHKERRQ(ierr);
-  ierr = VecDuplicate(x,&r);CHKERRQ(ierr);
-  ierr = VecDuplicate(x,&F);CHKERRQ(ierr); ctx.F = F;
-  ierr = PetscObjectSetName((PetscObject)F,"Forcing function");CHKERRQ(ierr);
-  ierr = VecDuplicate(x,&U);CHKERRQ(ierr);
-  ierr = PetscObjectSetName((PetscObject)U,"Exact Solution");CHKERRQ(ierr);
+  PetscCall(DMCreateGlobalVector(ctx.da,&x));
+  PetscCall(PetscObjectSetName((PetscObject)x,"Approximate Solution"));
+  PetscCall(VecDuplicate(x,&r));
+  PetscCall(VecDuplicate(x,&F)); ctx.F = F;
+  PetscCall(PetscObjectSetName((PetscObject)F,"Forcing function"));
+  PetscCall(VecDuplicate(x,&U));
+  PetscCall(PetscObjectSetName((PetscObject)U,"Exact Solution"));
 
   /*
      Set function evaluation routine and vector.  Whenever the nonlinear
@@ -266,16 +259,16 @@ int main(int argc,char **argv)
         context that provides application-specific data for the
         function evaluation routine.
 
-     At the begining, one can use a stub function that checks the Kokkos version
+     At the beginning, one can use a stub function that checks the Kokkos version
      against the CPU version to quickly expose errors.
-     ierr = SNESSetFunction(snes,r,StubFunction,&ctx);CHKERRQ(ierr);
+     PetscCall(SNESSetFunction(snes,r,StubFunction,&ctx));
   */
-  ierr = SNESSetFunction(snes,r,KokkosFunction,&ctx);CHKERRQ(ierr);
+  PetscCall(SNESSetFunction(snes,r,KokkosFunction,&ctx));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create matrix data structure; set Jacobian evaluation routine
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  ierr = DMCreateMatrix(ctx.da,&J);CHKERRQ(ierr);
+  PetscCall(DMCreateMatrix(ctx.da,&J));
 
   /*
      Set Jacobian matrix data structure and default Jacobian evaluation
@@ -285,28 +278,31 @@ int main(int argc,char **argv)
         context that provides application-specific data for the
         Jacobian evaluation routine.
   */
-  ierr = SNESSetJacobian(snes,J,J,FormJacobian,&ctx);CHKERRQ(ierr);
-  ierr = SNESSetFromOptions(snes);CHKERRQ(ierr);
-  ierr = SNESGetTolerances(snes,&abstol,&rtol,&stol,&maxit,&maxf);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"atol=%g, rtol=%g, stol=%g, maxit=%D, maxf=%D\n",(double)abstol,(double)rtol,(double)stol,maxit,maxf);CHKERRQ(ierr);
+  PetscCall(SNESSetJacobian(snes,J,J,FormJacobian,&ctx));
+  PetscCall(SNESSetFromOptions(snes));
+  PetscCall(SNESGetTolerances(snes,&abstol,&rtol,&stol,&maxit,&maxf));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"atol=%g, rtol=%g, stol=%g, maxit=%D, maxf=%D\n",(double)abstol,(double)rtol,(double)stol,maxit,maxf));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Initialize application:
      Store forcing function of PDE and exact solution
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  ierr = DMDAVecGetKokkosOffsetViewWrite(ctx.da,F,&FF);CHKERRQ(ierr);
-  ierr = DMDAVecGetKokkosOffsetViewWrite(ctx.da,U,&UU);CHKERRQ(ierr);
-  Kokkos:: parallel_for (Kokkos::RangePolicy<>(FF.begin(0),FF.end(0)),KOKKOS_LAMBDA (int i) {
-    PetscReal xp = i*ctx.h;
-    FF(i) = 6.0*xp + pow(xp+1.e-12,6.0); /* +1.e-12 is to prevent 0^6 */
-    UU(i) = xp*xp*xp;
-  });
-  ierr = DMDAVecRestoreKokkosOffsetViewWrite(ctx.da,F,&FF);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreKokkosOffsetViewWrite(ctx.da,U,&UU);CHKERRQ(ierr);
+  {
+    PetscScalarKokkosOffsetView FF,UU;
+    PetscCall(DMDAVecGetKokkosOffsetViewWrite(ctx.da,F,&FF));
+    PetscCall(DMDAVecGetKokkosOffsetViewWrite(ctx.da,U,&UU));
+    Kokkos:: parallel_for (Kokkos::RangePolicy<>(FF.begin(0),FF.end(0)),KOKKOS_LAMBDA (int i) {
+      PetscReal xp = i*ctx.h;
+      FF(i) = 6.0*xp + pow(xp+1.e-12,6.0); /* +1.e-12 is to prevent 0^6 */
+      UU(i) = xp*xp*xp;
+    });
+    PetscCall(DMDAVecRestoreKokkosOffsetViewWrite(ctx.da,F,&FF));
+    PetscCall(DMDAVecRestoreKokkosOffsetViewWrite(ctx.da,U,&UU));
+  }
 
   if (viewinitial) {
-    ierr = VecView(U,NULL);CHKERRQ(ierr);
-    ierr = VecView(F,NULL);CHKERRQ(ierr);
+    PetscCall(VecView(U,NULL));
+    PetscCall(VecView(F,NULL));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -319,10 +315,10 @@ int main(int argc,char **argv)
      to employ an initial guess of zero, the user should explicitly set
      this vector to zero by calling VecSet().
   */
-  ierr = FormInitialGuess(x);CHKERRQ(ierr);
-  ierr = SNESSolve(snes,NULL,x);CHKERRQ(ierr);
-  ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of SNES iterations = %D\n",its);CHKERRQ(ierr);
+  PetscCall(FormInitialGuess(x));
+  PetscCall(SNESSolve(snes,NULL,x));
+  PetscCall(SNESGetIterationNumber(snes,&its));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Number of SNES iterations = %D\n",its));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Check solution and clean up
@@ -330,23 +326,23 @@ int main(int argc,char **argv)
   /*
      Check the error
   */
-  ierr = VecAXPY(x,none,U);CHKERRQ(ierr);
-  ierr = VecNorm(x,NORM_2,&norm);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Norm of error %g Iterations %D\n",(double)norm,its);CHKERRQ(ierr);
+  PetscCall(VecAXPY(x,none,U));
+  PetscCall(VecNorm(x,NORM_2,&norm));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Norm of error %g Iterations %D\n",(double)norm,its));
 
   /*
      Free work space.  All PETSc objects should be destroyed when they
      are no longer needed.
   */
-  ierr = VecDestroy(&x);CHKERRQ(ierr);
-  ierr = VecDestroy(&r);CHKERRQ(ierr);
-  ierr = VecDestroy(&U);CHKERRQ(ierr);
-  ierr = VecDestroy(&F);CHKERRQ(ierr);
-  ierr = MatDestroy(&J);CHKERRQ(ierr);
-  ierr = SNESDestroy(&snes);CHKERRQ(ierr);
-  ierr = DMDestroy(&ctx.da);CHKERRQ(ierr);
-  ierr = PetscFinalize();
-  return ierr;
+  PetscCall(VecDestroy(&x));
+  PetscCall(VecDestroy(&r));
+  PetscCall(VecDestroy(&U));
+  PetscCall(VecDestroy(&F));
+  PetscCall(MatDestroy(&J));
+  PetscCall(SNESDestroy(&snes));
+  PetscCall(DMDestroy(&ctx.da));
+  PetscCall(PetscFinalize());
+  return 0;
 }
 
 /*TEST
@@ -355,9 +351,9 @@ int main(int argc,char **argv)
      requires: kokkos_kernels
 
    test:
-     requires: kokkos_kernels !complex !single cuda
+     requires: kokkos_kernels !complex !single
      nsize: 2
      args: -dm_vec_type kokkos -dm_mat_type aijkokkos -view_initial -snes_monitor
      output_file: output/ex3k_1.out
 
-TEST*/
\ No newline at end of file
+TEST*/
