@@ -2,30 +2,12 @@
 /*
   Contains the data structure for plotting a bargraph in a window with an axis.
 */
-#include <petscdraw.h>                       /*I "petscdraw.h" I*/
-#include <petsc/private/petscimpl.h>         /*I "petscsys.h" I*/
-#include <petscviewer.h>                     /*I "petscviewer.h" I*/
-#include <../src/sys/classes/draw/utils/axisimpl.h>   /* so we can directly modify axis xticks */
+
+#include <petsc/private/drawimpl.h> /*I "petscdraw.h" I*/
+#include <petscviewer.h>            /*I "petscviewer.h" I*/
 
 PetscClassId PETSC_DRAWBAR_CLASSID = 0;
 
-struct _p_PetscDrawBar {
-  PETSCHEADER(int);
-  PetscErrorCode (*destroy)(PetscDrawSP);
-  PetscErrorCode (*view)(PetscDrawSP,PetscViewer);
-  PetscDraw      win;
-  PetscDrawAxis  axis;
-  PetscReal      ymin,ymax;
-  int            numBins;
-  PetscReal      *values;
-  int            color;
-  char           **labels;
-  PetscBool      sort;
-  PetscReal      sorttolerance;
-};
-
-#define CHUNKSIZE 100
-
 /*@C
    PetscDrawBarCreate - Creates a bar graph data structure.
 
@@ -37,34 +19,32 @@ struct _p_PetscDrawBar {
    Output Parameters:
 .  bar - The bar graph context
 
-   Notes: Call PetscDrawBarSetData() to provide the bins to be plotted and then PetscDrawBarDraw() to display the new plot
+   Notes:
+    Call PetscDrawBarSetData() to provide the bins to be plotted and then PetscDrawBarDraw() to display the new plot
 
-  The difference between a bar chart, PetscDrawBar, and a histogram, PetscDrawHG, is explained here http://stattrek.com/statistics/charts/histogram.aspx?Tutorial=AP
+  The difference between a bar chart, PetscDrawBar, and a histogram, PetscDrawHG, is explained here https://stattrek.com/statistics/charts/histogram.aspx?Tutorial=AP
 
    The MPI communicator that owns the PetscDraw owns this PetscDrawBar, but the calls to set options and add data are ignored on all processes except the
    zeroth MPI process in the communicator. All MPI processes in the communicator must call PetscDrawBarDraw() to display the updated graph.
 
    Level: intermediate
 
-   Concepts: bar graph^creating
-
 .seealso: PetscDrawLGCreate(), PetscDrawLG, PetscDrawSPCreate(), PetscDrawSP, PetscDrawHGCreate(), PetscDrawHG, PetscDrawBarDestroy(), PetscDrawBarSetData(),
           PetscDrawBar, PetscDrawBarDraw(), PetscDrawBarSave(), PetscDrawBarSetColor(), PetscDrawBarSort(), PetscDrawBarSetLimits(), PetscDrawBarGetAxis(), PetscDrawAxis,
-          PetscDrawBarGetDraw(), PetscDrawBarSetFromOptions() 
+          PetscDrawBarGetDraw(), PetscDrawBarSetFromOptions()
 @*/
 PetscErrorCode  PetscDrawBarCreate(PetscDraw draw,PetscDrawBar *bar)
 {
   PetscDrawBar   h;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(draw,PETSC_DRAW_CLASSID,1);
   PetscValidPointer(bar,2);
 
-  ierr = PetscHeaderCreate(h,PETSC_DRAWBAR_CLASSID,"DrawBar","Bar Graph","Draw",PetscObjectComm((PetscObject)draw),PetscDrawBarDestroy,NULL);CHKERRQ(ierr);
-  ierr = PetscLogObjectParent((PetscObject)draw,(PetscObject)h);CHKERRQ(ierr);
+  PetscCall(PetscHeaderCreate(h,PETSC_DRAWBAR_CLASSID,"DrawBar","Bar Graph","Draw",PetscObjectComm((PetscObject)draw),PetscDrawBarDestroy,NULL));
+  PetscCall(PetscLogObjectParent((PetscObject)draw,(PetscObject)h));
 
-  ierr = PetscObjectReference((PetscObject)draw);CHKERRQ(ierr);
+  PetscCall(PetscObjectReference((PetscObject)draw));
   h->win = draw;
 
   h->view        = NULL;
@@ -74,7 +54,7 @@ PetscErrorCode  PetscDrawBarCreate(PetscDraw draw,PetscDrawBar *bar)
   h->ymax        = 0.;
   h->numBins     = 0;
 
-  ierr = PetscDrawAxisCreate(draw,&h->axis);CHKERRQ(ierr);
+  PetscCall(PetscDrawAxisCreate(draw,&h->axis));
   h->axis->xticks = NULL;
 
   *bar = h;
@@ -86,7 +66,7 @@ PetscErrorCode  PetscDrawBarCreate(PetscDraw draw,PetscDrawBar *bar)
 
    Logically Collective on PetscDrawBar
 
-   Input Parameter:
+   Input Parameters:
 +  bar - The bar graph context.
 .  bins  - number of items
 .  values - values of each item
@@ -94,27 +74,26 @@ PetscErrorCode  PetscDrawBarCreate(PetscDraw draw,PetscDrawBar *bar)
 
    Level: intermediate
 
-   Notes: Call PetscDrawBarDraw() after this call to display the new plot
+   Notes:
+    Call PetscDrawBarDraw() after this call to display the new plot
 
 .seealso: PetscDrawBarCreate(), PetscDrawBar, PetscDrawBarDraw()
 
 @*/
 PetscErrorCode  PetscDrawBarSetData(PetscDrawBar bar,PetscInt bins,const PetscReal data[],const char *const *labels)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bar,PETSC_DRAWBAR_CLASSID,1);
 
   if (bar->numBins != bins) {
-    ierr = PetscFree(bar->values);CHKERRQ(ierr);
-    ierr = PetscMalloc1(bins, &bar->values);CHKERRQ(ierr);
+    PetscCall(PetscFree(bar->values));
+    PetscCall(PetscMalloc1(bins, &bar->values));
     bar->numBins = bins;
   }
-  ierr = PetscMemcpy(bar->values,data,bins*sizeof(PetscReal));CHKERRQ(ierr);
+  PetscCall(PetscArraycpy(bar->values,data,bins));
   bar->numBins = bins;
   if (labels) {
-    ierr = PetscStrArrayallocpy(labels,&bar->labels);CHKERRQ(ierr);
+    PetscCall(PetscStrArrayallocpy(labels,&bar->labels));
   }
   PetscFunctionReturn(0);
 }
@@ -133,18 +112,16 @@ PetscErrorCode  PetscDrawBarSetData(PetscDrawBar bar,PetscInt bins,const PetscRe
 @*/
 PetscErrorCode  PetscDrawBarDestroy(PetscDrawBar *bar)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   if (!*bar) PetscFunctionReturn(0);
   PetscValidHeaderSpecific(*bar,PETSC_DRAWBAR_CLASSID,1);
   if (--((PetscObject)(*bar))->refct > 0) PetscFunctionReturn(0);
 
-  ierr = PetscFree((*bar)->values);CHKERRQ(ierr);
-  ierr = PetscStrArrayDestroy(&(*bar)->labels);CHKERRQ(ierr);
-  ierr = PetscDrawAxisDestroy(&(*bar)->axis);CHKERRQ(ierr);
-  ierr = PetscDrawDestroy(&(*bar)->win);CHKERRQ(ierr);
-  ierr = PetscHeaderDestroy(bar);CHKERRQ(ierr);
+  PetscCall(PetscFree((*bar)->values));
+  PetscCall(PetscStrArrayDestroy(&(*bar)->labels));
+  PetscCall(PetscDrawAxisDestroy(&(*bar)->axis));
+  PetscCall(PetscDrawDestroy(&(*bar)->win));
+  PetscCall(PetscHeaderDestroy(bar));
   PetscFunctionReturn(0);
 }
 
@@ -168,14 +145,14 @@ PetscErrorCode  PetscDrawBarDraw(PetscDrawBar bar)
   PetscReal      xmin,xmax,ymin,ymax,*values,binLeft,binRight;
   PetscInt       numValues,i,bcolor,color,idx,*perm,nplot;
   PetscMPIInt    rank;
-  PetscErrorCode ierr;
   char           **labels;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bar,PETSC_DRAWBAR_CLASSID,1);
-  ierr = PetscDrawIsNull(bar->win,&isnull);CHKERRQ(ierr);
+  PetscCall(PetscDrawIsNull(bar->win,&isnull));
   if (isnull) PetscFunctionReturn(0);
-  ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)bar),&rank);CHKERRQ(ierr);
+  PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)bar),&rank));
 
   if (bar->numBins < 1) PetscFunctionReturn(0);
 
@@ -203,9 +180,9 @@ PetscErrorCode  PetscDrawBarDraw(PetscDrawBar bar)
   labels = bar->labels;
 
   if (bar->sort) {
-    ierr = PetscMalloc1(numValues,&perm);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(numValues,&perm));
     for (i=0; i<numValues;i++) perm[i] = i;
-    ierr = PetscSortRealWithPermutation(numValues,values,perm);CHKERRQ(ierr);
+    PetscCall(PetscSortRealWithPermutation(numValues,values,perm));
     if (bar->sorttolerance) {
       for (i=0; i<numValues;i++) {
         if (values[perm[numValues - i - 1]] < bar->sorttolerance) {
@@ -217,36 +194,36 @@ PetscErrorCode  PetscDrawBarDraw(PetscDrawBar bar)
   }
 
   draw = bar->win;
-  ierr = PetscDrawCheckResizedWindow(draw);CHKERRQ(ierr);
-  ierr = PetscDrawClear(draw);CHKERRQ(ierr);
+  PetscCall(PetscDrawCheckResizedWindow(draw));
+  PetscCall(PetscDrawClear(draw));
 
-  ierr = PetscDrawAxisSetLimits(bar->axis,xmin,xmax,ymin,ymax);CHKERRQ(ierr);
-  ierr = PetscDrawAxisDraw(bar->axis);CHKERRQ(ierr);
+  PetscCall(PetscDrawAxisSetLimits(bar->axis,xmin,xmax,ymin,ymax));
+  PetscCall(PetscDrawAxisDraw(bar->axis));
 
-  ierr = PetscDrawCollectiveBegin(draw);CHKERRQ(ierr);
-  if (!rank) { /* Draw bins */
+  ierr = PetscDrawCollectiveBegin(draw);PetscCall(ierr);
+  if (rank == 0) { /* Draw bins */
     for (i=0; i<nplot; i++) {
       idx = (bar->sort ? perm[numValues - i - 1] : i);
       binLeft  = xmin + i;
       binRight = xmin + i + 1;
-      ierr = PetscDrawRectangle(draw,binLeft,ymin,binRight,values[idx],bcolor,bcolor,bcolor,bcolor);CHKERRQ(ierr);
-      ierr = PetscDrawLine(draw,binLeft,ymin,binLeft,values[idx],PETSC_DRAW_BLACK);CHKERRQ(ierr);
-      ierr = PetscDrawLine(draw,binRight,ymin,binRight,values[idx],PETSC_DRAW_BLACK);CHKERRQ(ierr);
-      ierr = PetscDrawLine(draw,binLeft,values[idx],binRight,values[idx],PETSC_DRAW_BLACK);CHKERRQ(ierr);
+      PetscCall(PetscDrawRectangle(draw,binLeft,ymin,binRight,values[idx],bcolor,bcolor,bcolor,bcolor));
+      PetscCall(PetscDrawLine(draw,binLeft,ymin,binLeft,values[idx],PETSC_DRAW_BLACK));
+      PetscCall(PetscDrawLine(draw,binRight,ymin,binRight,values[idx],PETSC_DRAW_BLACK));
+      PetscCall(PetscDrawLine(draw,binLeft,values[idx],binRight,values[idx],PETSC_DRAW_BLACK));
       if (labels) {
         PetscReal h;
-        ierr = PetscDrawStringGetSize(draw,NULL,&h);CHKERRQ(ierr);
-        ierr = PetscDrawStringCentered(draw,.5*(binLeft+binRight),ymin - 1.5*h,bcolor,labels[idx]);CHKERRQ(ierr);
+        PetscCall(PetscDrawStringGetSize(draw,NULL,&h));
+        PetscCall(PetscDrawStringCentered(draw,.5*(binLeft+binRight),ymin - 1.5*h,bcolor,labels[idx]));
       }
       if (color == PETSC_DRAW_ROTATE) bcolor++;
       if (bcolor > PETSC_DRAW_BASIC_COLORS-1) bcolor = PETSC_DRAW_BLACK+1;
     }
   }
-  ierr = PetscDrawCollectiveEnd(draw);CHKERRQ(ierr);
-  if (bar->sort) {ierr = PetscFree(perm);CHKERRQ(ierr);}
+  ierr = PetscDrawCollectiveEnd(draw);PetscCall(ierr);
+  if (bar->sort) PetscCall(PetscFree(perm));
 
-  ierr = PetscDrawFlush(draw);CHKERRQ(ierr);
-  ierr = PetscDrawPause(draw);CHKERRQ(ierr);
+  PetscCall(PetscDrawFlush(draw));
+  PetscCall(PetscDrawPause(draw));
   PetscFunctionReturn(0);
 }
 
@@ -260,17 +237,13 @@ PetscErrorCode  PetscDrawBarDraw(PetscDrawBar bar)
 
   Level: intermediate
 
-  Concepts: bar graph^saving
-
 .seealso:  PetscDrawBarCreate(), PetscDrawBarGetDraw(), PetscDrawSetSave(), PetscDrawSave(), PetscDrawBarSetData()
 @*/
 PetscErrorCode  PetscDrawBarSave(PetscDrawBar bar)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bar,PETSC_DRAWBAR_CLASSID,1);
-  ierr = PetscDrawSave(bar->win);CHKERRQ(ierr);
+  PetscCall(PetscDrawSave(bar->win));
   PetscFunctionReturn(0);
 }
 
@@ -305,12 +278,10 @@ PetscErrorCode  PetscDrawBarSetColor(PetscDrawBar bar, int color)
   Input Parameters:
 + bar - The bar graph context
 . sort - PETSC_TRUE to sort the values
-. tolerance - discard values less than tolerance
+- tolerance - discard values less than tolerance
 
   Level: intermediate
 
-  Concepts: bar graph^setting axis
-
 .seealso: PetscDrawBarCreate(), PetscDrawBar, PetscDrawBarSetData(), PetscDrawBarSetColor(), PetscDrawBarDraw(), PetscDrawBarGetAxis()
 @*/
 PetscErrorCode  PetscDrawBarSort(PetscDrawBar bar, PetscBool sort, PetscReal tolerance)
@@ -335,8 +306,6 @@ PetscErrorCode  PetscDrawBarSort(PetscDrawBar bar, PetscBool sort, PetscReal tol
 
   Level: intermediate
 
-  Concepts: bar graph^setting axis
-
 .seealso: PetscDrawBarCreate(), PetscDrawBar, PetscDrawBarGetAxis(), PetscDrawBarSetData(), PetscDrawBarDraw()
 @*/
 PetscErrorCode  PetscDrawBarSetLimits(PetscDrawBar bar, PetscReal y_min, PetscReal y_max)
@@ -409,23 +378,20 @@ PetscErrorCode  PetscDrawBarGetDraw(PetscDrawBar bar,PetscDraw *draw)
 
     Level: intermediate
 
-
 .seealso:  PetscDrawBarDestroy(), PetscDrawBarCreate(), PetscDrawBarSort()
 @*/
 PetscErrorCode  PetscDrawBarSetFromOptions(PetscDrawBar bar)
 {
-  PetscErrorCode ierr;
   PetscBool      set;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bar,PETSC_DRAWBAR_CLASSID,1);
 
-  ierr = PetscOptionsHasName(((PetscObject)bar)->options,((PetscObject)bar)->prefix,"-bar_sort",&set);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(((PetscObject)bar)->options,((PetscObject)bar)->prefix,"-bar_sort",&set));
   if (set) {
     PetscReal tol = bar->sorttolerance;
-    ierr = PetscOptionsGetReal(((PetscObject)bar)->options,((PetscObject)bar)->prefix,"-bar_sort",&tol,NULL);CHKERRQ(ierr);
-    ierr = PetscDrawBarSort(bar,PETSC_TRUE,tol);CHKERRQ(ierr);
+    PetscCall(PetscOptionsGetReal(((PetscObject)bar)->options,((PetscObject)bar)->prefix,"-bar_sort",&tol,NULL));
+    PetscCall(PetscDrawBarSort(bar,PETSC_TRUE,tol));
   }
   PetscFunctionReturn(0);
 }
-
