@@ -38,13 +38,9 @@ PetscErrorCode  PetscRandomGetValueReal_Rand48(PetscRandom r,PetscReal *val)
 }
 
 static struct _PetscRandomOps PetscRandomOps_Values = {
-  PetscRandomSeed_Rand48,
-  PetscRandomGetValue_Rand48,
-  PetscRandomGetValueReal_Rand48,
-  NULL,
-  NULL,
-  NULL,
-  NULL
+  PetscDesignatedInitializer(seed,PetscRandomSeed_Rand48),
+  PetscDesignatedInitializer(getvalue,PetscRandomGetValue_Rand48),
+  PetscDesignatedInitializer(getvaluereal,PetscRandomGetValueReal_Rand48),
 };
 
 /*MC
@@ -60,10 +56,8 @@ M*/
 
 PETSC_EXTERN PetscErrorCode PetscRandomCreate_Rand48(PetscRandom r)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscMemcpy(r->ops,&PetscRandomOps_Values,sizeof(PetscRandomOps_Values));CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)r,PETSCRAND48);CHKERRQ(ierr);
+  PetscCall(PetscMemcpy(r->ops,&PetscRandomOps_Values,sizeof(PetscRandomOps_Values)));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)r,PETSCRAND48));
   PetscFunctionReturn(0);
 }
