@@ -50,15 +50,14 @@ $       ifort -fpe0
 @*/
 PetscErrorCode PetscFPTrapPush(PetscFPTrap trap)
 {
-  PetscErrorCode         ierr;
   struct PetscFPTrapLink *link;
 
   PetscFunctionBegin;
-  ierr           = PetscNew(&link);CHKERRQ(ierr);
+  PetscCall(PetscNew(&link));
   link->trapmode = _trapmode;
   link->next     = _trapstack;
   _trapstack     = link;
-  if (trap != _trapmode) {ierr = PetscSetFPTrap(trap);CHKERRQ(ierr);}
+  if (trap != _trapmode) PetscCall(PetscSetFPTrap(trap));
   PetscFunctionReturn(0);
 }
 
@@ -73,14 +72,13 @@ PetscErrorCode PetscFPTrapPush(PetscFPTrap trap)
 @*/
 PetscErrorCode PetscFPTrapPop(void)
 {
-  PetscErrorCode         ierr;
   struct PetscFPTrapLink *link;
 
   PetscFunctionBegin;
-  if (_trapstack->trapmode != _trapmode) {ierr = PetscSetFPTrap(_trapstack->trapmode);CHKERRQ(ierr);}
+  if (_trapstack->trapmode != _trapmode) PetscCall(PetscSetFPTrap(_trapstack->trapmode));
   link       = _trapstack;
   _trapstack = _trapstack->next;
-  ierr       = PetscFree(link);CHKERRQ(ierr);
+  PetscCall(PetscFree(link));
   PetscFunctionReturn(0);
 }
 
@@ -104,18 +102,17 @@ static struct { int code_no; char *name; } error_codes[] = {
 
 sigfpe_handler_type PetscDefaultFPTrap(int sig,int code,struct sigcontext *scp,char *addr)
 {
-  PetscErrorCode ierr;
-  int            err_ind = -1,j;
+  int err_ind = -1;
 
   PetscFunctionBegin;
-  for (j = 0; error_codes[j].code_no; j++) {
+  for (int j = 0; error_codes[j].code_no; j++) {
     if (error_codes[j].code_no == code) err_ind = j;
   }
 
   if (err_ind >= 0) (*PetscErrorPrintf)("*** %s occurred at pc=%X ***\n",error_codes[err_ind].name,SIGPC(scp));
   else              (*PetscErrorPrintf)("*** floating point error 0x%x occurred at pc=%X ***\n",code,SIGPC(scp));
 
-  ierr = PetscError(PETSC_COMM_SELF,PETSC_ERR_FP,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
+  (void)PetscError(PETSC_COMM_SELF,PETSC_ERR_FP,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
   PETSCABORT(MPI_COMM_WORLD,PETSC_ERR_FP);
   PetscFunctionReturn(0);
 }
@@ -189,10 +186,8 @@ PetscErrorCode PetscSetFPTrap(PetscFPTrap flag)
 @*/
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -215,19 +210,17 @@ static struct { int code_no; char *name; } error_codes[] = {
 
 void PetscDefaultFPTrap(int sig,siginfo_t *scp,ucontext_t *uap)
 {
-  int            err_ind,j,code = scp->si_code;
-  PetscErrorCode ierr;
+  int err_ind = -1,code = scp->si_code;
 
   PetscFunctionBegin;
-  err_ind = -1;
-  for (j = 0; error_codes[j].code_no; j++) {
+  for (int j = 0; error_codes[j].code_no; j++) {
     if (error_codes[j].code_no == code) err_ind = j;
   }
 
   if (err_ind >= 0) (*PetscErrorPrintf)("*** %s occurred at pc=%X ***\n",error_codes[err_ind].name,SIGPC(scp));
   else              (*PetscErrorPrintf)("*** floating point error 0x%x occurred at pc=%X ***\n",code,SIGPC(scp));
 
-  ierr = PetscError(PETSC_COMM_SELF,0,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
+  (void)PetscError(PETSC_COMM_SELF,0,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
   PETSCABORT(MPI_COMM_WORLD,PETSC_ERR_FP);
 }
 
@@ -249,10 +242,8 @@ PetscErrorCode PetscSetFPTrap(PetscFPTrap flag)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -268,18 +259,16 @@ static struct { int code_no; char *name; } error_codes[] = {
 } ;
 void PetscDefaultFPTrap(unsigned exception[],int val[])
 {
-  int err_ind,j,code;
+  int err_ind = -1,code = exception[0];
 
   PetscFunctionBegin;
-  code    = exception[0];
-  err_ind = -1;
-  for (j = 0; error_codes[j].code_no; j++) {
+  for (int j = 0; error_codes[j].code_no; j++) {
     if (error_codes[j].code_no == code) err_ind = j;
   }
   if (err_ind >= 0) (*PetscErrorPrintf)("*** %s occurred ***\n",error_codes[err_ind].name);
   else              (*PetscErrorPrintf)("*** floating point error 0x%x occurred ***\n",code);
 
-  PetscError(PETSC_COMM_SELF,0,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
+  (void)PetscError(PETSC_COMM_SELF,0,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
   PETSCABORT(MPI_COMM_WORLD,PETSC_ERR_FP);
 }
 
@@ -294,10 +283,8 @@ PetscErrorCode PetscSetFPTrap(PetscFPTrap flag)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -320,19 +307,18 @@ static struct { int code_no; char *name; } error_codes[] = {
 
 void PetscDefaultFPTrap(int sig,siginfo_t *scp,ucontext_t *uap)
 {
-  int            err_ind,j,code = scp->si_code;
-  PetscErrorCode ierr;
+  int err_ind = -1,code = scp->si_code;
 
   PetscFunctionBegin;
   err_ind = -1;
-  for (j = 0; error_codes[j].code_no; j++) {
+  for (int j = 0; error_codes[j].code_no; j++) {
     if (error_codes[j].code_no == code) err_ind = j;
   }
 
   if (err_ind >= 0) (*PetscErrorPrintf)("*** %s occurred at pc=%X ***\n",error_codes[err_ind].name,SIGPC(scp));
   else              (*PetscErrorPrintf)("*** floating point error 0x%x occurred at pc=%X ***\n",code,SIGPC(scp));
 
-  ierr = PetscError(PETSC_COMM_SELF,0,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
+  (void)PetscError(PETSC_COMM_SELF,0,"User provided function","Unknown file",PETSC_ERR_FP,PETSC_ERROR_REPEAT,"floating point error");
   PETSCABORT(MPI_COMM_WORLD,PETSC_ERR_FP);
 }
 
@@ -354,10 +340,8 @@ PetscErrorCode PetscSetFPTrap(PetscFPTrap flag)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -437,10 +421,8 @@ PetscErrorCode PetscSetFPTrap(PetscFPTrap on)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -462,10 +444,10 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
   PetscFunctionBegin;
   if (on == PETSC_FP_TRAP_ON) {
     cw = _EM_INVALID | _EM_ZERODIVIDE | _EM_OVERFLOW | _EM_UNDERFLOW;
-    if (SIG_ERR == signal(SIGFPE,PetscDefaultFPTrap)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't set floating point handler\n");
+    PetscCheckFalse(SIG_ERR == signal(SIGFPE,PetscDefaultFPTrap),PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't set floating point handler");
   } else {
     cw = 0;
-    if (SIG_ERR == signal(SIGFPE,SIG_DFL)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't clear floating point handler\n");
+    PetscCheckFalse(SIG_ERR == signal(SIGFPE,SIG_DFL),PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't clear floating point handler");
   }
   (void)_controlfp(0, cw);
   _trapmode = on;
@@ -474,10 +456,8 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -549,10 +529,10 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
   PetscFunctionBegin;
   if (on == PETSC_FP_TRAP_ON) {
     /* Clear any flags that are currently set so that activating trapping will not immediately call the signal handler. */
-    if (feclearexcept(FE_ALL_EXCEPT)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Cannot clear floating point exception flags\n");
+    PetscCheckFalse(feclearexcept(FE_ALL_EXCEPT),PETSC_COMM_SELF,PETSC_ERR_LIB,"Cannot clear floating point exception flags");
 #if defined(FE_NOMASK_ENV)
     /* Could use fesetenv(FE_NOMASK_ENV), but that causes spurious exceptions (like gettimeofday() -> PetscLogDouble). */
-    if (feenableexcept(FE_DIVBYZERO | FE_INVALID | FE_OVERFLOW | FE_UNDERFLOW) == -1) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Cannot activate floating point exceptions\n");
+    PetscCheckFalse(feenableexcept(FE_DIVBYZERO | FE_INVALID | FE_OVERFLOW | FE_UNDERFLOW) == -1,PETSC_COMM_SELF,PETSC_ERR_LIB,"Cannot activate floating point exceptions");
 #elif defined PETSC_HAVE_XMMINTRIN_H
    _MM_SET_EXCEPTION_MASK(_MM_GET_EXCEPTION_MASK() & ~_MM_MASK_DIV_ZERO);
    _MM_SET_EXCEPTION_MASK(_MM_GET_EXCEPTION_MASK() & ~_MM_MASK_UNDERFLOW);
@@ -561,11 +541,11 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
 #else
     /* C99 does not provide a way to modify the environment so there is no portable way to activate trapping. */
 #endif
-    if (SIG_ERR == signal(SIGFPE,PetscDefaultFPTrap)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't set floating point handler\n");
+    PetscCheckFalse(SIG_ERR == signal(SIGFPE,PetscDefaultFPTrap),PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't set floating point handler");
   } else {
-    if (fesetenv(FE_DFL_ENV)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Cannot disable floating point exceptions");
+    PetscCheckFalse(fesetenv(FE_DFL_ENV),PETSC_COMM_SELF,PETSC_ERR_LIB,"Cannot disable floating point exceptions");
     /* can use _MM_SET_EXCEPTION_MASK(_MM_GET_EXCEPTION_MASK() | _MM_MASK_UNDERFLOW); if PETSC_HAVE_XMMINTRIN_H exists */
-    if (SIG_ERR == signal(SIGFPE,SIG_DFL)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't clear floating point handler\n");
+    PetscCheckFalse(SIG_ERR == signal(SIGFPE,SIG_DFL),PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't clear floating point handler");
   }
   _trapmode = on;
   PetscFunctionReturn(0);
@@ -574,9 +554,8 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
 #if defined(FE_NOMASK_ENV) || defined PETSC_HAVE_XMMINTRIN_H
-  unsigned int   flags;
+  unsigned int flags;
 #endif
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
 #if defined(FE_NOMASK_ENV)
@@ -586,15 +565,15 @@ PetscErrorCode  PetscDetermineInitialFPTrap(void)
   flags = _MM_GET_EXCEPTION_MASK();
   if (!(flags & _MM_MASK_DIV_ZERO)) {
 #else
-  ierr = PetscInfo(NULL,"Floating point trapping unknown, assuming off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Floating point trapping unknown, assuming off\n"));
   PetscFunctionReturn(0);
 #endif
 #if defined(FE_NOMASK_ENV) || defined PETSC_HAVE_XMMINTRIN_H
     _trapmode = PETSC_FP_TRAP_ON;
-    ierr = PetscInfo1(NULL,"Floating point trapping is on by default %d\n",flags);CHKERRQ(ierr);
+    PetscCall(PetscInfo(NULL,"Floating point trapping is on by default %d\n",flags));
   } else {
     _trapmode = PETSC_FP_TRAP_OFF;
-    ierr = PetscInfo1(NULL,"Floating point trapping is off by default %d\n",flags);CHKERRQ(ierr);
+    PetscCall(PetscInfo(NULL,"Floating point trapping is off by default %d\n",flags));
   }
   PetscFunctionReturn(0);
 #endif
@@ -621,7 +600,7 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
     fpsetsticky(fpgetsticky());
 #endif
     fpsetmask(FP_X_INV | FP_X_DZ | FP_X_OFL |  FP_X_OFL);
-    if (SIG_ERR == signal(SIGFPE,PetscDefaultFPTrap)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't set floating point handler\n");
+    PetscCheckFalse(SIG_ERR == signal(SIGFPE,PetscDefaultFPTrap),PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't set floating point handler");
   } else {
 #if defined(PETSC_HAVE_FPPRESETSTICKY)
     fpresetsticky(fpgetsticky());
@@ -629,7 +608,7 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
     fpsetsticky(fpgetsticky());
 #endif
     fpsetmask(0);
-    if (SIG_ERR == signal(SIGFPE,SIG_DFL)) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't clear floating point handler\n");
+    PetscCheckFalse(SIG_ERR == signal(SIGFPE,SIG_DFL),PETSC_COMM_SELF,PETSC_ERR_LIB,"Can't clear floating point handler");
   }
   _trapmode = on;
   PetscFunctionReturn(0);
@@ -637,10 +616,8 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 
@@ -668,11 +645,8 @@ PetscErrorCode  PetscSetFPTrap(PetscFPTrap on)
 
 PetscErrorCode  PetscDetermineInitialFPTrap(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n");CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL,"Unable to determine initial floating point trapping. Assuming it is off\n"));
   PetscFunctionReturn(0);
 }
 #endif
-
