@@ -1,12 +1,11 @@
-#include <private/fortranimpl.h> 
-
-void *PETSCNULLPOINTERADDRESS = PETSC_NULL;
+#include <petsc/private/fortranimpl.h>
 
 /*MC
    PetscFortranAddr - a variable type in Fortran that can hold a
      regular C pointer.
 
-   Notes: Used, for example, as the file argument in PetscFOpen()
+   Notes:
+    Used, for example, as the file argument in PetscFOpen()
 
    Level: beginner
 
@@ -22,21 +21,21 @@ M*/
 M*/
 
 /*
-    This is code for translating PETSc memory addresses to integer offsets 
+    This is code for translating PETSc memory addresses to integer offsets
     for Fortran.
 */
-char   *PETSC_NULL_CHARACTER_Fortran = 0;
-void   *PETSC_NULL_INTEGER_Fortran   = 0;
-void   *PETSC_NULL_OBJECT_Fortran    = 0;
-void   *PETSC_NULL_Fortran           = 0;
-void   *PETSC_NULL_SCALAR_Fortran    = 0;
-void   *PETSC_NULL_DOUBLE_Fortran    = 0;
-void   *PETSC_NULL_REAL_Fortran      = 0;
-void   *PETSC_NULL_TRUTH_Fortran     = 0;
+char *PETSC_NULL_CHARACTER_Fortran = 0;
+void *PETSC_NULL_INTEGER_Fortran   = 0;
+void *PETSC_NULL_SCALAR_Fortran    = 0;
+void *PETSC_NULL_DOUBLE_Fortran    = 0;
+void *PETSC_NULL_REAL_Fortran      = 0;
+void *PETSC_NULL_BOOL_Fortran      = 0;
 EXTERN_C_BEGIN
-void   (*PETSC_NULL_FUNCTION_Fortran)(void) = 0;
+void (*PETSC_NULL_FUNCTION_Fortran)(void) = 0;
 EXTERN_C_END
-size_t PetscIntAddressToFortran(PetscInt *base,PetscInt *addr)
+void *PETSC_NULL_MPI_COMM_Fortran   = 0;
+
+size_t PetscIntAddressToFortran(const PetscInt *base,const PetscInt *addr)
 {
   size_t tmp1 = (size_t) base,tmp2 = 0;
   size_t tmp3 = (size_t) addr;
@@ -63,15 +62,15 @@ size_t PetscIntAddressToFortran(PetscInt *base,PetscInt *addr)
   if (base + itmp2 != addr) {
     (*PetscErrorPrintf)("PetscIntAddressToFortran:C and Fortran arrays are\n");
     (*PetscErrorPrintf)("not commonly aligned or are too far apart to be indexed \n");
-    (*PetscErrorPrintf)("by an integer. Locations: C %uld Fortran %uld\n",tmp1,tmp3);
-    MPI_Abort(PETSC_COMM_WORLD,1);
+    (*PetscErrorPrintf)("by an integer. Locations: C %zu Fortran %zu\n",tmp1,tmp3);
+    PETSCABORT(PETSC_COMM_WORLD,PETSC_ERR_PLIB);
   }
   return itmp2;
 }
 
-PetscInt *PetscIntAddressFromFortran(PetscInt *base,size_t addr)
+PetscInt *PetscIntAddressFromFortran(const PetscInt *base,size_t addr)
 {
-  return base + addr;
+  return (PetscInt *)(base + addr);
 }
 
 /*
@@ -86,7 +85,7 @@ PetscInt *PetscIntAddressFromFortran(PetscInt *base,size_t addr)
 */
 PetscErrorCode PetscScalarAddressToFortran(PetscObject obj,PetscInt align,PetscScalar *base,PetscScalar *addr,PetscInt N,size_t *res)
 {
-  size_t   tmp1 = (size_t) base,tmp2 = tmp1/sizeof(PetscScalar);
+  size_t   tmp1 = (size_t) base,tmp2;
   size_t   tmp3 = (size_t) addr;
   size_t   itmp2;
   PetscInt shift;
@@ -96,7 +95,7 @@ PetscErrorCode PetscScalarAddressToFortran(PetscObject obj,PetscInt align,PetscS
     tmp2  = (tmp3 - tmp1)/sizeof(PetscScalar);
     itmp2 = (size_t) tmp2;
     shift = (align*sizeof(PetscScalar) - (PetscInt)((tmp3 - tmp1) % (align*sizeof(PetscScalar)))) % (align*sizeof(PetscScalar));
-  } else {  
+  } else {
     tmp2  = (tmp1 - tmp3)/sizeof(PetscScalar);
     itmp2 = -((size_t) tmp2);
     shift = (PetscInt)((tmp1 - tmp3) % (align*sizeof(PetscScalar)));
@@ -105,49 +104,48 @@ PetscErrorCode PetscScalarAddressToFortran(PetscObject obj,PetscInt align,PetscS
   if (tmp3 > tmp1) {  /* C is bigger than Fortran */
     tmp2  = (tmp3 - tmp1);
     itmp2 = (size_t) tmp2;
-  } else {  
+  } else {
     tmp2  = (tmp1 - tmp3);
     itmp2 = -((size_t) tmp2);
   }
   shift = 0;
 #endif
 
-  if (shift) { 
-    /* 
+  if (shift) {
+    /*
         Fortran and C not PetscScalar aligned,recover by copying values into
         memory that is aligned with the Fortran
     */
-    PetscErrorCode ierr;
     PetscScalar    *work;
     PetscContainer container;
 
-    ierr = PetscMalloc((N+align)*sizeof(PetscScalar),&work);CHKERRQ(ierr); 
+    PetscCall(PetscMalloc1(N+align,&work));
 
     /* recompute shift for newly allocated space */
     tmp3 = (size_t) work;
     if (tmp3 > tmp1) {  /* C is bigger than Fortran */
       shift = (align*sizeof(PetscScalar) - (PetscInt)((tmp3 - tmp1) % (align*sizeof(PetscScalar)))) % (align*sizeof(PetscScalar));
-    } else {  
+    } else {
       shift = (PetscInt)((tmp1 - tmp3) % (align*sizeof(PetscScalar)));
     }
 
     /* shift work by that number of bytes */
     work = (PetscScalar*)(((char*)work) + shift);
-    ierr = PetscMemcpy(work,addr,N*sizeof(PetscScalar));CHKERRQ(ierr);
+    PetscCall(PetscArraycpy(work,addr,N));
 
     /* store in the first location in addr how much you shift it */
     ((PetscInt*)addr)[0] = shift;
- 
-    ierr = PetscContainerCreate(PETSC_COMM_SELF,&container);CHKERRQ(ierr);
-    ierr = PetscContainerSetPointer(container,addr);CHKERRQ(ierr);
-    ierr = PetscObjectCompose(obj,"GetArrayPtr",(PetscObject)container);CHKERRQ(ierr);
+
+    PetscCall(PetscContainerCreate(PETSC_COMM_SELF,&container));
+    PetscCall(PetscContainerSetPointer(container,addr));
+    PetscCall(PetscObjectCompose(obj,"GetArrayPtr",(PetscObject)container));
 
     tmp3 = (size_t) work;
     if (tmp3 > tmp1) {  /* C is bigger than Fortran */
       tmp2  = (tmp3 - tmp1)/sizeof(PetscScalar);
       itmp2 = (size_t) tmp2;
       shift = (align*sizeof(PetscScalar) - (PetscInt)((tmp3 - tmp1) % (align*sizeof(PetscScalar)))) % (align*sizeof(PetscScalar));
-    } else {  
+    } else {
       tmp2  = (tmp1 - tmp3)/sizeof(PetscScalar);
       itmp2 = -((size_t) tmp2);
       shift = (PetscInt)((tmp1 - tmp3) % (align*sizeof(PetscScalar)));
@@ -155,13 +153,11 @@ PetscErrorCode PetscScalarAddressToFortran(PetscObject obj,PetscInt align,PetscS
     if (shift) {
       (*PetscErrorPrintf)("PetscScalarAddressToFortran:C and Fortran arrays are\n");
       (*PetscErrorPrintf)("not commonly aligned.\n");
-      /* double/int doesn't work with ADIC */
-      (*PetscErrorPrintf)("Locations/sizeof(PetscScalar): C %f Fortran %f\n",
-                         ((PetscReal)tmp3)/(PetscReal)sizeof(PetscScalar),((PetscReal)tmp1)/(PetscReal)sizeof(PetscScalar));
-      MPI_Abort(PETSC_COMM_WORLD,1);
+      (*PetscErrorPrintf)("Locations/sizeof(PetscScalar): C %g Fortran %g\n",(double)(((PetscReal)tmp3)/(PetscReal)sizeof(PetscScalar)),(double)(((PetscReal)tmp1)/(PetscReal)sizeof(PetscScalar)));
+      PETSCABORT(PETSC_COMM_WORLD,PETSC_ERR_PLIB);
     }
-    ierr = PetscInfo(obj,"Efficiency warning, copying array in XXXGetArray() due\n\
-    to alignment differences between C and Fortran\n");CHKERRQ(ierr);
+    PetscCall(PetscInfo(obj,"Efficiency warning, copying array in XXXGetArray() due\n\
+    to alignment differences between C and Fortran\n"));
   }
   *res = itmp2;
   return 0;
@@ -174,25 +170,25 @@ PetscErrorCode PetscScalarAddressToFortran(PetscObject obj,PetscInt align,PetscS
     N    - the amount of data
 
     lx   - the array space that is to be passed to XXXXRestoreArray()
-*/     
+*/
 PetscErrorCode PetscScalarAddressFromFortran(PetscObject obj,PetscScalar *base,size_t addr,PetscInt N,PetscScalar **lx)
 {
-  PetscErrorCode ierr;
   PetscInt       shift;
   PetscContainer container;
   PetscScalar    *tlx;
 
-  ierr = PetscObjectQuery(obj,"GetArrayPtr",(PetscObject *)&container);CHKERRQ(ierr);
+  PetscCall(PetscObjectQuery(obj,"GetArrayPtr",(PetscObject*)&container));
   if (container) {
-    ierr  = PetscContainerGetPointer(container,(void**)lx);CHKERRQ(ierr);
-    tlx   = base + addr;
+    PetscCall(PetscContainerGetPointer(container,(void**)lx));
+    tlx  = base + addr;
 
     shift = *(PetscInt*)*lx;
-    ierr  = PetscMemcpy(*lx,tlx,N*sizeof(PetscScalar));CHKERRQ(ierr);
-    tlx   = (PetscScalar*)(((char *)tlx) - shift);
-    ierr = PetscFree(tlx);CHKERRQ(ierr);
-    ierr = PetscContainerDestroy(&container);CHKERRQ(ierr);
-    ierr = PetscObjectCompose(obj,"GetArrayPtr",0);CHKERRQ(ierr);
+    PetscCall(PetscArraycpy(*lx,tlx,N));
+    tlx   = (PetscScalar*)(((char*)tlx) - shift);
+
+    PetscCall(PetscFree(tlx));
+    PetscCall(PetscContainerDestroy(&container));
+    PetscCall(PetscObjectCompose(obj,"GetArrayPtr",0));
   } else {
     *lx = base + addr;
   }
@@ -207,17 +203,12 @@ PetscErrorCode PetscScalarAddressFromFortran(PetscObject obj,PetscScalar *base,s
 #define petscisinfornanreal_            petscisinfornanreal
 #endif
 
-EXTERN_C_BEGIN
-PetscBool  PETSC_STDCALL petscisinfornanscalar_(PetscScalar *v)
+PETSC_EXTERN PetscBool petscisinfornanscalar_(PetscScalar *v)
 {
   return (PetscBool) PetscIsInfOrNanScalar(*v);
 }
 
-PetscBool  PETSC_STDCALL petscisinfornanreal_(PetscReal *v)
+PETSC_EXTERN PetscBool petscisinfornanreal_(PetscReal *v)
 {
   return (PetscBool) PetscIsInfOrNanReal(*v);
 }
-EXTERN_C_END
-
-
-
