@@ -57,7 +57,7 @@ FILE                      *PetscInfoFile = NULL;
 PetscErrorCode PetscInfoEnabled(PetscClassId classid, PetscBool *enabled)
 {
   PetscFunctionBegin;
-  if (classid < PETSC_SMALLEST_CLASSID) SETERRQ1(PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Classid (current: %d) must be equal to or greater than PETSC_SMALLEST_CLASSID", classid);
+  PetscCheckFalse(classid < PETSC_SMALLEST_CLASSID,PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Classid (current: %d) must be equal to or greater than PETSC_SMALLEST_CLASSID", classid);
   *enabled = (PetscBool) (PetscLogPrintInfo && PetscInfoFlags[classid - PETSC_SMALLEST_CLASSID]);
   PetscFunctionReturn(0);
 }
@@ -101,25 +101,24 @@ PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
 {
   char            fname[PETSC_MAX_PATH_LEN], tname[11];
   PetscMPIInt     rank;
-  PetscErrorCode  ierr;
 
   PetscFunctionBegin;
   if (!PetscInfoFile) PetscInfoFile = PETSC_STDOUT;
-  ierr = PetscFree(PetscInfoFilename);CHKERRQ(ierr);
+  PetscCall(PetscFree(PetscInfoFilename));
   if (filename) {
     PetscBool  oldflag;
     PetscValidCharPointer(filename, 1);
-    ierr = PetscFixFilename(filename, fname);CHKERRQ(ierr);
-    ierr = PetscStrallocpy(fname, &PetscInfoFilename);CHKERRQ(ierr);
-    ierr = MPI_Comm_rank(MPI_COMM_WORLD, &rank);CHKERRMPI(ierr);
+    PetscCall(PetscFixFilename(filename, fname));
+    PetscCall(PetscStrallocpy(fname, &PetscInfoFilename));
+    PetscCallMPI(MPI_Comm_rank(MPI_COMM_WORLD, &rank));
     sprintf(tname, ".%d", rank);
-    ierr = PetscStrcat(fname, tname);CHKERRQ(ierr);
+    PetscCall(PetscStrcat(fname, tname));
     oldflag = PetscLogPrintInfo; PetscLogPrintInfo = PETSC_FALSE;
-    ierr = PetscFOpen(MPI_COMM_SELF, fname, mode, &PetscInfoFile);CHKERRQ(ierr);
+    PetscCall(PetscFOpen(MPI_COMM_SELF, fname, mode, &PetscInfoFile));
     PetscLogPrintInfo = oldflag;
     /* PetscFOpen will write to PETSC_STDOUT and not PetscInfoFile here, so we disable the PetscInfo call inside it, and
      call it afterwards so that it actually writes to file */
-    ierr = PetscInfo1(NULL, "Opened PetscInfo file %s\n", fname);CHKERRQ(ierr);
+    PetscCall(PetscInfo(NULL, "Opened PetscInfo file %s\n", fname));
   }
   PetscFunctionReturn(0);
 }
@@ -146,12 +145,10 @@ PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
 @*/
 PetscErrorCode PetscInfoGetFile(char **filename, FILE **InfoFile)
 {
-  PetscErrorCode  ierr;
-
   PetscFunctionBegin;
   PetscValidPointer(filename, 1);
   PetscValidPointer(InfoFile, 2);
-  ierr = PetscStrallocpy(PetscInfoFilename, filename);CHKERRQ(ierr);
+  PetscCall(PetscStrallocpy(PetscInfoFilename, filename));
   *InfoFile = PetscInfoFile;
   PetscFunctionReturn(0);
 }
@@ -185,18 +182,16 @@ PetscErrorCode PetscInfoGetFile(char **filename, FILE **InfoFile)
 @*/
 PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt N, const char *const *classnames)
 {
-  PetscErrorCode  ierr;
-
   PetscFunctionBegin;
-  if (PetscInfoClassesLocked) SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "PetscInfoSetClasses() cannot be called after PetscInfoGetClass() or PetscInfoProcessClass()");
-  ierr = PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames);CHKERRQ(ierr);
-  ierr = PetscStrNArrayallocpy(N, classnames, &PetscInfoClassnames);CHKERRQ(ierr);
+  PetscCheck(!PetscInfoClassesLocked,PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "PetscInfoSetClasses() cannot be called after PetscInfoGetClass() or PetscInfoProcessClass()");
+  PetscCall(PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames));
+  PetscCall(PetscStrNArrayallocpy(N, classnames, &PetscInfoClassnames));
   PetscInfoNumClasses = N;
   PetscInfoInvertClasses = exclude;
   {
     /* Process sys class right away */
     PetscClassId  sysclassid = PETSC_SMALLEST_CLASSID;
-    ierr = PetscInfoProcessClass("sys", 1, &sysclassid);CHKERRQ(ierr);
+    PetscCall(PetscInfoProcessClass("sys", 1, &sysclassid));
   }
   PetscInfoClassesSet = PETSC_TRUE;
   PetscFunctionReturn(0);
@@ -223,11 +218,10 @@ PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt N, const char *co
 PetscErrorCode PetscInfoGetClass(const char *classname, PetscBool *found)
 {
   PetscInt        idx;
-  PetscErrorCode  ierr;
 
   PetscFunctionBegin;
   PetscValidCharPointer(classname,1);
-  ierr = PetscEListFind(PetscInfoNumClasses, (const char *const *) PetscInfoClassnames, classname ? classname : "sys", &idx, found);CHKERRQ(ierr);
+  PetscCall(PetscEListFind(PetscInfoNumClasses, (const char *const *) PetscInfoClassnames, classname ? classname : "sys", &idx, found));
   PetscInfoClassesLocked = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
@@ -282,32 +276,31 @@ PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID
   PetscInt        i;
   PetscBool       enabled, exclude, found, opt, pkg;
   char            logList[256];
-  PetscErrorCode  ierr;
 
   PetscFunctionBegin;
   PetscValidCharPointer(classname, 1);
-  ierr = PetscInfoGetInfo(&enabled, NULL, &exclude, NULL, NULL);CHKERRQ(ierr);
+  PetscCall(PetscInfoGetInfo(&enabled, NULL, &exclude, NULL, NULL));
   /* -info_exclude is DEPRECATED */
-  ierr = PetscOptionsGetString(NULL,NULL,"-info_exclude",logList,sizeof(logList),&opt);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetString(NULL,NULL,"-info_exclude",logList,sizeof(logList),&opt));
   if (opt) {
-    ierr = PetscStrInList(classname,logList,',',&pkg);CHKERRQ(ierr);
+    PetscCall(PetscStrInList(classname,logList,',',&pkg));
     if (pkg) {
       for (i = 0; i < numClassID; ++i) {
-        ierr = PetscInfoDeactivateClass(classIDs[i]);CHKERRQ(ierr);
+        PetscCall(PetscInfoDeactivateClass(classIDs[i]));
       }
     }
   }
-  ierr = PetscInfoGetClass(classname, &found);CHKERRQ(ierr);
+  PetscCall(PetscInfoGetClass(classname, &found));
   if ((found && exclude) || (!found && !exclude)) {
     if (PetscInfoNumClasses > 0) {
       /* Check if -info was called empty */
       for (i = 0; i < numClassID; ++i) {
-        ierr = PetscInfoDeactivateClass(classIDs[i]);CHKERRQ(ierr);
+        PetscCall(PetscInfoDeactivateClass(classIDs[i]));
       }
     }
   } else {
     for (i = 0; i < numClassID; ++i) {
-      ierr = PetscInfoActivateClass(classIDs[i]);CHKERRQ(ierr);
+      PetscCall(PetscInfoActivateClass(classIDs[i]));
     }
   }
   PetscFunctionReturn(0);
@@ -358,23 +351,22 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
   size_t             size_loc0_ = 0, size_loc1_ = 0, size_loc2_ = 0;
   int                nLoc1_ = 0;
   PetscInfoCommFlag  commSelfFlag = PETSC_INFO_COMM_ALL;
-  PetscErrorCode     ierr;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsDeprecated_Private(NULL,"-info_exclude", NULL, "3.13", "Use -info instead");CHKERRQ(ierr);
-  ierr = PetscOptionsGetString(options, NULL, "-info", optstring, sizeof(optstring), &set);CHKERRQ(ierr);
+  PetscCall(PetscOptionsDeprecated_Private(NULL,"-info_exclude", NULL, "3.13", "Use -info instead"));
+  PetscCall(PetscOptionsGetString(options, NULL, "-info", optstring, sizeof(optstring), &set));
   if (set) {
     PetscInfoClassesSet = PETSC_TRUE;
-    ierr = PetscInfoAllow(PETSC_TRUE);CHKERRQ(ierr);
-    ierr = PetscStrallocpy(optstring,&loc0_);CHKERRQ(ierr);
-    ierr = PetscStrchr(loc0_,':',&loc1_);CHKERRQ(ierr);
+    PetscCall(PetscInfoAllow(PETSC_TRUE));
+    PetscCall(PetscStrallocpy(optstring,&loc0_));
+    PetscCall(PetscStrchr(loc0_,':',&loc1_));
     if (loc1_) {
       *loc1_++ = 0;
       if (*loc1_ == '~') {
         loc1_invert = PETSC_TRUE;
         ++loc1_;
       }
-      ierr = PetscStrchr(loc1_,':',&loc2_);CHKERRQ(ierr);
+      PetscCall(PetscStrchr(loc1_,':',&loc2_));
     }
     if (loc2_) {
       *loc2_++ = 0;
@@ -383,16 +375,16 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
         ++loc2_;
       }
     }
-    ierr = PetscStrlen(loc0_, &size_loc0_);CHKERRQ(ierr);
-    ierr = PetscStrlen(loc1_, &size_loc1_);CHKERRQ(ierr);
-    ierr = PetscStrlen(loc2_, &size_loc2_);CHKERRQ(ierr);
+    PetscCall(PetscStrlen(loc0_, &size_loc0_));
+    PetscCall(PetscStrlen(loc1_, &size_loc1_));
+    PetscCall(PetscStrlen(loc2_, &size_loc2_));
     if (size_loc1_) {
-      ierr = PetscStrtolower(loc1_);CHKERRQ(ierr);
-      ierr = PetscStrToArray(loc1_, ',', &nLoc1_, &loc1_array);CHKERRQ(ierr);
+      PetscCall(PetscStrtolower(loc1_));
+      PetscCall(PetscStrToArray(loc1_, ',', &nLoc1_, &loc1_array));
     }
     if (size_loc2_) {
-      ierr = PetscStrtolower(loc2_);CHKERRQ(ierr);
-      ierr = PetscStrcmp("self", loc2_, &foundSelf);CHKERRQ(ierr);
+      PetscCall(PetscStrtolower(loc2_));
+      PetscCall(PetscStrcmp("self", loc2_, &foundSelf));
       if (foundSelf) {
         if (loc2_invert) {
           commSelfFlag = PETSC_INFO_COMM_NO_SELF;
@@ -401,11 +393,11 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
         }
       }
     }
-    ierr = PetscInfoSetFile(size_loc0_ ? loc0_ : NULL, "w");CHKERRQ(ierr);
-    ierr = PetscInfoSetClasses(loc1_invert, (PetscInt) nLoc1_, (const char *const *) loc1_array);CHKERRQ(ierr);
-    ierr = PetscInfoSetFilterCommSelf(commSelfFlag);CHKERRQ(ierr);
-    ierr = PetscStrToArrayDestroy(nLoc1_, loc1_array);CHKERRQ(ierr);
-    ierr = PetscFree(loc0_);CHKERRQ(ierr);
+    PetscCall(PetscInfoSetFile(size_loc0_ ? loc0_ : NULL, "w"));
+    PetscCall(PetscInfoSetClasses(loc1_invert, (PetscInt) nLoc1_, (const char *const *) loc1_array));
+    PetscCall(PetscInfoSetFilterCommSelf(commSelfFlag));
+    PetscCall(PetscStrToArrayDestroy(nLoc1_, loc1_array));
+    PetscCall(PetscFree(loc0_));
   }
   PetscFunctionReturn(0);
 }
@@ -425,19 +417,18 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
 @*/
 PetscErrorCode PetscInfoDestroy(void)
 {
-  PetscErrorCode  ierr;
   int             err;
   size_t          i;
 
   PetscFunctionBegin;
-  ierr = PetscInfoAllow(PETSC_FALSE);CHKERRQ(ierr);
-  ierr = PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames);CHKERRQ(ierr);
+  PetscCall(PetscInfoAllow(PETSC_FALSE));
+  PetscCall(PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames));
   err  = fflush(PetscInfoFile);
-  if (err) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SYS,"fflush() failed on file");
+  PetscCheck(!err,PETSC_COMM_SELF,PETSC_ERR_SYS,"fflush() failed on file");
   if (PetscInfoFilename) {
-    ierr  = PetscFClose(MPI_COMM_SELF, PetscInfoFile);CHKERRQ(ierr);
+    PetscCall(PetscFClose(MPI_COMM_SELF, PetscInfoFile));
   }
-  ierr = PetscFree(PetscInfoFilename);CHKERRQ(ierr);
+  PetscCall(PetscFree(PetscInfoFilename));
   for (i=0; i<sizeof(PetscInfoFlags)/sizeof(PetscInfoFlags[0]); i++) PetscInfoFlags[i] = 1;
   PetscInfoClassesLocked = PETSC_FALSE;
   PetscInfoInvertClasses = PETSC_FALSE;
@@ -506,8 +497,8 @@ PETSC_INTERN FILE *petsc_history;
    Synopsis:
        #include <petscsys.h>
        PetscErrorCode PetscInfo(PetscObject obj, const char message[])
-       PetscErrorCode PetscInfo1(PetscObject obj, const char formatmessage[],arg1)
-       PetscErrorCode PetscInfo2(PetscObject obj, const char formatmessage[],arg1,arg2)
+       PetscErrorCode PetscInfo(PetscObject obj, const char formatmessage[],arg1)
+       PetscErrorCode PetscInfo(PetscObject obj, const char formatmessage[],arg1,arg2)
        ...
 
     Collective on obj
@@ -542,13 +533,13 @@ $   -info [filename][:[~]<list,of,classnames>[:[~]self]]
 $     Mat A;
 $     PetscInt alpha;
 $     ...
-$     PetscInfo1(A,"Matrix uses parameter alpha=%D\n",alpha);
+$     PetscInfo(A,"Matrix uses parameter alpha=%" PetscInt_FMT "\n",alpha);
 
     Options Examples:
     Each call of the form
 $     PetscInfo(obj, msg);
-$     PetscInfo1(obj, msg, arg1);
-$     PetscInfo2(obj, msg, arg1, arg2);
+$     PetscInfo(obj, msg, arg1);
+$     PetscInfo(obj, msg, arg1, arg2);
     is evaluated as follows.
 $     -info or -info :: prints msg to PETSC_STDOUT, for any obj regardless class or communicator
 $     -info :mat:self prints msg to PETSC_STDOUT only if class of obj is Mat, and its communicator has size = 1
@@ -560,7 +551,7 @@ $     -info :sys:~self
 
     Fortran Note:
     This function does not take the obj argument, there is only the PetscInfo()
-     version, not PetscInfo1() etc.
+     version, not PetscInfo() etc.
 
     Level: intermediate
 
@@ -573,19 +564,18 @@ PetscErrorCode  PetscInfo_Private(const char func[],PetscObject obj, const char
   PetscClassId   classid;
   PetscBool      enabled = PETSC_FALSE, oldflag;
   char           string[8*1024];
-  PetscErrorCode ierr;
   size_t         fullLength,len;
   int            err;
 
   PetscFunctionBegin;
   if (obj) PetscValidHeader(obj,2);
   classid = obj ? obj->classid : PETSC_SMALLEST_CLASSID;
-  ierr = PetscInfoEnabled(classid, &enabled);CHKERRQ(ierr);
+  PetscCall(PetscInfoEnabled(classid, &enabled));
   if (!enabled) PetscFunctionReturn(0);
   PetscValidCharPointer(message,3);
   if (obj) {
-    ierr = MPI_Comm_rank(obj->comm, &rank);CHKERRMPI(ierr);
-    ierr = MPI_Comm_size(obj->comm, &size);CHKERRMPI(ierr);
+    PetscCallMPI(MPI_Comm_rank(obj->comm, &rank));
+    PetscCallMPI(MPI_Comm_size(obj->comm, &size));
   }
   /* rank > 0 always jumps out */
   if (rank) PetscFunctionReturn(0);
@@ -598,17 +588,17 @@ PetscErrorCode  PetscInfo_Private(const char func[],PetscObject obj, const char
   }
   /* Mute info messages within this function */
   oldflag = PetscLogPrintInfo; PetscLogPrintInfo = PETSC_FALSE;
-  ierr = MPI_Comm_rank(MPI_COMM_WORLD, &urank);CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Comm_rank(MPI_COMM_WORLD, &urank));
   va_start(Argp, message);
   sprintf(string, "[%d] %s(): ",urank,func);
-  ierr = PetscStrlen(string, &len);CHKERRQ(ierr);
-  ierr = PetscVSNPrintf(string+len, 8*1024-len,message,&fullLength, Argp);CHKERRQ(ierr);
-  ierr = PetscFPrintf(PETSC_COMM_SELF,PetscInfoFile, "%s", string);CHKERRQ(ierr);
+  PetscCall(PetscStrlen(string, &len));
+  PetscCall(PetscVSNPrintf(string+len, 8*1024-len,message,&fullLength, Argp));
+  PetscCall(PetscFPrintf(PETSC_COMM_SELF,PetscInfoFile, "%s", string));
   err  = fflush(PetscInfoFile);
-  if (err) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SYS,"fflush() failed on file");
+  PetscCheck(!err,PETSC_COMM_SELF,PETSC_ERR_SYS,"fflush() failed on file");
   if (petsc_history) {
     va_start(Argp, message);
-    ierr = (*PetscVFPrintf)(petsc_history, message, Argp);CHKERRQ(ierr);
+    PetscCall((*PetscVFPrintf)(petsc_history, message, Argp));
   }
   va_end(Argp);
   PetscLogPrintInfo = oldflag;
