@@ -9,12 +9,8 @@
 
 #include <petsc/private/petscimpl.h> /* for PetscCUPMInitialized */
 
-#if defined(PETSC_HAVE_CUDA)
-  #include <cuda_runtime.h>
-#endif
-
-#if defined(PETSC_HAVE_HIP)
-  #include <hip/hip_runtime.h>
+#if defined(PETSC_HAVE_CUDA) || defined(PETSC_HAVE_HIP)
+#include <petscdevice.h>
 #endif
 
 #define MPI_SUCCESS 0
@@ -69,9 +65,9 @@ int MPIUNI_Memcpy(void *dst,const void *src,int n)
 
   /* GPU-aware MPIUNI. Use synchronous copy per MPI semantics */
 #if defined(PETSC_HAVE_CUDA)
-  if (PetscCUDAInitialized) {cudaError_t cerr = cudaMemcpy(dst,src,n,cudaMemcpyDefault);if (cerr != cudaSuccess) return MPI_FAILURE;} else
+  if (PetscDeviceInitialized(PETSC_DEVICE_CUDA)) {cudaError_t cerr = cudaMemcpy(dst,src,n,cudaMemcpyDefault);if (cerr != cudaSuccess) return MPI_FAILURE;} else
 #elif defined(PETSC_HAVE_HIP)
-  if (PetscHIPInitialized)  {hipError_t  cerr = hipMemcpy(dst,src,n,hipMemcpyDefault);  if (cerr != hipSuccess)  return MPI_FAILURE;} else
+  if (PetscDeviceInitialized(PETSC_DEVICE_HIP))  {hipError_t  cerr = hipMemcpy(dst,src,n,hipMemcpyDefault);  if (cerr != hipSuccess)  return MPI_FAILURE;} else
 #endif
   {memcpy(dst,src,n);}
   return MPI_SUCCESS;
@@ -127,7 +123,6 @@ int MPI_Type_get_contents(MPI_Datatype datatype,int max_integers,int max_address
   switch (comb) {
   case MPI_COMBINER_NAMED:
     return MPIUni_Abort(MPI_COMM_SELF,1);
-    break;
   case MPI_COMBINER_DUP:
     if (max_datatypes < 1) return MPIUni_Abort(MPI_COMM_SELF,1);
     array_of_datatypes[0] = datatype & 0x0fffffff;
@@ -217,6 +212,29 @@ int MPI_Comm_get_attr(MPI_Comm comm,int keyval,void *attribute_val,int *flag)
   return MPI_SUCCESS;
 }
 
+static char all_comm_names[MAX_COMM][MPI_MAX_OBJECT_NAME] = {
+  "MPI_COMM_SELF",
+  "MPI_COMM_WORLD"
+};
+
+int MPI_Comm_get_name(MPI_Comm comm,char *comm_name,int *resultlen)
+{
+  if (comm < 1 || comm > MaxComm) return MPI_FAILURE;
+  if (!comm_name || !resultlen) return MPI_FAILURE;
+  strncpy(comm_name,all_comm_names[CommIdx(comm)],MPI_MAX_OBJECT_NAME-1);
+  *resultlen = (int)strlen(comm_name);
+  return MPI_SUCCESS;
+}
+
+int MPI_Comm_set_name(MPI_Comm comm,const char *comm_name)
+{
+  if (comm < 1 || comm > MaxComm) return MPI_FAILURE;
+  if (!comm_name) return MPI_FAILURE;
+  if (strlen(comm_name) > MPI_MAX_OBJECT_NAME-1) return MPI_FAILURE;
+  strncpy(all_comm_names[CommIdx(comm)],comm_name,MPI_MAX_OBJECT_NAME-1);
+  return MPI_SUCCESS;
+}
+
 int MPI_Comm_create(MPI_Comm comm,MPI_Group group,MPI_Comm *newcomm)
 {
   int j;
@@ -284,7 +302,7 @@ int MPI_Comm_rank(MPI_Comm comm, int *rank)
 int MPIUni_Abort(MPI_Comm comm,int errorcode)
 {
   printf("MPI operation not supported by PETSc's sequential MPI wrappers\n");
-  return MPI_FAILURE;
+  return MPI_ERR_NOSUPPORT;
 }
 
 int MPI_Abort(MPI_Comm comm,int errorcode)
@@ -301,8 +319,25 @@ static int MPI_was_finalized   = 0;
 int MPI_Init(int *argc, char ***argv)
 {
   if (MPI_was_initialized) return MPI_FAILURE;
-  if (MPI_was_finalized) return MPI_FAILURE; /* MPI standard: once MPI_FINALIZE returns, no MPI routine (not even MPI_INIT) may be called, except ... */
+  /* MPI standard says "once MPI_Finalize returns, no MPI routine (not even MPI_Init) may be called", so an MPI standard compliant
+     MPIU should have this 'if (MPI_was_finalized) return MPI_FAILURE;' check. We relax it here to make life easier for users
+     of MPIU so that they can do multiple PetscInitialize/Finalize().
+  */
+  /* if (MPI_was_finalized) return MPI_FAILURE; */
   MPI_was_initialized = 1;
+  MPI_was_finalized   = 0;
+  return MPI_SUCCESS;
+}
+
+int MPI_Init_thread(int *argc, char ***argv, int required, int* provided)
+{
+  MPI_Query_thread(provided);
+  return MPI_Init(argc,argv);
+}
+
+int MPI_Query_thread(int* provided)
+{
+  *provided = MPI_THREAD_FUNNELED;
   return MPI_SUCCESS;
 }
 
@@ -326,7 +361,9 @@ int MPI_Finalize(void)
   /* reset counters */
   MaxComm  = 2;
   num_attr = 1;
-  MPI_was_finalized = 1;
+  MPI_was_finalized   = 1;
+  MPI_was_initialized = 0;
+  PETSC_COMM_WORLD    = MPI_COMM_NULL;
   return MPI_SUCCESS;
 }
 
