@@ -15,6 +15,9 @@
 
 #if defined(PETSC_USE_GCOV)
 EXTERN_C_BEGIN
+#if defined(PETSC_HAVE___GCOV_DUMP)
+#define __gcov_flush(x) __gcov_dump(x)
+#endif
 void  __gcov_flush(void);
 EXTERN_C_END
 #endif
@@ -791,7 +794,7 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char* prog,const char*
   }
 #endif
 
-#if PetscDefined(HAVE_DLSYM)
+#if PetscDefined(HAVE_DLSYM) && defined(__USE_GNU)
   /* These symbols are currently in the OpenMPI and MPICH libraries; they may not always be, in that case the test will simply not detect the problem */
   PetscCheck(!dlsym(RTLD_DEFAULT,"ompi_mpi_init") || !dlsym(RTLD_DEFAULT,"MPID_Abort"),PETSC_COMM_SELF,PETSC_ERR_MPI_LIB_INCOMP,"Application was linked against both OpenMPI and MPICH based MPI libraries and will not run correctly");
 #endif
