@@ -1,12 +1,9 @@
 
 static char help[] = "Demonstrates call PETSc first and then Trilinos in the same program.\n\n";
 
-/*T
-   Concepts: introduction to PETSc^Trilinos
-   Processors: n
-
+/*
    Example obtained from: http://trilinos.org/docs/dev/packages/tpetra/doc/html/Tpetra_Lesson01.html
-T*/
+*/
 
 #include <petscsys.h>
 #include <Teuchos_DefaultMpiComm.hpp> // wrapper for MPI_Comm
