@@ -1,12 +1,6 @@
 
 static char help[] = "Example of using PetscLikely() and PetscUnlikely().\n\n";
 
-/*T
-   Concepts: optimization^likely
-   Concepts: optimization^unlikely
-   Processors: n
-T*/
-
 #include <petscsys.h>
 
 int main(int argc,char **argv)
