@@ -7,29 +7,26 @@ typedef struct {
   Vec update;     /* work vector where new solution is formed  */
 } TS_Euler;
 
-#undef __FUNCT__
-#define __FUNCT__ "TSStep_Euler"
 static PetscErrorCode TSStep_Euler(TS ts)
 {
   TS_Euler       *euler = (TS_Euler*)ts->data;
   Vec            solution = ts->vec_sol,update = euler->update;
   PetscBool      stageok,accept = PETSC_TRUE;
   PetscReal      next_time_step = ts->time_step;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = TSPreStage(ts,ts->ptime);CHKERRQ(ierr);
-  ierr = TSComputeRHSFunction(ts,ts->ptime,solution,update);CHKERRQ(ierr);
-  ierr = VecAYPX(update,ts->time_step,solution);CHKERRQ(ierr);
-  ierr = TSPostStage(ts,ts->ptime,0,&solution);CHKERRQ(ierr);
-  ierr = TSAdaptCheckStage(ts->adapt,ts,ts->ptime,solution,&stageok);CHKERRQ(ierr);
-  if(!stageok) {ts->reason = TS_DIVERGED_STEP_REJECTED; PetscFunctionReturn(0);}
-  ierr = TSFunctionDomainError(ts,ts->ptime+ts->time_step,update,&stageok);CHKERRQ(ierr);
-  if(!stageok) {ts->reason = TS_DIVERGED_STEP_REJECTED; PetscFunctionReturn(0);}
+  PetscCall(TSPreStage(ts,ts->ptime));
+  PetscCall(TSComputeRHSFunction(ts,ts->ptime,solution,update));
+  PetscCall(VecAYPX(update,ts->time_step,solution));
+  PetscCall(TSPostStage(ts,ts->ptime,0,&solution));
+  PetscCall(TSAdaptCheckStage(ts->adapt,ts,ts->ptime,solution,&stageok));
+  if (!stageok) {ts->reason = TS_DIVERGED_STEP_REJECTED; PetscFunctionReturn(0);}
+  PetscCall(TSFunctionDomainError(ts,ts->ptime+ts->time_step,update,&stageok));
+  if (!stageok) {ts->reason = TS_DIVERGED_STEP_REJECTED; PetscFunctionReturn(0);}
 
-  ierr = TSAdaptChoose(ts->adapt,ts,ts->time_step,NULL,&next_time_step,&accept);CHKERRQ(ierr);
+  PetscCall(TSAdaptChoose(ts->adapt,ts,ts->time_step,NULL,&next_time_step,&accept));
   if (!accept) {ts->reason = TS_DIVERGED_STEP_REJECTED; PetscFunctionReturn(0);}
-  ierr = VecCopy(update,solution);CHKERRQ(ierr);
+  PetscCall(VecCopy(update,solution));
 
   ts->ptime += ts->time_step;
   ts->time_step = next_time_step;
@@ -37,79 +34,60 @@ static PetscErrorCode TSStep_Euler(TS ts)
 }
 /*------------------------------------------------------------*/
 
-#undef __FUNCT__
-#define __FUNCT__ "TSSetUp_Euler"
 static PetscErrorCode TSSetUp_Euler(TS ts)
 {
   TS_Euler       *euler = (TS_Euler*)ts->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = TSCheckImplicitTerm(ts);CHKERRQ(ierr);
-  ierr = VecDuplicate(ts->vec_sol,&euler->update);CHKERRQ(ierr);
-  ierr = TSGetAdapt(ts,&ts->adapt);CHKERRQ(ierr);
-  ierr = TSAdaptCandidatesClear(ts->adapt);CHKERRQ(ierr);
+  PetscCall(TSCheckImplicitTerm(ts));
+  PetscCall(VecDuplicate(ts->vec_sol,&euler->update));
+  PetscCall(TSGetAdapt(ts,&ts->adapt));
+  PetscCall(TSAdaptCandidatesClear(ts->adapt));
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "TSReset_Euler"
 static PetscErrorCode TSReset_Euler(TS ts)
 {
   TS_Euler       *euler = (TS_Euler*)ts->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = VecDestroy(&euler->update);CHKERRQ(ierr);
+  PetscCall(VecDestroy(&euler->update));
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "TSDestroy_Euler"
 static PetscErrorCode TSDestroy_Euler(TS ts)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = TSReset_Euler(ts);CHKERRQ(ierr);
-  ierr = PetscFree(ts->data);CHKERRQ(ierr);
+  PetscCall(TSReset_Euler(ts));
+  PetscCall(PetscFree(ts->data));
   PetscFunctionReturn(0);
 }
 /*------------------------------------------------------------*/
 
-#undef __FUNCT__
-#define __FUNCT__ "TSSetFromOptions_Euler"
 static PetscErrorCode TSSetFromOptions_Euler(PetscOptionItems *PetscOptionsObject,TS ts)
 {
   PetscFunctionBegin;
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "TSView_Euler"
 static PetscErrorCode TSView_Euler(TS ts,PetscViewer viewer)
 {
   PetscFunctionBegin;
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "TSInterpolate_Euler"
 static PetscErrorCode TSInterpolate_Euler(TS ts,PetscReal t,Vec X)
 {
   TS_Euler       *euler = (TS_Euler*)ts->data;
   Vec            update = euler->update;
   PetscReal      alpha = (ts->ptime - t)/ts->time_step;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = VecWAXPY(X,-ts->time_step,update,ts->vec_sol);CHKERRQ(ierr);
-  ierr = VecAXPBY(X,1.0-alpha,alpha,ts->vec_sol);CHKERRQ(ierr);
+  PetscCall(VecWAXPY(X,-ts->time_step,update,ts->vec_sol));
+  PetscCall(VecAXPBY(X,1.0-alpha,alpha,ts->vec_sol));
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "TSComputeLinearStability_Euler"
 static PetscErrorCode TSComputeLinearStability_Euler(TS ts,PetscReal xr,PetscReal xi,PetscReal *yr,PetscReal *yi)
 {
   PetscFunctionBegin;
@@ -127,15 +105,12 @@ static PetscErrorCode TSComputeLinearStability_Euler(TS ts,PetscReal xr,PetscRea
 .seealso:  TSCreate(), TS, TSSetType(), TSBEULER
 
 M*/
-#undef __FUNCT__
-#define __FUNCT__ "TSCreate_Euler"
 PETSC_EXTERN PetscErrorCode TSCreate_Euler(TS ts)
 {
   TS_Euler       *euler;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(ts,&euler);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(ts,&euler));
   ts->data = (void*)euler;
 
   ts->ops->setup           = TSSetUp_Euler;
@@ -146,5 +121,7 @@ PETSC_EXTERN PetscErrorCode TSCreate_Euler(TS ts)
   ts->ops->view            = TSView_Euler;
   ts->ops->interpolate     = TSInterpolate_Euler;
   ts->ops->linearstability = TSComputeLinearStability_Euler;
+  ts->default_adapt_type   = TSADAPTNONE;
+  ts->usessnes             = PETSC_FALSE;
   PetscFunctionReturn(0);
 }
