@@ -108,7 +108,6 @@ typedef struct {
   PetscInt    interval;
 } MonitorCtx;
 
-
 /* Inputs read in from text file */
 struct in {
   PetscScalar Ts;     /* surface temperature  */
@@ -136,7 +135,7 @@ extern PetscScalar cloud(PetscScalar);                              /* cloud rad
 extern PetscErrorCode FormInitialSolution(DM,Vec,void*);            /* Specifies initial conditions for the system of equations (PETSc defined function) */
 extern PetscErrorCode RhsFunc(TS,PetscReal,Vec,Vec,void*);          /* Specifies the user defined functions                     (PETSc defined function) */
 extern PetscErrorCode Monitor(TS,PetscInt,PetscReal,Vec,void*);     /* Specifies output and visualization tools                 (PETSc defined function) */
-extern void readinput(struct in *put);                              /* reads input from text file */
+extern PetscErrorCode readinput(struct in *put);                              /* reads input from text file */
 extern PetscErrorCode calcfluxs(PetscScalar, PetscScalar, PetscScalar, PetscScalar, PetscScalar, PetscScalar*); /* calculates upward IR from surface */
 extern PetscErrorCode calcfluxa(PetscScalar, PetscScalar, PetscScalar, PetscScalar*);                           /* calculates downward IR from atmosphere */
 extern PetscErrorCode sensibleflux(PetscScalar, PetscScalar, PetscScalar, PetscScalar*);                        /* calculates sensible heat flux */
@@ -146,8 +145,7 @@ extern PetscErrorCode calc_gflux(PetscScalar, PetscScalar, PetscScalar*);
 
 int main(int argc,char **argv)
 {
-  PetscErrorCode ierr;
-  int            time;           /* amount of loops */
+  PetscInt       time;           /* amount of loops */
   struct in      put;
   PetscScalar    rh;             /* relative humidity */
   PetscScalar    x;              /* memory varialbe for relative humidity calculation */
@@ -162,7 +160,6 @@ int main(int argc,char **argv)
   PetscScalar    cloudTemp;      /* temperature at base of cloud */
   AppCtx         user;           /*  user-defined work context */
   MonitorCtx     usermonitor;    /* user-defined monitor context */
-  PetscMPIInt    rank,size;
   TS             ts;
   SNES           snes;
   DM             da;
@@ -174,12 +171,10 @@ int main(int argc,char **argv)
   MatFDColoring  matfdcoloring = 0;
   PetscBool      monitor_off = PETSC_FALSE;
 
-  ierr = PetscInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
-  ierr = MPI_Comm_size(PETSC_COMM_WORLD,&size);CHKERRQ(ierr);
-  ierr = MPI_Comm_rank(PETSC_COMM_WORLD,&rank);CHKERRQ(ierr);
+  PetscCall(PetscInitialize(&argc,&argv,(char*)0,help));
 
   /* Inputs */
-  readinput(&put);
+  PetscCall(readinput(&put));
 
   sfctemp   = put.Ts;
   dewtemp   = put.Td;
@@ -187,7 +182,7 @@ int main(int argc,char **argv)
   airtemp   = put.Ta;
   pwat      = put.pwt;
 
-  if (!rank) PetscPrintf(PETSC_COMM_SELF,"Initial Temperature = %g\n",(double)sfctemp); /* input surface temperature */
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Initial Temperature = %g\n",(double)sfctemp)); /* input surface temperature */
 
   deep_grnd_temp = sfctemp - 10;   /* set underlying ground layer temperature */
   emma           = emission(pwat); /* accounts for radiative effects of water vapor */
@@ -211,7 +206,7 @@ int main(int argc,char **argv)
   mixratio = calcmixingr(sfctemp,pressure1);
   rh       = (x/mixratio)*100;
 
-  if (!rank) printf("Initial RH = %.1f percent\n\n",(double)rh);   /* prints initial relative humidity */
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Initial RH = %.1f percent\n\n",(double)rh));   /* prints initial relative humidity */
 
   time = 3600*put.time;                         /* sets amount of timesteps to run model */
 
@@ -219,17 +214,17 @@ int main(int argc,char **argv)
   /*------------------------------------------*/
 
   /* Create grid */
-  ierr = DMDACreate2d(PETSC_COMM_WORLD,DM_BOUNDARY_PERIODIC,DM_BOUNDARY_PERIODIC,DMDA_STENCIL_STAR,20,20,PETSC_DECIDE,PETSC_DECIDE,dof,1,NULL,NULL,&da);CHKERRQ(ierr);
-  ierr = DMSetFromOptions(da);CHKERRQ(ierr);
-  ierr = DMSetUp(da);CHKERRQ(ierr);
-  ierr = DMDASetUniformCoordinates(da, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0);CHKERRQ(ierr);
+  PetscCall(DMDACreate2d(PETSC_COMM_WORLD,DM_BOUNDARY_PERIODIC,DM_BOUNDARY_PERIODIC,DMDA_STENCIL_STAR,20,20,PETSC_DECIDE,PETSC_DECIDE,dof,1,NULL,NULL,&da));
+  PetscCall(DMSetFromOptions(da));
+  PetscCall(DMSetUp(da));
+  PetscCall(DMDASetUniformCoordinates(da, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0));
 
   /* Define output window for each variable of interest */
-  ierr = DMDASetFieldName(da,0,"Ts");CHKERRQ(ierr);
-  ierr = DMDASetFieldName(da,1,"Ta");CHKERRQ(ierr);
-  ierr = DMDASetFieldName(da,2,"u");CHKERRQ(ierr);
-  ierr = DMDASetFieldName(da,3,"v");CHKERRQ(ierr);
-  ierr = DMDASetFieldName(da,4,"p");CHKERRQ(ierr);
+  PetscCall(DMDASetFieldName(da,0,"Ts"));
+  PetscCall(DMDASetFieldName(da,1,"Ta"));
+  PetscCall(DMDASetFieldName(da,2,"u"));
+  PetscCall(DMDASetFieldName(da,3,"v"));
+  PetscCall(DMDASetFieldName(da,4,"p"));
 
   /* set values for appctx */
   user.da             = da;
@@ -249,86 +244,85 @@ int main(int argc,char **argv)
 
   /* set values for MonitorCtx */
   usermonitor.drawcontours = PETSC_FALSE;
-  ierr = PetscOptionsHasName(NULL,NULL,"-drawcontours",&usermonitor.drawcontours);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL,NULL,"-drawcontours",&usermonitor.drawcontours));
   if (usermonitor.drawcontours) {
     PetscReal bounds[] = {1000.0,-1000.,  -1000.,-1000.,  1000.,-1000.,  1000.,-1000.,  1000,-1000, 100700,100800};
-    ierr = PetscViewerDrawOpen(PETSC_COMM_WORLD,0,0,0,0,300,300,&usermonitor.drawviewer);CHKERRQ(ierr);
-    ierr = PetscViewerDrawSetBounds(usermonitor.drawviewer,dof,bounds);CHKERRQ(ierr);
+    PetscCall(PetscViewerDrawOpen(PETSC_COMM_WORLD,0,0,0,0,300,300,&usermonitor.drawviewer));
+    PetscCall(PetscViewerDrawSetBounds(usermonitor.drawviewer,dof,bounds));
   }
   usermonitor.interval = 1;
-  ierr = PetscOptionsGetInt(NULL,NULL,"-monitor_interval",&usermonitor.interval,NULL);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetInt(NULL,NULL,"-monitor_interval",&usermonitor.interval,NULL));
 
   /*  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Extract global vectors from DA;
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  ierr = DMCreateGlobalVector(da,&T);CHKERRQ(ierr);
-  ierr = VecDuplicate(T,&rhs);CHKERRQ(ierr); /* r: vector to put the computed right hand side */
+  PetscCall(DMCreateGlobalVector(da,&T));
+  PetscCall(VecDuplicate(T,&rhs)); /* r: vector to put the computed right hand side */
 
-  ierr = TSCreate(PETSC_COMM_WORLD,&ts);CHKERRQ(ierr);
-  ierr = TSSetProblemType(ts,TS_NONLINEAR);CHKERRQ(ierr);
-  ierr = TSSetType(ts,TSBEULER);CHKERRQ(ierr);
-  ierr = TSSetRHSFunction(ts,rhs,RhsFunc,&user);CHKERRQ(ierr);
+  PetscCall(TSCreate(PETSC_COMM_WORLD,&ts));
+  PetscCall(TSSetProblemType(ts,TS_NONLINEAR));
+  PetscCall(TSSetType(ts,TSBEULER));
+  PetscCall(TSSetRHSFunction(ts,rhs,RhsFunc,&user));
 
   /* Set Jacobian evaluation routine - use coloring to compute finite difference Jacobian efficiently */
-  ierr = DMSetMatType(da,MATAIJ);CHKERRQ(ierr);
-  ierr = DMCreateMatrix(da,&J);CHKERRQ(ierr);
-  ierr = TSGetSNES(ts,&snes);CHKERRQ(ierr);
+  PetscCall(DMSetMatType(da,MATAIJ));
+  PetscCall(DMCreateMatrix(da,&J));
+  PetscCall(TSGetSNES(ts,&snes));
   if (use_coloring) {
     ISColoring iscoloring;
-    ierr = DMCreateColoring(da,IS_COLORING_GLOBAL,&iscoloring);CHKERRQ(ierr);
-    ierr = MatFDColoringCreate(J,iscoloring,&matfdcoloring);CHKERRQ(ierr);
-    ierr = MatFDColoringSetFromOptions(matfdcoloring);CHKERRQ(ierr);
-    ierr = MatFDColoringSetUp(J,iscoloring,matfdcoloring);CHKERRQ(ierr);
-    ierr = ISColoringDestroy(&iscoloring);CHKERRQ(ierr);
-    ierr = MatFDColoringSetFunction(matfdcoloring,(PetscErrorCode (*)(void))SNESTSFormFunction,ts);CHKERRQ(ierr);
-    ierr = SNESSetJacobian(snes,J,J,SNESComputeJacobianDefaultColor,matfdcoloring);CHKERRQ(ierr);
+    PetscCall(DMCreateColoring(da,IS_COLORING_GLOBAL,&iscoloring));
+    PetscCall(MatFDColoringCreate(J,iscoloring,&matfdcoloring));
+    PetscCall(MatFDColoringSetFromOptions(matfdcoloring));
+    PetscCall(MatFDColoringSetUp(J,iscoloring,matfdcoloring));
+    PetscCall(ISColoringDestroy(&iscoloring));
+    PetscCall(MatFDColoringSetFunction(matfdcoloring,(PetscErrorCode (*)(void))SNESTSFormFunction,ts));
+    PetscCall(SNESSetJacobian(snes,J,J,SNESComputeJacobianDefaultColor,matfdcoloring));
   } else {
-    ierr = SNESSetJacobian(snes,J,J,SNESComputeJacobianDefault,NULL);CHKERRQ(ierr);
+    PetscCall(SNESSetJacobian(snes,J,J,SNESComputeJacobianDefault,NULL));
   }
 
   /* Define what to print for ts_monitor option */
-  ierr = PetscOptionsHasName(NULL,NULL,"-monitor_off",&monitor_off);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL,NULL,"-monitor_off",&monitor_off));
   if (!monitor_off) {
-    ierr = TSMonitorSet(ts,Monitor,&usermonitor,NULL);CHKERRQ(ierr);
+    PetscCall(TSMonitorSet(ts,Monitor,&usermonitor,NULL));
   }
-  ierr  = FormInitialSolution(da,T,&user);CHKERRQ(ierr);
+  PetscCall(FormInitialSolution(da,T,&user));
   dt    = TIMESTEP; /* initial time step */
   ftime = TIMESTEP*time;
-  if (!rank) printf("time %d, ftime %g hour, TIMESTEP %g\n",time,(double)(ftime/3600),(double)dt);
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"time %D, ftime %g hour, TIMESTEP %g\n",time,(double)(ftime/3600),(double)dt));
 
-  ierr = TSSetTimeStep(ts,dt);CHKERRQ(ierr);
-  ierr = TSSetMaxSteps(ts,time);CHKERRQ(ierr);
-  ierr = TSSetMaxTime(ts,ftime);CHKERRQ(ierr);
-  ierr = TSSetExactFinalTime(ts,TS_EXACTFINALTIME_STEPOVER);CHKERRQ(ierr);
-  ierr = TSSetSolution(ts,T);CHKERRQ(ierr);
-  ierr = TSSetDM(ts,da);CHKERRQ(ierr);
+  PetscCall(TSSetTimeStep(ts,dt));
+  PetscCall(TSSetMaxSteps(ts,time));
+  PetscCall(TSSetMaxTime(ts,ftime));
+  PetscCall(TSSetExactFinalTime(ts,TS_EXACTFINALTIME_STEPOVER));
+  PetscCall(TSSetSolution(ts,T));
+  PetscCall(TSSetDM(ts,da));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Set runtime options
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  ierr = TSSetFromOptions(ts);CHKERRQ(ierr);
+  PetscCall(TSSetFromOptions(ts));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Solve nonlinear system
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  ierr = TSSolve(ts,T);CHKERRQ(ierr);
-  ierr = TSGetSolveTime(ts,&ftime);CHKERRQ(ierr);
-  ierr = TSGetStepNumber(ts,&steps);CHKERRQ(ierr);
-  if (!rank) PetscPrintf(PETSC_COMM_WORLD,"Solution T after %g hours %d steps\n",(double)(ftime/3600),steps);
+  PetscCall(TSSolve(ts,T));
+  PetscCall(TSGetSolveTime(ts,&ftime));
+  PetscCall(TSGetStepNumber(ts,&steps));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Solution T after %g hours %D steps\n",(double)(ftime/3600),steps));
 
-
-  if (matfdcoloring) {ierr = MatFDColoringDestroy(&matfdcoloring);CHKERRQ(ierr);}
+  if (matfdcoloring) PetscCall(MatFDColoringDestroy(&matfdcoloring));
   if (usermonitor.drawcontours) {
-    ierr = PetscViewerDestroy(&usermonitor.drawviewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerDestroy(&usermonitor.drawviewer));
   }
-  ierr = MatDestroy(&J);CHKERRQ(ierr);
-  ierr = VecDestroy(&T);CHKERRQ(ierr);
-  ierr = VecDestroy(&rhs);CHKERRQ(ierr);
-  ierr = TSDestroy(&ts);CHKERRQ(ierr);
-  ierr = DMDestroy(&da);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&J));
+  PetscCall(VecDestroy(&T));
+  PetscCall(VecDestroy(&rhs));
+  PetscCall(TSDestroy(&ts));
+  PetscCall(DMDestroy(&da));
 
-  ierr = PetscFinalize();
-  return ierr;
+  PetscCall(PetscFinalize());
+  return 0;
 }
 /*****************************end main program********************************/
 /*****************************************************************************/
@@ -479,55 +473,56 @@ extern PetscScalar cel_to_fahr(PetscScalar temp)
   temp = ((temp*9)/5) + 32; /* converts from celsuis to farhrenheit */
   return temp;
 }
-void readinput(struct in *put)
+PetscErrorCode readinput(struct in *put)
 {
   int    i;
   char   x;
   FILE   *ifp;
   double tmp;
 
+  PetscFunctionBegin;
   ifp = fopen("ex5_control.txt", "r");
-
-  for (i=0; i<110; i++) { if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();
+  PetscCheck(ifp,PETSC_COMM_SELF,PETSC_ERR_FILE_OPEN,"Unable to open input file");
+  for (i=0; i<110; i++) { PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->Ts = tmp;
 
-  for (i=0; i<43; i++) { if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();
+  for (i=0; i<43; i++) { PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->Td = tmp;
 
-  for (i=0; i<43; i++) { if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();
+  for (i=0; i<43; i++) { PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->Ta = tmp;
 
-  for (i=0; i<43; i++) { if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp)!= 1) abort();
+  for (i=0; i<43; i++) { PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp)== 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->Tc = tmp;
 
-  for (i=0; i<43; i++) { if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();
+  for (i=0; i<43; i++) { PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->fr = tmp;
 
-  for (i=0; i<43; i++) {if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();
+  for (i=0; i<43; i++) {PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->wnd = tmp;
 
-  for (i=0; i<43; i++) {if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();  
+  for (i=0; i<43; i++) {PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->pwt = tmp;
 
-  for (i=0; i<43; i++) {if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();  
+  for (i=0; i<43; i++) {PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->wndDir = tmp;
 
-  for (i=0; i<43; i++) {if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();  
+  for (i=0; i<43; i++) {PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->time = tmp;
 
-  for (i=0; i<63; i++) {if (fscanf(ifp, "%c", &x) != 1) abort();}
-  if (fscanf(ifp, "%lf", &tmp) != 1) abort();
+  for (i=0; i<63; i++) {PetscCheck(fscanf(ifp, "%c", &x) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");}
+  PetscCheck(fscanf(ifp, "%lf", &tmp) == 1,PETSC_COMM_SELF,PETSC_ERR_FILE_READ,"Unable to read file");
   put->init = tmp;
-
+  PetscFunctionReturn(0);
 }
 
 /* ------------------------------------------------------------------- */
@@ -540,13 +535,13 @@ PetscErrorCode FormInitialSolution(DM da,Vec Xglobal,void *ctx)
 
   PetscFunctionBeginUser;
   ierr = DMDAGetInfo(da,PETSC_IGNORE,&Mx,&My,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE);CHKERRQ(ierr);
+                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE);PetscCall(ierr);
 
   /* Get pointers to vector data */
-  ierr = DMDAVecGetArray(da,Xglobal,&X);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArray(da,Xglobal,&X));
 
   /* Get local grid boundaries */
-  ierr = DMDAGetCorners(da,&xs,&ys,NULL,&xm,&ym,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da,&xs,&ys,NULL,&xm,&ym,NULL));
 
   /* Compute function over the locally owned part of the grid */
 
@@ -575,7 +570,7 @@ PetscErrorCode FormInitialSolution(DM da,Vec Xglobal,void *ctx)
   }
 
   /* Restore vectors */
-  ierr = DMDAVecRestoreArray(da,Xglobal,&X);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArray(da,Xglobal,&X));
   PetscFunctionReturn(0);
 }
 
@@ -596,7 +591,6 @@ PetscErrorCode RhsFunc(TS ts,PetscReal t,Vec Xglobal,Vec F,void *ctx)
 {
   AppCtx         *user = (AppCtx*)ctx;       /* user-defined application context */
   DM             da    = user->da;
-  PetscErrorCode ierr;
   PetscInt       i,j,Mx,My,xs,ys,xm,ym;
   PetscReal      dhx,dhy;
   Vec            localT;
@@ -626,28 +620,27 @@ PetscErrorCode RhsFunc(TS ts,PetscReal t,Vec Xglobal,Vec F,void *ctx)
   PetscInt    xend,yend;
 
   PetscFunctionBeginUser;
-  ierr = DMGetLocalVector(da,&localT);CHKERRQ(ierr);
-  ierr = DMDAGetInfo(da,PETSC_IGNORE,&Mx,&My,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE);CHKERRQ(ierr);
+  PetscCall(DMGetLocalVector(da,&localT));
+  PetscCall(DMDAGetInfo(da,PETSC_IGNORE,&Mx,&My,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE));
 
   dhx = (PetscReal)(Mx-1)/(5000*(Mx-1));  /* dhx = 1/dx; assume 2D space domain: [0.0, 1.e5] x [0.0, 1.e5] */
   dhy = (PetscReal)(My-1)/(5000*(Mx-1));  /* dhy = 1/dy; */
 
-
   /*
      Scatter ghost points to local vector,using the 2-step process
         DAGlobalToLocalBegin(),DAGlobalToLocalEnd().
      By placing code between these two statements, computations can be
      done while messages are in transition.
   */
-  ierr = DMGlobalToLocalBegin(da,Xglobal,INSERT_VALUES,localT);CHKERRQ(ierr);
-  ierr = DMGlobalToLocalEnd(da,Xglobal,INSERT_VALUES,localT);CHKERRQ(ierr);
+  PetscCall(DMGlobalToLocalBegin(da,Xglobal,INSERT_VALUES,localT));
+  PetscCall(DMGlobalToLocalEnd(da,Xglobal,INSERT_VALUES,localT));
 
   /* Get pointers to vector data */
-  ierr = DMDAVecGetArrayRead(da,localT,&X);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,F,&Frhs);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArrayRead(da,localT,&X));
+  PetscCall(DMDAVecGetArray(da,F,&Frhs));
 
   /* Get local grid boundaries */
-  ierr = DMDAGetCorners(da,&xs,&ys,NULL,&xm,&ym,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da,&xs,&ys,NULL,&xm,&ym,NULL));
 
   /* Compute function over the locally owned part of the grid */
   /* the interior points */
@@ -657,11 +650,11 @@ PetscErrorCode RhsFunc(TS ts,PetscReal t,Vec Xglobal,Vec F,void *ctx)
       Ts = X[j][i].Ts; u = X[j][i].u; v = X[j][i].v; p = X[j][i].p; /*P = X[j][i].P; */
 
       sfctemp1 = (double)Ts;
-      ierr     = calcfluxs(sfctemp1,airtemp,emma,fract,Tc,&fsfc1);CHKERRQ(ierr);        /* calculates surface net radiative flux */
-      ierr     = sensibleflux(sfctemp1,airtemp,wind,&sheat);CHKERRQ(ierr);              /* calculate sensible heat flux */
-      ierr     = latentflux(sfctemp1,dewtemp,wind,pressure1,&latentheat);CHKERRQ(ierr); /* calculates latent heat flux */
-      ierr     = calc_gflux(sfctemp1,deep_grnd_temp,&groundflux);CHKERRQ(ierr);         /* calculates flux from earth below surface soil layer by conduction */
-      ierr     = calcfluxa(sfctemp1,airtemp,emma,&Ra);CHKERRQ(ierr);                    /* Calculates the change in downward radiative flux */
+      PetscCall(calcfluxs(sfctemp1,airtemp,emma,fract,Tc,&fsfc1));        /* calculates surface net radiative flux */
+      PetscCall(sensibleflux(sfctemp1,airtemp,wind,&sheat));              /* calculate sensible heat flux */
+      PetscCall(latentflux(sfctemp1,dewtemp,wind,pressure1,&latentheat)); /* calculates latent heat flux */
+      PetscCall(calc_gflux(sfctemp1,deep_grnd_temp,&groundflux));         /* calculates flux from earth below surface soil layer by conduction */
+      PetscCall(calcfluxa(sfctemp1,airtemp,emma,&Ra));                    /* Calculates the change in downward radiative flux */
       fsfc1    = fsfc1 + latentheat + sheat + groundflux;                               /* adds radiative, sensible heat, latent heat, and ground heat flux yielding net flux */
 
       /* convective coefficients for upwinding */
@@ -706,39 +699,34 @@ PetscErrorCode RhsFunc(TS ts,PetscReal t,Vec Xglobal,Vec F,void *ctx)
   }
 
   /* Restore vectors */
-  ierr = DMDAVecRestoreArrayRead(da,localT,&X);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(da,F,&Frhs);CHKERRQ(ierr);
-  ierr = DMRestoreLocalVector(da,&localT);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArrayRead(da,localT,&X));
+  PetscCall(DMDAVecRestoreArray(da,F,&Frhs));
+  PetscCall(DMRestoreLocalVector(da,&localT));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode Monitor(TS ts,PetscInt step,PetscReal time,Vec T,void *ctx)
 {
-  PetscErrorCode    ierr;
   const PetscScalar *array;
   MonitorCtx        *user  = (MonitorCtx*)ctx;
   PetscViewer       viewer = user->drawviewer;
-  PetscMPIInt       rank;
   PetscReal         norm;
 
   PetscFunctionBeginUser;
-  ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)ts),&rank);CHKERRQ(ierr);
-  ierr = VecNorm(T,NORM_INFINITY,&norm);CHKERRQ(ierr);
+  PetscCall(VecNorm(T,NORM_INFINITY,&norm));
 
   if (step%user->interval == 0) {
-    ierr = VecGetArrayRead(T,&array);CHKERRQ(ierr);
-    if (!rank) printf("step %4d, time %8.1f,  %6.4f, %6.4f, %6.4f, %6.4f, %6.4f, %6.4f\n",(int)step,(double)time,(double)(((array[0]-273)*9)/5 + 32),(double)(((array[1]-273)*9)/5 + 32),(double)array[2],(double)array[3],(double)array[4],(double)array[5]);
-    ierr = VecRestoreArrayRead(T,&array);CHKERRQ(ierr);
+    PetscCall(VecGetArrayRead(T,&array));
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD,"step %D, time %8.1f,  %6.4f, %6.4f, %6.4f, %6.4f, %6.4f, %6.4f\n",step,(double)time,(double)(((array[0]-273)*9)/5 + 32),(double)(((array[1]-273)*9)/5 + 32),(double)array[2],(double)array[3],(double)array[4],(double)array[5]));
+    PetscCall(VecRestoreArrayRead(T,&array));
   }
 
   if (user->drawcontours) {
-    ierr = VecView(T,viewer);CHKERRQ(ierr);
+    PetscCall(VecView(T,viewer));
   }
   PetscFunctionReturn(0);
 }
 
-
-
 /*TEST
 
    build:
