@@ -2,13 +2,6 @@ static char help[] = "Demonstrates automatic Jacobian generation using ADOL-C fo
 Input parameters include:\n\
       -mu : stiffness parameter\n\n";
 
-/*
-   Concepts: TS^time-dependent nonlinear problems
-   Concepts: TS^van der Pol equation
-   Concepts: Optimization using adjoint sensitivities
-   Concepts: Automatic differentation using ADOL-C
-   Processors: 1
-*/
 /*
    REQUIRES configuration of PETSc with option --download-adolc.
 
