@@ -7,26 +7,24 @@
 
 static PetscErrorCode ISDuplicate_General(IS is,IS *newIS)
 {
-  PetscErrorCode ierr;
   IS_General     *sub = (IS_General*)is->data;
   PetscInt       n;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = ISCreateGeneral(PetscObjectComm((PetscObject) is), n, sub->idx, PETSC_COPY_VALUES, newIS);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCall(ISCreateGeneral(PetscObjectComm((PetscObject) is), n, sub->idx, PETSC_COPY_VALUES, newIS));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode ISDestroy_General(IS is)
 {
   IS_General     *is_general = (IS_General*)is->data;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  if (is_general->allocated) {ierr = PetscFree(is_general->idx);CHKERRQ(ierr);}
-  ierr = PetscObjectComposeFunction((PetscObject)is,"ISGeneralSetIndices_C",NULL);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)is,"ISGeneralFilter_C",NULL);CHKERRQ(ierr);
-  ierr = PetscFree(is->data);CHKERRQ(ierr);
+  if (is_general->allocated) PetscCall(PetscFree(is_general->idx));
+  PetscCall(PetscObjectComposeFunction((PetscObject)is,"ISGeneralSetIndices_C",NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)is,"ISGeneralFilter_C",NULL));
+  PetscCall(PetscFree(is->data));
   PetscFunctionReturn(0);
 }
 
@@ -34,37 +32,33 @@ static PetscErrorCode ISCopy_General(IS is,IS isy)
 {
   IS_General     *is_general = (IS_General*)is->data,*isy_general = (IS_General*)isy->data;
   PetscInt       n, N, ny, Ny;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = PetscLayoutGetSize(is->map, &N);CHKERRQ(ierr);
-  ierr = PetscLayoutGetLocalSize(isy->map, &ny);CHKERRQ(ierr);
-  ierr = PetscLayoutGetSize(isy->map, &Ny);CHKERRQ(ierr);
-  if (n != ny || N != Ny) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"Index sets incompatible");
-  ierr = PetscArraycpy(isy_general->idx,is_general->idx,n);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCall(PetscLayoutGetSize(is->map, &N));
+  PetscCall(PetscLayoutGetLocalSize(isy->map, &ny));
+  PetscCall(PetscLayoutGetSize(isy->map, &Ny));
+  PetscCheckFalse(n != ny || N != Ny,PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"Index sets incompatible");
+  PetscCall(PetscArraycpy(isy_general->idx,is_general->idx,n));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode ISOnComm_General(IS is,MPI_Comm comm,PetscCopyMode mode,IS *newis)
 {
-  PetscErrorCode ierr;
   IS_General     *sub = (IS_General*)is->data;
   PetscInt       n;
 
   PetscFunctionBegin;
-  if (mode == PETSC_OWN_POINTER) SETERRQ(comm,PETSC_ERR_ARG_WRONG,"Cannot use PETSC_OWN_POINTER");
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = ISCreateGeneral(comm,n,sub->idx,mode,newis);CHKERRQ(ierr);
+  PetscCheckFalse(mode == PETSC_OWN_POINTER,comm,PETSC_ERR_ARG_WRONG,"Cannot use PETSC_OWN_POINTER");
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCall(ISCreateGeneral(comm,n,sub->idx,mode,newis));
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode ISSetBlockSize_General(IS is,PetscInt bs)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscLayoutSetBlockSize(is->map, bs);CHKERRQ(ierr);
+  PetscCall(PetscLayoutSetBlockSize(is->map, bs));
   PetscFunctionReturn(0);
 }
 
@@ -72,12 +66,11 @@ static PetscErrorCode ISContiguousLocal_General(IS is,PetscInt gstart,PetscInt g
 {
   IS_General *sub = (IS_General*)is->data;
   PetscInt   n,i,p;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   *start  = 0;
   *contig = PETSC_TRUE;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
   if (!n) PetscFunctionReturn(0);
   p = sub->idx[0];
   if (p < gstart) goto nomatch;
@@ -98,12 +91,11 @@ static PetscErrorCode ISLocate_General(IS is,PetscInt key,PetscInt *location)
   IS_General     *sub = (IS_General*)is->data;
   PetscInt       numIdx, i;
   PetscBool      sorted;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map,&numIdx);CHKERRQ(ierr);
-  ierr = ISGetInfo(is,IS_SORTED,IS_LOCAL,PETSC_TRUE,&sorted);CHKERRQ(ierr);
-  if (sorted) {ierr = PetscFindInt(key,numIdx,sub->idx,location);CHKERRQ(ierr);}
+  PetscCall(PetscLayoutGetLocalSize(is->map,&numIdx));
+  PetscCall(ISGetInfo(is,IS_SORTED,IS_LOCAL,PETSC_TRUE,&sorted));
+  if (sorted) PetscCall(PetscFindInt(key,numIdx,sub->idx,location));
   else {
     const PetscInt *idx = sub->idx;
 
@@ -133,7 +125,7 @@ static PetscErrorCode ISRestoreIndices_General(IS in,const PetscInt *idx[])
 
   PetscFunctionBegin;
    /* F90Array1dCreate() inside ISRestoreArrayF90() does not keep array when zero length array */
-  if (in->map->n > 0  && *idx != sub->idx) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"Must restore with value from ISGetIndices()");
+  PetscCheckFalse(in->map->n > 0  && *idx != sub->idx,PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"Must restore with value from ISGetIndices()");
   PetscFunctionReturn(0);
 }
 
@@ -144,39 +136,36 @@ static PetscErrorCode ISInvertPermutation_General(IS is,PetscInt nlocal,IS *isou
   const PetscInt *idx = sub->idx;
   PetscMPIInt    size;
   IS             istmp,nistmp;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)is),&size);CHKERRMPI(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)is),&size));
   if (size == 1) {
-    ierr = PetscMalloc1(n,&ii);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(n,&ii));
     for (i=0; i<n; i++) ii[idx[i]] = i;
-    ierr = ISCreateGeneral(PETSC_COMM_SELF,n,ii,PETSC_OWN_POINTER,isout);CHKERRQ(ierr);
-    ierr = ISSetPermutation(*isout);CHKERRQ(ierr);
+    PetscCall(ISCreateGeneral(PETSC_COMM_SELF,n,ii,PETSC_OWN_POINTER,isout));
+    PetscCall(ISSetPermutation(*isout));
   } else {
     /* crude, nonscalable get entire IS on each processor */
-    ierr = ISAllGather(is,&istmp);CHKERRQ(ierr);
-    ierr = ISSetPermutation(istmp);CHKERRQ(ierr);
-    ierr = ISInvertPermutation(istmp,PETSC_DECIDE,&nistmp);CHKERRQ(ierr);
-    ierr = ISDestroy(&istmp);CHKERRQ(ierr);
+    PetscCall(ISAllGather(is,&istmp));
+    PetscCall(ISSetPermutation(istmp));
+    PetscCall(ISInvertPermutation(istmp,PETSC_DECIDE,&nistmp));
+    PetscCall(ISDestroy(&istmp));
     /* get the part we need */
     if (nlocal == PETSC_DECIDE) nlocal = n;
-    ierr = MPI_Scan(&nlocal,&nstart,1,MPIU_INT,MPI_SUM,PetscObjectComm((PetscObject)is));CHKERRMPI(ierr);
+    PetscCallMPI(MPI_Scan(&nlocal,&nstart,1,MPIU_INT,MPI_SUM,PetscObjectComm((PetscObject)is)));
     if (PetscDefined(USE_DEBUG)) {
       PetscInt    N;
       PetscMPIInt rank;
-      ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)is),&rank);CHKERRMPI(ierr);
-      ierr = PetscLayoutGetSize(is->map, &N);CHKERRQ(ierr);
-      if (rank == size-1) {
-        if (nstart != N) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"Sum of nlocal lengths %d != total IS length %d",nstart,N);
-      }
+      PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)is),&rank));
+      PetscCall(PetscLayoutGetSize(is->map, &N));
+      PetscCheck((rank != size-1) || (nstart == N),PETSC_COMM_SELF,PETSC_ERR_ARG_INCOMP,"Sum of nlocal lengths %" PetscInt_FMT " != total IS length %" PetscInt_FMT,nstart,N);
     }
     nstart -= nlocal;
-    ierr    = ISGetIndices(nistmp,&idx);CHKERRQ(ierr);
-    ierr    = ISCreateGeneral(PetscObjectComm((PetscObject)is),nlocal,idx+nstart,PETSC_COPY_VALUES,isout);CHKERRQ(ierr);
-    ierr    = ISRestoreIndices(nistmp,&idx);CHKERRQ(ierr);
-    ierr    = ISDestroy(&nistmp);CHKERRQ(ierr);
+    PetscCall(ISGetIndices(nistmp,&idx));
+    PetscCall(ISCreateGeneral(PetscObjectComm((PetscObject)is),nlocal,idx+nstart,PETSC_COPY_VALUES,isout));
+    PetscCall(ISRestoreIndices(nistmp,&idx));
+    PetscCall(ISDestroy(&nistmp));
   }
   PetscFunctionReturn(0);
 }
@@ -194,17 +183,17 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
   hsize_t         dim, maxDims[3], dims[3], chunkDims[3], count[3],offset[3];
   PetscBool       timestepping;
   PetscInt        bs, N, n, timestep=PETSC_MIN_INT, low;
+  hsize_t         chunksize;
   const PetscInt *ind;
   const char     *isname;
-  PetscErrorCode  ierr;
 
   PetscFunctionBegin;
-  ierr = ISGetBlockSize(is,&bs);CHKERRQ(ierr);
+  PetscCall(ISGetBlockSize(is,&bs));
   bs   = PetscMax(bs, 1); /* If N = 0, bs  = 0 as well */
-  ierr = PetscViewerHDF5OpenGroup(viewer, &file_id, &group);CHKERRQ(ierr);
-  ierr = PetscViewerHDF5IsTimestepping(viewer, &timestepping);CHKERRQ(ierr);
+  PetscCall(PetscViewerHDF5OpenGroup(viewer, &file_id, &group));
+  PetscCall(PetscViewerHDF5IsTimestepping(viewer, &timestepping));
   if (timestepping) {
-    ierr = PetscViewerHDF5GetTimestep(viewer, &timestep);CHKERRQ(ierr);
+    PetscCall(PetscViewerHDF5GetTimestep(viewer, &timestep));
   }
 
   /* Create the dataspace for the dataset.
@@ -219,25 +208,40 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
    * permit extending dataset).
    */
   dim = 0;
+  chunksize = 1;
   if (timestep >= 0) {
     dims[dim]      = timestep+1;
     maxDims[dim]   = H5S_UNLIMITED;
     chunkDims[dim] = 1;
     ++dim;
   }
-  ierr = ISGetSize(is, &N);CHKERRQ(ierr);
-  ierr = ISGetLocalSize(is, &n);CHKERRQ(ierr);
-  ierr = PetscHDF5IntCast(N/bs,dims + dim);CHKERRQ(ierr);
+  PetscCall(ISGetSize(is, &N));
+  PetscCall(ISGetLocalSize(is, &n));
+  PetscCall(PetscHDF5IntCast(N/bs,dims + dim));
 
   maxDims[dim]   = dims[dim];
   chunkDims[dim] = PetscMax(1,dims[dim]);
+  chunksize      *= chunkDims[dim];
   ++dim;
   if (bs >= 1) {
     dims[dim]      = bs;
     maxDims[dim]   = dims[dim];
     chunkDims[dim] = dims[dim];
+    chunksize      *= chunkDims[dim];
     ++dim;
   }
+  /* hdf5 chunks must be less than 4GB */
+  if (chunksize > PETSC_HDF5_MAX_CHUNKSIZE/64) {
+    if (bs >= 1) {
+      if (chunkDims[dim-2] > (PetscInt)PetscSqrtReal((PetscReal)(PETSC_HDF5_MAX_CHUNKSIZE/64))) {
+        chunkDims[dim-2] = (PetscInt)PetscSqrtReal((PetscReal)(PETSC_HDF5_MAX_CHUNKSIZE/64));
+      } if (chunkDims[dim-1] > (PetscInt)PetscSqrtReal((PetscReal)(PETSC_HDF5_MAX_CHUNKSIZE/64))) {
+        chunkDims[dim-1] = (PetscInt)PetscSqrtReal((PetscReal)(PETSC_HDF5_MAX_CHUNKSIZE/64));
+      }
+    } else {
+      chunkDims[dim-1] = PETSC_HDF5_MAX_CHUNKSIZE/64;
+    }
+  }
   PetscStackCallHDF5Return(filespace,H5Screate_simple,(dim, dims, maxDims));
 
 #if defined(PETSC_USE_64BIT_INDICES)
@@ -247,7 +251,7 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
 #endif
 
   /* Create the dataset with default properties and close filespace */
-  ierr = PetscObjectGetName((PetscObject) is, &isname);CHKERRQ(ierr);
+  PetscCall(PetscObjectGetName((PetscObject) is, &isname));
   if (!H5Lexists(group, isname, H5P_DEFAULT)) {
     /* Create chunk */
     PetscStackCallHDF5Return(chunkspace,H5Pcreate,(H5P_DATASET_CREATE));
@@ -267,7 +271,7 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
     count[dim] = 1;
     ++dim;
   }
-  ierr = PetscHDF5IntCast(n/bs,count + dim);CHKERRQ(ierr);
+  PetscCall(PetscHDF5IntCast(n/bs,count + dim));
   ++dim;
   if (bs >= 1) {
     count[dim] = bs;
@@ -281,13 +285,13 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
   }
 
   /* Select hyperslab in the file */
-  ierr = PetscLayoutGetRange(is->map, &low, NULL);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetRange(is->map, &low, NULL));
   dim  = 0;
   if (timestep >= 0) {
     offset[dim] = timestep;
     ++dim;
   }
-  ierr = PetscHDF5IntCast(low/bs,offset + dim);CHKERRQ(ierr);
+  PetscCall(PetscHDF5IntCast(low/bs,offset + dim));
   ++dim;
   if (bs >= 1) {
     offset[dim] = 0;
@@ -301,10 +305,10 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
     PetscStackCallHDF5Return(filespace,H5Screate,(H5S_NULL));
   }
 
-  ierr = ISGetIndices(is, &ind);CHKERRQ(ierr);
+  PetscCall(ISGetIndices(is, &ind));
   PetscStackCallHDF5(H5Dwrite,(dset_id, inttype, memspace, filespace, hdf5->dxpl_id, ind));
   PetscStackCallHDF5(H5Fflush,(file_id, H5F_SCOPE_GLOBAL));
-  ierr = ISRestoreIndices(is, &ind);CHKERRQ(ierr);
+  PetscCall(ISRestoreIndices(is, &ind));
 
   /* Close/release resources */
   PetscStackCallHDF5(H5Gclose,(group));
@@ -312,8 +316,10 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
   PetscStackCallHDF5(H5Sclose,(memspace));
   PetscStackCallHDF5(H5Dclose,(dset_id));
 
-  ierr = PetscViewerHDF5WriteObjectAttribute(viewer,(PetscObject)is,"timestepping",PETSC_BOOL,&timestepping);CHKERRQ(ierr);
-  ierr = PetscInfo1(is, "Wrote IS object with name %s\n", isname);CHKERRQ(ierr);
+  if (timestepping) {
+    PetscCall(PetscViewerHDF5WriteObjectAttribute(viewer,(PetscObject)is,"timestepping",PETSC_BOOL,&timestepping));
+  }
+  PetscCall(PetscInfo(is, "Wrote IS object with name %s\n", isname));
   PetscFunctionReturn(0);
 }
 #endif
@@ -321,75 +327,74 @@ static PetscErrorCode ISView_General_HDF5(IS is, PetscViewer viewer)
 static PetscErrorCode ISView_General(IS is,PetscViewer viewer)
 {
   IS_General     *sub = (IS_General*)is->data;
-  PetscErrorCode ierr;
   PetscInt       i,n,*idx = sub->idx;
   PetscBool      iascii,isbinary,ishdf5;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERBINARY,&isbinary);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERHDF5,&ishdf5);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERBINARY,&isbinary));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERHDF5,&ishdf5));
   if (iascii) {
     MPI_Comm          comm;
     PetscMPIInt       rank,size;
     PetscViewerFormat fmt;
     PetscBool         isperm;
 
-    ierr = PetscObjectGetComm((PetscObject)viewer,&comm);CHKERRQ(ierr);
-    ierr = MPI_Comm_rank(comm,&rank);CHKERRMPI(ierr);
-    ierr = MPI_Comm_size(comm,&size);CHKERRMPI(ierr);
+    PetscCall(PetscObjectGetComm((PetscObject)viewer,&comm));
+    PetscCallMPI(MPI_Comm_rank(comm,&rank));
+    PetscCallMPI(MPI_Comm_size(comm,&size));
 
-    ierr = PetscViewerGetFormat(viewer,&fmt);CHKERRQ(ierr);
-    ierr = ISGetInfo(is,IS_PERMUTATION,IS_LOCAL,PETSC_FALSE,&isperm);CHKERRQ(ierr);
-    if (isperm && fmt != PETSC_VIEWER_ASCII_MATLAB) {ierr = PetscViewerASCIIPrintf(viewer,"Index set is permutation\n");CHKERRQ(ierr);}
-    ierr = PetscViewerASCIIPushSynchronized(viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerGetFormat(viewer,&fmt));
+    PetscCall(ISGetInfo(is,IS_PERMUTATION,IS_LOCAL,PETSC_FALSE,&isperm));
+    if (isperm && fmt != PETSC_VIEWER_ASCII_MATLAB) PetscCall(PetscViewerASCIIPrintf(viewer,"Index set is permutation\n"));
+    PetscCall(PetscViewerASCIIPushSynchronized(viewer));
     if (size > 1) {
       if (fmt == PETSC_VIEWER_ASCII_MATLAB) {
         const char* name;
 
-        ierr = PetscObjectGetName((PetscObject)is,&name);CHKERRQ(ierr);
-        ierr = PetscViewerASCIISynchronizedPrintf(viewer,"%s_%d = [...\n",name,rank);CHKERRQ(ierr);
+        PetscCall(PetscObjectGetName((PetscObject)is,&name));
+        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"%s_%d = [...\n",name,rank));
         for (i=0; i<n; i++) {
-          ierr = PetscViewerASCIISynchronizedPrintf(viewer,"%D\n",idx[i]+1);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"%" PetscInt_FMT "\n",idx[i]+1));
         }
-        ierr = PetscViewerASCIISynchronizedPrintf(viewer,"];\n");CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"];\n"));
       } else {
         PetscInt  st = 0;
 
         if (fmt == PETSC_VIEWER_ASCII_INDEX) st = is->map->rstart;
-        ierr = PetscViewerASCIISynchronizedPrintf(viewer,"[%d] Number of indices in set %D\n",rank,n);CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"[%d] Number of indices in set %" PetscInt_FMT "\n",rank,n));
         for (i=0; i<n; i++) {
-          ierr = PetscViewerASCIISynchronizedPrintf(viewer,"[%d] %D %D\n",rank,i + st,idx[i]);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"[%d] %" PetscInt_FMT " %" PetscInt_FMT "\n",rank,i + st,idx[i]));
         }
       }
     } else {
       if (fmt == PETSC_VIEWER_ASCII_MATLAB) {
         const char* name;
 
-        ierr = PetscObjectGetName((PetscObject)is,&name);CHKERRQ(ierr);
-        ierr = PetscViewerASCIISynchronizedPrintf(viewer,"%s = [...\n",name);CHKERRQ(ierr);
+        PetscCall(PetscObjectGetName((PetscObject)is,&name));
+        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"%s = [...\n",name));
         for (i=0; i<n; i++) {
-          ierr = PetscViewerASCIISynchronizedPrintf(viewer,"%D\n",idx[i]+1);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"%" PetscInt_FMT "\n",idx[i]+1));
         }
-        ierr = PetscViewerASCIISynchronizedPrintf(viewer,"];\n");CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"];\n"));
       } else {
         PetscInt  st = 0;
 
         if (fmt == PETSC_VIEWER_ASCII_INDEX) st = is->map->rstart;
-        ierr = PetscViewerASCIISynchronizedPrintf(viewer,"Number of indices in set %D\n",n);CHKERRQ(ierr);
+        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"Number of indices in set %" PetscInt_FMT "\n",n));
         for (i=0; i<n; i++) {
-          ierr = PetscViewerASCIISynchronizedPrintf(viewer,"%D %D\n",i + st,idx[i]);CHKERRQ(ierr);
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer,"%" PetscInt_FMT " %" PetscInt_FMT "\n",i + st,idx[i]));
         }
       }
     }
-    ierr = PetscViewerFlush(viewer);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPopSynchronized(viewer);CHKERRQ(ierr);
+    PetscCall(PetscViewerFlush(viewer));
+    PetscCall(PetscViewerASCIIPopSynchronized(viewer));
   } else if (isbinary) {
-    ierr = ISView_Binary(is,viewer);CHKERRQ(ierr);
+    PetscCall(ISView_Binary(is,viewer));
   } else if (ishdf5) {
 #if defined(PETSC_HAVE_HDF5)
-    ierr = ISView_General_HDF5(is,viewer);CHKERRQ(ierr);
+    PetscCall(ISView_General_HDF5(is,viewer));
 #endif
   }
   PetscFunctionReturn(0);
@@ -399,11 +404,10 @@ static PetscErrorCode ISSort_General(IS is)
 {
   IS_General     *sub = (IS_General*)is->data;
   PetscInt       n;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = PetscIntSortSemiOrdered(n,sub->idx);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCall(PetscIntSortSemiOrdered(n,sub->idx));
   PetscFunctionReturn(0);
 }
 
@@ -413,28 +417,25 @@ static PetscErrorCode ISSortRemoveDups_General(IS is)
   PetscLayout    map;
   PetscInt       n;
   PetscBool      sorted;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
-  ierr = ISGetInfo(is,IS_SORTED,IS_LOCAL,PETSC_TRUE,&sorted);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
+  PetscCall(ISGetInfo(is,IS_SORTED,IS_LOCAL,PETSC_TRUE,&sorted));
   if (sorted) {
-    ierr = PetscSortedRemoveDupsInt(&n,sub->idx);CHKERRQ(ierr);
+    PetscCall(PetscSortedRemoveDupsInt(&n,sub->idx));
   } else {
-    ierr = PetscSortRemoveDupsInt(&n,sub->idx);CHKERRQ(ierr);
+    PetscCall(PetscSortRemoveDupsInt(&n,sub->idx));
   }
-  ierr = PetscLayoutCreateFromSizes(PetscObjectComm((PetscObject)is), n, PETSC_DECIDE, is->map->bs, &map);CHKERRQ(ierr);
-  ierr = PetscLayoutDestroy(&is->map);CHKERRQ(ierr);
+  PetscCall(PetscLayoutCreateFromSizes(PetscObjectComm((PetscObject)is), n, PETSC_DECIDE, is->map->bs, &map));
+  PetscCall(PetscLayoutDestroy(&is->map));
   is->map = map;
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode ISSorted_General(IS is,PetscBool  *flg)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = ISGetInfo(is,IS_SORTED,IS_LOCAL,PETSC_TRUE,flg);CHKERRQ(ierr);
+  PetscCall(ISGetInfo(is,IS_SORTED,IS_LOCAL,PETSC_TRUE,flg));
   PetscFunctionReturn(0);
 }
 
@@ -476,13 +477,12 @@ PETSC_INTERN PetscErrorCode ISSetUp_General(IS);
 
 PetscErrorCode ISSetUp_General(IS is)
 {
-  PetscErrorCode ierr;
   IS_General     *sub = (IS_General*)is->data;
   const PetscInt *idx = sub->idx;
   PetscInt       n,i,min,max;
 
   PetscFunctionBegin;
-  ierr = PetscLayoutGetLocalSize(is->map, &n);CHKERRQ(ierr);
+  PetscCall(PetscLayoutGetLocalSize(is->map, &n));
 
   if (n) {
     min = max = idx[0];
@@ -526,12 +526,10 @@ PetscErrorCode ISSetUp_General(IS is)
 @*/
 PetscErrorCode  ISCreateGeneral(MPI_Comm comm,PetscInt n,const PetscInt idx[],PetscCopyMode mode,IS *is)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = ISCreate(comm,is);CHKERRQ(ierr);
-  ierr = ISSetType(*is,ISGENERAL);CHKERRQ(ierr);
-  ierr = ISGeneralSetIndices(*is,n,idx,mode);CHKERRQ(ierr);
+  PetscCall(ISCreate(comm,is));
+  PetscCall(ISSetType(*is,ISGENERAL));
+  PetscCall(ISGeneralSetIndices(*is,n,idx,mode));
   PetscFunctionReturn(0);
 }
 
@@ -548,49 +546,101 @@ PetscErrorCode  ISCreateGeneral(MPI_Comm comm,PetscInt n,const PetscInt idx[],Pe
 
    Level: beginner
 
-.seealso: ISCreateGeneral(), ISCreateStride(), ISCreateBlock(), ISAllGather(), ISBlockSetIndices(), ISGENERAL, PetscCopyMode
+.seealso: ISCreateGeneral(), ISGeneralSetIndicesFromMask(), ISBlockSetIndices(), ISGENERAL, PetscCopyMode
 @*/
 PetscErrorCode  ISGeneralSetIndices(IS is,PetscInt n,const PetscInt idx[],PetscCopyMode mode)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = ISClearInfoCache(is,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = PetscUseMethod(is,"ISGeneralSetIndices_C",(IS,PetscInt,const PetscInt[],PetscCopyMode),(is,n,idx,mode));CHKERRQ(ierr);
+  PetscValidHeaderSpecific(is,IS_CLASSID,1);
+  if (n) PetscValidIntPointer(idx,3);
+  PetscCall(ISClearInfoCache(is,PETSC_FALSE));
+  PetscUseMethod(is,"ISGeneralSetIndices_C",(IS,PetscInt,const PetscInt[],PetscCopyMode),(is,n,idx,mode));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode  ISGeneralSetIndices_General(IS is,PetscInt n,const PetscInt idx[],PetscCopyMode mode)
 {
   PetscLayout    map;
-  PetscErrorCode ierr;
   IS_General     *sub = (IS_General*)is->data;
 
   PetscFunctionBegin;
-  if (n < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"length < 0");
+  PetscCheckFalse(n < 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"length < 0");
   if (n) PetscValidIntPointer(idx,3);
 
-  ierr = PetscLayoutCreateFromSizes(PetscObjectComm((PetscObject)is),n,PETSC_DECIDE,is->map->bs,&map);CHKERRQ(ierr);
-  ierr = PetscLayoutDestroy(&is->map);CHKERRQ(ierr);
+  PetscCall(PetscLayoutCreateFromSizes(PetscObjectComm((PetscObject)is),n,PETSC_DECIDE,is->map->bs,&map));
+  PetscCall(PetscLayoutDestroy(&is->map));
   is->map = map;
 
-  if (sub->allocated) {ierr = PetscFree(sub->idx);CHKERRQ(ierr);}
+  if (sub->allocated) PetscCall(PetscFree(sub->idx));
   if (mode == PETSC_COPY_VALUES) {
-    ierr = PetscMalloc1(n,&sub->idx);CHKERRQ(ierr);
-    ierr = PetscLogObjectMemory((PetscObject)is,n*sizeof(PetscInt));CHKERRQ(ierr);
-    ierr = PetscArraycpy(sub->idx,idx,n);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(n,&sub->idx));
+    PetscCall(PetscLogObjectMemory((PetscObject)is,n*sizeof(PetscInt)));
+    PetscCall(PetscArraycpy(sub->idx,idx,n));
     sub->allocated = PETSC_TRUE;
   } else if (mode == PETSC_OWN_POINTER) {
     sub->idx = (PetscInt*)idx;
-    ierr = PetscLogObjectMemory((PetscObject)is,n*sizeof(PetscInt));CHKERRQ(ierr);
+    PetscCall(PetscLogObjectMemory((PetscObject)is,n*sizeof(PetscInt)));
     sub->allocated = PETSC_TRUE;
   } else {
     sub->idx = (PetscInt*)idx;
     sub->allocated = PETSC_FALSE;
   }
 
-  ierr = ISSetUp_General(is);CHKERRQ(ierr);
-  ierr = ISViewFromOptions(is,NULL,"-is_view");CHKERRQ(ierr);
+  PetscCall(ISSetUp_General(is));
+  PetscCall(ISViewFromOptions(is,NULL,"-is_view"));
+  PetscFunctionReturn(0);
+}
+
+/*@
+   ISGeneralSetIndicesFromMask - Sets the indices for an ISGENERAL index set using a boolean mask
+
+   Collective on IS
+
+   Input Parameters:
++  is - the index set
+.  rstart - the range start index (inclusive)
+.  rend - the range end index (exclusive)
+-  mask - the boolean mask array of length rend-rstart, indices will be set for each PETSC_TRUE value in the array
+
+   Notes:
+   The mask array may be freed by the user after this call.
+
+   Example:
+$  PetscBool mask[] = {PETSC_FALSE, PETSC_TRUE, PETSC_FALSE, PETSC_FALSE, PETSC_TRUE};
+$  ISGeneralSetIndicesFromMask(is,10,15,mask);
+   will feed the IS with indices
+$  {11, 14}
+   locally.
+
+   Level: beginner
+
+.seealso: ISCreateGeneral(), ISGeneralSetIndices(), ISGENERAL
+@*/
+PetscErrorCode ISGeneralSetIndicesFromMask(IS is,PetscInt rstart,PetscInt rend,const PetscBool mask[])
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(is,IS_CLASSID,1);
+  if (rend-rstart) PetscValidBoolPointer(mask,4);
+  PetscCall(ISClearInfoCache(is,PETSC_FALSE));
+  PetscUseMethod(is,"ISGeneralSetIndicesFromMask_C",(IS,PetscInt,PetscInt,const PetscBool[]),(is,rstart,rend,mask));
+  PetscFunctionReturn(0);
+}
+
+PetscErrorCode ISGeneralSetIndicesFromMask_General(IS is,PetscInt rstart,PetscInt rend,const PetscBool mask[])
+{
+  PetscInt        i,nidx;
+  PetscInt       *idx;
+
+  PetscFunctionBegin;
+  for (i=0,nidx=0; i<rend-rstart; i++) if (mask[i]) nidx++;
+  PetscCall(PetscMalloc1(nidx,&idx));
+  for (i=0,nidx=0; i<rend-rstart; i++) {
+    if (mask[i]) {
+      idx[nidx] = i+rstart;
+      nidx++;
+    }
+  }
+  PetscCall(ISGeneralSetIndices_General(is,nidx,idx,PETSC_OWN_POINTER));
   PetscFunctionReturn(0);
 }
 
@@ -599,18 +649,17 @@ static PetscErrorCode ISGeneralFilter_General(IS is, PetscInt start, PetscInt en
   IS_General     *sub = (IS_General*)is->data;
   PetscInt       *idx = sub->idx,*idxnew;
   PetscInt       i,n = is->map->n,nnew = 0,o;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   for (i=0; i<n; ++i)
     if (idx[i] >= start && idx[i] < end)
       nnew++;
-  ierr = PetscMalloc1(nnew, &idxnew);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(nnew, &idxnew));
   for (o=0, i=0; i<n; i++) {
     if (idx[i] >= start && idx[i] < end)
       idxnew[o++] = idx[i];
   }
-  ierr = ISGeneralSetIndices_General(is,nnew,idxnew,PETSC_OWN_POINTER);CHKERRQ(ierr);
+  PetscCall(ISGeneralSetIndices_General(is,nnew,idxnew,PETSC_OWN_POINTER));
   PetscFunctionReturn(0);
 }
 
@@ -630,25 +679,23 @@ static PetscErrorCode ISGeneralFilter_General(IS is, PetscInt start, PetscInt en
 @*/
 PetscErrorCode ISGeneralFilter(IS is, PetscInt start, PetscInt end)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   PetscValidHeaderSpecific(is,IS_CLASSID,1);
-  ierr = ISClearInfoCache(is,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = PetscUseMethod(is,"ISGeneralFilter_C",(IS,PetscInt,PetscInt),(is,start,end));CHKERRQ(ierr);
+  PetscCall(ISClearInfoCache(is,PETSC_FALSE));
+  PetscUseMethod(is,"ISGeneralFilter_C",(IS,PetscInt,PetscInt),(is,start,end));
   PetscFunctionReturn(0);
 }
 
 PETSC_EXTERN PetscErrorCode ISCreate_General(IS is)
 {
-  PetscErrorCode ierr;
   IS_General     *sub;
 
   PetscFunctionBegin;
-  ierr = PetscNewLog(is,&sub);CHKERRQ(ierr);
+  PetscCall(PetscNewLog(is,&sub));
   is->data = (void *) sub;
-  ierr = PetscMemcpy(is->ops,&myops,sizeof(myops));CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)is,"ISGeneralSetIndices_C",ISGeneralSetIndices_General);CHKERRQ(ierr);
-  ierr = PetscObjectComposeFunction((PetscObject)is,"ISGeneralFilter_C",ISGeneralFilter_General);CHKERRQ(ierr);
+  PetscCall(PetscMemcpy(is->ops,&myops,sizeof(myops)));
+  PetscCall(PetscObjectComposeFunction((PetscObject)is,"ISGeneralSetIndices_C",ISGeneralSetIndices_General));
+  PetscCall(PetscObjectComposeFunction((PetscObject)is,"ISGeneralSetIndicesFromMask_C",ISGeneralSetIndicesFromMask_General));
+  PetscCall(PetscObjectComposeFunction((PetscObject)is,"ISGeneralFilter_C",ISGeneralFilter_General));
   PetscFunctionReturn(0);
 }
