@@ -23,58 +23,55 @@ PetscErrorCode VecDestroy_MPIHIP(Vec v)
 {
   Vec_MPI        *vecmpi = (Vec_MPI*)v->data;
   Vec_HIP        *vechip;
-  PetscErrorCode ierr;
-  hipError_t     err;
 
   PetscFunctionBegin;
   if (v->spptr) {
     vechip = (Vec_HIP*)v->spptr;
     if (vechip->GPUarray_allocated) {
-      err = hipFree(vechip->GPUarray_allocated);CHKERRHIP(err);
+      PetscCallHIP(hipFree(vechip->GPUarray_allocated));
       vechip->GPUarray_allocated = NULL;
     }
     if (vechip->stream) {
-      err = hipStreamDestroy(vechip->stream);CHKERRHIP(err);
+      PetscCallHIP(hipStreamDestroy(vechip->stream));
     }
     if (v->pinned_memory) {
-      ierr = PetscMallocSetHIPHost();CHKERRQ(ierr);
-      ierr = PetscFree(vecmpi->array_allocated);CHKERRQ(ierr);
-      ierr = PetscMallocResetHIPHost();CHKERRQ(ierr);
+      PetscCall(PetscMallocSetHIPHost());
+      PetscCall(PetscFree(vecmpi->array_allocated));
+      PetscCall(PetscMallocResetHIPHost());
       v->pinned_memory = PETSC_FALSE;
     }
-    ierr = PetscFree(v->spptr);CHKERRQ(ierr);
+    PetscCall(PetscFree(v->spptr));
   }
-  ierr = VecDestroy_MPI(v);CHKERRQ(ierr);
+  PetscCall(VecDestroy_MPI(v));
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecNorm_MPIHIP(Vec xin,NormType type,PetscReal *z)
 {
   PetscReal      sum,work = 0.0;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (type == NORM_2 || type == NORM_FROBENIUS) {
-    ierr  = VecNorm_SeqHIP(xin,NORM_2,&work);CHKERRQ(ierr);
+    PetscCall(VecNorm_SeqHIP(xin,NORM_2,&work));
     work *= work;
-    ierr  = MPIU_Allreduce(&work,&sum,1,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&work,&sum,1,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)xin)));
     *z    = PetscSqrtReal(sum);
   } else if (type == NORM_1) {
     /* Find the local part */
-    ierr = VecNorm_SeqHIP(xin,NORM_1,&work);CHKERRQ(ierr);
+    PetscCall(VecNorm_SeqHIP(xin,NORM_1,&work));
     /* Find the global max */
-    ierr = MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)xin)));
   } else if (type == NORM_INFINITY) {
     /* Find the local max */
-    ierr = VecNorm_SeqHIP(xin,NORM_INFINITY,&work);CHKERRQ(ierr);
+    PetscCall(VecNorm_SeqHIP(xin,NORM_INFINITY,&work));
     /* Find the global max */
-    ierr = MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)xin)));
   } else if (type == NORM_1_AND_2) {
     PetscReal temp[2];
-    ierr = VecNorm_SeqHIP(xin,NORM_1,temp);CHKERRQ(ierr);
-    ierr = VecNorm_SeqHIP(xin,NORM_2,temp+1);CHKERRQ(ierr);
+    PetscCall(VecNorm_SeqHIP(xin,NORM_1,temp));
+    PetscCall(VecNorm_SeqHIP(xin,NORM_2,temp+1));
     temp[1] = temp[1]*temp[1];
-    ierr = MPIU_Allreduce(temp,z,2,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(temp,z,2,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)xin)));
     z[1] = PetscSqrtReal(z[1]);
   }
   PetscFunctionReturn(0);
@@ -83,11 +80,10 @@ PetscErrorCode VecNorm_MPIHIP(Vec xin,NormType type,PetscReal *z)
 PetscErrorCode VecDot_MPIHIP(Vec xin,Vec yin,PetscScalar *z)
 {
   PetscScalar    sum,work;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = VecDot_SeqHIP(xin,yin,&work);CHKERRQ(ierr);
-  ierr = MPIU_Allreduce(&work,&sum,1,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+  PetscCall(VecDot_SeqHIP(xin,yin,&work));
+  PetscCall(MPIU_Allreduce(&work,&sum,1,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)xin)));
   *z   = sum;
   PetscFunctionReturn(0);
 }
@@ -95,11 +91,10 @@ PetscErrorCode VecDot_MPIHIP(Vec xin,Vec yin,PetscScalar *z)
 PetscErrorCode VecTDot_MPIHIP(Vec xin,Vec yin,PetscScalar *z)
 {
   PetscScalar    sum,work;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  ierr = VecTDot_SeqHIP(xin,yin,&work);CHKERRQ(ierr);
-  ierr = MPIU_Allreduce(&work,&sum,1,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+  PetscCall(VecTDot_SeqHIP(xin,yin,&work));
+  PetscCall(MPIU_Allreduce(&work,&sum,1,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)xin)));
   *z   = sum;
   PetscFunctionReturn(0);
 }
@@ -107,16 +102,15 @@ PetscErrorCode VecTDot_MPIHIP(Vec xin,Vec yin,PetscScalar *z)
 PetscErrorCode VecMDot_MPIHIP(Vec xin,PetscInt nv,const Vec y[],PetscScalar *z)
 {
   PetscScalar    awork[128],*work = awork;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (nv > 128) {
-    ierr = PetscMalloc1(nv,&work);CHKERRQ(ierr);
+    PetscCall(PetscMalloc1(nv,&work));
   }
-  ierr = VecMDot_SeqHIP(xin,nv,y,work);CHKERRQ(ierr);
-  ierr = MPIU_Allreduce(work,z,nv,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+  PetscCall(VecMDot_SeqHIP(xin,nv,y,work));
+  PetscCall(MPIU_Allreduce(work,z,nv,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)xin)));
   if (nv > 128) {
-    ierr = PetscFree(work);CHKERRQ(ierr);
+    PetscCall(PetscFree(work));
   }
   PetscFunctionReturn(0);
 }
@@ -134,28 +128,27 @@ M*/
 
 PetscErrorCode VecDuplicate_MPIHIP(Vec win,Vec *v)
 {
-  PetscErrorCode ierr;
   Vec_MPI        *vw,*w = (Vec_MPI*)win->data;
   PetscScalar    *array;
 
   PetscFunctionBegin;
-  ierr = VecCreate(PetscObjectComm((PetscObject)win),v);CHKERRQ(ierr);
-  ierr = PetscLayoutReference(win->map,&(*v)->map);CHKERRQ(ierr);
+  PetscCall(VecCreate(PetscObjectComm((PetscObject)win),v));
+  PetscCall(PetscLayoutReference(win->map,&(*v)->map));
 
-  ierr = VecCreate_MPIHIP_Private(*v,PETSC_TRUE,w->nghost,0);CHKERRQ(ierr);
+  PetscCall(VecCreate_MPIHIP_Private(*v,PETSC_TRUE,w->nghost,0));
   vw   = (Vec_MPI*)(*v)->data;
-  ierr = PetscMemcpy((*v)->ops,win->ops,sizeof(struct _VecOps));CHKERRQ(ierr);
+  PetscCall(PetscMemcpy((*v)->ops,win->ops,sizeof(struct _VecOps)));
 
   /* save local representation of the parallel vector (and scatter) if it exists */
   if (w->localrep) {
-    ierr = VecGetArray(*v,&array);CHKERRQ(ierr);
-    ierr = VecCreateSeqWithArray(PETSC_COMM_SELF,1,win->map->n+w->nghost,array,&vw->localrep);CHKERRQ(ierr);
-    ierr = PetscMemcpy(vw->localrep->ops,w->localrep->ops,sizeof(struct _VecOps));CHKERRQ(ierr);
-    ierr = VecRestoreArray(*v,&array);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)*v,(PetscObject)vw->localrep);CHKERRQ(ierr);
+    PetscCall(VecGetArray(*v,&array));
+    PetscCall(VecCreateSeqWithArray(PETSC_COMM_SELF,1,win->map->n+w->nghost,array,&vw->localrep));
+    PetscCall(PetscMemcpy(vw->localrep->ops,w->localrep->ops,sizeof(struct _VecOps)));
+    PetscCall(VecRestoreArray(*v,&array));
+    PetscCall(PetscLogObjectParent((PetscObject)*v,(PetscObject)vw->localrep));
     vw->localupdate = w->localupdate;
     if (vw->localupdate) {
-      ierr = PetscObjectReference((PetscObject)vw->localupdate);CHKERRQ(ierr);
+      PetscCall(PetscObjectReference((PetscObject)vw->localupdate));
     }
   }
 
@@ -164,11 +157,11 @@ PetscErrorCode VecDuplicate_MPIHIP(Vec win,Vec *v)
   (*v)->stash.ignorenegidx = win->stash.ignorenegidx;
 
   /* change type_name appropriately */
-  ierr = VecHIPAllocateCheck(*v);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)(*v),VECMPIHIP);CHKERRQ(ierr);
+  PetscCall(VecHIPAllocateCheck(*v));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)(*v),VECMPIHIP));
 
-  ierr = PetscObjectListDuplicate(((PetscObject)win)->olist,&((PetscObject)(*v))->olist);CHKERRQ(ierr);
-  ierr = PetscFunctionListDuplicate(((PetscObject)win)->qlist,&((PetscObject)(*v))->qlist);CHKERRQ(ierr);
+  PetscCall(PetscObjectListDuplicate(((PetscObject)win)->olist,&((PetscObject)(*v))->olist));
+  PetscCall(PetscFunctionListDuplicate(((PetscObject)win)->qlist,&((PetscObject)(*v))->qlist));
   (*v)->map->bs   = PetscAbs(win->map->bs);
   (*v)->bstash.bs = win->bstash.bs;
   PetscFunctionReturn(0);
@@ -176,12 +169,11 @@ PetscErrorCode VecDuplicate_MPIHIP(Vec win,Vec *v)
 
 PetscErrorCode VecDotNorm2_MPIHIP(Vec s,Vec t,PetscScalar *dp,PetscScalar *nm)
 {
-  PetscErrorCode ierr;
   PetscScalar    work[2],sum[2];
 
   PetscFunctionBegin;
-  ierr = VecDotNorm2_SeqHIP(s,t,work,work+1);CHKERRQ(ierr);
-  ierr = MPIU_Allreduce(&work,&sum,2,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)s));CHKERRMPI(ierr);
+  PetscCall(VecDotNorm2_SeqHIP(s,t,work,work+1));
+  PetscCall(MPIU_Allreduce(&work,&sum,2,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)s)));
   *dp  = sum[0];
   *nm  = sum[1];
   PetscFunctionReturn(0);
@@ -189,31 +181,28 @@ PetscErrorCode VecDotNorm2_MPIHIP(Vec s,Vec t,PetscScalar *dp,PetscScalar *nm)
 
 PetscErrorCode VecCreate_MPIHIP(Vec vv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscHIPInitializeCheck();CHKERRQ(ierr);
-  ierr = PetscLayoutSetUp(vv->map);CHKERRQ(ierr);
-  ierr = VecHIPAllocateCheck(vv);CHKERRQ(ierr);
-  ierr = VecCreate_MPIHIP_Private(vv,PETSC_FALSE,0,((Vec_HIP*)vv->spptr)->GPUarray_allocated);CHKERRQ(ierr);
-  ierr = VecHIPAllocateCheckHost(vv);CHKERRQ(ierr);
-  ierr = VecSet(vv,0.0);CHKERRQ(ierr);
-  ierr = VecSet_Seq(vv,0.0);CHKERRQ(ierr);
+  PetscCall(PetscDeviceInitialize(PETSC_DEVICE_HIP));
+  PetscCall(PetscLayoutSetUp(vv->map));
+  PetscCall(VecHIPAllocateCheck(vv));
+  PetscCall(VecCreate_MPIHIP_Private(vv,PETSC_FALSE,0,((Vec_HIP*)vv->spptr)->GPUarray_allocated));
+  PetscCall(VecHIPAllocateCheckHost(vv));
+  PetscCall(VecSet(vv,0.0));
+  PetscCall(VecSet_Seq(vv,0.0));
   vv->offloadmask = PETSC_OFFLOAD_BOTH;
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecCreate_HIP(Vec v)
 {
-  PetscErrorCode ierr;
   PetscMPIInt    size;
 
   PetscFunctionBegin;
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)v),&size);CHKERRMPI(ierr);
+  PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)v),&size));
   if (size == 1) {
-    ierr = VecSetType(v,VECSEQHIP);CHKERRQ(ierr);
+    PetscCall(VecSetType(v,VECSEQHIP));
   } else {
-    ierr = VecSetType(v,VECMPIHIP);CHKERRQ(ierr);
+    PetscCall(VecSetType(v,VECMPIHIP));
   }
   PetscFunctionReturn(0);
 }
@@ -244,12 +233,10 @@ PetscErrorCode VecCreate_HIP(Vec v)
  @*/
  PetscErrorCode VecCreateMPIHIP(MPI_Comm comm,PetscInt n,PetscInt N,Vec *v)
  {
-   PetscErrorCode ierr;
-
    PetscFunctionBegin;
-   ierr = VecCreate(comm,v);CHKERRQ(ierr);
-   ierr = VecSetSizes(*v,n,N);CHKERRQ(ierr);
-   ierr = VecSetType(*v,VECMPIHIP);CHKERRQ(ierr);
+   PetscCall(VecCreate(comm,v));
+   PetscCall(VecSetSizes(*v,n,N));
+   PetscCall(VecSetType(*v,VECMPIHIP));
    PetscFunctionReturn(0);
  }
 
@@ -288,15 +275,13 @@ PetscErrorCode VecCreate_HIP(Vec v)
 @*/
 PetscErrorCode  VecCreateMPIHIPWithArray(MPI_Comm comm,PetscInt bs,PetscInt n,PetscInt N,const PetscScalar array[],Vec *vv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  if (n == PETSC_DECIDE) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Must set local size of vector");
-  ierr = PetscHIPInitializeCheck();CHKERRQ(ierr);
-  ierr = VecCreate(comm,vv);CHKERRQ(ierr);
-  ierr = VecSetSizes(*vv,n,N);CHKERRQ(ierr);
-  ierr = VecSetBlockSize(*vv,bs);CHKERRQ(ierr);
-  ierr = VecCreate_MPIHIP_Private(*vv,PETSC_FALSE,0,array);CHKERRQ(ierr);
+  PetscCheckFalse(n == PETSC_DECIDE,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Must set local size of vector");
+  PetscCall(PetscDeviceInitialize(PETSC_DEVICE_HIP));
+  PetscCall(VecCreate(comm,vv));
+  PetscCall(VecSetSizes(*vv,n,N));
+  PetscCall(VecSetBlockSize(*vv,bs));
+  PetscCall(VecCreate_MPIHIP_Private(*vv,PETSC_FALSE,0,array));
   PetscFunctionReturn(0);
 }
 
@@ -337,10 +322,8 @@ PetscErrorCode  VecCreateMPIHIPWithArray(MPI_Comm comm,PetscInt bs,PetscInt n,Pe
 @*/
 PetscErrorCode  VecCreateMPIHIPWithArrays(MPI_Comm comm,PetscInt bs,PetscInt n,PetscInt N,const PetscScalar cpuarray[],const PetscScalar gpuarray[],Vec *vv)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = VecCreateMPIHIPWithArray(comm,bs,n,N,gpuarray,vv);CHKERRQ(ierr);
+  PetscCall(VecCreateMPIHIPWithArray(comm,bs,n,N,gpuarray,vv));
 
   if (cpuarray && gpuarray) {
     Vec_MPI *s         = (Vec_MPI*)((*vv)->data);
@@ -361,54 +344,58 @@ PetscErrorCode  VecCreateMPIHIPWithArrays(MPI_Comm comm,PetscInt bs,PetscInt n,P
 
 PetscErrorCode VecMax_MPIHIP(Vec xin,PetscInt *idx,PetscReal *z)
 {
-  PetscErrorCode ierr;
   PetscReal      work;
 
   PetscFunctionBegin;
-  ierr = VecMax_SeqHIP(xin,idx,&work);CHKERRQ(ierr);
+  PetscCall(VecMax_SeqHIP(xin,idx,&work));
+#if defined(PETSC_HAVE_MPIUNI)
+  *z = work;
+#else
   if (!idx) {
-    ierr = MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)xin)));
   } else {
     struct { PetscReal v; PetscInt i; } in,out;
 
     in.v  = work;
     in.i  = *idx + xin->map->rstart;
-    ierr  = MPIU_Allreduce(&in,&out,1,MPIU_REAL_INT,MPIU_MAXLOC,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&in,&out,1,MPIU_REAL_INT,MPIU_MAXLOC,PetscObjectComm((PetscObject)xin)));
     *z    = out.v;
     *idx  = out.i;
   }
+#endif
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode VecMin_MPIHIP(Vec xin,PetscInt *idx,PetscReal *z)
 {
-  PetscErrorCode ierr;
   PetscReal      work;
 
   PetscFunctionBegin;
-  ierr = VecMin_SeqHIP(xin,idx,&work);CHKERRQ(ierr);
+  PetscCall(VecMin_SeqHIP(xin,idx,&work));
+#if defined(PETSC_HAVE_MPIUNI)
+  *z = work;
+#else
   if (!idx) {
-    ierr = MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_MIN,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&work,z,1,MPIU_REAL,MPIU_MIN,PetscObjectComm((PetscObject)xin)));
   } else {
     struct { PetscReal v; PetscInt i; } in,out;
 
     in.v  = work;
     in.i  = *idx + xin->map->rstart;
-    ierr  = MPIU_Allreduce(&in,&out,1,MPIU_REAL_INT,MPIU_MINLOC,PetscObjectComm((PetscObject)xin));CHKERRMPI(ierr);
+    PetscCall(MPIU_Allreduce(&in,&out,1,MPIU_REAL_INT,MPIU_MINLOC,PetscObjectComm((PetscObject)xin)));
     *z    = out.v;
     *idx  = out.i;
   }
+#endif
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode VecBindToCPU_MPIHIP(Vec V,PetscBool pin)
+PetscErrorCode VecBindToCPU_MPIHIP(Vec V,PetscBool bind)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  V->boundtocpu = pin;
-  if (pin) {
-    ierr = VecHIPCopyFromGPU(V);CHKERRQ(ierr);
+  V->boundtocpu = bind;
+  if (bind) {
+    PetscCall(VecHIPCopyFromGPU(V));
     V->offloadmask = PETSC_OFFLOAD_CPU; /* since the CPU code will likely change values in the vector */
     V->ops->dotnorm2               = NULL;
     V->ops->waxpy                  = VecWAXPY_Seq;
@@ -440,6 +427,9 @@ PetscErrorCode VecBindToCPU_MPIHIP(Vec V,PetscBool pin)
     V->ops->getlocalvectorread     = NULL;
     V->ops->restorelocalvectorread = NULL;
     V->ops->getarraywrite          = NULL;
+    V->ops->getarrayandmemtype     = NULL;
+    V->ops->restorearrayandmemtype = NULL;
+    V->ops->getarraywriteandmemtype= NULL;
     V->ops->max                    = VecMax_MPI;
     V->ops->min                    = VecMin_MPI;
     V->ops->reciprocal             = VecReciprocal_Default;
@@ -482,6 +472,7 @@ PetscErrorCode VecBindToCPU_MPIHIP(Vec V,PetscBool pin)
     V->ops->restorearray           = VecRestoreArray_SeqHIP;
     V->ops->getarrayandmemtype     = VecGetArrayAndMemType_SeqHIP;
     V->ops->restorearrayandmemtype = VecRestoreArrayAndMemType_SeqHIP;
+    V->ops->getarraywriteandmemtype= VecGetArrayWriteAndMemType_SeqHIP;
     V->ops->max                    = VecMax_MPIHIP;
     V->ops->min                    = VecMin_MPIHIP;
     V->ops->reciprocal             = VecReciprocal_SeqHIP;
@@ -493,40 +484,41 @@ PetscErrorCode VecBindToCPU_MPIHIP(Vec V,PetscBool pin)
 
 PetscErrorCode VecCreate_MPIHIP_Private(Vec vv,PetscBool alloc,PetscInt nghost,const PetscScalar array[])
 {
-  PetscErrorCode ierr;
-  Vec_HIP       *vechip;
+  Vec_HIP *vechip;
 
   PetscFunctionBegin;
-  ierr = VecCreate_MPI_Private(vv,PETSC_FALSE,0,0);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)vv,VECMPIHIP);CHKERRQ(ierr);
+  PetscCall(VecCreate_MPI_Private(vv,PETSC_FALSE,0,0));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)vv,VECMPIHIP));
 
-  ierr = VecBindToCPU_MPIHIP(vv,PETSC_FALSE);CHKERRQ(ierr);
+  PetscCall(VecBindToCPU_MPIHIP(vv,PETSC_FALSE));
   vv->ops->bindtocpu = VecBindToCPU_MPIHIP;
 
   /* Later, functions check for the Vec_HIP structure existence, so do not create it without array */
   if (alloc && !array) {
-    ierr = VecHIPAllocateCheck(vv);CHKERRQ(ierr);
-    ierr = VecHIPAllocateCheckHost(vv);CHKERRQ(ierr);
-    ierr = VecSet(vv,0.0);CHKERRQ(ierr);
-    ierr = VecSet_Seq(vv,0.0);CHKERRQ(ierr);
+    PetscCall(VecHIPAllocateCheck(vv));
+    PetscCall(VecHIPAllocateCheckHost(vv));
+    PetscCall(VecSet(vv,0.0));
+    PetscCall(VecSet_Seq(vv,0.0));
     vv->offloadmask = PETSC_OFFLOAD_BOTH;
   }
   if (array) {
     if (!vv->spptr) {
-      PetscReal pinned_memory_min;
-      PetscBool flag;
+      PetscReal      pinned_memory_min;
+      PetscBool      flag;
+      PetscErrorCode ierr;
+
       /* Cannot use PetscNew() here because spptr is void* */
-      ierr = PetscCalloc(sizeof(Vec_HIP),&vv->spptr);CHKERRQ(ierr);
+      PetscCall(PetscCalloc(sizeof(Vec_HIP),&vv->spptr));
       vechip = (Vec_HIP*)vv->spptr;
       vv->minimum_bytes_pinned_memory = 0;
 
       /* Need to parse command line for minimum size to use for pinned memory allocations on host here.
          Note: This same code duplicated in VecCreate_SeqHIP_Private() and VecHIPAllocateCheck(). Is there a good way to avoid this? */
-      ierr = PetscOptionsBegin(PetscObjectComm((PetscObject)vv),((PetscObject)vv)->prefix,"VECHIP Options","Vec");CHKERRQ(ierr);
+      ierr = PetscOptionsBegin(PetscObjectComm((PetscObject)vv),((PetscObject)vv)->prefix,"VECHIP Options","Vec");PetscCall(ierr);
       pinned_memory_min = vv->minimum_bytes_pinned_memory;
-      ierr = PetscOptionsReal("-vec_pinned_memory_min","Minimum size (in bytes) for an allocation to use pinned memory on host","VecSetPinnedMemoryMin",pinned_memory_min,&pinned_memory_min,&flag);CHKERRQ(ierr);
+      PetscCall(PetscOptionsReal("-vec_pinned_memory_min","Minimum size (in bytes) for an allocation to use pinned memory on host","VecSetPinnedMemoryMin",pinned_memory_min,&pinned_memory_min,&flag));
       if (flag) vv->minimum_bytes_pinned_memory = pinned_memory_min;
-      ierr = PetscOptionsEnd();CHKERRQ(ierr);
+      ierr = PetscOptionsEnd();PetscCall(ierr);
     }
     vechip = (Vec_HIP*)vv->spptr;
     vechip->GPUarray = (PetscScalar*)array;
