@@ -26,6 +26,7 @@ typedef struct {
   VecScatter  localupdate;              /* scatter to update ghost values */
 
   PetscBool   assembly_subset;          /* Subsequent assemblies will set a subset (perhaps equal) of off-process entries set on first assembly */
+  PetscBool   first_assembly_done;      /* Is the first time assembly done? */
   PetscBool   use_status;               /* Use MPI_Status to determine number of items in each message */
   PetscMPIInt nsendranks;
   PetscMPIInt nrecvranks;
@@ -38,6 +39,9 @@ typedef struct {
   PetscSegBuffer segrecvint;
   PetscSegBuffer segrecvscalar;
   PetscSegBuffer segrecvframe;
+ #if defined(PETSC_HAVE_NVSHMEM)
+  PetscBool      use_nvshmem; /* Try to use NVSHMEM in communication of, for example, VecNorm */
+ #endif
 } Vec_MPI;
 
 PETSC_INTERN PetscErrorCode VecDot_MPI(Vec,Vec,PetscScalar*);
@@ -52,6 +56,7 @@ PETSC_INTERN PetscErrorCode VecView_MPI_Binary(Vec,PetscViewer);
 PETSC_INTERN PetscErrorCode VecView_MPI_Draw_LG(Vec,PetscViewer);
 PETSC_INTERN PetscErrorCode VecView_MPI_Socket(Vec,PetscViewer);
 PETSC_INTERN PetscErrorCode VecView_MPI_HDF5(Vec,PetscViewer);
+PETSC_INTERN PetscErrorCode VecView_MPI_ADIOS(Vec,PetscViewer);
 PETSC_EXTERN PetscErrorCode VecView_MPI(Vec,PetscViewer);
 PETSC_INTERN PetscErrorCode VecGetSize_MPI(Vec,PetscInt*);
 PETSC_INTERN PetscErrorCode VecGetValues_MPI(Vec,PetscInt,const PetscInt [], PetscScalar []);
@@ -61,8 +66,8 @@ PETSC_INTERN PetscErrorCode VecAssemblyBegin_MPI(Vec);
 PETSC_INTERN PetscErrorCode VecAssemblyEnd_MPI(Vec);
 PETSC_INTERN PetscErrorCode VecAssemblyReset_MPI(Vec);
 PETSC_INTERN PetscErrorCode VecCreate_MPI_Private(Vec,PetscBool,PetscInt,const PetscScalar[]);
+PETSC_EXTERN PetscErrorCode VecCreate_MPI(Vec);
+PETSC_INTERN PetscErrorCode VecDuplicate_MPI(Vec,Vec*);
 
 #endif
 
-
-
